/**
 *	@file BoxAlpha_New85.h
 *	@brief image in header, generated from 'box.tga'
 *		- using prediction / RLE / Huff / BASE85 pipe (lossy)
 *		- predictors used: gap for luminance, up for chrominance, paeth for alpha
 *	@date 1999-11-21 20:00:12
 *	@author ImageToHeader (built May 19 2017)
 */

#pragma once
#ifndef __BOX_TGA_INCLUDED
#define __BOX_TGA_INCLUDED

/**
 *	@brief image in header, generated from 'box.tga'
 */
class CBoxAlpha {
public:
	/**
	 *	@brief gets width of the image
	 *	@return Returns image width, in pixels.
	 */
	static inline int n_Width()
	{
		return 256;
	}

	/**
	 *	@brief gets height of the image
	 *	@return Returns image height, in pixels.
	 */
	static inline int n_Height()
	{
		return 256;
	}

	/**
	 *	@brief determines whether the image contains alpha channel
	 *	@return Returns true if the image contains alpha channel, otherwise false.
	 */
	static inline bool b_Alpha()
	{
		return true;
	}

	/**
	 *	@brief determines whether the image is grayscale
	 *	@return Returns true if the image is grayscale, otherwise false.
	 */
	static inline bool b_Grayscale()
	{
		return false;
	}

	/**
	 *	@brief determines whether the compression is lossless
	 *	@return Returns true if the compression is lossless, otherwise false.
	 */
	static inline bool b_Lossless()
	{
		return false;
	}

	/**
	 *	@brief determines whether the BASE85 data is allocated dynamically
	 *	@return Returns true if the caller needs to delete the string
	 *		returned by p_s_Base85_Data(), otherwise false.
	 */
	static inline bool b_Dynamic()
	{
		return true;
	}

	/**
	 *	@brief returns CRC32 of the stored image data
	 *	@return Returns CRC32 of the stored image data (if lossy compression
	 *		is employed, then this is different from the original image).
	 */
	static inline uint32_t n_CRC32()
	{
		return 0xe095e7c0; // after lossy compression (original image 0x70805958)
	}

	/**
	 *	@brief gets BASE85 compressed image data
	 *	@return Returns BASE85 compressed image data in a null-terminated string
	 *		on success, or 0 on failure (not enough memory).
	 *	@note The caller is responsible for deleting the data once no longer needed.
	 */
	static inline char *p_s_Base85_Data()
	{
		static const char *p_data[] = {
			"~~0RR911^@s62mk;81poj52mk;82LJ#74FCWD5C8xGApigXJ^%m!K>z>%8~^|S1ONa4~00jI2{{sF61N{gF2mA"
			"Q.2@LrP3-|Q)4Gs|X^AGUy5fT*f6Ym!66&UUp85->y>m2Cn=^h^)A!8utbtL8@Bjn>IY9%LgY-cgyC~M{4TPZ("
			"fSvxN(Jyk6(E8;icVKdx-HGMEi-P$ZqM.*PXMQ+>IQG2g(*;CJ{es^tYIA2#mG|oCrt;)>SdERtRL^42)tII;A"
			"g3#EVe@JLXa.)>uW>~m~OVw~%hNpa$$z;aG!(Nh#v5QPTRC>0XHonuN!gkTrJjlesy;6vbn3<Ylcu<p(w}pY9&"
			"9ujksF$;@z+k_;pu3M&oU*WqkgT<omZqe+x=Mths$8C;,|qXt5A!E<XqL@{RcRfs32ix*s!8NaypW=rMRPzFD$"
			";Wdng&i0!.fne>Zs^b!9#&Wv}yy%uvQ,p5z$p39wl>an&5TPYn}@sSVH!bB$Ep|6C&pd6kW;z-6hY1<h-_O17t"
			"$BsL77NIy^5J5.^dMxo%>Ct1O)G!i=u)L=G@,;x4M5RC|hfybk50Y}!i%Ne8SKX!>v5{sZ-ju-7CytEyq5tfcg"
			"cq&d0!X$ickC$a}XBC&;*GLG_XeWigZ#|Dc$VJN#KZD*u#B+V|)P$;6=0-%.Y_,sS*&VeAyBYMaQAdm=n5UNqF"
			"Tnfo%YRTtqyJncdEUG04poo+J!A=U+<+()jrUr<}l@,n$qnSXgj.s#|gcAu#m&V,1%8x7>F+|%%Moh_Ljk7;}^"
			"a}*ncMv3o3!G.@R3tQlH<)-6MvQ.NBvBO{sXIQZw,<748c9kp=x|yFlF7By)yy!kd03Slr0U3l3u~^bQ3F93N!"
			"F2x$sHP5_KpR.nDr5}<6J6=kGGuBty;J>dNdVdX+k=~;#G|nws%%2*~tk{2{Jk$l0q;-gNZPNu!~jYkAFC&onX"
			"r8NZUB9(g}R<m0Z@TL58@q6q#6;Sc5.G&axgZ!_Pex6f{{9A<$<mbs^BxBx0VaM6}rjeu+GhWePQ&0>QAJG7Qj"
			"Q@nj5-kurvLjEPwuHf3~6_6Gj7M;=ROuJ*qs(+4XoHMcgs.5dU&23E0IS|DYejb@Qh!E@J!GUJ@kQ5hi4@Mz#l"
			"O3aB9D5B2E+vjKEzs,+O4+=m!JwRQtoEI8mK!G7kD;p!lYDWV,9Al4w_Pb}QF+m4%WQv(nlx*j{cZNkW7f8}jF"
			"K%;5OF|<jCT*K.t#LdNilG9;v^q%QVT~RuBmx$7>|y5gKOV;$Yqjr%t%b8Y$kcQ8eU-f#BM^BQjT-g+vx9a<98"
			"hYqHWUeHN=R*3MT-kXV#._VNS+MgVCdLkPWk7ZL#!o=Sd|5vEb1CHjA4%vXw9Q6a=S%rQ%M@ylZQSN^LqyGE%~"
			"#kNUKPmI_rYxn+9|.k6L+|Vz%0~Dk>mLFeBfIOZ;}_n)9S^O9zr68c0Coh|v<lNU5*G(dJKmf@XTR_H}Z#mQa4"
			"gZOM*!_WgZ3TOAgO6}(;zvu2k|b.H~bWp=*%S3NJk9Aa)*KDB3!B}B;,Nsv0ds-~3gKD;+VS6MY7Yzc$zDN-bO"
			"M,U@^M@5Xb&UO$$dkv{J*-bI>M{lp)Q,fZC5ppCbyF+J@hW@2N#;jr(ypkMvj=4.nqpGAJ+GlvLJ{Icmwqh$MC"
			"PWSxIYbgFq!t4,zGnK&hfe;U|B4|6DJ8-5>Fn_Gel,uiv)=CPT@kEP0l)J}.,Q6|xLXLyFn7,=S!Y2aSJxB|MP"
			"#B#$ztwmXy+w<n02;trL)qDp4(9)89dWsMdH;.v;gOTc;R,di!;Vgd,2ASJ9$2DeY(|>*_g!SZfcR6!5CLIdA)"
			"gX#&{j}7YL^{VPZIlwUi~VujTsP!UTbtR5VmHS}Gb%5@H<ueBNCbp9%K#$6M-_%U=hI5#L>L.d)Fa.r&GSZnle"
			"|G;fSvJdH.e+HjQim8}jX*cw7NlbmG+#EoHT61}AcMM*N296DFX2hV_F*2@KgGsw2QUG2thtn98K{U{^sWMLOt"
			"XV2@i#{>)A+ozWNRdEoA2c.nO3eXE3v7+6pzb9@@u*Mn-o(APRUp,0Q2&i{bCupceNC%57kQ7xIQP%nS+B~k$+"
			"o9hMGLi>-p0Y%zG>0#)<mB.}+3j8NbwkTHS.{M~p9;b<&6;5GY-,3<jSNyD@WN>)XLNe1S}0kpxO8*z*vfk4>O"
			"Y3Dtbqhm*NkG43bJUHoHe{@ExO{-YTF1;UJl4an0VHorw;1tjG9u4O~g$}_}XfDVCCd&>sO-+Wc>eE)@lf_cpP"
			";>gK3tk(;Z7;HAyUnZ$yeDVu=)BHtqB@T=l)B+P,bNubt+2Nuw6Dfs1ly8AHNd&t=W7^EqOXi&>jYW*vzNNfuU"
			"xpf3}F8oM*#tc0~=MI|-X$Kd7iIkv@$GFv(|Mrnvew<FR4Vb@N)9pf-;R9jdKB.fF~rmkLxRKi<tUoW%eBD0n$"
			"VHm+-ZL39+^Y6xa<prL;u6}uPM;1cfOFTt;K2t<JCxSy86RzcwqO_6&&.HidLfCV8hfX|R5SQV4z1~(FdHd=p@"
			"T(Ll9d3{hfE_+(jfXunc3l+O0|@7.T5qus-+u1#DH9=^Izb|$qAZqVj4c;e^5NR%&7LK@vq(qi=#hKL9zqacX^"
			"gWpSE&BeBfc}FAn$17N2E;^(YX(QtLpoGZb=9vq_)E8is1}#te#e|-(2}HwmiMYt&>Xf8n+*k@{%SKg_V)Y9zo"
			"Hhtk93_1Ei2C_<PN(lQMzJ%JffuIAh|L-fioW!1chthShk<wLaZ,4LI7#E%G>qw{{(T3#iI5=jQTdj&hAGB_oV"
			"jGQx,#20{rH&e;1bdffO>IAxp@KxWj&1va{}HCOhcYCNWJx!~Ov*~IW}U0LU<a@LUrMn4b9^gVyJ@w=-FYjlyj"
			"2tnnnQL>Pm@WY#rM=dL%7QHz=YFR0*d6S|JYP|Hlimhv<8WEsk29EYuvG7ORQ6XFRj^XUv,1w)QHcLpMxnOP=B"
			"Tm;_<MsO6aECi;MGLE+VNVR+Nrg7^y7IsY@pV}diwG!Sib5e}pPT8gxAmz4s;p&(n2s>zZhf}FHE-Fi$.a~$Z~"
			"-C~*iV<#.#ZQx9D3yY9UxTWNHm|1<5FGvJ4M<{1bMy)@=IXvR_D,)vh_RMXHyosF~~&Vli%6rbahCFXzSKDv>w"
			"q(BdpdkgpX%lrN%6vv*_jH3h|Jv^5(8eAyKD7N<o(KiX6QST;4R&I|-)5B2XM$w(-x+UHZ0|h7PBOPiO,rX*#t"
			"O(IX0btN6tfDlPJ5y^a;jpSq%4oRslr#bU&qWlaO3+_h=V(c9G$d<s@6LQ4$F!7+7BUN+4Ps.nPq808Pzn$qJf"
			"d*QF;|HbTEE+!I@i^ZrzS#am>$}n2*S<+I%@yapl6<x#G5{NjrUGNpb#UzTd@wSe#u$LZ7T.Wr5(Umd5(;7S_&"
			"tBYt)=+w2Q,OsA>PvY%dz>SJx,S4PGR>Mv7iyXj;aJB8^&hXcF{Py{YbO!3b9aJo-K%|d^KjL-Su#%;OC)Ue(R"
			"Hq#cB,FWen+F$=o;Ax;~Z@n$B&_2a<;)1RU<MEkqD{NU9At@cC+7hQFo37owLF==aOiWYUQMtZUqQTX7-*A.qM"
			"Aeo3X2xS-{!O1CE^A8;@D^JnPTyux3HAA%Q{_G$PotF8.zr6N={s.w3@1eLZd(#+GKRRoJ0ITB.cP3BnB*j<v4"
			"Nj.X.ZRmEcLw!BZ},=.%AAey^8JG@>Au%,)0bHF|j_Wm7SJ$l|Y%UXF$Uw4F|o-|xy_$)QOc-{0f&BT!ch_s!}"
			"cENogPotY%Z.xZ)(j>N,m04(DyBhezd6pxOqs1v926{x<;2$#I$2dqbD$v(2b#P*,t~$$nF&cO|R$QJ,8b=sBb"
			"WP=gO(7{!*zdLd-n^W(TSQ4U5v@!C1dK!$8NTM0+H5^=%+oMYOHMbY1=fa9*Vfm@+y5i8m&^9}cQcd9&Jyc%z8"
			"m1Yn<E%YVC<(RZERr(2f(F-x31M<q2.MZ7Ly_>9>-ZPT#u~_WU(r}9hn_sl1@58lAKnUa_!joG}3Od0Wf(;w&Y"
			"ks#%~DO{GNWlg7KbQ*UjeVr$JUQo-kg20}(n_BM#%=87h^S40Gh^w^unw$i=FSgn>-x=!Dn1QcNz.+RH6*%RO("
			"=;m*@o(^#|bpEajd&%+Ll*XG*WN$^-U4}~x&2h3i<lM3&#wiQLgoxb%m4+hI>gu;;,2,L4Mt&$7(x>J2)8AAfq"
			"M#9im5saf)QDFbsG}TSJB,RaUQbj_kNfuFEys}9xM,}VD@^U;9,p+,eCH20KPW!6Lo681EPlMa7ucEw|0wjbN4"
			"p=uCSId6Jnd.|R9yDA62BqzyBQBCqb&$g;N0Xbes+}jzuYPPHlIGGp9W#YK)$,M6Z0pr5<AfYMkB$$SnH;F@O2"
			">1yv8iK)IO{4bLrF!_LCl,0@1DJr%cHHf=~8t|NScoFku<,<PhS~jIu&CZq>c.<4smBbn-zma11x78<tsX*D<<"
			"&9u(;&o#|rAFt>)}{4ST~~XT@Od3tb-Fj=M~2rwXnAj<O<VND.zFxnQ(AQt.|$7^gnEZImf}m&dV$S&iayeP.N"
			"FvII#Lqa&+5iwMEr1>|{JF4.vhSe^It$@<~Sm^3=TMI0=Zg335yG-ygONp+H)6y%hP0C6i8u_l$7VB2TE!Q|<#"
			"q_V=o5NlI8>P9EVgl<qpvx1nQgexE8KqN@F*RT.!Jnxhg,rf4{7+aqwQj}.(TT#jSb=calSBdKymk8w|%IF#^5"
			"hT2#W(PepIJ~y)v;>Wl4WP4$%QZc8FrpSIL$P,iq*7Y(F2_5._VNy1J5i<K<l)QN!=BI(#WN-nS4FT,#i$jMG;"
			"r*WkxaXBk-},$)Vegp!{dgk>*oFsiaB8D38J*Y(OQv;;U%)9f)KNurJIPxvy@>iRaK^^FqgBf6VbxZ!EIfZQr8"
			"PR,aP&=vDR;&TJ(EPDz;bSsG5$Xs.rE=C1{n~Ry!_T*<TfWqbYJeU2edPwdN)^v|,CUepU&~JoD8|EeIOP<eU-"
			"uu<JrF&Bm_{i*%!QNQF5)k>dst5=M+1mO,n4v|>@*Rh&Yx(F!d271JMYw$nBP0alkzwWACGmC2+<Bv=eRA6<Dq"
			"wa,NzC2AnFds)Tpg^>v}O>WUv!!mtZ^NMm{crFFbmu@zBlLUqWm$a!Qb$Te29*2lbHNv}j7epLR{TAb=4z)OTt"
			"mw>3CdDpVQPk064#nu&%X2Fv_l=g87J{An)>xZ#WW!*gBcq@tc8ak;B)_cYq|3zmG>wlu;xL7sA_!*V0v(SQT="
			"y$x<3SNLmfdt!7T2op2LFjrb9<>5Od@yi(gd.}3Mq#Zb<D+sM=MF1G)GKQh}dFVYc1EtQnoZ%1%OFr8Yh8kc,H"
			"HP8D|&T)$UWR$(Xc{5e>TA4Ej27R%lMy#Q5Q)q)ry,(,C;*.AYqZ7{1MT9U%9QG3&)!cKPsvs#W0X(MS>,8KES"
			"zF$IQO<+EDb3o;~vqD^oKC_Aq5enhq|O#vp^Bmo*wytIpwq_*>I>Ggbl^~y2pbDasW)+wEug7y-CSe{Qdw%sHZ"
			"60weS!7$F#Ekk&&{c9y~bOF{1;s)}f%1M)p&H6cgj>|eIr%k70+ii)fb~KE(>$,))OI@nb%{L{aXu06ahP|$eu"
			"T6T(dX19jx8rv<WO0p2V2Kq}C22GqD.v=L*N1mHBqJ6LBuJZq6p*LU7BCT5n_^F$lIUD-s|*9|oef<j<6+tD@7"
			"zsUUIonM8e1@Y@^LFFDWhYeO3H<r9){Mo{<8yq{>_{<alQ*oa~IYP7S@A2OtXwz1kRBuQ.XAQ%O_fNd543>%IC"
			".g+*<A&*cLLh5T7F5jnsp=o13U+ckR=yvj@Ubo,bozwl*k4FjjGS8,|,XLKa(Lw>H$!h.2V5+(eQt8BpH{Y0Iw"
			"*v<NJzjn.tuDArQONUz7SZ#R||-L339lgD3MMAfTpsUtKIM3jq0yRpWQlp#1S+$~t+32mx2*tQ3!87~%zVFiM;"
			"|1XXhwGS|22,NDQ&U*HJc}BFG>eGs_teoWFGb,,aTHf&{&sPa%.2aPBK$+f@^f0&*Qs~cSqTPLzj$s)jjB-%>L"
			"*t4n>8i7}P>P_~%L5T)3.&4M2UXNqJfmbs60+g+IK0AbVJtZ9&%dj)zn{Z=%|_~$2LsmDxJfucfy*%#OfiDd.F"
			"bHvNfabiYOv6##,e-!$fp@H$6J7|Y^sA1vRtiQj^~_XTW_k<1SFD|<*-*pla}<%tnQNAIPk$kMUhyV0q4-k>~P"
			"Le-REJePg0X}Jn-ZkZEP>MJ8{C=_3~d0d~bbc$a{0+&$j$_VXpjd$+u>A&u(|aW$(u{rrx(>lVrI&TJ6ZVZRcG"
			"_Q>.bHnT|>1URun.xKBIbIQ69)8KZ-F2$drM<j+,Po#nPp*0Ufx>0OzWjyN.0c9K!hTrH;@Bem>z5_P5.H)LnK"
			"pTpWLUkth=Xwiy@vIR)w@#6ZmGwLo%W5WXu9TC86e_nJ{-{bG=b>+uzVfJ}GFyr0Zh4|jqe9rcjoooZPY,Lwio"
			"^c#tZ-uUQL1sXqB&ZbjbKTaKymN}$QN>)G4-YjvJMkT*!pKpH-=mjZ;j2xkz(_MhiYX},F}_J%c9!2;d+X-s+s"
			"}o%-cH,PJ{+5NU!TLrt+&R*k3PMdZ!M3<yVkvr4V,X$F!28B8C$J}w2zR@2W+(!omGQ{K|R7*<p.qwN(wuDb2U"
			"~9%{~2n*gc,gE|JOD%-0DUImXg9mJ*Y,610}@V^M;s;O=>&<}Lq}r1pF;uzOlY69tWd*gcX)cNYt^wMPi^a(B2"
			"#8h1sh5~HKaUOpMUb#&38L,X%%3ISp=zS@=Fn,!2O1*L,o32TPbVpVnxXq1{#v*zr1%Lld6PVvBNysN{vZMBfE"
			"e|apC(G.-PryHbf&JZAIFxAyqt3rFX@a1Kthw|Ie<m1i6qJ|yht03-*i0&LLVuCJ=&|mtI6+*hYqs0{.AhA.uF"
			"!GYRqlR=fd1r$4jOBhkyh}=W(zQzJtb)&^<+m9_QZ!&+(MrOEBImDMA4=^}-Plg@b3q0AJ4-YQh7CiTtgsf7on"
			",-ey4hHj1EI9F,j#2nfP7=Sg-RkZ$CsB<N)ZmI%Em#JC8a5jSmn!&LX6mXS<=>k*O-zk%1&@{J6aNh^xFwY&pa"
			"@;CQ^~=kj@9bPbpw_KJ>r7a+183R$5ZnA9^$1J6XM4)=Pp{T(xht$tCKfV%3cbX$2-Xuq$_Ed&h2dF)UBBCv!P"
			"i>}O~lFf+p$LI2,2w56|J7+CPJiN;VaZpSL&idRa_qe6uXIIALBj}.on2|QAXsV5N@GEPrhnyv-N_^qWUfD8Pg"
			",1UzQ9Ywxz>>DzrX#xQ#_-=c(yIzgBREgmfSh^{}s8qwBG~*wBKfb4d&syi@czSBmf-FgCD7zZ4bcw4hAmuD<w"
			"0NLtDu-W3!r&pF>.4G}^ZY~hFB&$L$3*VB(r{JJL|HXwuSp)E-RHKr>M2ACMo6v&BKWB1FSi{s!I9;&-7feq.O"
			"sgi%L7W_O91E_Hlu<<DA|Y$9sN&}WQ-YV69rG,58b-z.q!KflL<nR2td>_hm<0A-hj8x)g.th%Lle{!!Exf%j^"
			"g9rB{PX4^!LYHF&gS^k}&#BhLA}t%cIt7dbq&.YBQCKaGPCVos(c|ENE9nQ+Uu+c(*o<3o7HQgG1@gu,APN.Y,"
			"8Xin<!3lxG99QJ4I$MWU35}gh6^*g0(#ocqYu-N(R*RR9j+pk@(vtGV1+Bm~+ma2&iU.Cwhl#},c_9@H1hW_&L"
			";&{#ydnD%342w@w^!;m$_+luS2-*m&&I!>7EnWQ~zDyErR)&AZ+pmtjyms;1w+!<;9k5ivTq1=Cih)FEh|wmL9"
			"$%<GtedCT)mm-5HDLnMb0l|))mXOnt2byIdlJ_eJYte1X+<8W,bj11$FFokf&_~@h6;+J3EWVNN-;($IBKV%7$"
			"IYo97Yw-3oHLXf0erWvDFgmYr~3S&}C&pXr^_}ojP**zAaJBbJwVXfWeiVqFrjnfu-!ns;rR3ks+&4Vy!C(Q,L"
			"b%w8pTFEX0WxC^w-LqcOZSR*lcLNT1>#%}jM_p01nnPLszwa&mL.-wH$},r0Q~J~|oRG{wmT7t0KY_$X=GP%$r"
			"NJhfzp0-SKOP>Bi+,q4%R(qxK72%|,}Xw(sD#ubHUPb8)KgZJ&%$97s}$F&rurQ>DAB>Co2Y8l&e_6v-*vP^9v"
			"bwyNiTv.PNFF(_JG4)FXu7yIOG+.leP=gT$iE7BTMx~,-O<gf)QC7IniWnpRKz|vs-;Pt&pJG%7,&OK!m5U=iw"
			"=_~1XA4tXq)Eh5O;qY;3aBLsAEZ5dvM&hdjagorLYknBTK_Os8@I=P1xVDXG^JwEjWJ2hEW!W8KGuCR=*LXCJE"
			")h*7BnTitdVV&bb-nSXc2c=l@%lrKu4ktoI,4n,a}MANoPz$6g3FYsWOdHF=(V.jW=l;PL%~1yFw9HSVEb&f8Y"
			"<%ZCbM4+w{Mw2fiySUrnACqr7VEDC+WYqF6<WARtv~Hei-5o*SA9)_+KSQ.dw=&8rMGHtCdS7DA)ND05h$.=d8"
			"2c{Ey4L||wi^+O_6y@DtSyGrSnIdk~LQ4Dm!B^%0DmmYUQr1ayUbl-xKv#UvJJC2%#^XsIZk(Z=Csn94a2q2SH"
			"o(fS99k6pPI^9NNW_No$1esu|WQAEn{OE!ZMEYPJ3;ci!hU(=Go~~}~b!>)u(F4<~H3p.j.JZ.9jE)HvWDN%bD"
			"xwW1CY@}Q2k8&0bR>jb;-WEvqZnnDY-5fb*Y&cbk+T(x$^_C_glLna{6V5BAWx+q-=8i$&ZzM6JZ;ucwy>;k&B"
			"(DyVYbMS&%@kDGpt5zBm)Q_wIHf8d!FLulvmk|ofQ%ZQTt+{A~U>}QFhjP_Q=9OLYj=(Bx(dg#&D2-,v>wha_6"
			"TnMz43Yk#9zfvyL|6XrYo$iqapIvbY{A5R4+^Q41B#=|r}*BFNc&nD97>(E^8P$}k_xM0q<fcy+JS9TH77j*W9"
			"tiqVoS2UM5l59Dc$anO_H$(u5eJauP-=_xdv21TTk!}L^&X3o-rw2C%mL5r;lQk)fT=jjisa1f}hC1xgdBvc6#"
			"fL=AL0MS>G)+Rw~N{~R33;dz!>gAsO+G*|CfPH~Pk_Y}p(2ZRLqYTwYKB75MNkYaLBEjH,yF3zGH4,k_OYFzhJ"
			"3&%0c*rD#QZ|z~q7olxP-V1bC6%{$X6+d2O{m0{NBzM5I&$gN+=l3WHY&,Fn1;hV#hw$ak)sM<J20sx8)*>;8s"
			"c$xqS|xA4spPxx^*&_vmaFKu2GB<D8WKDXeC5agec7DlH=X7dhbx9M6PeI7buz}zi>Z~zgGUfJrC+>g0><#qf("
			"8vRP(|*VvlWxjOW)_SYoR2SXz-$3#vt%8Xr7(.AAuU%zae0nygin#7#,&V67QOEsHdfmPsPa=vIJy{TWE24Uzw"
			"7KY1P5Z}HkI^2uFJt{e$QYlNQG<F)nRY!oIImscjp54}Lk4CJR8OFC#805iwDM!w8^b#+&OW><L$Gb<p4k^}Bk"
			";L9hZ3rIX*Ff,gO&=IhI^^fqwmsNCz,+Kshg5#YD4UkiQ({+=HD0hm)NVD(zj>oR-U%>^F&{5+TwVOq^IX^7-o"
			"|g7w>Xj8qky=Y2NYGPsc|poigjII#-<1lD0H*OLbRuA@,lI}5x_w<V(%+4gB+fC877=GeE}Se7l>$0C40&T$@B"
			"JSi;tWY;6,HC<-%FXxRtd<PP8RlK(^ZQTIA&0YN*tkY&*V*1a*R;xExh(ZdJJ)ikZQC}QJ2pT%Ph5YbY;uQ^72"
			"+d!9r2cRjiTfoRuLT=AlHRyA)Y%RD2~s@i%0lpp+|vLXK3|1CskO,&C4YXc9IWIvXI8$~cvGNJ)whoy#YQA+o}"
			"+LJZIW{&;,gt1gb1<;~+{$rV-sAry77EtqcLNT|fxwQeggN;@Hx>uD^SN=j#YQv=$$;G8b+.8nt85hQ0vVv<Op"
			"@MW$mj}3cK8ASAgB;BIYQ;boPDB=GUe(oI^baLURH;p).Ktf*-IL8PdUj<}ZW2=31oe(6Eom.+ibTD,iaICOGm"
			"Z(XY(j,qtTs@fjrASGc8J%Mqp}kSrTHJnITF+eB(y^_cPV0k8ErnXo34O5s%yQq9kFVkI&M5L&Nl^+fg9Q9dO9"
			"&_Npz%d@5mr@T(mWS%M3TV}o+|{wvv-71a<jj)4ERDn4hw-+#b}72V9yiQbA$d<AR<gJ8py2_j*G.&QIoHvKlr"
			"ajdU#{Q%JAe^EJ8X9d%iplD~71FB@%RsD5JtrHFat^oNDJ5RApjAg^o}avbw#b{>*(+%U=.BFhhe2rD*x%XU^*"
			"cKq,+#vk5!Fs*7bvgOp|L$Nu_m$G5.,eb*daBc>4xK@RRxpgKXFD98~)J_xK9NU^|iI>6M4(AYj3t$=o{sFT-F"
			">+HlA@8C>Uix~n#auP6sv63u_)&tj*1q&#Jn36_{%Ku<LTOHbVX-)p_QAxCn=@_EuWY&m~i7;hI58EQMD<c3y3"
			"T#}cXsB#fQYXVnM44oi-HEilnEIsxD9mjWh>qAv8Q4V&O9N<}L}JW}Nl~0+86uH5%l2dPXUmU+ml5vcFiHV4k~"
			"~TnL<J1Uiv<2K4yd6JFqCkg6Q<$;rC8A+32,Dv7&E5994l{T0>FOMk)4uJMaGY0cEJp=l7+G=6hKrrFxz;vNs{"
			"Ux.Z^IkYA*sz,%KcI$4n6-6oqtjVq|1y0RUBW4AE%<<e}.KpcR@ZLNUKOWX!RIghX)_!,Y9jQ4}b$h.z2o#ajh"
			"g)!9T{UMK;,phObUi&#*hoL}6J,FHBB@}Tl)(J2)~PLg{CCL~s~G@Vo^bXQP;<s#Rk@o4ZY<7Fv13-T-oG-3!0"
			"CK6BV!z,e,!eq2iOy2|!N<mc$Eb(ZlXrn5JQo>C5ITj3$_XGb4>aTOBNPaXcJ^3PQj8PO&NzEYPfmwnwshTK2u"
			"7!av7hJVq.U_j9nWI57Wo9g2UZqJ%{UPlQU1Exf6l@k~gevh24$g=ef|E*E0$CJg1($W5pW2Ve<({txLO;67Rf"
			"kFOSh+|Opo1wXICPV|u!H_WyOM+i=.!-j>X24IsU|3~j28<vks!2$k^Le4nFv&o+Q>;NRRT^1OE9umK.G-LFP1"
			"Rb8ZP2qepw;~^T+esRdn+-j~.tI+H>Ev%2izA8LX06n#v0n>eeuW8ir*7;V8oVj62l6bK24%t{wy)EZNb|NZN$"
			"2=.~^fBUXyC#F-.7Nes1-tJzv25vqD|K&zx8g>70-5>Wpze%!cE9qzjQ8gjl1&Gl}W@xYcW36Uh&8;5^cgo@ZQ"
			"tGGq0oHp^p9<BQd$f%~s%D^UY$mg$KC>w_~rRfi8DKJJtyb&39$s^tEQrgV|Nox{|MFNH..&Oix+Jyj;,=S5Td"
			"1<.&pkK8!jt8)F$7XLqI|PH_R(43fzbp8A$f;Fyc0fmI^X+x$>)&2v^vr^^gCts1ysUgUX,QUXUXb>VB+*ACNU"
			"px,Ht5Ny6@wyG3E6_lB#ycAD2l%wTbfA!P(SIeP1Dz<dAaMIqZweBxWg!CBudIKSivbO*J{j05m>r_tDO1syt@"
			"7DIK>z;Qb.>4D;*z8uypV.*s{N*J)@*zkG3,s8rfki(W8PXEE*c3(SR*gu90gmXL=(vBY=N+KlP5Rd;Ttx*=uU"
			"2JPMgw0$AX*1kO&3s*oi_n4KdAib)mU9evY2&wpL<-stmtfUq8{R#=@NtI5yWZ4pEIL)uDE%CwAFLY2!W)2g~^"
			"i7hE>B@YV9(P*UYUY-1xII,,*+5Q0kn@!Q*x^w5f3K+DY<FChkFuh_@L^f0kfu7GBBwb<An}teo>sWXCZGje|g"
			",kNSf,!j_S2X+n4<ik44p*8<eIfaBb*eUM1Ve&$5zii;WUV9^EF%T<$,|CPd&!q;TuE,7#6R7S*lL1w_a_gl@a"
			"e|%f<{LxIWZ!lm64K2AfJu{sl@EO{GF~;LXRH_t9auEXz@7e@m+IaD@z=@%sReLCLCk5tE$NUkofX+qBW$s)lI"
			"Jz+lPm(;p>P;,Yifu<D1&S_1g~{Zgk407!gHZ;*agpW!~tcdvnRPTMSMy5,vuJ0+JgLc.L+sX+CpJNpoIIZ4tN"
			"010OJ1*!K0Nyq{Q9L^(zo><z>8{YNh5ks9GCFQh%AtLaN3;YUN~$)=bi_9-aGw);Fhq.SgMwQlJUvsO7pbv^<9"
			"$bS!YG4XV6pQw!(Fp>q#nPDd+HF(NE<|!&fij;+Qo>YNG&_1)So+@D~TZwPb((eg7#Zo1wCu6a%9$6nfqEc1#h"
			"qRKGC<J1{6vf67#*o!mp;mOdJ7Wn-#SPIp6iRZ2Nd<qTAB33JzK3$#z1FogOlv#V>WLdLK&~)ggd+I!c-&zfBW"
			"o(P5-ff(ih0q^a60m~2LjMZmNI19T)Q2PHSZ+&&rIP|Ur2jNNl#r6MC%8J1Qu9gm<b(WGK)xDjsd)nU58X*mio"
			"POvp>=gztb9Y_3ckvE*40=SyM2BITETPLCQudzs~i&-hQ,Y#LE>@g>&21+ZuXnV~rqL!UU(Jlp_*evF5)=Eb{H"
			"=j5S^tNA!oZd0E)74vhFnr3qmcqF~nZJ2(,XWKS*FkWPZ4.Jg(X)~x@4KMzUA#om;8y*^y#$<p$C1d&M{BGG<!"
			"VHh~s*4jHg7e2>Z1F%S}d%3~AlWVoBDOD3V-<A@hAf|9ts%TJUuPv0Jk}sq_<>d@y3<$f$QpB)Tsv^hXdEC%nq"
			"kvGF.Tt&Gk%n9(GIVwN0sAQK(|>a)U&,0s^~|L%*I.@uShS=Aot;(4J-N0d_trXOOB0tL4,W,u(|@N<V66!*d9"
			"mb|s!}pb&uS$$@6t8v^6K<(LM4Q~n90{Vv!n;@mr}E*6Nz3(;QrhHu8K5OjtrO>R*pILK2Kv7q.%tqKV,!%k29"
			"l9zb_8g@N+_W>qtVFCTyw#z^f#M<DX+(YuD.{Xx1j,o)*KCG}Y@Dhzx=,li|Gchnuxc<Vi|1Wf1-ESL;1&Wyvi"
			"}YwXA0yrPc-Wj2eJzA>e*ObWwXIAU;5hQuJX2Ns3(wQfxp5A,Ga3AtCj7USayOKmjY1j|z0)G~;{5ZPHH9!{{P"
			".Kyin-nG.DN*gOEPC70SlPX7v1+xeH.;Q5BmDw|m4Jr6vy6p18XRE#8KS+B=0t~3{nRN5)b&*e(VGITkiIRkX("
			"vV5!x%1vCnpXo>f2kjdxU1ETIsAya,LOHaxh88QS7lhd8@0.tfcn=i9HWFbW;xxOoBNpk4<HGm=et}ats2Ttt&"
			"49,$T3|W)6P,ya(!dXUHntcS$&xC+.PX^VFusR#%~ONTgou;l.R9-Eg4oy9zy)_g&.C<Wa0jpf5V~^@M,Gf<Zk"
			"Z0+8-pjPgy)n*3v|Vem1l4%DVWBdaI{Zyf_BiYvFBpUo&(T)o7~L$p-weu_SHEjPe8$Sl3Qx;R#^_!Q*%IhqRH"
			"cXcZeix!uY!)rnZx6(WHhGn2OcFuE)sUQ|LXY#IIV,0bHp;D$YB^EgWzSPi3+4P}7;;xV<lx$)eb-EFAdT.4Bg"
			"w~;GI$<{gR>~kX77g9z.6lG0lVxc93!zq)Xt$NZ*v0*obW9lpVL)uD9w28=LElEV9,n_opk}0~.6&N<S_VGP1*"
			"0=2*oAI$=&+!M%w=8$~q08ahf0r7iwMd%I!HlC86qdhx<v!}!^>kA$_<1HPf~_JYe@5~<I*v)#k|C870E>&mSd"
			"UJ-6G{;33Q,dWi;AZKFGzbwLPU!rAvFXc&-h)LK}pKn;Iy)kgZVy*>V,0g-N(t)+P1Pk!5_bd;^E%Mm&3;&FRk"
			"L|),v)rYQ3WyNg@*m-{*UMxKpb_=$~7(uC&}}Plfs9Z)%U*JSc4@3>hN%lw}2ZOf2JvCVky_S;CoXtorW$koJ;"
			"R;bsB!I3ZE.+Cm@|sbJAEXtofHg6bv46qn2F=RmLY<K^S39bJ^Cl)QHF-JWGS$(dpr>sb)9Rl6MKx^&Yn-p.zH"
			"15wJ9x!bI-D=NHDLQ*U!31q-A^|(83k<.*kGV-=-y{>9{q_cT.L)uAXMJH6v<pkTimJ)QTGsf,>5FQ1rEb+-*b"
			"vJGr;Z|4qL;3W^96MznM_!ieK)DMpNmk8_i6aq5YF0damya$*(GJI2x(dM{,mmMxBx_^=R2)%QBC;9AS>s!YNa"
			"F_d)Mv9.ixoa@Z15Q3QuK$kk_{1+V$g}i-zh1uLXE7DjDTm97c=C,tsK6O(YC(4l+pfleXQ{=|0%=P$|7Ss#uk"
			"J#g0jRkC,i(mYml<w+,WAKm!TlS(kpG(pIF_^DnEGQRAos<QMM!nB$9VQnY5gBv&)4#JKY^Vr;X!I,.LFD.Ih,"
			"(BGi$TG}(M}i^Ub<5(rSRjESa^mt);7%>KpZ>Uc1JnjdQ&A=SaL_0eQXK&H@DILVmYImRn3oYu#6OSt,x>~8G1"
			"D4wmi!@92cB}Z||o{mxwI7SWm^;StVy1.0}FPeGVy+2-CR+RlecM&ru,vLdzSj}y&^-TKL+.#pvmUNH>SxPGe_"
			"+Truydc@}y=$%;+ClxW,&~4zb9%3>Du^<yVVRX4.T!jV8REQotTlAMF6Hj=)e@G,raQND^K06MwoFI3c9YemC#"
			"0hs!8#yHx6jTJ>uZ*NE{>jiM5)8r{qOOA8;<M>Utm5Qsayj<M$pPlgv6O-AfJBH8bnD^z.4v<jB}%<DW0=M_(S"
			"b^a))QZQ}S4YA}U!~8Yu-wjA|2KYmBSeYWJUx%cYrXj)8UgJ8<WFE)A%Ekx@hzCiGNk$rUUeqP52uG4-,{7iv+"
			"Ky|{JyzJu(1IUa5H1KJ+m$1F-BZc|vMGgZJUm,q7oQRo$&!!$IVX&Ga=&_Bi>YYOh~c1iq(48aw^Vl}|B.a6ec"
			"kau;4-aFk~d#|dlGbRsf;P,Bng,05n9tyEUkcMqFR<&39EK1mR7LB{Tqz.O62ixOt==+xE<-fBY(n*%3*7#aH_"
			"$}aDxe6yF1m=)SDg=0jXvKn}=WSRp5Ap}v.$q7x;~%Yw1!ZY4ML-J!<I%yA{#TWRIdYGWF4hP~b}dy%=Ci*ZNl"
			"9>SQT|6|TB<6+sNxi)RTxSwz4zN@t=PXNd!ubyxa~su|2Cbz*Vq9lN5,frHB.SHCcF,<I-JvLN)lvf4^~2o8QI"
			"mIS;>R@A@hlpVc.vh>yikeWfF~)2J4Gn^KPDQ*0Qec-F@7iG>F%st}H6}%bTB_)o^Zs,&U)M2#m0COGr8#mWzV"
			"n7dvH6e;cDpb;lEnoVR+uKb4f9.Z>p1-qyZUTnfa52R9u>8bIuYWERb&r0j+mAXRdFqa{guA=8z0dAp&1cUnPz"
			"gf<~0q,_sMZwTSo@ch0fj_ow)Uk_lIt1m9L1q{LQ<F!@rZn*t-X#x%{H;=2a$#5YRd25LvO|#iXq,F=!Gm-4,d"
			"!DedSN9|KvQ1tqqO%9a(koU0p+PGu;c06m46LmoCXN&!xWVAQuzcchP9BGC,8gdKq}uS46YWt%!(NhUb8D8IG3"
			"x2._,+#RYuoqK#pJqY*4L~$;N7w86piR3C1YRW@}m.{oJE~wyH4)-y=BOL-8Cg{w|^s-$NGPDHn-dlXzN9;8L("
			"sRYST<B4S1$8g2;GEwk0HISTM~4#Z+Rh1Np<}Bhc0LbQ.QFP.HNVet9$1o+zhXe37p&R;^L%JB3zQr)nWsapSX"
			"SlHlFp.H($)#!B(emJ0HKx}#W%u-#8b3Z;hpxgddxDaj7*{=d=do|^rr_-@h~M+Ra|dP)<HWQ@>HzoyHUGK0|$"
			"FjxR&iW*3Z6@NH=uPbzV$lJSO4#7<mk0Z}RqQnHxpKD{Pc^5RH4CNO@r6d8y-D~SvE)CxwRPiGwR9FN|!$}Y#%"
			"1~oWTaVUXx5JsO99ndSl<<|.v-4h3^z-}i.IerAWnF9!hhkLKEM1N=mAIDtv0pbiM3zL3^s}q9wIiB8m_FC08F"
			"_ghHs0AzM6o<M_}7=0bbMTFug%W1>+<wvF2,$0NvQI6lpZAm<i5~j2JsKwy8|QyDH9-|ETbr;ugJ-f,8eUUc-i"
			"W#iG%6CR.TvzUmJ>aZ1cyomT-ZpBos3ea>h2IBUTyp{9EOJ!>;FygS1&#C_LcGq5MPV8<e;Cd12k>(~;p17PI7"
			"$+qvH1hab+y8uP*RW51.6cH-VuL|!sM#6jkrZJR-@o6R4wbdakQOke}EiosC|m_9gk{qFSZZLa<D<9(XV.aNAW"
			"*u!_R7wPMK!R;i97LtNgBwl>^wy!Ud@G94>_<K;e<mimg5Rpc3f-2xYe0=13Bg^Py_){x$u;cnr(U76t_k3Qq#"
			"{7vMUL3I3&7MM(K*0h%EVR##+}=xM^9PRPa&ETJ(+Ge;|IIa,>AOric%C)Yv3GCJttPApa(Lb7YR|fjzrpBNE>"
			"F51(oS%KNy|9K3$wLR*!wsTu|UI8omT|t@d)cENgE1IN*}yFa=JH9of&xCXr)=WGmS!vN_.fOn*!z4zjJbOF0J"
			"~>Tsumc#1&7E9NtQ4=MU>UE)v(uQj~0PT18n,s!_%8-);K,VZ!oSJq>9*$0buqbKwo$JFC~{,ho2v+3IK-XA!#"
			"&NOJ1HYfTO&eLJzNM5P%#;.jz+2qlZ8M7v|x!zgrm%O4=)=4,yJSm^Ht{,EV2Cc5^^9$ICqJ)MZ8xza3QUMR#6"
			"a&jB0ntH+hSBNv<5pRTH2^$)5=AT+84&Hip29P|RqZPgqv~f4IK-b9v^LumY<oAR7GFb.WBQ@6b$&U!nfyo@e("
			"StyFbc*Im;M@{QO^Wr$&Q}<BJX-JF!;dG~=M;k;ry|6o7sIV0$FIK,XR|tDe0J2VffW)-2HD3qlG#0o{&U1fDk"
			"hYj3.vjg(p{p3w{|6h4i.R2BH84MTQW^(^@<5fxcIkp_WYlKJ*1f;#DGC#3=0x>nz$+xBM750N=oQ0G633DDL8"
			"(C^O<N|I<Lo>Hrrmv){)oB)}ka+ZoOkxuA-UsxymVOEWyMr1gx~fpN.*>Y3zsZ-auna5%tQH!9zA7r@O3|MCXq"
			";V_L@rSaLbaT-;nptnAk_-{)ptKaKZe=;WIBq_9B=XAv8g8=&~KBhu=uA{NU8^4^Gm(Lk(O1i44fM}2)~P4nly"
			"xiIl3RPfSS)hfrC.X)Y)I2R,&rJ9RK7.4C%aFXNJvzwZG(e|r,&qrJ|U9}>s!J0BKyHi(UJ4=afl$noC31oR=O"
			"W*{GPWv#+PajOX{!hgo(nm>2B({y7*^~9-gj|~Lr59kzu@2dgP^QTlRwkkM58-Ouo^L}Zl}7a~zf>%JD&^+ujI"
			"Gag$D@8a4z|UTMGTD9l;s5KD2{GRJE^C}A8OMsx1-lcQ97jIm.|.naV{}kDLrC1^Z0DD4Y#diOlhwTOPg%x-H!"
			"eKgm!(9_L4.eI#UC!r-pm=$-M3&RKP+ksEa8oB9xroP!Tz!t3ILgiMqZ1t6#{V-Pf9hbvHx%.;k$4yHBHmV-39"
			"5ibggOIU>ar(HSMr){+~Vd.E9XjXQrQ<@gcv^{^#i(MGPk(KN;|CgUwyTbpVc#5;)7ILRQmL!W75tH$#.epl9y"
			"$&uhA9dUvl(n)5|FX8!.*kG_{LK0+v^dPc(0PPt;qG<S!|GK$r=X71XnX(6oA=xh$w@)WKu3EI7EzQqpy(E)EM"
			"u73z9b*;d>pYE3J+S>1dG=@OdY!t$QA$)uF8(YEaDv9,h1OlSwsJ%WAw1P$m,xr%t*585Ch6z;LG2tqHrJzIx9"
			"FA+tdoy^Pb$R8!yH,$24xaNWC)~-Sv^NqHOI^+mz4<G3H%~rqDT^l<h6J5>V}u_=KvrPg8>vkjO5G7$g1xo,Jw"
			";eJauZXuJSq(O3uy=xiKW8M)A&.q_NjrmP)SpCYk2iNTDQ2Rk-Ki>hmkv.*0JD+(Hy659u)kc!q9<c)>}XjFK+"
			"SjPi(yN=A=B@K*sc#(q5Me$f%T0dXTmEakHC-@~P<+d9fljOa@jR)TmH(VAW!b#r+q%@5=,EV,qWeot$.R9SLn"
			"X9$p>8OG5nTFZPl_q8(>HCJb1-M48K!WN0MXIq!O>|3v~{(y76o<~if%3Bi22W%~j$,2<<uyj^HNo7Y;M,+UvT"
			"qsTx-,~|Oo=qyq!NVc5#V.-Nb#+j*!_mQ_(SwwhBLIpO9<@HlBCEWU=STP*B,%(e>Ti.i_1InEM07}@$|RAjR#"
			"eBa<x_u8Dq7szTYQuo!O;pe=GOXe.2g{qeJJL0N<c~4A>ETlEpjdfLu,TwqX{CUkx~x,qDZ3EiKi.%eT>_0c8Z"
			"Lt7eaD^UuN3l)4a89@bjw0oJCb4BoH$qsD8%77I,PiAMkP(;pOSaa(llgq=+!3klh{;uMtFZtQP%,4i~n|zM31"
			"dESdt@z.AdPr.2Jk-CciDKP_|HI)Ft4Xp<O#qQ8r3;I7CN;FVwh%p$-@.FDW7_T<*p!%j{)FcO4bC~C6TouLmg"
			"MK<ibmNdHz8A&AUjwCBva&iYbI(<0(;-sIktFx=0CH1|o6%l7cDMc_7!RS(#ElWseg25@I3*(xoXn.P6yPc*r."
			")ZGo%eU%B$FxE!Q65cDY,u=Xql_$YPxmlph)0ZF3BoLbuA9=lys*{N%i8+Qt2iOCpj3#yW-H*yF}H,tpb@TeSv"
			"o~Q1W@RhN4v-z-P7QY<EuH-(dh5!,CG~6oL2>l1b0,XU{!8I%As_,6GbOTN=P8#oy!~_Uw7<yCvVu4bmR2H$g)"
			"Dw7*H$WMZ;9hu-Eo|vUEp_y0MUWqbO*ZJ)_k3)Y$xQk+1s~*RQRcK~y|OyWxE|_TDww*1$5+xe6^R$2h8yN=ih"
			"Xu0.q(r^FwUtg6S|%gc)H!_@0;3L@zgI$&04(Y4+X_2,f)HERHh^|Y$NAl.UaPJ8;=_r5(b%WvKfQp$!gWR3U4"
			"Mu02eTI^,CK&sB{&Jl.P0>)h9xhyyN-CJ<+SB#$fFRc)i&s=&s,CBP=4+*%ca!{~R42sUG#LG_,ksi+J.}zwRt"
			"dI}Q)8Dgl.euly7HT45wrE}ZT;17W7F2;p8oP%yv_w%}E@+XvxR+Uc9=}TP&3+*JTRnFKh|q$Hh%N{M#DJ1XB#"
			"s;^lbXJ*{EeSl*kR)6k3V9gucqP<!}7T{=9nz_a@b|I,PPoK7z8l{^wr722!hYCb$L6d-VexDTTGhXH%Fn#9^A"
			"WJca)^ZJzZefdWs77qymU1<i(,n!iJ%Mt0PE3N+dSy==UBz%~D^2K1sYH*hLOEWU{bEQiMifRoqx3BM7Pk9UAs"
			"+*!sM_QL~!^u+n))9JE~Jfpm7#*+-jfNGU=h7+^tzqD7KaNax+;jI8dTOh3G>D9zqW<8}Pb#kp|uA*xQcZd@Ha"
			"eZ1KGZ!#Q-H4$2;<>D;Nq=>3wR0j-Nii^o.y~n-Tm2dRp,G%QRP_syj29nx{v5FMi19w=w7yMyjkPj~p%hP4+*"
			"VV$!;l8,uj@%)ppws0l)0M|Yp0-hI$s9q)VrT&c766Htn~I#Isr4iO^0cFqw5_+FujcF++tH*D<=FRogK0-j@*"
			"FT-R&Y7EM+|g(RgnO2Qfnj0kZqr1pMR_C__nM3q51X{X-yRA5T>bwiLg>26r6JBC_q6!{Dhr(HQJl0)!4tc^0h"
			")URhG@V*).wJs!u5Qe2l2lD4ZdjSd$qiR@H$RfR~NW7)USB58bRml#-HK,@aXPXwTH-;1JU|HW<OXN_VU.<5yB"
			"k!.6HIvUIaF6WlZwP>yd5.pSrWd4CTC)qkBIMP=I)jKMP0Mkvt|Dq$$_Ss3qYC3GZ6K04M}j*c8TEwa.pW1<LE"
			"(D^WuM^$>>6^xqc0SFvcJLIZ3N-t=^7sIrzC12c+|LTtA2,V3FpVxXGZ#8h_=}K6)NJ~nMjawu&am8d!94DK>Y"
			"O+9pmPCOGM-4oOwquWr=kE#M=7-T)@pg-,kam+vL;|zM5tSo{=T|_gluedeZ86*J&i24Sp{l7U1%xRFeoi{=xk"
			"SdgEOL~VB($.7zp*).vqQ.-mXwu0azFT02S!$wAG)deJ,T<W*pr-N1&h-qza1dTnjV*AfdKBTNT{nI<dRsjLxF"
			"<V{@3t$zB*G@zidCHWvo>Zlhf@ZC88O#5qM$lyIKkxk}.c.Jm,CF+&hbgyw(QD@L4M=#3TW2+izQ>V+Kftd1GY"
			"4$5x99w)E|7lDwDc2k+i0vyerMMK<iwGT60NiLxxWF!FK}%sZ_WZkw<XBW~<b0-~b9Ju}zpd##;GT;;JlKN^X+"
			"<.)B%+3,MQgG>5cq|+u6c9ga8x7f!)j;g>3CnwO=<#O{n_dG5m9rJ>@B(p=2phd}|z(}6bX*_V#i}!U<6v_-ww"
			"_.IyWIz5p$Th6dOn!fVt=CsxY}+pWRuDaWCmn0cfniq+usrOFPLT+KRopC,nDhF|MRCepc^k9rdz|xC,2+N<@T"
			"h_eWJn_0R6_)M;p22_gDWySAhS_<m&fUpuZAE.0@cevjz<(=9twc3VzZN|G{<D>BUpn0N.1nDe-wY_uz6NRLka"
			"A9wptP>v1h(_ky{G(Pm|H.mE.(6b$HHACrF0~il8CBtG0!r4&J^!7<W&(.|b>_J-+mRKGLeLa7,Y>l#@Fv#j_Y"
			"{W=4e+s|C^Do.b4S@j$AM2Hj&-O9-N*VD8Lzi83l9FlDkK8^WV{#T3&yec1n%!.fhBCg<!S%54i(xa-fbI#BJ,"
			"%KVS2l8MBY5sE=V>qbz3Iw1y8POT8H<wu}6v-0|W4ta0e.1$l*#UeqKnOMTH#GO_d>d=rTv8HP9es%2iam;k8y"
			"#lk#ZzNz|2ePPBH;Vv3kyXt=fpVlBRRg0-JK^vL{tm8sIwcct@O{.uV5w~fchs,_%+FnWa_o0>VT3lNEQ%EtEu"
			"9q+(E_kpM5gU1;yg0WFXcZ+$M+o4-.!M0XlPN2I-o~UM3E>Z)jfG=8geOK2z+z5U%|4=v&dQ.M~H)d*~Gbus_2"
			"1(5OPTXgr&DbssM&auu5UHKfoXNtSs7K9qQlH<lLz!=5W{RuT=fM_~8zZ7m.*v#AH{IG;>5#jH4!Ja&nY#gk#H"
			"O71Lh.#F2X0^7_xp@TOPwgZNfh0|*j95C|M_Cur~Gg5qZKi69#A>dUaNDMziTk^}yE3Mgk~c2-0L=pdkip,gPy"
			"u)swWltu8fufQMfaOt0o8Q5c~qO@m_tj{=ZwHQ}Uh<JQGSgegAFklHCLI6q,)g+FIVysbQaGl(#e#L!%w(Bme{"
			"Neak6(Ht8)=*h6Slc)V(3l5Ra2q|a@k;=4hA>$vJ0XS$6<mbGVqs$.S7<njl.4T$p,=15ac_7(p7Bx0%yL@7Iw"
			"ayPcus.TF9_d{R{qbE.xIaQw!BK_^eoaS@dF5;X#.q&d1(u#bbJ.FgW;ZDU$(+pXXX#Wv&B.,#.f^NCW^,lmj1"
			"NKWCAP3+Y8QprE5e|$O9,YNJ*oG2rQZK!Ko#4Xvhd5sbwkviV>7qrSAvr-JhsND-|sTBu=uFX{%KuzXnc4.|Ha"
			")euudTu#VSi(pNA^gjw071ao{aq~j<i;Ho0=&K#aLJ^zO%%MUbmZG>oYv%1LO|M,Z(l(O&oKO<zKYV3iJZ&sXE"
			"R*Y#$GQ}Cz3^PFSRbzLgU1Mc{5JZv@VdOy~&1OcW%uC)6L012V-jxPxS{O;j693ehieV7i-cNhS_FpH%^L(*q<"
			"Rskt3mKC|BC6~dES$$DhV&wGbWqqT#}6hRXV1N~L+_9LB@{Tx&_&%AO{<jfu=>yadmxMgC,9@4>DMMWB13EnP("
			"zFs02v~NOGPITj-W*Fld}.~+6&Tzh{<V5{owwS#IueGB$X*tydV(w&ZNOa5ijF-z3&ervFo{Nv6dZyi,s6nIHE"
			"qRA_*d4xYS9WM2xEjeBqyK9~Z-.VuXF+_*NXdxed}xkwcDFY_&YTPihIR5;15o-.*n>2sJwu.b=Z#kt4k<>g^j"
			"x9.yfxlPa^MP6;T6CRI#i7J|}Ad%^!RttsQ|0TxXJ4U5R.ls1b6KsIsnJ{^3X@1siTB,R&6EoFnO7~t%TmLfJL"
			"R5Us&NXf)i{ABU|KUUV|<J%vFZj9@iyRxF27U%4jqnl~d+*OLOGmkc0uVDGHEnvRgH#}q=qRPQVpofU{9iYrDD"
			"9<&OiqVXdqbS{+-4%V{{;I)-q9,m<Fe4~YEd$0V%ApMxn.CofuXnrUVw.+EyS2zlDj8z&cA|+OR*X^-SJ#Ra=&"
			"@7mORL,dk0APXb;sdr>rhz9Ns(P+Uk79Q{xx!*6%u^jOxrENWhI1S>hP4OBt~b5NTWDKCGxzEeN7c>J4*BtOFP"
			"no9^O,!FgsiCJ>dS_npP^J1cy(ZEvrn,;|!;Q$yvgrxsS{ESL}FsxwUW9{Ia{;n+Y_YAUn#m%!#m|bX|JhPZ}("
			"-NjD|CKF8tmVZU!c{.)k&iGV~{$w@w6.3)&R4SL$*)G-dVdKU))Tqt;CZcdLBMOP^$$|!gh6h#mT3t<{GLOJzx"
			"Z{*Pp1N}e,2>(kLXC=2UEOzHWm{t4Qvo{MA3X918U&da>y.#q{>hX$YN-c>{&DJFN69DdVt{7U,M$lq}_CZgc{"
			"eOG&Uso+K<saHQ%Tl~(7D)%!_.}g2Sy8I1WX_seTzcb+J5c2S7.I7S^JI92WFvG+YE)=hRqQ1kV%Ve@XZ-&o$@"
			"I!Ml%MJc_MM!v;%c$Owe(9{Xn4zgys2|WC>b5qpPyfs..+pXev4(Q+gdG0wgF0sD6Q;d<kUu6B)RtQWkimpTNZ"
			"te=bP~GeOc}w(mJwGoivk4wD9X_7NOb3TzuXd+0vZFzXK1zJF=,|h_s64KqP>U1|X=hv<-.8z~>no$!v3{TjcX"
			"(kdQyRAKG}oW5)BILEEkLC+0.~xH^2E*CgnaXvGy4T>E>TcVDr|hRvP5{GLv7nzF6|!idq}@sQ2Mp3k>*mLRa!"
			"kby5BBTrxLy9tKj{5%cAq;tX{u$Lrhh,H>)B7OIg7Em0VDT2vzLk!WB9wIW5x&@;nSdEAx0I3Yqmr}G<T8Q^Vu"
			"J>#uC;OrP2a0Lc.(>t;rR8SFx#-;~x1Bf=B$go&k$Tt5&GP%ZHa{j9anAbYp~;cuCL~!TAivSO;Vd$gfk^z}g0"
			"shuKE3|G=hjQ8f9qxIYjT<08m7I@f@&S)b~)-O!1K2W8>G9~98i_sG8R;fUWgGegh(^s63,G&qmqKfp*5^_Q(p"
			"JpI.KhE>Idh$N<DIlBQ)Zq8w}rQ<y|6ag+ri&en4C6$ISHkxjD;b9yYl<YDoe@qM,}Haw57UAy0-T@GE(-IK<O"
			"Eyk*Ph0)0dKXAb9R9wdS}EJ&UZt#N}tOF@>MX5OI%zlxIy6hmO_6,mo{b7Eo+jSEPhUagT<Sxbki-;5zXrOPvv"
			"v-yMYoUP>7U1}7vqzev!|3tkSvcMdmifR#nMn1$nkJJ30Te7|!A3b;H=.KOY;<6$zP(o%X77Z2S$^Fb,h_EVjb"
			"-hW#64XD3XXy0)UAE<}0QGE8w!-JP${sukQc>HwFheHT^>u|Jn&T%{2*DKE3l<VqM$!+Js&Yhwc6*DtL{_=V+i"
			"V~1hxr^)A=bS.>&aGu9JW0VF$PnT1xY$Qm7lc_AMZAP>t=9Y,St71t-cb8J6P~C*Kwv4WOR%ZVNPAyq)AsKQG6"
			"CJsD4S2eK%*(mK*A9TqS3MLYS0RF,!|G1&jylHZ^@U%JC@5ECNJ6XBI+1f*==5tOu{op{1Xd<#^nv@L;dRAD%y"
			"s<dCks9fT7a1)BoUQ1=pq5m6u!LYqG|yuaxAzkCn{k@Ip#CaNG1Y&q$_uY.2}=-nb3tiwD7F@=>p$!=+4KevUu"
			"A4B@yU#Tr*B&)6t8Zm=zyb#^6h&=5~)!^2WqDnPbgbMZwizx{sg-NF-!$*pvq5hYyk5UN,w#|#0e8Kn5$A2M^m"
			"FX3ED0ITWvRnf_bCIeeGP}wPv$f*(-^}|Mvr7!r^Vdllt6.o|mA-F+JQ+f<#c6mtJ8akyihbvstw-eQ;gvjZ$@"
			"QOEuv%kSX&c$!J-uX$2xms6pg$iHRDuSP1X7I>EjA}cY+Yj1mC94olMHKRjBU@l>RPeSt=L<8@%vYc<2}_=K-p"
			"q;+)Zj}C}.OQ#ZVHuL<Cz9e-DfDz9;qV0PAUOzP(8hRVSix=-OzZ8J;hjbQ&Yu1zO8y.-vRdTR^8zE.vJX=zQO"
			"U_*{*8lB}AFBO+Lab<Pw5L,evxGNTj+ZQNk16N(73.X<Ncqf=Bq9<pxdrhMxNN3pwf<+sS}2,|4Ndg&PQ$=a;t"
			"<Mw#%)Qo#Xy^o7#a14-wI;@0T2,p{pH>~g3ndtm)*w.UuC|l_!N0OqPl}h9uBK%V#9F~N8J<jsScK#iHu0CIl%"
			"{_hpiTYgee;+jn7BP6TsC!!&6_Lnll,7h=rS|r)iXi_pI@lwFNffjQahB5C+1*;^E5kg!4jxxGlf+>D)N,v7)="
			"i{X@F-462YXIjG&E(2BP>OLN-{}AWyq%q2ap&,F@!,R(_2~6kwl7s>ukw&;eul}6iH0|XT<OSRFk$P!^,HAj(("
			"4A,g.ZX36MZ(7(xFiT2>-;f-}gbHaT<0UptoQC*(&3HMFISA5d*;8l4{hrR8hsr6Z+V#^>>~TPpie.G+Sdi9L@"
			"Ef7kWi1Xl{s+xUM)$5Jy0qKFa6nk5u=QpUzCl^@43%=+Z5uNRrEW+D}cn>j2}G>#mbB|Y))^X>WnJL7nLayKmg"
			"vu>L3oV)&aVfcxpRu+tbLH|Vw;K_v8pE^16O8lF9GSu18)=r_>lWZ<>jbmuW<3Fs!s}QK(Pm#x;HM;we,Rd7@,"
			"X%KGx7hWnQ-dyaZ*|=p&=Nb87tm(Bk}+nJp,Z_lcd~P-%aZgd4O%5IP>m=yl@PFzQhU)ke9S)&@4qX*A%{J_i,"
			"$0P#r!;bo(-Mdu&a~QXQC{cIWtM^K=}4>;i7Bwb@gczJKcggDHNG%yk~<dGE#_sI,s#WuD)(e1>(Nse!HM($=z"
			"$q%B,tW7tJWBKuDzQ%AzoJ4=AdK!Qe-@JLY_uyfRx,mE=kpS>xq&v9al)945$B_geiQUHc}YVdPV%%G_rrO.z."
			"e%aZydNmB+i!Oi,4%A}wP_6_^{d0&)QMT;tckb@%=%L;_qDgcYAZQRji7hSsU,NjU+e,V4#SRlS1R=bd;9r6~g"
			"tt}8h6d%({hsi=o72HIr3v>_srG%t<+ZMo+KE&QGlk3V#)56OJes0A%Jx,+c!Sm^l8FGzQt%cJY!M$EM9Nk@-O"
			"NF4n&gV.AFet|>arzwh1jaLHB%>EXGDV7Nro9V{,D=tUj|B|*;m&r!m-b,z-BsxBQBKx5UWpWW42B||#K0jsG~"
			"tWdA&q5ch*W;K{_^0PGs8%,$qm{}!!!_v392.!ZeJ%3ZyUzL8*;-B$.Frz;)w2=;nUgf-JOl_l&>a<!>=h;3Ht"
			"6.+e6,m7i<lk7#X{;Bn4>3bho(d%bn}d#UiJEvf4<$U_V_$N;_7p-CcSlA%Q9xHA@xZ,nB3v6{9IZ6E~CRfQwG"
			"uu=3k3Je=gwG$=S!NVJb!R|Ve)>DBZ;M,Av|R$IHOmMq>G#ugSR@.q+)Vvv-LsMtwMOFb}FXO95d;=Ohn30WC1"
			"EUrkQkY3m<@$L-F2+oSP)3IqvE9}SXtXlpKbXax7r@0o}<sGqvW7hI(lf<tDE+&qMq!2zDXs_Q7Yrh_KqXt$1;"
			"_OSM638EKhsb<*C&D!HQc;Fz*itV9VwYI;,I,B=.VOFff>mH,N^x*bYU>KEH&QCtRU<qba^P,TzCzU3{9l{Tf>"
			"%g2yB;u7G+#)5Td>b$rHw5Sj5F6+fyIs)(tz;jZScd@W^mZD#%jcq0sG_OzdP;gTNpD@rB|$sl9|B%,vDfLqCO"
			"YH@~Mtoi-^scQAAD@&3imNVUD!JUG,a+ux-~EDaX5pTl3eORv4u<-m=2TjcAf3x+JkroAuW56l;XLy=Sws{>(u"
			"=qdGPoLt|LNx.pidCo2^++jJ}v_05C|B.e-3nK.BgtKt|w%S*dzDJn_EQ+)8dVGJ90FFi4V{N7QY&G|ccF0S7."
			"!q}@I97^5;>uP#geRqS0S!S~JJx.7q@yC8Aw%B2>j(S0w,!L{^<0_;>EMt}%,a0bOF==+W9>IRxeEI|mh#D!=="
			"Rz7Fk!d59VK2+1WRYY_+cG0nt!=tCH)g_{<0OAHZCozg-239,D=5{@#kul{DfNk=DOVeD<H.>7^7-R9RnpOT!!"
			"_N@<4+jU$GaLvIjuD^Ci-HW&TEUk{5++QMdH%U@swUq2-qz;w22<yCt%GJ+=.Ixi1rT_FEf<).NFQjitBwrc<b"
			"#yNzoeCgxbj}&n!}bniG^a&EL)(,S@$cy2Bg~KP#J+BMLIY&1CKA7x4SJZ{Ul%eba;C7$8-SEoIV20Gp|5(e+n"
			"NMu)wnEvh;u=H!{<6st6aDB+Gx3.%EjJx_f5TP=h_{n%tq_z3~*9SRul&p5sr<sIhw8fIL*&t*>3BSu.RbkhMF"
			"STie4(T$(h5Ae&Hymsl,(5!JP=d@HjOMhJTrMB~}G#yps5IhqLIk2syZK~x#Xl}~VrVp#DTP>0S;NOvfvBDNdj"
			"F}oJjINK@@|21!O.!DbJ,5M)hD7!w*gCER9YHRBN3G99i4tn*-PcPgTUBGf7_3XN;Mbd&H.)lGzQlPl>r0=.<t"
			";LsS4Jn-p~J<_J008#6L!V<B@)cUh{LYy4A4zhP#m43#U%ZUpny|cB@6Nbv%VWuNl,3CBS^q8q%ug.ZTYt0Vhj"
			"GU>=qGvR.=o%{EsC%>&j_@=lWka-7Pr7r&UZR8Fo27iqVQ8h,eI!.1!y=YJFqu..)nH1!I.EobVj01ZrPg=!YG"
			"7xvIqSwZ;>0r3J{br;X3uOGZ$z!e)+JURkc&T0yLAtf3>K=YE<-GntPL*R)^#L)bY=(b7>;SYg&ZIrgG93+u0*"
			"TDNV&)#KJQ<A%LxRE^-&$Fgev^ndKQW__;g_)Vdh!VuNdBkUG2q.cLO8D@5mL.sa5,mk1%DYVflR_au;$txLQC"
			"kw_LAurE%q|F_TA6x^XT3YK~6rR~__gc*2zqlU4Oy=ZvEa{~khhmIUZTRd7jIMCkhG%}XyaRmHK@$<atuKr|i1"
			"ydD-P$3>(Z*JSqcs=.43C6RkuV}ygumI=Wo!|w<qdm$y57S+GQ2R9L~z^Wh7Nb)b<r=i@FzzPD@A)9&35D3&PL"
			"Dwi2f9aN+{@YSY-}Z9I#IedSO+L5aFow$*<*0b}>do5rbMVe}q30TuRC-WJWX|A5%Vx3=)_kEMm@zAd3eJv,qo"
			"(+ibdZ.XUgc+9<vCw;X4OU}Sr6CK0ougu>fNf}^@c_@_F1d-k}>O#jLr!b}ydB#FdRN#hCE4Yobpy1F7WcgrrW"
			"h19Cag$8Yemt><aY(9PSf%B9Jux-ah=)<+ik~<a<6eUQ&e}Xb0La1lgCCz<E.&QaInmtpYqmDV}ZBmKFB-41p("
			"$.6,QCykuw0xhNw;gtrU-Jj+NtoM5c%r3LwR+Au(=Hg{xSgk6a$EeoH$l7>CR2j*dgmS+{(sF6oLy$UYVHg<G2"
			"JbZ=iz5vx#LA!EQ7MLyDC61&uhNr&k9m&Sflc$4_Hg~5zy.Z6~QNbB(zIJNRe6C+J3t;c)$IF*f|H$V(%d,hTJ"
			"o~Mg,aB<l2$UPFnSA(>SrrlEOBP;jEedQ2y2$@9Jj=-GGE.({+hdK_1T)P5M;|7*2$V6SN+)F)iejwVt%vnY)|"
			"ANLdpIrW{SeS,H}}NkW>l_fBgU|3LN<NlJ0q7iW_u-aNy&&GLS)mYGG^qcN-=pmj&H1(j#JxnqB)AKRAH^kI~9"
			"*K}bh6rrRU%raInRHCIKk~Ab.YF8U>g=tzQ1UB2RgUenArX=ci!cL2ZA}j-|M6cv6m7o0M*f}Yr4I=Xh++ULpq"
			"=R;KF8<GHg_5m6%|%&Sl+Sm2mmK=|OW=.Bp6Tm(>%TIUgU~=aX0Smyf{O^UYtk(hWIQO.+G$E9GtPxOLN4-NJj"
			"-r#e9r=mWhkN=qaf$-o&qoY0qi8mAdv.<RUwaB5Ee^zb(4DO2<B}TB%l$(u90hYHb<VP@dxr32>9D.P$C{j7m8"
			"Xa4{U3PFAEHztRm,)s}yN0T&XC<%uJ&mTp7*qvxrOKpg_4mES1$CXLe4E|M8Dt@EOFU9Yxc@=6PKPPj_xn-tn;"
			"C7IbFMNd%1y-81JK,eG&Thwa}3KO00O(V}vIN;xV*H<_LmE)wR<m7|=Uje!X%K*Q<;l+s2GTq1-Kj5;FBc8W9d"
			"b)|qu{}A>PXud@#2{Uc#<ragSysW9i$L.;<%{&osGy^Qz7^Bw|eu+!zhyD54{EE_G(hYP,XxXN=;.={o8q8~Cf"
			"KD}~369RP#oTaXX6tFF(E|p7P_ZV!2T4ahJo)Cx|Ii-7NSeVaMl8I4r{zy}bBr_g>%S-F#gOFPoW0P(-5rX_mj"
			"-RmWq+w3^2+e_*|Np6W+XaEyF{-EX>Ha=lA4lO-U$#hvx+_(Ktv,QxnxR(5j=8>g-gZ&^X8UhkNShyJYuk=sHh"
			"PBi^9TGl&!0+^,E8M^AT-0q%=26{h1,e!j,iwZS<r6;p>N#WNNU8Cc)u{TB*r&!)v_g,K.Lqs*(uML=}v6-jaz"
			"zu8^GTq%lHZm_rJq@z0R(ia+}Yu#-KB7RvF4i>_3LFmAR!4{zwn8PVm3y7k*STDCgjisz_bL^t{Y|GVcN.%gZJ"
			"ksi!#4%0ySySp}Vz3Oohi^2sQ^P#0dLte%x1w@Tva9ANlktIwi3-L~DFeHEfN3fGEs>T-5e00@9EJSd=EYP!ui"
			">DvcC_FVy7YYtY6Ie_4BlatVx%@Gn45|hSaP_viNnHvzJY,JS>qB;el.,HNfI#T1&@XXVl2Qn0&,#+uYSxOc^#"
			",z$w6QE4A_yY7Up0Z}O;UbTlH;1.8N.<iayZD)p%s_X5Bsf!xu-bmX$lUt#gb$l$2dZ2JdA-+QIuKghl5R^B$5"
			"jT5lE@52>B_=&UT8g=nr7xSUht;tgRZ;aNWsE_ify!=t_@EN4J)t7$8{9<1rSj59>$%(lzp|l)#NQaluB;#@)9"
			"ID1=vmyO9|pnlz!N8t,S-5ggUkWw$heC9OXW%+3$.gV;JDl~tZ9HA%7@bkiKUJe}QfAQr@1@S-xw7P4BJSRx<U"
			"5AWfbc}YxB_EVPVY,~)YTDF0wT2!fmiq}R|mWOF3vPv<;Dj^<jBIk!{2E_lGJ%fW>R9HDU)E4ZRzO6f6H+&Vy^"
			"oF%pIJj,G7D&*kTjGz{O7Ze-Y^g3zRa8ZgbsVB^79C*+Sh.c;!Kkg8PLGyuupV2q(d8Ly;(KIHznVRQq;SQg<c"
			"3JZkf7h8!%o+!NJ*mFX2)i9Vu8k|6=-Ji,.36m!*7wr_iBP<hk_tNoS+Pm_0W+ls)~vMa^I0rPs$7fBx2JQ*L&"
			"LGpX<l4R1!uwIwVb<anC&|*TEyV!jLs+YZDi0IiykI(METdz#qMgrG9KX*v,1,4v{RFl}Xjt7@~wxNQZRFymj9"
			"gnlvJ8>O^+ihJAgpf8>u~tgi^DiZeyPbHK|V9|erPM%BxY7KBOE#7zy*<r+v!;1AxYf!oULZh<1{sn9,H$pZ62"
			"4yYu7)RoFQH(7AeAr*HD$j8ZsdHwGDukuH*bq,cFAkhGb.H#yo<.trjk1LzM)z;!lwK81YkT,V3#J&Li>j=AN<"
			"nlt(rnbh75@^cAdtp$D5glV7FHIw3u+<h#aXD3O*0ibPo>Rm5Bm2%12-R3D4Voxqi7mF}.iRMEjr%XY.joYeSk"
			"kfHhT$Fu@CWZu1tEu$Dlye-2t}15A7#8t87v~PaDm+$8FFjRWUH#oM=onCdJjs>|B^j|v@N6zM508o1|*93TQ0"
			"v0*.ew$K(Lgf215{6vX+V^@CWzOA=#sck;NBQM4{OzPkof&vI2@C%8rpT(66_S$S@QtZ0s5rgK6)PMqge%gOg,"
			"kXB3IT%T;E9B(UN!>gCv6C7!ZYt,Rz@W(*rfL-+&roo6QL{H_18^*YFS&JqYroOzddBH)lUx<&);WSZxyIp1eG"
			"$=,2V2YvmLlM!GS>&LK=X%rEFN-%m!ks$|ZXC9vRaLW%X4NlBZ#aSarh-j}bcsq|~wy)-V|1Z1l,9o|c,&5Wi<"
			"l7Cw3XV.HS7Z){ZX24%DINy4vvl^-Sz6jzpX<l4c%~Y%Rt-}Rf+LWSeap9!JUrYp(R;e$.C|3eB1uW;82(,JNx"
			"6F7v+4gE#_^Ysq9A|9.(D.5Way0+Rg*{w2+eWmNa2~tS@P,eGZ;N-XusEwVJM~$oRutlB}TI_lckJUy9cYm-0t"
			"$*vCpL-aE@rGkd,tM,Ge;zo%-4Je0{!0ldeYk&%3QDmwQ^c5k!*7l>)92T27U-gs%<QtfZJGnyl~j<Jd,%yJu%"
			"NG>~|TltQ8MR4x{doH*A@,6SAumW-,D;-X(LeCBC;YuDiUsd(JmHlDkLrd|Vy#U$,GHc|>Gpg}R=!*;BvT0D_8"
			"*3G7If3F_GNZRx_XHD2FRRhVRVI_jWcJtwnq2a.Vo=s.J1X^iks-(VP,OF$cYw^.P{O.,F.BHtY>Mlk#ghYhgA"
			"Yi17vcM,upi7yfo-&fu(qCRXE{ckZ5.g5j{JWhLVT>oLeHYDE9lZQP{JeX%o5+n-2s}^b51cwej+a|@{,}S$@9"
			"X8urovdDFicjAq$4IqK#NGTA>hQW.2MXPGWzlC9g$eGQ.hBxnzZ{3njWT}UblHYxw$xS.hZO(+S!X#J2FzLe=v"
			"OIo{H-3l1{Gu_~$<SyA,oYP<YN>9xxF=5-$~H+R1{GCJd1zQmeGSyn6.VON29n)%fg&t1@n6ZYQ%iBV!,t){T4"
			"}SLNpB<Y,9EQb(n}VEMy1l0Ftdr(CyDw(.g3K.*|!Ue>J<qQR0*>QT)dU2v;lWU5rUOY6t5k_~i_cgc0c9Hj|k"
			"3yz(E@Dgbz3V3hjKF>G0+E_&#My,J_epU.>XGGe7KOL4fry&K4ye0bC.j%VpRV>Qv0<t2-<siiBT098<1bYc6%"
			"%ChRAs}%W25wmGSd2C2q%UxhnRoN<4^y9}_M+&F|1f@u;TWR3QIOTB1X_ym7^A#XuLD)H*_{v|lnhviCJ4yxOd"
			"{*}A,ko{;VCk#84;+On~M%;+I6W%YC.Q-&%4X3rv7#OpOfJ6sJn.J^9O.2Rw2<*L>f>Z^OAuEi^bG1cT,zQfHa"
			"6n1Rg8|nH2,&XAAfv*gFT)Jl$BLOe{|!$;qgfX1+7yWXZH;ZzE@KF2Q>q@6lp)DLlTQeakYepd%.WoRv^o&Xuw"
			"Ti9vrR.gF_iP$+>(PLT-tg+e!^!prN&uyl4uvMS2R(5W(Ogcv{+H}!AhwDE!.U(ugN9=Eg6_C0P;Z7--E1$}Tw"
			"M2p4VP#.l~fGNT+go6=X=YfSh83IL=VMbH|0wkUx7(d{TVDW@ywb9~6OabRS&83=l<vBR%(@rsmAtk#Q,J6d4;"
			"rf2>zKVY^eu_o;9cn7&8vxLnQA{(M%2t6&GDi^%#ze6=$k2i@BDwDYSMW!$bd=Ps3Q4H0,$,X-3k>jDJFJ{W2%"
			"4.CRv#q0o#%fCH=_,~@P75WE7{e<U~7oU83c_)PE6~!2,lYqA,)6ki6w#vyCS(8$|{ni-4E->uyn$1Fp8*2IBe"
			"}s,,RyrBP3)B;x4ag&b}LWyV&|Q!<^UK5Bu1uI#LydVN#7@NK%@bbFFM@%_u>m7kDy8K{f3~6UJBuf<_8LD(w>"
			"_G>W3CBtycoim%{~4$}EE&9geU,Iel$J-oE(hhZuOs}Qcr&_fHUPm{aTmuEd*HowpL1NQBzl_|n8VvJb,qZT4<"
			"{dx4;6To1WIV!l^%Z6^o!pSZ_jWEGy8ni-(h&2d,%<*DnN.9uM{1NRQD~2w}mZlyKh)UZo)b*b$$@f.};Ej7>D"
			"92M;_(b#Tb9lOYxapi<*$>|78TI_$oV4i6r%sMtI8&#im#@piPP}.!YZ*yF<5Ut+BM~;ShG8raT_B)XEFJ^UNI"
			"a;4Cno^mSiye;dq*h}vJ=Sgw(Y$7-R;fYFNN@>XOYU0qDUnpu2#M;<6ypP=9E8TKj}zv_&YuPijh=!!E==kGKo"
			"ucxl8Czp!C+v67#CyLf9>lX!fNv-$)a(q#fV_GO#pAvsv9J^rRiv@JFz8S#nlUB5vF3Rg77YZ_nzRzUxXd!Ys&"
			"TrzV<bW#+v7SRNk4e@Q2gf7t!(tX5.>MHW%98#,D-lj,{(LOHNDiplUO*zrJ,.g@o++5xMmBUTRfilkZ9nhhs_"
			"L.iqW>>UBrr6L.WWr&VA&T&y~d.%c-t8u6gs3hupanYSSzGLYxVn2VOcly1Oa(bQ}y>7Mk@*vL0#C-jZPS+*5F"
			"D_ngU{*RU*x=E0rDfenAay;mSSQb@K}2.QXkZ=D8JtN<2+IG0J))zzGnKkKt{%Ac_dZ*rdu!so99AU~>),EN+b"
			"zs=km={opwax{|1-B%{=bp^k6i5oj.7~5*im9Q$s{3W;;x9nUo{x4qZ~Y)Z3B^#-E+RSWp#OHf$LZcGn1nrX-5"
			"jpLrd^Sv{IIP)>-Izz*QIB>*PMaE;cjRTe;bzhj&SAmgMIJx=uG=X6Fy*5Baqhf4)9%iHIs9n<BD7;.6LLg6nD"
			"GR|#YUT$OnoG$x~}GsJ3PB_OMWaVo}7j7G5rl7%Ty*a!U4,yE|95{&N)YU@z7Va=aTpgq+0QQ|vYe8MbJ(c^~A"
			",Eail!TzykJaf^{#6PPj@5TGJkqb*1TMbx5BSoEEV<6,l1U5%>sxJ.R)ytu2IrjV}kVV+<3R%MN_Byi5S6_x(,"
			"x4SOW>;%Ql2HF>KON%PTKlAeH!9=BIc={sk0zCpM*$ZlP)oF9t>w@)h(^-o!y85XL;9}Wduy|Gh>en(G=nf^NC"
			"gwLY^^|!4H8kekKe<Y@7Pp.,(#Tl&zs}pN^zbu#|}1-%9(U},*_jo-5J|bM1sHC564uKOFG5FnL@~2jiq6#=SY"
			"S#DHGaJ&Nf@@>vK(6@@DMpsabqO,mYX%VH1s+jAsXE#^Ok_c%_ko&wC3vWRE9)UbnSwCUV1X9{-D%y*TxB#Jiq"
			"8=);rSg|X*<8;@tb%j;t5j,_<+yk+)-,D)7$b!-_nx}24~Yi(|EwJdDx6getV59kSJc*IgpF}{u$#68AMsx92k"
			")C%2%jG!#hg8v@CFhaJnw24,RY0blDU{.oNgyiwEyB+rISK|,EbEO;y4Q_p1T;D{Sf*7q9DKE4iuyn;GDXO%!."
			"MO;A!#-%_cu!jk5*$=Py*U,9PcvI+pi1cz@ek^p^)vZD^kndS^=r>^yp#kpj8R<TxJa,^k_B5+t;y*5RDe}B&u"
			"$v+hmGS}(mUXEtI|R-QJ&0IunKY8rYRYIX#96rPRfNTPj1O.&RNzp*Mv^5+G}o<VijCRFzy;MfJGa)iU;qH+L-"
			"03b8=$iSxcr;RVpFp8i4M$@b<Zj8kP}7R@Xi<R}zAM+Rb#14z7r.ScXJZc+}WiW|Ewwg1M$#>A!E<564oTmb})"
			"Q<KD-{Y;&awEb7*_d-Qn(0SW7yq)I6gM3niobXD(<<*3j@S1dCw3$D;IaCy<=D,0u{Jsj6<#wPV2RJXz.D@T9}"
			"7zBt_i.cX%RI@=Covkd+k1%wY#_zuWXg.lX,EfmPR<;6bx1yPZNoNRc<j}btpn*{0;N>R;30e}Xn$e}-AIpYFO"
			"|O=nG^RAp5O_0OP~;zzwZ$P8j;4u0KVqwLl_aY+P$I%HCMy%51t6$SZXqVlwrVmlAo2F&(PjPc{C!)oi{05Ii^"
			"f|u^knJ^hvRcwU85HY&~X<cRCRetmQ%v,(l+al{ZR%pqNNE@urfJ0s|1QFKa<GurjdQjO_~CV%NJPD8DkX;iqV"
			"V",
			"30y-hUeEO(qI~B1oK|qV,#@cmr{(%0sF8q2EZLdKTl$H59%RZ9i@biKap-9<cXe$W^Fya&n(d2!#nd$),--eM^"
			">C{>3!VGZFnh|)aV)8Y&kaX3K=vMF+5@ZP@C2O0-r0T*<>n0KkR*Eu8D31pQ(-$WP2U%,D=T4|Y=j%vPkgO*<R"
			"u!dTI970lD_VJTD$=l|%5<bBJZoO5&sA}rIL{qWo8zk;SmQi$#(K2fmyZouLLP^AJTh3ixumby@;UXY#G*wMSB"
			"fE58s$|eG*YiIccycWJFXb1LJ@)&E}BjvScFAxnhnnDAn(uQy&Am=Nn+h8enJxlcg5AHjIoM_MQFwC3Omm@sEa"
			"PRNAcC=PXDPyNkro<$EUH<*j5##D+&}RN*0ucB}{8LPIbo}D_m=)s%Z>qJt.Fy>YVZABAsVi!xz<A!%S-m7XDe"
			"wQzapfNcSBHekTT3b$3B!h=>T)3gsxgczAf3^lr3a6M,~l;f|VWF7~e4@S7I$jTfU_POhuANp0}FSlRCleiqWD"
			"*Lz2+xy2nu97H8(&4{eX&u9f@R+Xa>3apVJVPLpH65G4w&szeuEwLx&^r-689wj9TlFLbB9oiW#1l+ZZQW#X+n"
			"ByXlT5E,lV0fne>1_mu>;p<Iex8fsv5V6@dufiYt$sxFQ<PXi;.PH<MO-m6EL,7CDXSgD$<Q;&66VgFV+.u|Yt"
			"tB%ZH!BIEE&#A6Gmddj.C(*Zb(;qCXcJ={C$2MM-#3XPW~m7QKGKVRt|~-;Bh-q<4v;uWQhW_7TNXu.(W*zo+@"
			"(J_c5(0U4bAR&@)Oi8p4ILwDU%l=QYOB2NpCfb$sooRjoJ-@-&+33m#6KNaJB!X|f_(b9&xt;^zc7)u6G23EnL"
			"TRuM#,O9R@,viB.K#e2IdY}4BBF27Hi&^*mueuL@8L|iCwJpOMC;TD<UOa=sLF2ibtcTbK#ABWL.G_d4kTNb@L"
			"DQ5wlkrqm99>yUHos{gXsTDU@K7GD#gI^_T6E5j^ey%;~bLRv)JGs3LC5)nI&3Qe#UD*6;^0mogv^{E;NTsn^O"
			"1DEjTX%9(ZoD~k*VDCd#&6FHO#2**BJ(G&4NrO0L_,uOglR%Tq@G2eZ#yo{eF=PCg*Z!%k;g{AS.#y>vfg<}%A"
			"HzH7bDI0(ulK>-k8kaku-%jQd9fgzlq7lS,=>OuUC%P1ZGD_vDsOW4p.C#M}$!yTfvcF>YRLU2UR;(GHsGSADh"
			"(K<VpE9jePHX_Dt};a,y1#*DiYUcUHSOGb@K.cG&DIDsk9c.^8%eT!WeU4IU9ZGF!m4Z|!U0)@KV4o-8@aC>oI"
			"pks.AM5(McjxVrJr1ln=2Y^.Fd6Xvh@JIyXl{4W*c-GhP(m}i)$EEz,Bq)F=<^S(_0cE{D*^gCf~xXNKR^l(31"
			"aA3}24#8lKO$s$@2$ZV@jdRt2XvHeKdp&aS!6|gtvz^;I(_bMXvPEOg*~4V&B+<*ti~<sq2&96u(Hmbr{Vj@d3"
			",NYLV|0rZ@4J^,*R9s.8cK#n$eD1{Uu$t^1{H!ZXhqqPkR<6W&u.H,ZF3P6OLtQ|HE*;$KHt{k.$gNab1C4wdH"
			"KU8qph$80)>Wp^,&Ccpzn3PYR*q6N*UqX(q5!dRo1daAR..8qe&1fmlre<jG6M1Jf)ro)#8U*s9a~#OxZ>H@Jw"
			"kKJgl%t&Xlc0S4|kAQNu=yHWU_hj#^DZ%$J)8^jBP$rzyF1_jjS1MhG^_Sm.OQ2QJSYy{!l,Mgj#EDE}aXDhDa"
			"-j<UZqgIH_nL6GJ5dUx>U<c,OqW7.X=ln01|YJqJ-kunp%Bj=445d8MvpS$G8af~2~hi{fWY)b,-gG3Q%!gWWr"
			"vo+yTR.A9OX}1DrZ64i>,#t!1JQFy*=upAMscFgCYEX<BVh%Qu)(Vo$^FkTnTS}0w+n(V=GHfc-)P&6%LiY99."
			"jZ)%4uGi>t_a#cXOoXTB=Kg8BSiurSt<k<&s}Q#ZmtN$sp=mMD|NziiC1#aj!h703lbWUBWuQf9Im>s&xIwr9n"
			"{2Qn_4o@zrx+zFxs$C=!9Yn$m$vFqIK6Ob.vicr3|-gv.B7dN1w6a^ee37HJnit6fKUus.WrdsHh%RSy~dzI.-"
			"|xiAR3M!Ubt&ghLfN.xopDse*)J%wZ0Fx+S8Lb4e_|Pr~KDHKwkRNRG8=MHs<i5vd6&i~vHch6S(5<.w6ASsOs"
			"5Q8!TL=5%V>+KvKEXmm>WbYyxn@ZGH@iq9n*dbn%xtV&AaFt6movezPZ2_BA(F1NDp=J1+dyU$M*FGhkv-)E!W"
			"@ArH#E$GO*L|&_eZz@_Lc*s30jA-&{Jfyo}DK{r}wzeFwnW~9jEYi$XsUz8GyQucY8OkWL0oDm2cJbFwCkiZ<A"
			"|C73>#7v6RnAgZD8^EQ6iXR0_B@UrEHur~B%Dd&$tZ<t-Ed||wx{CVk6qW>hfPx~G0R^&!piBk+Pqvi,AY#u!n"
			"=nZxLI_^J2NXsrE2D!Z^*p4W6Pf&eqC9gOFGcqx%_Opwd01R!q1KdS*k%=81fyG7PCnbSL&70%qJ2_8{DN_@Ka"
			"<~8uZfsCRrWhon<Wj9_!3ylmVQQKoUNCY1@^3Z-;U.1@7&iKR+iw95~+Cb)TP;j$<rpNn<X4#CPs$atN@LL;<c"
			"cl1wC)Nwy7FykdA8qzU&^b-2baX;J#!*70oh8S,DTr8MN,aV|WO.+g)ucy*pv,F(BuSk*M{a,<,fuieCqgUCjE"
			"Hl8d_%=9S9aeQgUl7SUX;ikB8PPwizi!~xzXAXpCq!>k}ZBZL{HHgx588=#Bw*=MLXR~$d8pyC_57(L(YumOUS"
			"58yedONU@**^(YH8u3c0QUIYkI~=FIS,5C5|e2rj;*j)=#$A8HEOL~x8}u2MJg<55~FI@#~xh!K#^GMg2Fnt<+"
			">Pkx9Yvb3z,>l>r*7dX3NWeXP4yq+&kDaQ4$#^YuoE{cA,EG3&-cc3&J^B;&#.Wg{6n$X<IGnliLVrK$_Qxni-"
			"-V)8_l>#cIH8ZCQHG>b~Dw+1;Hb$Ac}J#3OFMv3v%a{BI5z<+BeTep*jaX-Pn|=*D(;Cp<e_3$NZOV2Oh;k_;G"
			"KBS}ELxy>YPiSj~ntZ>JncJ7,#HHg.6azVP-ZX.ZLbho<l7gjZC_4#.VtQzefm&h}Fr%tYWQj4F4ojG5%&n,|4"
			"7@;3,TwsyGT$)3z^K{cHXSxKfYR-B0UbfJ%AZU})*,7ry;aIXo.;UcH!aEgMmRN{KoAEhQRXH+*q)43Y3@B!+&"
			"(QvFuktk}&Tl7eGWtJ5Zo1kqvtm-gGVAl0+vxR^mzTl9#w.Lslmlq>r<s;3ZL3nI3&U3w5{c(ZsT6hV0U0SMPm"
			"hP!ZPZ9DCfPirpB;N&PTv1r>vQS84*btQ;k+_;5<C&Ggev$_,nO6.$>nvZf-z|{Ye{L=fU{-TJhz%mwkKOr9h+"
			"BI7@)V4R&A.8s39mzC%&$,%Y~^6.BcP4ymPbSH+!YsLl_1ekvpQljUK<UdrtcGrTsAJ)xf)b7)L!Rsy&0(;o2v"
			"=#poY3iY&2z4PeG0i^(C!i0hQx-Mo(.5{@-IJ9@aSdvC0(R&16l4E&q!qO8AJU3X86p-0294jFChYmO7;-zIW-"
			"S#_=luJ8_$CF4s}{Z7^_5oSq9#!*g*MUawDT1|.y34L^~OkQQ<E!kio_Huh,mClr!sLkA>vC_%6bsCY%Q76G_O"
			"(,^SN^O#>w>*4ao7NH$+p<CXr8#NL=QAxid8Cxnv+gqP+}RdVc~MqxUR*Jr2YrRYDb0yJw@e&UDrx3+,,s<hV$"
			"hRo#PCAq_j|FcS~6,w*v|w@lxVi8lJCI}V@FvT=PPGai<l!Gxox}KlQb&DhCwdI@G~2^0pF5~%a1vCb63-^9jE"
			"KHceiz.!BDV=b3.2k(%N*@ytK<o)^*b@EqZQuQHrzC@XD&@D;)O;J$d>1{$C2iW%iz7<Ax5(f<aewcW~wR9ldw"
			"vaDW~HY)f{o{GGWr!x(5TeWLI0+PM>>.t^%|R,*W{9=gowGn6Id{a>=EHgJa}*7lX$1,gOyKPpcAWy{v)Siaoe"
			"l;d#-=L@a%UXHcOPrF,o6*SJZ;*|=T,6Zu~x,,HtKdsIXyY@F%l5ZRe-oKho#>owMSdNuS.IyDxkmG1=MHs_BA"
			"a,|lW|9hwSTh-C+Rv9RT&ne6>RAIAlAD*W^.7C1^0~8vxk_5$%67{KFC%AKy%<v,=lZ_0X=+M@&qQ<P_a5)|T-"
			"$3mi$u;4r(dj)KOmNdmcTXPDP7MvICLYF+8cLr^HZ0@WrBY4i.$n!TRjsD-58;x&eKH9^L%rGVL-2|RGqZloCC"
			"9yu2;_v0IaC.{5|>1Q98+{.QxWGO|#b;Yd-7JDh)#RHBZ2<Rm+=PQ=d8pMtfkpZ1H17ptH+7P08a=Hr)M=dy-k"
			"92_-7>UVZq_JfO4J)z8oT$#O>$.q,{9lk8F&|8LVVqaYy@tCT9.V}%%%<;C*k=XPCry%OsPN^yd1x.!JRqXi8}"
			"VT2EDx+)=DvrK1;LFJ1ijo@;4*NYZAbK43*^H>&IF-uy#wYt$99olhGrB7_BzMW}nM=-V11iv+1bwcB(4ZQP=@"
			"Lvlhsex_L8v.@6=hcK!QBk1,mISem9*(>usS+y}Ih<Y.<5@hdVZOQYVQhJOjR_N5F&P#CIKd+)W0WjTBnlt4n~"
			"6p>E9JYM8Fnymi9|Nk*J=hV&t802P58i{Tr+ih<H9r2x#PQYyt!)yD7ggHt;J}pNYA;o!gkdreXNs6qw%sa7bZ"
			"1%A7ZJFFJzi9IKzwahJ={CwG$)-27M1G.-!B|OmIypj=nv<)pRJs{_4veO{(iDx)DZFj7b=+ovW<Op&X<p{4nO"
			"@(aTEcMYZDyfpS4Ct&ALnO,0gLAxJ~~Zzx3u+~b~o8}Lxjju=ARZKEq<mk%wP!acAwQ)P)MGwEthfKQ=y^D|M="
			"<s1s>2Yhw(<CW&kJi~=3(NP)iB~IO+S&GL*FqcauwPy7g^Xgw4V1y;ADDmc=p09N!Tuw2ELCb=)M%ZV!JS_3f="
			"4gP,.6Hs{4H;2+FyRQEbi%*;w.3Rbm#N<4I+(T4L_k%HBPLg+g2)2RT-kwYX8@wdEx2(SWm1dZ3^RFPND!lEik"
			"iaC;Z!lM=#1M)XGViUlRlZgyp5U_NHZo!NptqUPpX1LI>8D9JR>EH!W=feD}gi)#!-rBFtn{G.s7$VYt2OS;Z8"
			"og{oOGnLRLOSo17_{K6#XC6;j9;#FkF@H4y;}&GkZ4D$Y~az8d~t{9eVf;$bNoQ#f&TMvG%C3DPxFY}qc09n#S"
			"iSc-!H=d$Y;J4h^%(qWOcC4wTUBci)AtT}0gWO-|3Md$ZeVY^&TvSdrG>A2UYc48YLA;pHK;AewEDvvBDM|..j"
			"2C_IfNwq~)nlp+mBz%pA.knH2rhkl>3#&3pw1C.SO4~bYI@m1*o>}5<PZ,vdD<NS%B-Dy6L-bc,L-$>*_uZ6T_"
			"eCVHL$xzj<uOM_X)2gxOl>*^Oj0wmu#%n<P!$.Wr3hi4E>2<%{#6W!t|Qk#!(Kgn(kz>L!8OI}z10pjL*SaB<Z"
			"aW#;(RQ->w,xeg=&BQ+jh3s2{j=o$RZ3MN#L&1w@;f5sKo0A._;|Td*RmM*XuZu.Ynw)uB1OBpTXA_W>i#YLnV"
			"PMBIP@RJR2M#ja,=QJ-A*A==yye+UtF$,bsF!e9_b,t&D9v1IaA*rZ8JpZ6=,&7}g=tnH^9ljxQV}vfs-ia1c6"
			"$N$-Yi4g(.(j6a{i<Ex(xi(!jWOK8iv+WbwlepX}E7PDCjQr5~IFAA|jFHFh^(PT.{vBQqTLh$)GYk5,h=$$tH"
			">&VodvxX2ykP++,RC|3rZWa|aj*)Rl6$xm7O7DxS+0.5Uw%he<*jnC8*CXpf*(^#3.I#&F6;j7ElVB1_C!}nh^"
			"1(3y(Ow)SC1}MGAp@arW)8<5n0EVilY|T!8Fs,F@F;7|QP!R=+2N}U>GO4Lj4Ud.-,mHiv5Fp)5x~Wyl2;EL7F"
			"UX(eRVik>3MNK(!-~0I9J>4<J&DrR&#Gt,w5m$w.U<Nvzd1DEA4-GuO}*CO88hhJun1;jVWncH;!Ibsa5N03g3"
			"+Dh}~GmP{6fNNckMgHOAShquT(OGD>4UIsap4Lsthi0X1rKbwv(}61&M_pSK6q4)*TXZ%M356WzNMk{ma1lB1w"
			">>5SfugT@lNHM7_5yA$PFM%AWvjGB<eRN0,lV5.>~P(m&S5FfGET=9<TYvYR@9NyafzpjSjfXShOxl)R|Ikn*J"
			"p1yv1UjV9%lDfi9pmJEK(<9,_v9Pk28!-gDcEeXkTW!*$p&27~8!@xK9Gr7AVVNPxC9sJXUJ<NhZI>!Ls)ST5b"
			"w<j<_|uPno5Ryt<l3PEsRn}<<EKY2C&P.i4<~UW#*L{,uC!fugFZU#lm,f$qXc;zm|D2z@v>UlLWv*}&8QJ#G>"
			"<aVcC><vC3x)B9YxcfG&{L;$*@*H<yy@+RTgoCF-HjU4w6cSC_I!T!wSP(*iG}c-8fR+5ag7J-Zrw%L,ENO3n3"
			"OEXu6X%ARfzRgBVtZ{UXg6S4}ZzK#i^k<$ap+pm<^-dexCMZJgcKC(W7h>oyB;xynZ&25n_AC(;NjPTIVX-NPf"
			"q7Hb.7Iy%F)3}&bpnTFP5hOO~24J,d.6<&!Z=TAcj>8,;Qk!V=LC$ib#cv,|(S=u4dGYf,oQZu$0!6dbhApZRH"
			"<ip79eoq{GX,dn9BL}vN$)733@KTRNMQwMYm1H%^9&tws(Ty8TSyHSSV3bt*1E|o*5IjK{90M6Z5uEzri0TNzR"
			"C#6yg~)+,LT3QRa2gR92LMJ21Kb!RBL+kW5V._&Vl*IN$^eY#QtW_0fq-K5J>(1+nAClc3>Y&81x^Boa}Yh.Oo"
			"hSJa3Y+*Fj$HhGk}=@Wl,$iX2S+Rz%W37sd}>p4CgQ|KoA8{+#q1CL}meM0N@CW^$*w>1VE-hhQpk|FeXKPfDk"
			"YWWl=%|AX~sNV9o>XOb,SCTnWs~0t8@;$Q%I~h!@<L24rSH8G<7q4&V.ldWX-MfM!Q.J)GMwvzq%hTwh>;&;u1"
			"LN2_oM129AZ5Ho<_V2sEaKzInn.g8AUK&k=qfN&o^WDFSqK*Z(<0tR3},z3pk8IcLj1=#~5*bIO(#BVWhK#vlD"
			"1yS4}Q!AJkxHuFCxG+Qx,z{E9kpMtchysA5$X=#E9wVs10|sPgQqo,@_Co$x7a@6rFkl(L0)fmCf~fQi5rQFom"
			"oP*R5v9QaI+O=df)@lpilc#pG6oMBu.QA,5C;JQ_~t;!jD*3Mz04U6gis%PV9XI23Cs|<FkoB|I0~1iFbG,Cfd"
			"F6-Dvk#-0DwG24tx#+%OFGu#qMNALIv3~D}X@E2p5+*juRjZfsp|Vk&(a=9qIwVOo2@5Jpu#)fIxsU6U2&OK>A"
			"3*0We1akrCX4^$rF{G6pAzflvZC1|op_(m8-Yft}32BAmc5U{v@3cLYG-C}2+#DT0B{;DNwoV1Ock(10*8EPyj"
			"Dm#F.>0|sD$m<D850KpW<Op7d_TmcJ$GAu(K>IlrBJp(X6$P~fM5I7Cy2wVby=^#LWnI0gB2onOR;WM}(K(P#S"
			"fT=J%M{t3d7cvEV!2Nk-K!6|!$QT3#P67o{)j5#>K!HF&zbwIkK!6}b0f1nL12AA2Km)D*^udXML=ND9A^^)Nk"
			"QFdG<iOxrOio}PpbDe!Obg6R82~_lFkpeqiU-mN5oIuEQIUfH$^nc(zhD7^DT|mp+)RNG1SVTHb6kNCok)S41q"
			"^_JG2Q@(gb9H_c1RiAk6{83IuT6j0l<C96v!RO5Cj3-%n+Ca0YK<eAp;;s01FZ0m<5p70UgNB1waVuG&8s>z+^"
			"xX0)S#XM93dC;By5sC;)H-LuEr4f$!!$f@Vco_cENzET@)Jo>@YBvZUvi2xY&7$O1d+0H7*W9Y$h#5dcC3(hQ6"
			"d0-Z>XVg)c}4x{dN0sz76xEI;XV2*ik.iN$Zd1E~.obt<rG85g9oHC^Hoa$4V+!P0(Mq>LeXM30g3K.ZS95U+R"
			")eaeD)x$0vI-$ezGA^zeOb|Y8mje3.7z6>|o1108ET=Ld0%4BmHaPg8G2IRL&SiU%KzU|h$d3Cja{z=2xQIg$3"
			"~_DSy7>BKIpjcJXE!y>0s!.07MXAa2B>}D$nSFi;5tYHF~E%AG$0IP^Fv5L4jDkT0C>)&!hAZ2z=S_.H|yE3!3"
			"p9rBAMLEqGn(h(~PkOU0f$poad1gCtQT;e_B0%Cc^-M+,uqHn89=ae-Ko}>z0$58I8xFxr|}^k-w7WV2nb0$fj"
			"2^p5P1WMJ{(7r{236egN)rT+9$6Fb)ExxKO|^ybNc{co@E;,~jt,2PNQjEdc,p21E,51V9(mik)u*>IMN2AZPR"
			"gd>}g;FR<WM85GD7mLqupW(@u)foU=ZWrzp#1G&fr=Q1D+ix5,_xJ-z_ec%TG4geKEI1S,rUf{lzcR4m*,4Auo"
			"k5C*s1k4aWd.;YgaPS#|1(fmzQ$ML0Td~X!B7m8gB7lK%fOvu;KY|#GPz3=4Vi3Iq=3i1gdu+L1AP55nH5P_8Y"
			"{=j!KpX=Zd*MPLT%$rVAS!=SD}K&K0f2Wq-UpTT8O~==#vnuieE{r,1P<f@pWqEG*tw1n5Iq4H2Mw8A7zKSpLj"
			"ZyM;0qC<8G_4j1po,;0j.W6BY}WoWMXhSiI@dF!$JlKz3>N!2LQx%8W;u--wvI3=D3-dI*E}0eQ,4&4{!(g0)z"
			"q7br>@OV8MLo_4@Cy$d2Y<8G|qjP=PhX4}d9{1,Fu}5p}~5fqdxd*Rz{p5!.fS(98lZP(()o0-=yUsQ|GAK>7y"
			"qAZ7vkVf1{L*.EvDm<9n57X(^{g>VS93J^2*z#Ib@f#.W;I*km-1NOtKlKT%LGMP>Tq,{aegBX=3b1Xv{z!BWP"
			"atMJ,bzICH%<gCHg!wPCVL(joV0F!b)K4pzzM-L>z(x0gjNl-Ch4vl5A^.Dy5&U7*$$f{wfsiO2KrBN~C=K~sz"
			".i-xLn)CTz5wbt5GmvV&I5TJ#qMYF1o<{|Y{~!>0}<4,0KhXNFfzU12*lu9z@Gy$FQ6O@128rnK^(*n<PXc_*|"
			"6qd%n<-ZG6Y!^$O9Q(<%p^Df+M-y9li+eOn@Q)j26sBL}1JpvK>8+Ze!p.WLS=pm<2i9.*TdGdz1vo13HY1_G}"
			"=31Olk+m.8uVxL,o^Av}n^h|7@fTncbD1&H<cFhga)JD4K.!9aHifFKX5V(0Kf7{r9&0b(>GBA9{s!.SKpn+%A"
			"+BB%#an7+cwq|={V1H@!xCJ4Ro-e3_O&Hx_aLj-<s{HtG^Va$vIAV9#mgSpJA3x-A885jm+RRI0)1p}qeBGe{k"
			"Lhvy^FlB4(xlVeAuOl#JF|%Pz12K^l04=~3M+xPW@*pAbLm9wiXK)Pn36WeMnmAhg+X,S7BeGz,$nGW%0%egDF"
			"&.~#%zz>VJNB=0n76.IwE$R#GpL~s1.G+#_H$lyFnfouIpi;KG6MIWMT,V76fy.^)L^!3APDF5pokm*J;JBr9X"
			"jvLu!z7Y4_;.+GQP,^0|Zl<W2j8X1E}s9gSa4I,L=u!p@3lE2!VCM5H8r^uKd@W!4wC$GnomM_7*_F11yUiK@c"
			"b&BgY^>i0%xBHzmFx;6.!*z=1$yL;-{AjvSZmUnziEhpJ,3_Fp10$bc-19#Jy_Wl%;AqlCzW$7^Q4ogO&.1PsB"
			"LBfJ3^F8Irm{iB#T4=!N9B0ZNWm.MCs@+@}%dVnYlhyutI21F)Zt(yL5Xkfr7906SCh$98p9>0.O$1(;dJDkMI"
			"_d1sV2wbN;c|^z%Ekh#*vtSS)Dn-q+U&<ZB21H~>Jb^$1.+>HozcI|fm@_GYJ%&UN5DpU%>y8s3Ko}UD280NJf"
			"fmi0{jltqBLpT4kJb-g$$nzWd<YmjnGKgI)T$<8bBA0&*d8OYL<oTpnH&a$N6pR2^FWLWp8#MPfL*cc,8IP2%o"
			"&3)Q$2!n=oFq)hioxU0gUkibuSzk6Cwbz8#%c.Fk%oaftWCG8W9*G+%n|m*d,951.i2K6C(hDOc_pa.~N}q1R#"
			"6.12P9V1|z7RMSg95$YewTgMlz84G4.^#BeY<He5,qDp_A)mPBw2WdTX$ICzGKav&gHI5Pmqt^t,HMCMoK<oN-"
			"Nsvv9x56b|6FbIbyHo=zR(nDp$$QfcZoyuhoG-P)&0JjbX2#moT2J;6w^K){0(ZGxl1b4(tj01q_JN693%p3+p"
			"SJ-o$0}<jUa-8Aj42Wzwk>Wax1Gpjvc#Mb%-<y-p0vL>p5rQg!dVnY&xY#nB$bci*Wsw2^@e.tW;pYsBV,0p(8"
			"4v_7cpL|0z%W^GzmdsrSUZLc8I<N^1PTIXQ<=baZ_TjCh0GM{0d5p5iXO0JV1@5E4x=G5xCe8@5dx^3&&a;NFf"
			"o(>C<+(_QK6Y-GJ%4G=nrPdU8Yq8K;T*cSrk3!.i9@LFj)gJ1AqtK6Uh9F>+.oLWC0WaK7sMbu4OVHMKT~$0L%"
			";GCS@{*#vPN&=0F$*U2qDg(hR|5U9Fn@;16*8nSub!h-@+jMKU7=IfDR<5tI&-%5eBY&@O3%BL+r5!Jgp6P#g<"
			"^6vu0uUwC#*1DG&CrvcPvCJN.8aJ<ZbC=CdK0)PhqL{Ryl4xmm0d6^IdDpdfWI2Z>q=H}Pp7@P#k=4Aj=x#A#m"
			"*a#OWV>*H&hsFTl8^<b+&Q}GqAVdMw0>m+$M98_kjeW4jc!,(>c!|$oDe4*+GY85bPz*)zgvfwAM,ZE<_7Q+(0"
			"1Hs;k=z3XJNX*>WADg;5CnGsfS$qt!2m=7_k$V0F&D}oMrHvW%n;eYj1iaya2XK;1}amX{Eka*9Hjx4z(B#,GB"
			"W_dR14}1XSfJ_Au<FG0gUQ0nfV+D3Y-Rp3<BIVEU)BWUZFxMlm}$)C)^-nW>pO,sNP_R5IT(rfY^U1Ou>uw#,&"
			"L-z=0MbgaP%&g^~Fe*Qf%h=,)<ckRsF=k8pufV1x>yce#;#5DEZ{$^$}~,4gX9Zy*Q>lm<pJKOpUh^zLQ>b#(&"
			"<Kp6|}3_=7z&H@Ke-aiNzwjD%dI1n.R4MV19+9,q{Pynh3h(NcP2a$OjF$_lm)JJhSkP|IJgaJSi1LYbX!XrPF"
			"JBC0Q1V.aKjq@F%obsNb1MmU{48S6oI)HT;pRWMS83B+60RTnY7@Yx59@uaq0L&RwK%h6wc8+-Eln1Xf1Ypb<$"
			"O5<,wMLg9VBlIEz#@Q|f+13X2T;UN8}jY|VrBC{P5>St8~,W|q69W,S,)~z0(Bk&AVek)W%Z6oUWYO$42X;aya"
			"5muEknyN3~bm8_8Db3dtp=b0JsEO3<Cr}K)0FLPbrspdZcDUXOYe0Y~~}q$j.w>I0_I201vi0a_R.io>Pa;jSR"
			"rcC<-4,#0~+B>LCItln3-q=3o#8M0X*xwc4D@cf7&CP=(3^$2;6y%mM&,Ky;ZHDe%g0_#hMxfWcxqNX!r-2LU("
			"~@-4s}N70xm%obAwSqqQ^0ZyYLDT$FlXh6U.1~Y&u;}4WHAV)K((C=^y5jl_tQNkFMz#v.sdG!z}%&I6xMF2z&"
			"1F}Gc!I=X*M-7)CV6rcQJ~^2SgCGb@0|Y=AE>ZFEo<sqFW(ZFr=GZ_HKoL)506oKbfIxx3cnpDw^%;W5q45TpT"
			")~tEMqm*Nm=HcuNKYxid1hn,TpmE.HXHyr4x>D-W<Xs0(Y&@8%Pe8<hMO*6UI3<dfT4rEPp&vac2glah#vv6<A"
			"E8LBSQuS;5u$#5HM$m>L3UimQ%;+he.73)C}(c4i{iG7hGkIQx,kH1A$@zKz2-s0|rwe0.5dKBB<bHdzhTd>Od"
			"_+e8F(Y$U=1BKtTIovCAw+!.>B4AVgpgAP64Hmrx).WJYBHz=0WMkwfVRg5bct!Ha-.uysOxQ<xK(l|Vd0WOW,"
			"{cMj$ZfdT-E2LYt|xMU&qqq2JdxtIkqfSC-ZKKLjWP#)mS0tN^e2XIp|DxCoW#CHgR5C(IYhtL3U8_aMAFmM2>"
			"CSzsxc!p5Ngvw<A4geiQ%or6sMkPsuC=Co{F%OCb;0Vk>fPuh3yup.{G9m&6KnS2bvM>l3APgCZ7i7Vh23br)."
			"#F=45gx+.U>!pp{NPZW-~qq_fT4g,jsyV^25,So+ygS4#6AGaxIoJ<9;1PYkOoET29TapnLsfJ79bo1%n&#Vp8"
			"yOL<{|I{5x{r|!4NJ4W(57{C=~S#CPgwR0B{o^WPGC|BFb=wyaZ=>0xO6cY&wE6FJuY@I1vC<oX8LmIe=tPI1G"
			"pa$f5HFh5_Di0,LI7bZ>.;AVx7b08jwn2!TLkcR7(m&jesV*ovSR!5&#<kQXp!2pB9x.m+KRNsFJ<09cHQXRyK"
			"jD4}Eo4gscp1FB$*#KD95finQk14)gSpA1C|5&Y25,LZBz6Chym6f23qw8-veUhsKl0fGi#i0^sgAb$vD2p>1C"
			"6R2X@P!0oui=5_L58sLyBE)zKb32^DnE+opI%ZtgnHECu5G+LxX3M|=,=P+d0szHMlNUG@0U7+E*&^A@MSfxcy"
			"wDHdiI5;w9V8}OE<_LM#{&dIwc6%7f-*k%BNq4oh{^-NK+FR$Q$2.QV1G_E7XU_N2p1@s0tfE{89+eTilee-0o"
			"=%dx5f=)>w+*)0J~s}AJhO.f+8A=BPo@^e9#cYRIw00#Q.Dy5ClS}z<.s=*)s2lS{mzaoqUF50fK<uL<oVOC<p"
			"TgaDf14bH2-plm>=VxtDBkw<k9@Yn!#r%.{N$xvo_l2*D5qKQIILfr#J%LS>cCqY^33{joc2^}a,~uaG@#Jc;_"
			"=(F1@70>}b8kzycQfIombhyx-3&U=PN49Fi,aKCEh!>g-@3iWvYKX3_vL}moWBm@iGj~,vk83LIQA~*stRTL|o"
			"w+$_@,nXO7KtMu$k|QDj&f@SCFbW4d-(WvH5rU}dFhl_Z0t5sJjQK|M84w~oMGO(*2+TmW9WDr=G7~SD2!MfTV"
			"qg>j5GVp5eX*6y$Qe{*Q<yMVfjWjEQfZY#5UCI&_@hHGVBjWTfqZ~QGJz41KxkkQ9wKv@0Rq$@d;tRoaDQYn*K"
			";660ilo}U2#L0Jwq*E9.RYb@W=w3z#wKo!I&_5gb9Jv5gEf=Esn8hYo)c@U2W%UZcfB6*&tx12uzBi2cQNBpfR"
			"_A.hFD33>HufMc)9o3K$oF;77By&CS~KJ6Q8}dtBQ#cDcJ;-LBV>+Q*o-b8~cdtIS6-sM2IW&H#*r4}b(meodP"
			"pf1lV4z%w94kT5{O5rcpSQ39w1xDg)6a}Avw#oFfCk2iz0&CRo$XKS0AXE!#@nDb._{0PBfegI|+36LN~0omE)"
			"c^$7K$mZ=_PI!(4CU*koQM|w~2=@jefb5Vn0J7oL!>d;fI=FRZ)zzzqtJTA+E*WskhYshD!>fmLt0-{r5ZFcx7"
			"&8Y@#84hxz}O}M0|0^4beNff7czhc015yW;16&Ih$9E6beJ%AG6zuu>Hv%#&fw}8&H$zbO@Y8byc3xiIhdYP%5"
			"Ww#sL19(fk66!3xGrju@E{5kyH^(,9ul>sK|uK0tHb*GZi)>fD_aUm=+)%Kst,eg3DkaV8u%j>W~+>*|5k1AV5"
			"H|5Ft1S6y{)$Q0$R_KoNsFk6uIw5rAd^7.=l$_~ku<WCZ%UxNysa$jk}c_XryTfPs2o9qs{@!4L!iR8WW%1Pef"
			"9XFWn@4)=iRBFbb88Ne}!7vy9N!R!PG7zQuQbC}udds{9H.m)7=!D0bo7>)vFV9o-B2%rSuK;TpaWw>ZW1o%KP"
			"oCM5)okcHmDu8evSs4PE0W-N6olB=F^K%KAA2d5$Ij$yMtC3<p^vn.%42Z$(JDGz6APA~7AV3{N3#bDHJ^;b$A"
			"4X&h$XpQ}%xo}30oMH{41s,WQ8LK+xu9NO45u<3uUpy^AVA<gIgl_8<^{o!APh_$M)Dv)5%d665Iq1O4g-Nq!0"
			"PJCa4d#I0UQQ|Ln11O84xHA84(yDMNnB~JVgisfa;kTFhhn@)Cj>;P=GB%LLgv3x0nZTXHW{GeZl1j8PuRS5rA"
			"X.R6xLi^n(U2K!r|V859R(rU)1_AaEKGFlPV,0teIq5tuLw5X4m*%z!fj2LaMT_n!f.lad2MFhD@a1Aytdg8;<"
			"(su+)OA|V3s127C+!OwxfZ!-oA$_E1KJDCF@L.BZJ4*G-*u5c5|WM={XYo0>nciGKw2pBT}fr34N$gU.d%ZCZV"
			"><$Cx$QUqY2m,nTM{*MfsC1Yj0L&Z!J;T6c4,$1NcepqYEU(O9h{4aOz&HjWQ=kM;A97g{mr(-~>L4yJu&2Nf1"
			"P-DEK#l;2gbyOwa6)h|A1tOs3m{|x-w{igI1UH1Wy}I70XPi^5S~yJJA<ePQA4;W4=ll4!50I$fz5an4geeoff"
			"nKEk(eQ};D,ePd1a_EP6M)Mvgdt<2l5LL#CnISVqm}{69VJ,>I7s^85lDFpgM>G0F1zaKxkJ0&H,i%9Y#cCMn_"
			"S=fr21s07eT.VmgK*=m6j-K+Xdr0M6p4kTWAO0-yv.m@0sHiI^e~I**.ra8n,xflLrEE@lb>XK+Ugz!3s~2iqM"
			"+1<b%OPyo6G3<7}QU>N{+sn8e@C<&1OP#g|qcQ6hE)4b*Z07M7^APS-fh{(Z$1p(P0U>V#4DuN>@096D)wE%Dg"
			"VCr4KQzHaMQ<=a_rU>9Z8G|f=aO#;56Q2MI_o$)F6bAAz3=u$dm@)(bl|U#0BQ8<gDVPKd0|fxadV~wm0L%k27"
			"r6,EpeT1CsQq~nn7=m7movGT*mF9Gk<17fC<q=vfdF+K!Uh3.0On8t^#(K4C_oiJI*E,la4q8JGAZQ%3!p&vf-"
			"8eN!2agveSjD-k(e{Nl;%VMfK>qX3J.XTF,giZ6bADE!I**20uU;Ia2.5z21R>=xj^*~0hl5N3>Y%h0b)CbCI}"
			"e<1|WJ6A_V{rpoj<_@Ma7HfMOLqM}WXE4)-ubAbA0B51SF8Ow1id^8knuKmvdV0s6#d0iDbO21H<im.I(v1;Lm"
			"&4#@+(%mV=N5Iq492iG4A!GkaeftdpYV<Lgj36uaR3K$27fxvz3.g)&59moSRG6oD>9Y8*Tp_njzaWepma0jSN"
			"hy&CJfmC)#9n26gX8;ZW9138}6-5r<VtRuSVlp5,2)Y0|hA{&oBg6ymfO>!,pD6SuK*5QT0sw{JG9W+^z)*o5M"
			"96.Dk6u6#m.H)O1GxbLV=jOSqL;ZAAReF#aPSxg49E+aik2gR3!T9M1Ar@ofW+7qAYKN*w+,WeV8{.5I1T0j0t"
			"Kjd4DJk!!GL,MrcgK$8H%3pEDXSb&;l$*M{_bMz%d_)WMe7hM^OW7o+Cp91nO9VFmN6@fMUi*CIOrZ2E{lXL=Q"
			"j+j6nB*K+Fn}096~vrVJUtP=Gx{vSdaG5zLRE1H^AI3<EvDjLM)C2J<2SfPvI8ln1LYV89.*6v(jy6Km|o^*Y~"
			"q+|Ktq)WzU^kY{l)W(=Sze52Da3>Y&8U>G7jKw|=^{GtHCiGg!6ET#yiL;+%bdy$>>7{5XK7rB@-1,H4|ScWOU"
			"m=>W!*|PB2<=pRcy}_N##qX&61OXJtgz_RiLWMb$1rGN=q#mh&QzHPtG61InfFlEx=nTfA0tdKI.{k2mPGz_;p"
			"5WKNz!V|}QM|zeJD*$w_#v--z>LNwFH@!V0{Eh3G6zw-z%U4)0YC!!VL}@(Qy1@.!2o|+AWQ{FgvtS.Pz*=(fr"
			"xUO5pswZ*$5Rx4|p&L1Av*31@$7OxOj*k(hkWK!GL4|Kv035KsW$@OejPLc!c#A*$NR%;5&v4=0FfIRTCgUzL*"
			"23)L8&v8Po&%(cmJT%mV~vd-lLRKo,UvBnS,&1P-8x2oV5ZKqynl>Qn;a2QVgOPzw=50RAAMfKULc0pbCCQK4l"
			"sBE$lKp%}iP4x(lOm)3$HP#PKB1NuN&5x@}v1Kvao7%W9g5D)7>JVXcx832Dw2(l<1Bf&5)a{z.$GTbIW5qv;I"
			"Lvg.Y+$KO7ec+i)jOr#t3Uw_35WV#PRSakJpci-o)EJNA3Ka4xfKUumfbJ1aWC$4mRT>$BBl.j-AYA|+;0xf53"
			"VZ>bLm0&1C}so<h!)@r=m0K&53T|H5xl37f(HN!0gUPxil82$k$^xSz5w7RV1ap|i2j^XbG,Kl83Q~<qnyAqs0"
			"9GTUl4SVAV3f=iak=xBRsMM0RjeP*9>K-P=TBPKco~e54HjP==94hu4H!x0f0mcpfTkEyoduZPyoIl7sL@6_rN"
			"cdI*N0>%<pq5o>wy$Gt.<^2e@QJbC^GfG9U;Y-~sLwAPeOQmQ&bxjHY1B3Y|vt2YHa6DAHwf1@J),2pIwpEki;"
			"w27fd+mkF2zPz,hIk1UMAoX7(N0qOw$@G+jDGcXFE9wb1E<O&u=cn;wM0KrUvE>K2Ah^5TR2HOwm0})g)6-5YK"
			"RDt,^p=B@*pcDm5APfR10=(y_K$sWZjsyV^6DR^ORRH~vnNNXisp=3W0}=-SN0C%{W<Y^}KoB!8h$cXRR8YX#Q"
			"NV$NFbmlZ&P8+BWI)KOC}s+v6b=KZz%XFJ3XuXod.rAQstCbUF%$-d42b<;o.HmT3vi*4o}r2A0H8aB0RTW;f&"
			"0Kl3ZNIV6P,q8h=EK3Bg9aFh#ug^U2qTSMGP2$^bQ7PFbvDg9a(TY+yVfgbO6s0p%4amiI^}|9g-ktvt,V|eMo"
			",$;D{ImKoK1Mh@M#k5HCOx0ATKO0D<18$^mK+J_7UMmPBXpKsW$(5I#|%jer-LH}J^z7zc>%5d$JHKoLOq1|d,"
			"60fGlIft2z;f;bU.KoL{|<rE+fz9w8U7u+CF9h,t72155fQSi(H1OWp8fFrobzMKPq(7-b&379Z,$aI!dy~qPN"
			"46b72SAYdj#(m(#RRHQZ8BB%CfqUS@Z~*lNGSmTg$DzV!a9|h)V)x3Uc^Q!%&$bA,z<LB=z%VXgT=Fk,7>krlh"
			"{4nmgXkTS>MNN8Fhx<|n7NoE1ZQ*a08ky01_1$bF#^yS;gNhm##oGq8IUbN7bq$4oDV=,0YLn5FbEL<M0Y<Bp#"
			"X3msSup*K+F*tl*{0X5rTlBm@hbQp9$O$I1UGJb1RutXkcu)_k_#.I1b^F0tO7,4gz->Ouew+U>T7a)B^K|!=C"
			"|r>@pw-0-2Zwa1$aIKKS53fdFNR,Cx%u=0*t4WM3d~AV3ir>KlxJEyL5F0egY~h+Iq<7.yw#*nRQYGay6^j0hg"
			"^W=1w_fY7dUnSD5!f(P3G^$)+FQCtE5.q,-pU=RcfWqpU@9+^zQxCTJM5CyYP-avq!MeK)U$O8rl1JoFcu04KS"
			"4,2jfh{i(T5kO>M7,gevgkY)&$f,0qkRmt$Py|^|;|>G}5CmNUh5^7+E&%ln4)e$zKsXHuf%6}%9YhQQAVBdR0"
			"|X3+10pdA,(O$Ih_MW307fTLBe~)_jAU0ZKpX~y1@<4T8W<wDfsh3O>&StaAP55l1oEG<7@WW$dxzx^A_P;&T<"
			"&08=0|ffH~>,ycRyGN!N7(31nvrRfp-CbMr3y^r{@5Ag$x<>#K,Zksyma)V9H>.BE$oLBiMe#dx8Ssh!Gh8Vqg"
			"(Kc;o>BD~aqGWL{_mhy~srfs2,tBLe1PbEpM~-avppWA;O,WC+B;fqlV@-~s9z$O1CTerTb9T%d>+q1iK;8G|w"
			"c2Qo4<fCW%Qdp<zmKo~Gb0il8bsx+7cLI(k)#m;l_08k7.sCO<55Flb.a1b^J0p;8RAPmS5JD<WGCJ!S72%tBZ"
			"BAF4uc;*NZgXRZw%6=fmDs=$rH<&OcM*^542Z$mC0la~O7e9;,&Z1^u9Y*p73<J~wR0+UP&n&ycBL-m30E,x)L"
			"zp^@OL!n)!R,b={tyLFJ5U{y7ny>%1XzL~bqqoWFn69^@C#5QBGf2kX8;dyV>*T*17J,9{+tm4sO;PVBL)E-Kr"
			"BT{0+%d{yfPp}0dj^SsADZcgaK|E5f}&b;fS#Ssv3JBdJB*TP{dFGpde*F1<*AV0~GZJBY>F$2Z&;wKs-eV1NO"
			"rsFbot2ra%xemcuYW7zY6ZV0ek0%OczefmBX&2Yg3S7z7LuEx.Qv4|oPLAb!{}6aXwojzkO@WplU&eE=Szp$&z"
			"RZW&C0096_pfM).i0I.g)7,P*-nGni;_yT}|Z!;havc&QRV8QAXFhv1NmPM#Bokp83KokWC0;nSb2aqsejsb|E"
			"Df0P&{1L-pf*0l@sF{.(.f~i-iUI,zOO6w$f%gG}A^^;R^aeB3JaQmFhzx;|AJl>{TZZ!!273+yhAwarCIX~D&"
			"kzcrh=wHrk%4eUs4<^hWiSYi|2jJ+U=f2b4{+XNA~Ad7JBM%#ft}363sC8q0AxTM06K~gGt.$T2tfCP0{x>9Kb"
			"-*TAYa)4frBs%1D^mdu*eV~2nv)13{0^UDS=bOOo$OcK=%&;kpaUXWiWU7LIvx=5s(}R84v_U4-ui51XzGuhpJ"
			",O!z,v|CINs&hy_p%03IX2WM&4=&>}nE>BfXcE_EGUtC1K60YG+01HH_^Gl2I7U=Rf|EVytWE&;%AGXRVXN|Pd"
			"<p^=dRa)51@_=B=w5C#Yl)B.l<#AtgA!BjDoM978qLirdma-0At0B{)@g9dOOS%5%+Ob,dK{+I*QC_o;e17KQ("
			"PGG<+M98)n#NZgq5DuUm2Ld2K!5jq)OhAZS{_uAUOo+fR2)Y9i>JT^%;eciV8J7vvWI%v9z{r8_0H7vB0YGpe&"
			"9H&&KfDccsOca.0hl_769U,_.s$Mu8_WW@7l4@pAp)2=kzycxpo|C=0qj4f9aACzfHR&Y0YU(~VwboOKH(4s1@"
			";M%>Ju^qPynhjA_PG74Gh6v|41l%0I4t)BA5_9*dw{XvH*ZP)G.MI90r64.r;QR@HV;X8ct+;59vTEh#!^@o0t"
			"PIcQ8P^!^bnZf-@js5P^^f$~<xaz%nxiWL%-Iv+w{Y4$Q#<DVc&lWF~jH-Uk2*0f.#y$W-af2%rJ#0QCaDHqWF"
			"R%mM@i3IH8M%oslq.j6Ap1V&<T9~,C#8IS}(fHMR@9^l7+qyX^~xEByD!iGgZG!g7PMJ7Pt7|x.20Dvq;qtqDh"
			".*>yK2#x.2p#$@STtKn_fHTx6MhkFa5IO)wP{)6}6fg>+Wsn7^P=w3Q1bo+k(7^y)q6Gm%AU7359sU66AUTW!+"
			"1h|(C>anhdK+fSh#Ub-&Y_IpOb()@P{)5fOn@.|nd}5m3}@_xFR&B<C>Z9%c1*xC0Dvt(jPLaUjPV)}m<Ix=2l"
			"0VlVZZ~0*v_C70T3)eJVPD*-~|DZkr@m2z%PU{J(mEB5JqJIp_m|W0ICK3sPGX21V&^=4-gCC37*Y>VnhMrCPV"
			"@16FZd4-U=8Zfax$MKui{(59WqPa|8;Y7NJ8SdWsp5dy&~P0LYJ+fqUWEER4YbKo;RcBE3zgKXM4cz<3ORFbo3"
			"#y|9^O)D8fS^TY#y>LQpiGB96sC}7S6z(DdTg9LQ|{jlyG&my^<!5D#55s^Y{NB01Tgb&LEK*Y$w0x(|KbdWQj"
			"0CVAp2Z({_48SkC8W9*F0)Xl>xse%wUphD$0B4sBw+a!0!~*vqh#uhr;ASQa8T,;91pxzKa2XuI5tp+NI)HE;k"
			"|02V5rX-lLk4vWXHdj&3,YP80)zp6%y$eKfJR_}{OF+=5I#}VKo}rEAGH)P3ZaPg4h9Gu=X3bOsE7~*K+jO2f+"
			"zwocz|CpF&#k^%W#>4IrxJV@yWPwu0n7b8G<7aJgxzQJwOxyFQ@>u3K@,r)M#MtN827e_;qmMmRvH+hFMJN0aQ"
			"%EnN$MQ0b&7s0Ye5_gBXES0)T0kTzq-tSJ,vf&9j@D,!)kG3>m;N6b_&lTm$$5gkWN10pd6rf&%j{Q3C0,!I%a"
			"F4T0hTLVh^{AV3)u=aG5f7U8^rGXU,vGY8%p7Q+Cy3K@}9F%%36l)xf5UYh}(KrcKI8R7wAGB5}N<sPXS7zSVv"
			"1_;j(*BF=(GP#!E56>IO7%&c.9v~Np5fSbH,(lQ7I0>16PypZoz)*<G;))RifT02.3K#_d4xo${;0gj~a|Zzfs"
			"AD>STYx%%dxZ=Ud*DPvQF!wJ$OE_sdz=Sk!2$$8!D;}Yc!,h(a1$^HywT;E5ClMs6!Oc2GN%q1aP^r(g!0OB$,"
			"jsGnM@hfPWLcaj>(w<APf}u5I71En1R$W79xa3c!(CE)L<9}Cy_%g%;%Ky%5%#p&bfAHl=7ZMGMw_P@+px_%At"
			"sAE#Qp6F;gKttH83#c#RAhfl.rMfCW%Q3IYd0DV0Y8BQST^eS6IIY,yEV=g#M{{M$LNvzwaxHeUNLeTF7*0JjP"
			"l2e@f5a|cik0gT,Q)MP{f0;tG=7zY8=XLA6I!Bh#<5dwe(PznRnBL)l+7$Pw<1&AUC0aAee$pbr>APgDbW$t${"
			"49I{o#AHAj1H=P>$bkT70Ye~g1Yqhnm@)v)0%if8;R2X2M^U_hGsqu6nSezBLoyIP$pQps2#oaz7KQ;Cz(C+VG"
			"Xmyd7&8P$0YE_DG%yGiLm6T^h=I%z13H%gL<Ptk0K7I<,WPT*Q9=eFVs!;FI1S,LfI0TX3>oSh%)lT=h=DLD4x"
			"%zJ2oNX^lLa!^3<{Pb)gUL4T+VzlnE*ur<J^cC1VF$tfZ$+&A_Y-HFd%RfGXU,&CIJ9IUr_W610W0-1ZE2nGX_"
			"Ngp#!;|BO^PU@(.gp%fT>rJc!H.2T~wYfn*AOQzEFDTm$QXRRmz*GChNs5UB~kyl_*Qn3y1DGQ_3~0)UwV2LkX"
			"IAa@g)9rj)az-85tGZU#$13g1R6EU+9(q=>m13pj>pisal0B,,{G%!R2C*UF*3<5I%iUE#rEiPbzz(Bx(5C;L-"
			"z04691,Y+(FLMBf&6mV>NPz%gz&efO3<3fNkOWf&r~-hQ85zJprU(M5kh#E4V8DSuOvr)aG9W-1;sI1nWC6g48"
			"Ni.cz<F~c0L*|OW)1_S%oqd#zyg4wgAgg1f*Onn831q$M^Fw0KsF3Y0~62~1|Vz%4uBsuMuq_cs0WDZBQgNMGp"
			"K3LP{g1qb25PU1_jK4OzvP91TJtNazKQ^m=hs6@XBTg5dc8oKIDu70L%jfV<I4C2!JAhflv@F!+,=5$bf+m1p("
			"YFh!,+Ou!^Ima{!1Dh!=1j%*Mb7hc!SdnOu$mjPVdJaApAjK!M!AoXCVHG9x.U7>g0^2!Rk2%PEitb0BA^a68N"
			"qZ~_O2-b4X|zN7NN>>voau4H6W#DIZR5fRjAVtfdoJaZsrJcz&|2T;X07Ly<qR9FR2p+bcU6ev)kLWK$xC{Uq7"
			"g$fiXP@zJF3KS.%p+bcU6ev)kLWK$xC{Uq7g$fiXQU6#a2&1kvmA3Ka-}Qq{p4|I=RQqB7d*8<J=bx_fKfCjCC"
			"bBY=aLzVGYJ@AzqUP.5xKV6Ngkp-83,-^~EYP#O9D.H.R^C))=6!F*VrQkj@4O$j!B-FV|Ht),X3mV}0=z^.Qw"
			"Sl1XmQmm2UJv2gZXd_!dy8s^gi>~_b8s*.Z>!2*IQ>Fll@P_GD$d4z;QovJaqjzAWz+G{C=3p2fg#fKdbg1jK4"
			"}5pP+DMA4C4%zxq#*pKdyD>v-SB|9A8K887VzflLHb_Wn;SlD.na4HaMdA40!C1iIsdf**(W{jY26eaPW&M~;5"
			"),2T%^{$S})Bk=nu^!5Jy7i;R*-;9+P5BC2*{GV_*FI$QD-=X)|FZu@cPXF_LVawcm@Jr<UpST;*MjzGqKa!sO"
			"Z^NAU|H=K!FYpGMzU$!cUXOk#tL^Xi19}Bs*WtW;@x6I3FSGpJi~Iqk|84rn{XcLC|Jwg>H_3pP*x,.!GF~h4|"
			"Har};0-JLZ}N3NPq_qt.O$><RS(6z_|Wz9fByO<{K3-7sZZwnUfevtatSv57u$fa4Yj@ao_jxo{keW%>58gv_#"
			"ejW!^,i6*N@hQ@;t9dG@<XsIr;xLXXXx;S8iY7ecuA|,{9<qS_yfd*@j$wsHZp9ePaJ8bj3t_p8xVWVdnUNPl^"
			"W5wgEk;rysN8zdQm|bf9ovpVfQpyx%wk,ydzXfPZQWZ,sS=43SVMPgp&|fQpf1S8$;,zp(e%,M$6+r,CpodO%C"
			"sg8LtvUwQ&S2-I+AkW@up*a.UW0q8Tv5l6GAPczy3.0nzF1d(4z342iA^6c{fN{^q4h=fogA|)1aD2WA4!is@v"
			"JhxSF=HMr1()wBWK6o@A(gGgTH{(B;I+P-b29h)f(Yvw{B&8Ox2&fbwYL87>Q9x670lNQD^z-n3s0;SMC%+V1B"
			"KgCDfT<)B#7%&~AU=KBLk0#2AW#q*qJyZ>yx;PEw_m~ju*jc6D1.jeK,33r*Sdg;iVz720JtOoT|=^gP$YcMxc"
			"zPZKkWc-wgCS$1%S~)fV},OTm^v18_@lK*68p5s5VXM0S_2&K;CDy,VIa6Yyy3d6Z>Ex.Lbe}8_^rweZR!v-~Y"
			"rlQ_=&,_MxJmJTh4PKkI!yJ^%bcAupr@,%uXLJTy-;.Y<3rpO_nJdO$<kf>xK}jT6oEzW%+>%mlpY=>Wde2KnJ"
			"XSN&gqKHvHSB6>g<+yaZPAdoMfG*6NGKPnx+f(b%>Xl.E5fLuc&,|+cEPxbpK_Wytjg.T-g4ednWh|f,.1qi<Y"
			"X&<EgUmiWbd>I$)gCu<*IQvo4WDdc=SPCiy,yr!#fAhRi.f-~3jknSP{iyNTKyVZw3K!yu)ARq!<M+Q%HrMokF"
			"Srb=s7*p5{82oAoBIB*d*}d9tptvqkO}tyKA}Vkzjh~&y#0R%bNzsqNPDo(x,1DRG)n*d,mW!5,hk.a*bD7OiL"
			"3XYv+MW2KsSw_qy~RxG>=#CzVENz{qP$;*bTq!8aJ8tA4|Wz,,}ASdO$C=0e%4KMFBmR=>5$*KWGUxVeP.1*Xu"
			"w.4HM1#U%Z~L%>=zm.#77VBL3ubpirJa>iq.0_#l!G=>Y!JWQ=GLet>XL8,J%t.rT5!08e%Tzy<nI)PX=xqx^q"
			"tQ~pR~x3.5P7vT*MDg~(SAW)zu$o7AgPQU(vjXk&z@PQy&f{LUERDyutEBfBNy^s1sQN17++Km(h3*H{#6%_)Y"
			"WN^z6=(4ENKg|4JLO!qhMHhCgJ=i4+-yaPE1Pm2,L}URS)&oZUhx5D<^FQkatIq6w2npg8KpLaKsK^#Bp;k*#q"
			"JKy0ywvl5>k~@-2idRK0G,wZ+!+.5(.)oORtk=RB#t1xArvRk|0~RI2mJzx@tR*.0{c+Nnt)n>kRCdKk^(_mKr"
			"Ke}P~O}2o@bBzP)*xUp%jvYsAWt+IDJBj5.rGt4fj9l_C7Ci7|ZU%Zcm{dECPfI7rX*M1.!2Y!~0)l-}fMw0{b"
			"B}5i5OI2~jmbi{1fy;%V+bN91.@+!FflW%fddp*)~U7v_ZH@V{yC{C{#Lqi6kJxcebR4F2o{_rhiL-@o;p|8g,"
			"@pXh(P_a9^^s!jAEm3|<cKO^ycUC(kfP=E4&.cMmIjv,7t(Kvh0u<Z9e$jL+hZ~cE)m&FuBq!f6B<M|$!U%loA"
			"RQgf9LjEW1KC&_RqKL7Ij,*B@o6_s|yx<e*M+Fc1f7bpgMjsSS6CPhBM{G>L,~G*G+4m!*L;aumf4FF,@Bu%_,"
			"n4T#IDQB3{C.lL9286VpNsq#LihtkSNQ+QRUD#q|F,YCJ->20Di,|yyZw,(blverjDyE%DBLHf)O}ZPx9&#u3-"
			"mtE_D+xuD*RESQ+vW+VhLJbAWxU={_BTV!33c_=<q0i#P>hj2m=R~#Tg@0ztiZi)&@uU0(!ll)NbqjI1BKHj-p"
			".~,wz2Ffn^Zib~0x7AJPBj>-(S=-i;E!wfn6)|0o533GYXiqTk8;U$IaWAaMTxWe%V3dY{+9R8D{7_PTX^pcVi"
			"py&5Rj|Hth;ZlFpN;0}}ntMa|!{NBgp0U#;A>OF_D,Op@iC&(Ho.*3=^dmN&O0)0Ts<Vqid,P(1tz+VvHfdY5^"
			"ukpOT_|Z@WPEZ!0C&(Hq,>&q=,LCc7g!zLnk4@V.&dcQv2oX!m{onI@o$*Bqop2VQC&Co@zu5oRhj=ot%o%%vP"
			"tp1pUtAdy0&VDi$LTwr;1;2kIY3%~pBPPk&)NSE4-g6GjJ+}bU*&w+ujc@qqp1;<!+D.9{0,4}1;i2r#07u}h-"
			"FV$CcmZj-^90.1ikp*>DROU|IV_n,@mho3A,#t!S!F}>h*vm1r#FG1k.!.JmF7w^Pk;cFbMlm!_6N#{}1BpRe!"
			"M=IIqt9U)XhbgDPSI)G{mpPJk266!8A{_Uq>W|8O{Yt^QhncLvS=%t10#$M-(-)%E@07p^o#P!r_}bN*-AVe0^"
			"2ayWRC*bnXOo(KF85(6b^|1a2ed*1j7$_WC%1o=Xo-{}7i&te3A+;H%BDZ~Dr=x6>Q>OmB7(fgm{cfEg{GC-jf"
			"U;=i-DtLy9J73EGA6wY~pR*hr;!nBy9*QFW@;rMu2pJ@uAH4s!x9ok8BnwazyaIQ|N(ZC+-_*ao1C#6r2Kic7,"
			"kuAXfAk(Z.NAmeA(!{RdDZItVKh(^aAi+8WT1MVtN)$*V.+T$KoXAEq%,=,^gp5acK=9a;{m}MNxT2=.>hdkwg"
			"EXoDkq#WP,*d=zSBO~WLOR86#^,N*k$Zt)%l<A!GGioX92w&ZvGeTx_s}c0X<;JLir!7|MNUSAX<R60bnSgC*q"
			"8~1pI&0|F4SwBz9IHAY8s@.>apXd.=tNtQja@m-C-#ga>65C<ve;z)=(|0AH>dd58PFzQ1ezc<PQ<bQAhdfy2="
			"Iz(}d<21*y*{{Q}5It36S)DkM{1Bbs1sn;2L$opMio7jKB9V_#{#N<rAlh5k&zN7^8gCz_2->d&F9dH(+iURV1"
			"Pl^dbVhI&G<1azH{.GXQm;BMeKAYEioBik3^m(4-WTAd<=fCj7Pz&!sZ-5CxKn3rNytV%Jui$&BeW1v{D-LgE."
			"Y=+TjFd0w{x9>->A+uj0zeXk.~J_0,bq!C^Jn|vqIf.pxcdLM87N=V,tSWE@IYUf0{O!)H,jhlf1&%M{qUtaQ,"
			"UXB$w2;}rTy3cU.mCX47}e*^6~#a^yT^hi9Fx887N<({D1l%^#)1;1y3+#-%o=t{l60r>ISD*+l-Vit@,ioujl"
			"~2$YtE_FHiCR-*5jw>iSU1o.r_BPbcTU@L#3@J@^UihMwXc)06sV;|!DpSC2po0Z&Ky-}}GRfWPP(ddYsr{vWc"
			"JU=ql>2K51dPw{,;|3WnN.e@Pp{WtQ35kYr_7xTY&{jXd!^vmnNd;K|j;1U2Qcu{|Y,@h2c03ZG_m!U7N{#V(W"
			",=ArNDF5&Lf5Q4eAI||kXl3gY>_1ccTvy$ORPPEe=YB8eeP{{q!zz1Wm#VwJ;{JbOeylR5d{fH(r~BXkkQ2liQ"
			".@eogU|1O)!kpQ0XyQ7|7ZO&,w&Q}+ZlSn_j~{H=3cO(|6lkRd{7_H45{.vFIZo>zv_5p;|ZwG,~K_hz;AdN7u"
			"bNFA-~LTt.+-x^ip3m1pj!VFWCOy-~hhx1^Q9H%^%F@{|Dk(d_bot{}2-Y)5xMDFEo7r|DT!oTzo*dXQ%N4OY^"
			"_D0(~&c%@O+V{C}&Td=lSJ;s)dNKJWzm5vRBxZ2!f>yc;wBcyDj*{oo7dhE)1dr.^kW>i$jo;F8k$;L4v&34c4"
			"S>w_wLA(ygGXS.(+y#O!I0KZBKU-aAF0Ke)1K0wRY{a@.$f5XiBg%CZz6b1SKT%U-(@D1Pk4gSaG|Lya.^7*_M"
			"_W+b8B8mch=x<xitTLyFW$FB%zwiEM@OJ79>*);.1qp}=^PrdLv;HUv@PJ=9cs#$8>i#eKzlUHD1z+3%p7aug#"
			"1sEdZ,1(4b^<^J,9PE>h<N^AxA1+p)qL0pqMIGQxH6}<0W|{8_F4bX0()Q<04JC{9%sq*f6f1qhLT5ZtLKU+3H"
			"Cs{zU<U_gSpV(dHqi)MZ;%>eqamqpp_F)qWYa>|Ih^cz!T0L#jJUKkCL#k7Jr@rJ.JGw<plp%&;7v4o#90RIY3"
			"T;%AEtajRDfqbX=iNt^qzk3D*Um^!Wd95(z;$K_Fj<J1j}1b=ecY*QfVI7s>qW|A;sF7t28$Q&7<WP@gnAC|ms"
			"wuOdSqr|.Jmf{FriiLQT#,=$G!7tb6guiY18F9&fq4HO_$_QRyI_TNSM-O~L3vfb~)BJ=>A@XDKjPJv5&-,aLQ"
			"U<>Dt5y!*KJs%rZ{lFvuPWTDi9Y|b0JiNc5)&D=okF^0c0G.<I$^vu=+w6aj|JEPD960|I{VV;RpC9BW$_%Nva"
			"E,AQuaTcGdspxQC,~{oDA8~FU!(su{O~2,j^h3&>U~)L$KUsRop2N30KEceS!(aW0{@(ER8SNrY)@zOzkBz,,N"
			"P3)tMV25zuo)of4|g<o^T}z01^R}F%&.J02A$iSOA>@h@pH!eoxwegV!&$0X*^9wzdKG.f*r6r*GJRod75811f"
			"X.ow1..0XhWN-G86_eBaj|f(a@pbN*MO,yWhzPWWX{_{9(^R1zwD(3|~V&V7D=ZUXt^)t_>F;SdY|)%!27{GNt"
			"X.*N~u0%,#~&,7DuCoiJ(zi%(ufZlk.u_Z@H43G1_U*3M#;g^&Ga*5&eUp@Yp,oW^Uu&IdNy>IaS57&ICC(Qy-"
			"pY@6H{twQ75&ZDTx,2<r8~OFCI|Zo8|N8WQ!SA4-2u(m#,ryi*U.mCAC)WRW|DR&NbOJzRj20;V)M>TR0,42v,"
			"yT)PAN|xP$N@fh1@DGbs0-T^@c#Sv9;e^}K)8ZH&>PS)yb%4U7VnMk@_nc7J}xSrAj+NbMFBmiq5!=BFDMDPO."
			"+.T|DT,fM^XTwAc$BF<WL2Sl8Di7JY@JXpk9H!e2+,W{e9}4@Duq$iUM+gyMRtnIeWj%|Em9Z0%{#mWC).ajYQ"
			"(0Ke-b=X)^bQ_3eMF>py.zGJNP{U)g}1pf8AIsDIe~U-aAONB.M{6a_%SD5#8RA_E5j!a6&H^TBbmR0Zpe>&g4"
			".-G9U7K|U~=gbDWGCnyU56Rt8)e|,JE;J=(176OQ<upX)ajEVvW5m-qoD7I(BXtE6@^Tu9,oG4!S%MZT)pZC9!"
			"H1&dNfG4v7IYkr%.TnOR{a>p474.8D2i%}V2oN%Ws1el_lFp$X1GymJDg{Fr,QmtYqni1HC;V@7^8ahf-e3#)g"
			"Cz(8rzpurzxckp%3oMNqKXhIFm.z6AW*8#5!RuV>L#HAKv6(XJW@VBu0F(R;r$=${{PuW#0f%woCW9^DCYkc.l"
			"~8}Jv3Ab6#}9%D+F9dis7C6z$^e.ND@|_^l7*4KTG)^Q(pK9{&7VCHw_hickh3xugn|~LIA<wD4;(mB@(EbDh2"
			"g,FP;hH-ymrJS^RID,J1}nlqdXPCZUpt{-4,_(Qfc0RDcNpOdbK9w+xg72(<*Ef9wpY@P.g_uJV6l(43=00YZP"
			"+0%{p3m+<}1;y)<fiV;*UBga7CDghu6E+CXI$^rcF+SBHSn.K>.{*QS(U.oE;e$WKeGEo1;,;V)BQA7x^1c7P-"
			"@,@sb{m2dHf<%wa4K@GO>wnSdr$7ma3Hv}3P{~Fg$@=e>,-g!7phXCvBJzO0b^,g}m^aRiE&G4_fA03p{=gFvy"
			"+GssFYtI}-yKR2B85P{{0H;FBNxgVFZKV8|98r7-wo;qW9L8Fow@}S1%L~P3-<swo(Y0|IMIH,.!VXkz20zTPo"
			"5jp4%gRyh6bRKSKy4L^M2>*|6i{k5DWUFdV$vc$NX3y^Z;*u7|-Gimz((.WBVVYuZRTt;k,iYe<SoPf2afb;tT"
			"JFOULtmi}!y))7}9-xNlItPul;<uKR-,@,<2SUuFV%;Fw40hF1MAweh~Ar8)%^1oVdW3-bT1{V8na1gNzcB835"
			"cARo^JrH|B%kK6yB58HU{|6tL6$Lv1}+dAMbATRpBUpx}Eew1Y|lm3sB@BQsRlsC)$zmNEq*ovZ{nV0AWQu4mj"
			"#{K8S>HoxZ|9A0yb{tVaNC2=CMF_v@0}p-~ZS(_r%e(u3UFiQes}RV)vka*L)A~NACSec-+$f+gU^2hp44-H0z"
			"r&x@bmAEo+<>@=_PH|&,,{nX1de}5H@*IE{CIoL,cwq_fEQ4n-Ds=(;2X~b>VH}.mHuD*IzMff*Z{kP_5h3f;2"
			"+Nf@_(,!O8&S1e)s3<{ZJ$I;6I)T9$yq__x&&ZyZ.LpKo|2sFFXbJgGSr>U;KI<UpxYRcn9Z#M2El=KG){^@2&"
			"aZ7wf>Eo(al-b~25hyZz6=FVzHre|!Wy@FVXATUZ~~bM*aiqJY0>0{P&S&)^LlKdIw%{cslg@DtAjugB^I7n|L"
			"CFRlcP>N){Q)9!;lA3Oo5.*_wP-3G^Z&k3jqsy70B8}5TwAD$Ff3-*97o(Ug6s0@$(u*~W@0Xjd-0ls(>h5XPT"
			"&jk.QFbDbI$p6#~ivT0%f_87H1hJp$f>dAj0JQ>McxR8@0!+1h@GBzzfTAe3o(UG-uymq;iUKdO1fBeSm<dqKf"
			"4B^bQN0xcfS<Dj(l0o4pg^D^udx)RK6iJ|0Kd2aAT&h^7NbQ#5q<b5qWQymgixV<=%yKa>Ztkj0aXwx1w{y<08"
			"ksx1*5OA0e!HXcYed;C(i*dwiH0A0pp-x90X7lCZH3~1-LK542#Mc76YXf15elf^ZC2KR5CBv4$3N|LZT>LLqt"
			"#!bpU>NDCdX09;#2d-cBy8.5Ya@&>Px5KkPosyc70dC+z@AiL$B)DFj.VUBEw{8dvwDMEM@)^7nYZPz3tm5}-z"
			"-&~{K7NE9M~ivcuH8_xv0aP}ic,ft(s)<qp~NT~tt7%BjuGP;BTKv)2^0e#4t&.5Q5e+$z7iXx6tL{wUdunMpY"
			"si+0>fR~;!<cuT{d_sO_v-ik~Hw_RfDpXO~)&M0%6b1EwC%+T),~K,Nh*BQ&,E>tC3-@3xM~<K(hX|l3UxWpH_"
			"@__g|NEbs3()><@BTv~,~lK|0)+v7AY%L9JWs*N@x0%g@d_u!_-v!R0{#Fb,2NGs8hHC{,G1W4@LT@^iay{Ke|"
			"hn|@uWOnPtoJYyeOYP^k}2*0ej!,Q_mVE{}+|Z$Gi%k_UNPBg8csyd+|2zZ|nM<;9dXar}slc53~*FL)wZanDY"
			"096YhKIh-FXe22,jopZqud0Y;)HwFH#Qyb6DiU-AHz6n|y*Z~6hN<NJ{{9Sr.&UC+Ny,UO2cUhDt*DBnBx.e_v"
			"{KDlAIO#*z^dvFQ$<0kq)=6|O(U+4-qr~hX!xgLUV;XD99$q^l27QfsZ{2zg{@bI;t_yTF}KY{R*+>b#wc3=oH"
			"Mk,8vZ~tli!PBRw@BaU-,hG!y1@z#,0y-)L3aAlr86v6$NDs)00FM<=85l||9hIV>BO|h*4.Fq4*>Bm89-b~7l"
			"*W{k!asBVU0=l-d~iO<B92i;>;HTE-rNLGp+bcU6ev)kLWK$xC{Uq7g$fiXP@zJF3KS.%p+bcU6ev)kLWK$xC{"
			"Uq7g$fiXQT&h"
		};

		char *p_s_data;
		if(!(p_s_data = new(std::nothrow) char[61418]))
			return 0;
		char *p_s_dest = p_s_data;
		for(size_t i = 0, n = sizeof(p_data) / sizeof(p_data[0]); i < n; ++ i) {
			size_t n_chunk = (i + 1 < n)? 32767 : 28650;
			memcpy(p_s_dest, p_data[i], n_chunk * sizeof(char));
			p_s_dest += n_chunk;
		}
		*p_s_dest = 0;
		return p_s_data;
	}

	/**
	 *	@brief gets raw image data
	 *	@return Returns pointer to raw ARGB32 image data on success, 0 on failure.
	 */
	static inline uint32_t *p_Decompress()
	{
		char *p_s_base85;
		if(!(p_s_base85 = p_s_Base85_Data()))
			return 0; // not enough memory
		uint32_t *p_result = p_Decode_RLE_Huff_Base85(p_s_base85, 256, 256, 77274, 5, 0, 3, 2, 2);
		delete[] p_s_base85;
		return p_result;
	}

protected:
	/**
	 *	@brief calculates reverse prediction on a single image plane
	 *
	 *	@param[in,out] p_buffer is pointer to image plane data (just the data, no padding or align)
	 *	@param[in] n_width is image width, in pixels
	 *	@param[in] n_height is image height, in pixels
	 *	@param[in] n_pred_type is predictor type (one of 0 = up, 1 = left, 2 = avg, 3 = paeth, 4 = med,
	 *		5 = gap, 6 = no prediction, 7 = up-left, 8 = avg2, 9 = diff, 10 = grad-h, 11 = grad-v)
	 */
	static void UnPredict_ImagePlane(uint8_t *p_buffer, int n_width, int n_height, int n_pred_type)
	{
		_ASSERTE(n_pred_type != 1 && n_pred_type != 2 && n_pred_type != 4 && n_pred_type != 7 &&
			n_pred_type != 8 && n_pred_type != 9 && n_pred_type != 10 && n_pred_type != 11); // some code omitted
		int n_first_row = (n_pred_type == 1 || n_pred_type == 6)? 0 : ((n_pred_type == 5)? 2 : 1);
		int n_first_col = (n_pred_type == 0 || n_pred_type == 6)? 0 : ((n_pred_type == 5)? 2 : 1);
		for(int x = 0; x < n_first_col; ++ x) {
			for(int y = n_first_row + 1; y < n_height; ++ y)
				p_buffer[x + n_width * y] += p_buffer[x + n_width * (y - 1)];
		}
		for(int y = 0; y < n_first_row; ++ y) {
			for(int x = n_first_col + 1; x < n_width; ++ x)
				p_buffer[x + n_width * y] += p_buffer[(x - 1) + n_width * y];
		}
		p_buffer += n_first_col + n_first_row * n_width;
		for(int y = n_first_row; y < n_height; ++ y, p_buffer += n_first_col) {
			for(int x = n_first_col; x < n_width; ++ x, ++ p_buffer) {
				if(n_pred_type == 0)
					*p_buffer += p_buffer[-n_width]; // up
				else if(n_pred_type == 3) {
					int a = p_buffer[-1], b = p_buffer[-n_width], c = p_buffer[-1 - n_width];
					int p = a + b - c, pa = abs(p - a), pb = abs(p - b), pc = abs(p - c);
					*p_buffer += (pa <= pb && pa <= pc)? a : ((pb <= pc)? b : c); // paeth
				} else if(n_pred_type == 5) { // gap
					int n_not_last_col = (x + 1 != n_width)? 1 : 0; // the last column extended right
					int nne = p_buffer[n_not_last_col - 2 * n_width], n = p_buffer[-n_width], w = p_buffer[-1],
						ww = p_buffer[-2], nn = p_buffer[-2 * n_width], ne = p_buffer[n_not_last_col - n_width],
						nw = p_buffer[-1 - n_width], n_d = abs(w - nw) + abs(n - nn) +
						abs(ne - nne) - abs(w - ww) - abs(n - nw) - abs(n - ne), n_ad = abs(n_d);
					uint8_t f = (w + n) / 2 + (ne - nw) / 4, g = (n_d > 0)? w : n;
					*p_buffer += (n_ad > 80)? g : (n_ad > 32)? (f + g) / 2 : (n_ad > 8)? (3 * f + g) / 4 : f;
				}
			}
		}
	}

	/**
	 *	@brief decompresses the image
	 *
	 *	@param[in] p_s_base85 is null-terminated string containing BASE85 compressed image data
	 *	@param[in] n_image_width is image width, in pixels
	 *	@param[in] n_image_height is image height, in pixels
	 *	@param[in] n_huff_stage_size size of the compressed data before Huffman encoding
	 *	@param[in] n_predictor_y is predictor type for the luminance plane
	 *	@param[in] n_predictor_uv is predictor type for the chrominance plane
	 *	@param[in] n_predictor_a is predictor type for the alpha plane
	 *	@param[in] n_subsample is number of chrominance samples per 
	 *	@param[in] n_color_type is color type bitmask (if the first bit is set the image is
	 *		grayscale, if the second bit is set the image has alpha channel, if the third
	 *		bit is set, lossless compression was employed)
	 */
	static uint32_t *p_Decode_RLE_Huff_Base85(const char *p_s_base85,
		int n_image_width, int n_image_height, size_t n_huff_stage_size,
		int n_predictor_y, int n_predictor_uv, int n_predictor_a,
		int n_subsample, int n_color_type)
	{
		bool b_gray = (n_color_type & 1) != 0, b_alpha = (n_color_type & 2) != 0,
			b_lossless_color = (n_color_type & 4) != 0;
		size_t n_base85_length = strlen(p_s_base85), n_base85_size = 0;
		int p_b85_ic_tab[128] = {0};
		{
			for(int i = 0, j = -10, k = 55, l = -62; i < 85; ++ i, ++ j, ++ k, ++ l)
				p_b85_ic_tab[(j < 0)? k - 7 : (l < 0)? k + j / 26 * 6 : "!#$%&()*+-;<=>.@^_,{|}~"[l]] = i;
			const char *p_s_src = p_s_base85, *p_s_end = p_s_base85 + n_base85_length;
			for(size_t n_diff, n_rem = n_base85_length; p_s_src < p_s_end;
			   p_s_src += n_diff * 4 + 1, n_rem -= n_diff * 4 + 1)
				n_base85_size += (n_diff = (p_b85_ic_tab[*p_s_src] == 84))? 4 : min(n_rem, size_t(5)) - 1;
		}
		size_t n_image_size = size_t(n_image_width) * n_image_height;
		int n_chroma_w = (n_image_width + n_subsample - 1) / n_subsample;
		int n_chroma_h = (n_image_height + n_subsample - 1) / n_subsample;
		size_t n_chroma_size = size_t(n_chroma_w) * n_chroma_h * 2;
		size_t n_image_data_size = n_image_size * ((b_alpha)? 2 : 1) +
			((b_gray)? 0 : n_chroma_size);

		size_t n_prehuff_size = max(n_base85_size, n_image_data_size);
		size_t n_temp_buffer_size = n_prehuff_size + n_huff_stage_size;
		uint8_t *p_temp_buffer;
		uint32_t *p_raster;
		if(!(p_temp_buffer = new(std::nothrow) uint8_t[n_temp_buffer_size]) ||
		   !(p_raster = new(std::nothrow) uint32_t[n_image_size])) {
			delete[] p_temp_buffer; // no effect on null
			return 0;
		}

		{
			uint8_t *p_dst = p_temp_buffer - 1; // points to one before the write sitze
			const char *p_s_src = p_s_base85, *p_s_end = p_s_base85 + n_base85_length;
			for(size_t n_rem = n_base85_length; p_s_src != p_s_end; -- n_rem, ++ p_s_src) {
				if(p_b85_ic_tab[*p_s_src] != 84) {
					uint32_t n_block = uint32_t(min(n_rem, size_t(5))), n_code = 0;
					_ASSERTE(n_block >= 2);
					for(unsigned int i = 0; i < 5; p_s_src += ((++ i < n_block)? 1 : 0))
						n_code = n_code * 85 + ((i < n_block)? p_b85_ic_tab[*p_s_src] : 84);
					for(unsigned int i = 1; i < n_block; ++ i, -- n_rem)
						*(++ p_dst) = n_code >> (8 * (4 - i));
				} else
					*(uint32_t*)((p_dst += 4) - 3) = 0;
			}
		}
		{
			const uint8_t *p_huff_src = p_temp_buffer, *p_huff_end = p_huff_src + n_base85_size;
			_ASSERTE(p_huff_src + 16 * sizeof(int32_t) <= p_huff_end);
			const int32_t *p_code_num = (const int32_t*)p_huff_src; p_huff_src += 16 * sizeof(int32_t);
			int p_min_code[16], p_max_code[16], p_table_off[16], n_code_num = 0;
			for(int i = 0, n_cw = 0; i < 16; ++ i, n_cw <<= 1) {
				p_min_code[i] = n_cw;
				p_max_code[i] = (n_cw += p_code_num[i]);
				p_table_off[i] = n_code_num - p_min_code[i];
				n_code_num += p_code_num[i];
			}
			_ASSERTE(p_huff_src + n_code_num <= p_huff_end);
			const uint8_t *p_symbol = p_huff_src; p_huff_src += n_code_num;
			uint8_t *p_huff_dest = p_temp_buffer + n_prehuff_size;
			for(int n_byte = 0, n_bit_num = 0, n_counter = n_huff_stage_size; n_counter --;) {
				for(int i = 0, n_code = 0;; ++ i) {
					_ASSERTE(i < 16);
					if(!(n_bit_num --)) {
						_ASSERTE(p_huff_src < p_huff_end);
						n_byte = *p_huff_src ++;
						n_bit_num = 7;
					}
					n_code = (n_code << 1) | ((n_byte >> 7) & 1);
					n_byte <<= 1;
					if(n_code >= p_min_code[i] && n_code < p_max_code[i]) {
						*p_huff_dest ++ = p_symbol[n_code + p_table_off[i]];
						break;
					}
				}
			}
		}
		{
			const uint8_t *p_rle_src = p_temp_buffer + n_prehuff_size,
				*p_src_end = p_rle_src + n_huff_stage_size;
			for(uint8_t *p_rle_dest = p_temp_buffer; p_rle_src != p_src_end;) {
				uint8_t n_code = *p_rle_src ++;
				bool b_compressed = n_code & 1;
				int n_run_length = (n_code >> 1) + 1;
				_ASSERTE(p_rle_src + ((b_compressed)? 1 : n_run_length) <= p_src_end);
				while(n_run_length --)
					*p_rle_dest ++ = (b_compressed)? *p_rle_src : *p_rle_src ++;
				if(b_compressed)
					++ p_rle_src;
			}
		}

		{
			_ASSERTE(!b_gray && b_alpha && !b_lossless_color);
			uint8_t *p_y = p_temp_buffer, *p_u = p_y + n_image_size,
				*p_v = p_u + n_chroma_size / 2, *p_a = p_u + n_chroma_size;
			UnPredict_ImagePlane(p_y, n_image_width, n_image_height, n_predictor_y);
			UnPredict_ImagePlane(p_u, n_chroma_w, n_chroma_h, n_predictor_uv);
			UnPredict_ImagePlane(p_v, n_chroma_w, n_chroma_h, n_predictor_uv);
			UnPredict_ImagePlane(p_a, n_image_width, n_image_height, n_predictor_a);
			uint32_t *p_dest = p_raster;
			for(int y = 0, h = n_image_height; y < h; ++ y) {
				for(int x = 0, w = n_image_width; x < w; ++ x, ++ p_y, ++ p_dest) {
					size_t n_cr_idx = x / n_subsample + size_t(y / n_subsample) * n_chroma_w;
					int Y = *p_y, u = p_u[n_cr_idx] - 128, v = p_v[n_cr_idx] - 128;
					uint8_t r = uint8_t(max(0, min(255, Y + 1.402f * v)));
					uint8_t g = uint8_t(max(0, min(255, Y - 0.34414f * u - 0.71414f * v)));
					uint8_t b = uint8_t(max(0, min(255, Y + 1.772f * u))); // JPEG-like YUV
					*p_dest = (*p_a << 24) | (b << 16) | (g << 8) | r;
					++ p_a;
				}
			}
		}

		delete[] p_temp_buffer;

		return p_raster;
	}
};

#endif // __BOX_TGA_INCLUDED
