	static void UnPredict_ImagePlane(uint8_t *p_buffer, int n_width, int n_height, int n_pred_type)
	{
		int n_first_row = (n_pred_type == 1)? 0 : 1;
		int n_first_col = (n_pred_type == 0)? 0 : 1;
		p_buffer += n_first_row * n_width;
		for(int y = n_first_row; y < n_height; ++ y) {
			if(n_first_col)
				++ p_buffer;
			for(int x = n_first_col; x < n_width; ++ x, ++ p_buffer) {
				if(n_pred_type == 0)
					*p_buffer += p_buffer[-n_width];
				else if(n_pred_type == 1)
					*p_buffer += p_buffer[-1];
				else if(n_pred_type == 2) {
					*p_buffer += (int(p_buffer[-1]) + int(p_buffer[-n_width]) +
						int(p_buffer[-n_width - 1])) / 3;
				} else {
					int a = p_buffer[-1], b = p_buffer[-n_width], c = p_buffer[-n_width - 1];
					int p = a + b - c, pa = abs(p - a), pb = abs(p - b), pc = abs(p - c);
					*p_buffer += (pa <= pb && pa <= pc)? a : ((pb <= pc)? b : c);
				}
			}
		}
	}

	static uint32_t *p_Decode_RLE_Huff_Base64(const char *p_s_base64,
		int n_image_width, int n_image_height, int n_huff_stage_size,
		int n_predictor_y, int n_predictor_uv, int n_subsample, bool b_gray)
	{
		int n_base64_length = strlen(p_s_base64);
		int n_base64_out_size = (n_base64_length / 4) * 3 +
			max(int(n_base64_length % 4) - 1, 0);

		int n_image_size = n_image_width * n_image_height;
		int n_chroma_w = (n_image_width + n_subsample - 1) / n_subsample;
		int n_chroma_h = (n_image_height + n_subsample - 1)/ n_subsample;
		int n_chroma_plane_size = n_chroma_w * n_chroma_h;
		int n_chroma_size = n_chroma_plane_size * 2;
		int n_image_data_size = n_image_width * n_image_height + ((b_gray)? 0 : n_chroma_size);

		int n_prehuff_size = max(n_base64_out_size, n_image_data_size);
		int n_temp_buffer_size = n_prehuff_size + n_huff_stage_size;
		uint8_t *p_temp_buffer;
		if(!(p_temp_buffer = new(std::nothrow) uint8_t[n_temp_buffer_size]))
			return 0;;
		uint32_t *p_raster;
		if(!(p_raster = new(std::nothrow) uint32_t[n_image_width * n_image_height])) {
			delete[] p_temp_buffer;
			return 0;
		}

		{
			int p_ic_tab[256];
			for(int i = 0; i < 256; ++ i) {
				p_ic_tab[i] = (isupper(i))? i - 'A' : (islower(i))? i - 'a' + 26 :
					(isdigit(i))? i - '0' + 52 : (i == '+')? 62 : (i == '/')? 63 : -1;
			}
			const uint8_t *p_src = (const uint8_t*)p_s_base64;
			uint8_t *p_dst = p_temp_buffer;
			for(const uint8_t *p_end = p_src + n_base64_length - 3; p_src < p_end; p_src += 4) {
				uint8_t p_tmp[] = {p_ic_tab[p_src[1]], p_ic_tab[p_src[2]], };
				*p_dst ++ = (p_ic_tab[p_src[0]] << 2) | (p_tmp[0] >> 4);
				*p_dst ++ = (p_tmp[0] << 4) | (p_tmp[1] >> 2);
				*p_dst ++ = (p_tmp[1] << 6) | p_ic_tab[p_src[3]];
			}
			if(n_base64_length % 4 == 3) {
				uint8_t n_tmp = p_ic_tab[p_src[1]];
				*p_dst ++ = (p_ic_tab[p_src[0]] << 2) | (n_tmp >> 4); // 6 bits of byte 0 + 2 bits of byte 1
				*p_dst ++ = (n_tmp << 4) | ((p_ic_tab[p_src[2]] >> 2) & 0xf); // 4 bits of byte 1 + 4 bits of byte 2
			} else if(n_base64_length % 4 == 2) {
				*p_dst ++ = (p_ic_tab[p_src[0]] << 2) | (p_ic_tab[p_src[1]] >> 4);
			}
			_ASSERTE(p_dst == p_temp_buffer + n_base64_out_size);
		}
		{
			{
				TBuffer b;
				b.Resize(n_base64_out_size + sizeof(uint32_t));
				uint8_t *p_data = b.p_Data();
				*((uint32_t*)p_data) = n_huff_stage_size;
				p_data += sizeof(uint32_t);
				memcpy(p_data, p_temp_buffer, n_base64_out_size);
				// reconstruct a buffer that huff codec is supposed to know how to decode

				TBuffer t_tmp2;
				if(!CHuffmanCodec::Decode(b, t_tmp2))
					fprintf(stderr, "error: not enough memory for decoding\n");
			}
			// debugging a glitch, the BASE64 output is "too short" for huffman
			// (although having a good size - probably some data was not reconstructed properly)

			const uint8_t *p_huff_src = p_temp_buffer, *p_huff_end = p_huff_src + n_base64_out_size;
			_ASSERTE(p_huff_src + 16 * sizeof(int) <= p_huff_end);
			const int32_t *p_code_num = (const int32_t*)p_huff_src; p_huff_src += 16 * sizeof(int32_t);
			int p_min_code[16], p_max_code[16], p_table_off[16], n_code_num = 0;
			for(int i = 0, n_cw = 0; i < 16; ++ i, n_cw <<= 1) {
				p_min_code[i] = n_cw;
				p_max_code[i] = (n_cw += p_code_num[i]);
				p_table_off[i] = n_code_num - p_min_code[i];
				n_code_num += p_code_num[i];
			}
			_ASSERTE(p_huff_src + n_code_num <= p_huff_end);
			const uint8_t *p_symbol = p_huff_src; p_huff_src += n_code_num;
			uint8_t *p_huff_dest = p_temp_buffer + n_prehuff_size;
			for(int n_byte = 0, n_bit_num = 0, n_counter = n_huff_stage_size; n_counter --;) {
				for(int i = 0, n_code = 0;; ++ i) {
					_ASSERTE(i < 16);
					if(!(n_bit_num --)) {
						_ASSERTE(p_huff_src < p_huff_end);
						n_byte = *p_huff_src ++;
						n_bit_num = 7;
					}
					n_code = (n_code << 1) | (n_byte >> 7);
					n_byte = (n_byte << 1) & 0xff;
					if(n_code >= p_min_code[i] && n_code < p_max_code[i]) {
						*p_huff_dest ++ = p_symbol[n_code + p_table_off[i]];
						break;
					}
				}
			}
		}
		{
			uint8_t *p_rle_dest = p_temp_buffer;
			const uint8_t *p_rle_src = p_temp_buffer + n_prehuff_size,
				*p_src_end = p_rle_src + n_huff_stage_size;
			for(; p_rle_src != p_src_end;) {
				uint8_t n_code = *p_rle_src ++;
				bool b_compressed = n_code & 1;
				int n_run_length = (n_code >> 1) + 1;
				_ASSERTE(p_rle_src + ((b_compressed)? 1 : n_run_length) <= p_src_end);
				while(n_run_length --)
					*p_rle_dest ++ = (b_compressed)? *p_rle_src : *p_rle_src ++;
				if(b_compressed)
					++ p_rle_src;
			}
		}

		if(!b_gray) {
			uint8_t *p_y = p_temp_buffer;
			uint8_t *p_u = p_y + n_image_size;
			uint8_t *p_v = p_u + n_chroma_plane_size;
			UnPredict_ImagePlane(p_y, n_image_width, n_image_height, n_predictor_y);
			UnPredict_ImagePlane(p_u, n_chroma_w, n_chroma_h, n_predictor_uv);
			UnPredict_ImagePlane(p_v, n_chroma_w, n_chroma_h, n_predictor_uv);
			for(int y = 0, h = n_image_height; y < h; ++ y) {
				for(int x = 0, w = n_image_width; x < w; ++ x) {
					int n_cr_idx = x / n_subsample + y / n_subsample * n_chroma_w;
					int Y = *p_y ++, u = p_u[n_cr_idx] - 128, v = p_v[n_cr_idx] - 128;
					uint8_t r = uint8_t(max(0, min(255, Y + 1.402f * v)));
					uint8_t g = uint8_t(max(0, min(255, Y - 0.34414f * u - 0.71414f * v)));
					uint8_t b = uint8_t(max(0, min(255, Y + 1.772f * u)));
					p_raster[x + y * w] = 0xff000000 | (r << 16) | (g << 8) | b;
				}
			}
		} else {
			UnPredict_ImagePlane(p_temp_buffer, n_image_width, n_image_height, n_predictor_y);
			uint32_t *p_dest = p_raster;
			for(const uint8_t *p_y = p_temp_buffer, *p_end = p_y +
			   n_image_height * n_image_width; p_y != p_end; ++ p_y)
				*p_dest ++ = 0xff000000 | (*p_y << 16) | (*p_y << 8) | *p_y;
		}

		delete[] p_temp_buffer;
		
		return p_raster;
	}
