	static void UnPredict_ImagePlane(uint8_t *p_buffer, int n_width, int n_height, int n_pred_type)
	{
		int n_first_row = (n_pred_type == 1 || n_pred_type == 6)? 0 : ((n_pred_type == 5)? 2 : 1);
		int n_first_col = (n_pred_type == 0 || n_pred_type == 6)? 0 : ((n_pred_type == 5)? 2 : 1);

		for(int x = 0; x < n_first_col; ++ x) {
			for(int y = n_first_row + 1; y < n_height; ++ y)
				p_buffer[x + n_width * y] += p_buffer[x + n_width * (y - 1)];
		}
		for(int y = 0; y < n_first_row; ++ y) {
			for(int x = n_first_col + 1; x < n_width; ++ x)
				p_buffer[x + n_width * y] += p_buffer[(x - 1) + n_width * y];
		}
		// unpredict n_first_row and n_first_col using left and up, respectively,
		// in order to completely avoid having pixels in the image

		p_buffer += n_first_row * n_width;
		for(int y = n_first_row; y < n_height; ++ y) {
			if(n_first_col)
				p_buffer += n_first_col;
			for(int x = n_first_col; x < n_width; ++ x, ++ p_buffer) {
				if(n_pred_type == 0)
					*p_buffer += p_buffer[-n_width]; // up
				else if(n_pred_type == 1)
					*p_buffer += p_buffer[-1]; // left
				else if(n_pred_type == 2) {
					*p_buffer += (int(p_buffer[-1]) + int(p_buffer[-n_width]) +
						int(p_buffer[-1 - n_width])) / 3; // avg
				} else if(n_pred_type == 3) {
					int a = p_buffer[-1], b = p_buffer[-n_width], c = p_buffer[-1 - n_width];
					int p = a + b - c, pa = abs(p - a), pb = abs(p - b), pc = abs(p - c);
					*p_buffer += (pa <= pb && pa <= pc)? a : ((pb <= pc)? b : c); // paeth
				} else if(n_pred_type == 4 || (n_pred_type == 5 && x + 1 == n_width)) { // med
					int a = p_buffer[-1], b = p_buffer[-n_width], c = p_buffer[-1 - n_width];
					*p_buffer += (c >= max(a, b))? min(a, b) : (c <= min(a, b))? max(a, b) : a + b - c;
				} else if(n_pred_type == 5) { // gap
					_ASSERTE(x + 1 != n_width); // the last column predicted using med (gap looks right)
					uint8_t n = p_buffer[-n_width], w = p_buffer[-1], nw = p_buffer[-1 - n_width],
						ww = p_buffer[-2], nn = p_buffer[-n_width - n_width],
						nne = p_buffer[1 - n_width - n_width], ne = p_buffer[1 - n_width], p;
					int dh = abs(int(w) - ww) + abs(int(n) - nw) + abs(int(ne) - n);
					int dv = abs(int(w) - nw) + abs(int(n) - nn) + abs(int(ne) - nne);
					if(dv - dh > 80)
						p = w;
					else if(dv - dh < -80)
						p = n;
					else {
						p = (int(w) + n) / 2 + (int(ne) - nw) / 4;
						if(dv - dh > 32)
							p = (p + w) / 2;
						else if(dv - dh > 8)
							p = (3 * p + w) / 4;
						else if(dv - dh < -32)
							p = (p + n) / 2;
						else if(dv - dh < -8)
							p = (3 * p + n) / 4;
					}
					*p_buffer += p;
				} else if(n_pred_type == 7) // 6 = no prediction
					*p_buffer += p_buffer[-1 - n_width]; // up-left
				else if(n_pred_type == 8)
					*p_buffer += (int(p_buffer[-1]) + int(p_buffer[-n_width])) / 2; // avg2
				else if(n_pred_type == 9) {
					*p_buffer += int(p_buffer[-1]) + int(p_buffer[-n_width]) -
						int(p_buffer[-1 - n_width]); // diff
				} else if(n_pred_type == 10) {
					*p_buffer += int(p_buffer[-1]) + (int(p_buffer[-n_width]) -
						int(p_buffer[-1 - n_width])) / 2; // grad-h
				} else if(n_pred_type == 11) {
					*p_buffer += int(p_buffer[-n_width]) + (int(p_buffer[-1]) -
						int(p_buffer[-1 - n_width])) / 2; // grad-v
				} // note that higher than the predictors below paeth are mostly untested
			}
		}
	}

	static uint32_t *p_Decode_RLE_Huff_Base64(const char *p_s_base64,
		int n_image_width, int n_image_height, size_t n_huff_stage_size,
		int n_predictor_y, int n_predictor_uv, int n_predictor_a,
		int n_subsample, int n_color_type)
	{
		bool b_gray = (n_color_type & 1) != 0;
		bool b_alpha = (n_color_type & 2) != 0;
		bool b_lossless_color = (n_color_type & 4) != 0;
		size_t n_base64_length = strlen(p_s_base64);
		size_t n_base64_out_size = (n_base64_length / 4) * 3 +
			max(int(n_base64_length % 4) - 1, 0);

		size_t n_image_size = size_t(n_image_width) * n_image_height;
		int n_chroma_w = (n_image_width + n_subsample - 1) / n_subsample;
		int n_chroma_h = (n_image_height + n_subsample - 1)/ n_subsample;
		size_t n_chroma_plane_size = size_t(n_chroma_w) * n_chroma_h;
		size_t n_chroma_size = n_chroma_plane_size * 2;
		size_t n_image_data_size = n_image_size +
			((b_gray)? 0 : n_chroma_size) + ((b_alpha)? n_image_size : 0);

		size_t n_prehuff_size = max(n_base64_out_size, n_image_data_size);
		size_t n_temp_buffer_size = n_prehuff_size + n_huff_stage_size;
		uint8_t *p_temp_buffer;
		if(!(p_temp_buffer = new(std::nothrow) uint8_t[n_temp_buffer_size]))
			return 0;;
		uint32_t *p_raster;
		if(!(p_raster = new(std::nothrow) uint32_t[n_image_width * n_image_height])) {
			delete[] p_temp_buffer;
			return 0;
		}

		{
			int p_ic_tab[256];
			for(int i = 0; i < 256; ++ i) {
				p_ic_tab[i] = (isupper(i))? i - 'A' : (islower(i))? i - 'a' + 26 :
					(isdigit(i))? i - '0' + 52 : (i == '+')? 62 : (i == '/')? 63 : -1;
			}
			const uint8_t *p_src = (const uint8_t*)p_s_base64;
			uint8_t *p_dst = p_temp_buffer;
			for(const uint8_t *p_end = p_src + n_base64_length - 3; p_src < p_end; p_src += 4) {
				uint8_t p_tmp[] = {p_ic_tab[p_src[1]], p_ic_tab[p_src[2]], };
				*p_dst ++ = (p_ic_tab[p_src[0]] << 2) | (p_tmp[0] >> 4);
				*p_dst ++ = (p_tmp[0] << 4) | (p_tmp[1] >> 2);
				*p_dst ++ = (p_tmp[1] << 6) | p_ic_tab[p_src[3]];
			}
			if(n_base64_length % 4 == 3) {
				uint8_t n_tmp = p_ic_tab[p_src[1]];
				*p_dst ++ = (p_ic_tab[p_src[0]] << 2) | (n_tmp >> 4);
				*p_dst ++ = (n_tmp << 4) | ((p_ic_tab[p_src[2]] >> 2) & 0xf); // fixed byte order
			} else if(n_base64_length % 4 == 2)
				*p_dst ++ = (p_ic_tab[p_src[0]] << 2) | (p_ic_tab[p_src[1]] >> 4);
		}
		{
			const uint8_t *p_huff_src = p_temp_buffer, *p_huff_end = p_huff_src + n_base64_out_size;
			_ASSERTE(p_huff_src + 16 * sizeof(int32_t) <= p_huff_end);
			const int32_t *p_code_num = (const int32_t*)p_huff_src; p_huff_src += 16 * sizeof(int32_t);
			int p_min_code[16], p_max_code[16], p_table_off[16], n_code_num = 0;
			for(int i = 0, n_cw = 0; i < 16; ++ i, n_cw <<= 1) {
				p_min_code[i] = n_cw;
				p_max_code[i] = (n_cw += p_code_num[i]);
				p_table_off[i] = n_code_num - p_min_code[i];
				n_code_num += p_code_num[i];
			}
			_ASSERTE(p_huff_src + n_code_num <= p_huff_end);
			const uint8_t *p_symbol = p_huff_src; p_huff_src += n_code_num;
			uint8_t *p_huff_dest = p_temp_buffer + n_prehuff_size;
			for(int n_byte = 0, n_bit_num = 0, n_counter = n_huff_stage_size; n_counter --;) {
				for(int i = 0, n_code = 0;; ++ i) {
					_ASSERTE(i < 16);
					if(!(n_bit_num --)) {
						_ASSERTE(p_huff_src < p_huff_end);
						n_byte = *p_huff_src ++;
						n_bit_num = 7;
					}
					n_code = (n_code << 1) | (n_byte >> 7);
					n_byte = (n_byte << 1) & 0xff;
					if(n_code >= p_min_code[i] && n_code < p_max_code[i]) {
						*p_huff_dest ++ = p_symbol[n_code + p_table_off[i]];
						break;
					}
				}
			}
		}
		{
			uint8_t *p_rle_dest = p_temp_buffer;
			const uint8_t *p_rle_src = p_temp_buffer + n_prehuff_size,
				*p_src_end = p_rle_src + n_huff_stage_size;
			for(; p_rle_src != p_src_end;) {
				uint8_t n_code = *p_rle_src ++;
				bool b_compressed = n_code & 1;
				int n_run_length = (n_code >> 1) + 1;
				_ASSERTE(p_rle_src + ((b_compressed)? 1 : n_run_length) <= p_src_end);
				while(n_run_length --)
					*p_rle_dest ++ = (b_compressed)? *p_rle_src : *p_rle_src ++;
				if(b_compressed)
					++ p_rle_src;
			}
		}

		if(!b_gray) {
			uint8_t *p_y = p_temp_buffer;
			uint8_t *p_u = p_y + n_image_size;
			uint8_t *p_v = p_u + n_chroma_plane_size;
			uint8_t *p_a = p_v + n_chroma_plane_size;
			UnPredict_ImagePlane(p_y, n_image_width, n_image_height, n_predictor_y);
			UnPredict_ImagePlane(p_u, n_chroma_w, n_chroma_h, n_predictor_uv);
			UnPredict_ImagePlane(p_v, n_chroma_w, n_chroma_h, n_predictor_uv);
			if(b_alpha)
				UnPredict_ImagePlane(p_a, n_image_width, n_image_height, n_predictor_a);
			for(int y = 0, h = n_image_height; y < h; ++ y) {
				for(int x = 0, w = n_image_width; x < w; ++ x, ++ p_y) {
					size_t n_cr_idx = x / n_subsample + size_t(y / n_subsample) * n_chroma_w;
					uint8_t r, g, b;
					if(!b_lossless_color) {
						int Y = *p_y, u = p_u[n_cr_idx] - 128, v = p_v[n_cr_idx] - 128;
						r = uint8_t(max(0, min(255, Y + 1.402f * v)));
						g = uint8_t(max(0, min(255, Y - 0.34414f * u - 0.71414f * v)));
						b = uint8_t(max(0, min(255, Y + 1.772f * u))); // JPEG-like YUV
					} else {
						uint8_t Y = *p_y;
						int8_t u = p_u[n_cr_idx], v = p_v[n_cr_idx];
						g = Y - (u >> 1);
						uint8_t s = g + u;
						r = s - (v >> 1);
						b = r + v; // lifting
					}
					if(b_alpha) {
						p_raster[x + y * w] = (*p_a << 24) | (b << 16) | (g << 8) | r;
						++ p_a;
					} else
						p_raster[x + y * w] = 0xff000000U | (b << 16) | (g << 8) | r;
				}
			}
		} else {
			uint8_t *p_a = p_temp_buffer + n_image_size;
			UnPredict_ImagePlane(p_temp_buffer, n_image_width, n_image_height, n_predictor_y);
			if(b_alpha)
				UnPredict_ImagePlane(p_a, n_image_width, n_image_height, n_predictor_a);
			uint32_t *p_dest = p_raster;
			if(b_alpha) {
				for(const uint8_t *p_y = p_temp_buffer, *p_end = p_y +
				   n_image_height * n_image_width; p_y != p_end; ++ p_y, ++ p_a)
					*p_dest ++ = (*p_a << 24) | (*p_y << 16) | (*p_y << 8) | *p_y; // gray / alpha
			} else {
				for(const uint8_t *p_y = p_temp_buffer, *p_end = p_y +
				   n_image_height * n_image_width; p_y != p_end; ++ p_y)
					*p_dest ++ = 0xff000000U | (*p_y << 16) | (*p_y << 8) | *p_y; // gray
			}
		}

		delete[] p_temp_buffer;

		return p_raster;
	}
