/**
 *	@file OpenGL20LogoLS_New85.h
 *	@brief image in header, generated from 'opengl_logo_2_0.tga'
 *		- using prediction / RLE / Huff / BASE85 pipe (lossless)
 *		- predictors used: paeth for luminance, none for chrominance
 *	@date 2009-11-04 05:31:52
 *	@author ImageToHeader (built May 19 2017)
 */

#pragma once
#ifndef __OPENGL_LOGO_2_0_TGA_INCLUDED
#define __OPENGL_LOGO_2_0_TGA_INCLUDED

/**
 *	@brief image in header, generated from 'opengl_logo_2_0.tga'
 */
class COpenGLLogo_LS {
public:
	/**
	 *	@brief gets width of the image
	 *	@return Returns image width, in pixels.
	 */
	static inline int n_Width()
	{
		return 150;
	}

	/**
	 *	@brief gets height of the image
	 *	@return Returns image height, in pixels.
	 */
	static inline int n_Height()
	{
		return 57;
	}

	/**
	 *	@brief determines whether the image contains alpha channel
	 *	@return Returns true if the image contains alpha channel, otherwise false.
	 */
	static inline bool b_Alpha()
	{
		return false;
	}

	/**
	 *	@brief determines whether the image is grayscale
	 *	@return Returns true if the image is grayscale, otherwise false.
	 */
	static inline bool b_Grayscale()
	{
		return false;
	}

	/**
	 *	@brief determines whether the compression is lossless
	 *	@return Returns true if the compression is lossless, otherwise false.
	 */
	static inline bool b_Lossless()
	{
		return true;
	}

	/**
	 *	@brief determines whether the BASE85 data is allocated dynamically
	 *	@return Returns true if the caller needs to delete the string
	 *		returned by p_s_Base85_Data(), otherwise false.
	 */
	static inline bool b_Dynamic()
	{
		return false;
	}

	/**
	 *	@brief returns CRC32 of the stored image data
	 *	@return Returns CRC32 of the stored image data (if lossy compression
	 *		is employed, then this is different from the original image).
	 */
	static inline uint32_t n_CRC32()
	{
		return 0xa35d092b;
	}

	/**
	 *	@brief gets BASE85 compressed image data
	 *	@return Returns BASE85 compressed image data in a null-terminated string.
	 */
	static inline const char *p_s_Base85_Data()
	{
		return "~~0RR910ssI21poj53jhEB9smFU6#xJL9RL6T8vp<R8UO$Q9smFU5dZ)H1^@s6~~00#&L1p)yC3q%7<2.|g"
			"<5dT&7,VajQB2f$z4fz%>FMIb68WsK~MHKk-eR}dW8%G=$PZ$yN.Lg=u89d}3VesyJ+41$|,!MRmC@F#K9p5E1"
			";41IbC+F-Wx**t>{5IRw;^8af+,Bp6GSKPf*4o$IOVd9-&CD#mLps9B%URJ=uhN~ht++E+I3F#+rJ<j{$C<rIB"
			"gSA}#73#Nz^l2lvRznOLQc<*&XHxvo5eAsrl-k0K}kwYR$E_WW@l(=YH)yym9d<xs#I~tJAg+RjDBHyUMw<)AQ"
			"HepL&9U,<k5o+t{zEx!zdD-5k3W~bZI{qXiuBNvx{3O5,eNWiDQ_NZ6O@90q5;gxwh9-PnYd.b+U;<$ipmR7HU"
			"gK63A$v1Q2+VjaT-zr+fpUFWT<%#Gz*lzGX,_1i51fm831dDe!1Pdx_f5+@1cxKZDZl<&-St=2Wv%SeJxKrV$V"
			"nQZG@&0s!Fw{#owD,<q<dr$0E};P-iARh+nmnu1)sGM*SBqgK_U4Ll!6=t=^}<qSD.aboXxhpq5i,a3Ru_}=As"
			"x}sNWl~T<.E.yBSA^5d5Dz!;3K7fE2(7oiA2OzVrXJ2+!&!@ZX_I,b*KET|Y)%FCg*DHWj66N6%fQo;8s#Bh#^"
			"N9|12Zu;u=1P~tuV-J}#q_<uyzKAc9=,|E%PY0Y;1vY1mQWFDUeTpGi^)esciasKrrVV(lJ>s8x%xgo=JL7zW1"
			"Bb9,3AmRR%!t*UKv6DhktuL8Yy$t8ZJ19w6OAQ==Z%p^z(gozc95o+vAnm<#1F;tBVYvJ%0alQenBED!9{HU9J"
			"u3U*G+|wQu|dslQK,ua^~.i5M|qlr(;g.Wu<40XfVTuy.6$>*+b;6lMG#YdZBf2u_!VQ~eLY*0^qcQ2G#h+K>K"
			",MsLCAS<Asvn6;zp-kd5W&*c~mGhA.Cni7xxgZ*DR&b>;M#atLW-O!XC)cvPEsMK(9,TF@pr^eRQ;uU7~dShGV"
			"!QR)Uq~yT<E<h$x&M3|8R0U}rK>sWDY~,uJFltNorHmla.R=M;i|>!YFXQFw<;7$@N0<AaUn_uN_9b.>MemSn="
			"y+ZTo7(g_&jx1Ib5tU3&d)f5D)U^@56%A@IdO1P8,9<Bl@%JV%GvboaCLub=hqM6,ddEE.|6qm=*9PSzIO$l_Y"
			"VfXw=ccQ8vRESEzQ~cBb&*sPGIJH9M>t0NxXiCHLYPzVDNnCxDVOt;pSPGJTmx3kFTRhS=ajBDRn>7{^zDXDSu"
			"06-reCEG+*a#;l)SnQs%fhTpHMN-sMWQN^6N4I^SoT$.^fRI>D,-M;;n8c6|<R.#LTDl=i+3Ynq|.eY,UGDpMW"
			"#ct(x-(IgH{8(&QxFY5BS.~BuX{;t073}3r}@hf-faN!^SbQ)+sOa2@)qH!a7Z@tar^AB3k!K.>j<Bts)zXvyW"
			"XSd-;xCKAY&}&p8S5{svQAS*$f3JZF5gX$#VIOz#QTN5}XR(*r!xawB1~V3j{z*f{>wY2@r30C9l-x+2ho^UBa"
			"(_iGPhlaQy4Kzb%UvS}U#yK!(W$NQ,W.q9hvxcOd6sHZ6lH<X>tI0+,;mBS,%.FId-FhWa-}&%6v6VPIYk5@nj"
			"8~(Cce-UadPoumF2B%02{+D%l4j{1wi;FnrK_I+wK9,p49ImN1M3N@XhCH@@)40uTT#aJ#Cct+@=vX+~!o$46S"
			"h#$NnhwzL3l7X#ZC)Yj5^>a>c6Oc>qoHzD,,RYiqAKaQwsJ^Zrbs8UBl7(B)aeI,<Gli(7vFTQjgEFr~_*G+EZ"
			"|id,0hSu>CXygV~(t5_ut2lIic_GKcNM>D5V%^-{;dW^yUXC,g>W0#AUudnTMm{mNU_nY~VH{1EWYo$}k.|Z-X"
			"J|0;6p6s@&c|C7)|4-}Gs3OudjTxXnx3&UY0-%17(LCKjYitf=sI,Z0.>s2o>9tR0)9(gT^LDjDtn##i3_O{G|"
			"860q3Yfdzw!R-NQHRdf,1;;oXXf>j=$Q2VuUqc_#.KEsF5fiAr,VVJzh1SFD8Aql|AQ$ArF%cG@c>fgQW,12I4"
			"Qw5&gV6<J1@K+ng+0OB8ouP)Z@D_9J-c8OMoVj3,l~fla;N*>-F=al9#D3_d4CaRo{!PGG6!h,Tu9<=5S.4#nz"
			"cG2Rc_{la!DMhV-v@gaS@3cXzl2K>Z-693d7iK6clbcHlXIRQ5;&q%&k)qy<Vr2$ngNfbt}D.Ex+S!RXU-0)Dr"
			"()9LkUZRqWs(L2xG;7HNb.Cm);czwR.wyH}ygg2#nUD;2X23>2Q6uDW(3A;Ns+Vc+IUg69dn!qFrqGqrW,XJCc"
			"zblgm^UKzjDKH7!RNM%ibG@y*uV<b4Vj)w5y(^aR7ou=EL.Wk>)U<&uA|!gg*c_axa)>gZe{5iz$LMo+c1Lfo{"
			"#vw!T~2o}1rADkJjKiiMDIxyfuM2zv{M)+_i;-aC=^op4+^e(qR$4s)^L.T5Q9inr-*bK0hF2KN0Z#Pfk*Fc4S"
			"%SuXM&1e*sC{>(B|&!j9L@vxo{5BL;S%rbXC;,%Ys@d14pIye6BPq^E~bhJJXN~$Z&^;lqJ1nQv1zvnjEI7QsG"
			"DrBnBjR(WytAf&M<e0GoP~d,(o=ec;3$szR*ZKSP_zv)lA@ZJU(C6IWRxcaRE^@&HVjA3dgdC8CftecPK(5cTE"
			"#E!<MQS|OmXLrK6qovcs4MpaJcqrr%Kg&-<mo{v}ef-L>dpT6UheBN}sGUYrBhbzyR(C.;qYtRE*yYXkE9grx^"
			".Rp6sFa5uSd^IMybPbWTa{;DxUcxm;{H1}x|Nr~CG~Aco.fjmX53km>my{*,evCq2o0o^PI,^KBssBR)Zwicny"
			"D)EB+US2{<J$Xq.NjCJ,,X!B9h!i9-J^QT)<(TAujq4mIVt>8J%ozf(6ss-;k7cRuFj=3Y>l37=<WSf%oJRTzh"
			"YQK!TWOV%a,^)JtwT|,#89I9{$<@)|c;pU+YI#>GIL|E.4urzQ(^_Zx@@lL;Qv*K}0.-R$0LvPw3}viG1!{RV."
			"deLO1}LDq_NTxyT^=xpgsH-FOY8irc@B,R8=@wY=PLbU1cKwuozYWOd.mR8fDeSI+.r4+;Y),T2QZ@QG1ub@!="
			"|^4-+*|NTU~DE-~5TiPEtpXYnX8BY|^!UfldmQnzxwf#RgicrhT5{8ej{hR<eHMm5rP{;UrZvnFK(e6vaJivD!"
			"+Sgvl*&xnO#Qh;@7d>A;3MHYTynr3_,NI_II-6QM+O81t(e-a,$,9AAITpPUySpe0ef_5,e@<Pc5c1Y#R0lMW{"
			"clg5i-IZL{.3grt!rv)JzY$+g&Oa2dPB&{W3$vj)%i8YqI7#c-<|S-+a4P6BH*KIv*r4EO$,ka6Me6K%%C5ga*"
			"AAdc}uO._GLcyq~i$Ee,_t7PrW+gaDTU%am0_n|D&Sy5FFL!=ic,LwMuozrgeqGbFbF3NJXfP&JktnFFZOHrYm"
			"_o!8!DAKc8P(U!zMtq3H;bx7XS61OzlEJ(ucy@dhO*)f8r6+vX+1A-v>N@Qz.KxGBCIaUjv9fH;w&<4N~C>KjO"
			"7=m&r$#%W-.stryHT9k$5IOeUZp-u#8PQ)dl<8wH)*K$@Z&}bnQLbCS1+uY{4NGmH6ia|~_Oex1Hg*fBF)Z9P6"
			"^z=5goFJzhAg3JL0nFh}IM8E,A4El~=#S*x0SHJH2p,SW_-8pxBfTngy#Z=(xA%Piqef$&+9x@K(X;Aqj5d%!R"
			"7gIqzSmxJz}f2RRYmb@)Al*{evWSQU;T^-!Pk4{@c.K-MEaEp;qLWzzFj8(KEGM&KM0+Nci8wj%=$UI$NEK7X$"
			"SQ,f>6U~AtQRAvlPE~t4q1mi1e@rJyBL~51;35,cmrpy,8qc(5mK>.^XSs&<<S,i**Zu;YSX;+LX7aIhb3+!,<"
			"rZ>-t$y&Fk%8N97w1Q|@YD_Wh0tPk@99f}sFSc8|_})h)N_xwI$C#ly+3mtPMrTPWW3ba%B}{Dc3FG-%P<,rfw"
			"$p!uL6RHzD|qn6gb&zv8$DIwtaNahJckZX*hRh+oF*+i~|ZSARzeZlcLf{e,_->vI#N|g98fQpp,k%&<Uv#vHs"
			"dhg19Q}UmbEa8,nf.iQ5bT4T2t{b1mC!UneO&x!4)5X9g2f>6SXw()!co0ZLv,a|u^D0@WF$^+*i=keYc&WMkL"
			"$2dTI~Lbhz0UObWl9o*;209X)<Z%mU,rT4ltL({=;+eam~MVC&~d}Hf>$SIS7T=uE(t(N0rZ3(6T(1BrZ7dQ|9"
			"=H3)Lu6}pq_+9gKk%&.8@(9-Ia.F;FOTbLRB$tA*lVTtx}xz8Yy$#6VQmJ=;4(v&7FPRxn*J)o*UFaqp50@C#^"
			"n)KI5K{)N#X#Y~E#,N0QB%Ndn472ZQek$b8c0C}45K9NE)(fO#Gkm;ypvaxk!,9E.UI5s$C}(h}lS#~fT.poND"
			"N^BPGpN.kyusF;+g2+|~>31b!PfTXbrN)VFn8c7Lbi{lTej7m_FrfMSFLJ0&!W<<p=;}(|2B,6|j)I~8A*c8(e"
			"g%KpwO#K1%F^NG_Fij$h7^R5g(iCHiElgrb254XE54gr8iK9^wAq-OE%qXc$BQ$>yHZdek8i<mHF;U+Ssf1}.*"
			"apTViK7IRDT.~x3Nu&mgfWOJX89omsQ&mwYC.Y.HL)a37$l)ek9;Xb,9c)L6*DqI86W;YU)l(9C@N-xK,JoNLy"
			"195H4+E~#u6Bm6(b6Gl!kwB4kd<,F~!piQkakza6KR41t07NB.X++M3Yf7,9c)L5gJG-;S&-@z{VnARCijMBhm"
			"_v>(fQvpkokM4FrZUDmD.BeNcuZjp8E=AvuI*pv0xdf+L$Zi8d3&F47E+ZxL8$7Zlv#h$5tHLKx6B5t&FTu_kC"
			"k6s91OVZ.}%W<hCE>4r_>u=X_A5zGjVZxw>Zn*#2TV+g4m2@IGGWM;3fA3+)!8^G9tB_tsxWpG7zipD%^0~%}#"
			"vjtncRx!sKqsL;z-5{hD!%,7Q1ti3JVAw,XND+,EM6eQOfW1)_+Zgf2up>=@Heg2=6^vvA)YuWy3|SS!QWdHcu"
			"#.pRcK}_$7fcx$p>qNjr7a-|Gb%w*%}z1~yB0CyrVc(U7~>#!Y*@#3kW!0C)QIj0$ueM591KY*3TOr-upx^9Y+"
			"!K-AjE@kjFI.45@w5mF^jJRaahNWm^-#CW12u+O@Vfh4AM0cG=}m_fMO74grLnS5iE@fL760YNSJ1n8ITM!CVm"
			"ivnU,1{-YXd6rVj0k819fewk%_tNCfSeEg}1CGGJkuE;zzW)Bzeqaj4BfW@M2ZYBNw#nK9tgB1tR+nWOdt_h#6"
			"~jyhoO*s+f30d+PNHF}^H*{GLrM8hS7niTM&gCN2~!qQB@GGoFd8bVCTF91nA1V(HDCS~|V81Bunj~sIW-LYdG"
			"(g$|MjB{xKTV@MLT49h0GH6jzm_d_5iI@gTcp6P1Nic_k5=bPSqEHDlM^Hr_-YXdK#v,T<.TZ-hkUP9qG0mg_X"
			"E3XR(HQ,fW5M;X%n=;oBQih+O#.}w1eim>m4PN,Pzf_E;*4{6tYgO=ATFlBx<KyOv5q=GGdY5!B5=%rNu{BAMq"
			"tf|Vo<~}jsqn;A7P*bB*P{Q1ZIT*lQP>BW1Gce9ysm+bv6Xj2X~6bJG6jTP{OrDNit9gG&D65W)NwNMg(LSWT%"
			"7dGytMHVkZd9lmb#=R|E0Q;<1iA;Wh-+hu1d6jB(rn9YdH9!ZaiyhH7|GBVbXYkYSRZ3}K-l5=<fCIcXy_C<LU"
			"!X$w)!o5f=24@STvE2<MyU,CLMwlU+<0bN5;Dd21)LXr@ZG9eO-k^veT53B<vJUw<A09uenWX36oGa^EONgYx,"
			"P.R8$F7XwC#8Z1bTtHo$HpdXVj>V2B<GaOU9D8GI!xC{45,r^Ahy;<orx;|!jTDiS7NnYhG%4W3k_a(~B$y<g0"
			"%H(,07h30LyF~#(.Gjo#yOy4$70796^j,0=L%6=H6cV#nGzVcfuz,.NwAq21}KRpqBMpf3V1OnW56jWNnk=47="
			"$PVZJ-UjYy#<HNSTaB)CwZFY*cC{DNCjeCcp_(1IiJQ3#Jsf+7_cz7=|%v3R1,g+){u{VOp,I9oXXwND-$RV+-"
			"mAEQ;ZT=L|,w.|~oJ0d&F~Vx#T,DFtxCHp3EWpcKUZkj5aX8wi}Z7.Ng~QxEM1F$GB2M9M*mLOt+>k|X@V3_%v"
			"DnGzVeflH75;S4lK{$UD23X!0R4Ex~NX2}248qk6*Q%NxlU%nr4BxbL;4mKeLaNi<ASm(kmIK&Z.7yMw>#2~I3"
			"NYIus&qP&Nag0G3kt@^+Qxbqz4FpI+QkE&j(h70HWaOZX$dIW27*d#&D2qtaNkhr1#IY<(5|j}n%!vqB)C^k~N"
			"KqEq=@Ui.C{q>i1V*+K$VqjLB=Qu+bwS3pF_h3m!y|a6Aq-NZ>4ZiUq_e1p*u^Pv#u&9K;}oUFBN2$iVlfzuQV"
			"2GPlT|t2t5#tX(S(Q0s^_0QHQLOY=RZ8gm#h%<%=6P-IiH3djf.lmv|qomu$WIZdHKthH<g}!dik.M4#oTKyFx"
			";N=Tim=C{T5~,x&d%KXiB1p1pk8q1e9Lv.P)TU2VO%bsL4Y-GWLD->;nhpzy9_,uVd%eYa>y1P->,$WwTyi)o&"
			"l$%fNyyCb*jmpo{%J$m_}zU#Ckk_TIA8P})8(@R>GvI$&DQr6Q}=iW<bf!Jn#p>C~u,L-K&gpxq(ZIm%yw$juV"
			"6!50Dg;lLhMQ-zM$q9Y2Y^&GJu-yt0Ndv96m}uUKY5,ToqQaK7HEw%yW<R(!7e2mihUid|NFZ%6zk1tCTD}k#k"
			"ouap1eyPMQB,{I-*$pzodd1I3vnzfOeJiKb2sD<%&(hax&<PgZ7{MWuj+@$E+*Ri!Tj~%zU=~$_gjV;>)!^lTB"
			"d!Vb#p@7uSrG*;cg|X,-2_}{{VG!Lw<u&T7kXBfKkRA23etP+HzomNUyft{fK9l_.-1w_3P%ZUa7PqEcxfO8kp"
			"4}HIvvH--IKl*z9!wU.Vg)-I*d_oa.Q&><+hGfAbY{*M|GFC_8^+V>,lieA^DsReJEMm{(80*GP2qg1a6Ex<kR"
			"#2%io2W=W$1t;2eKxUJr93K!n{;S=*;k><_W9d>yM-4^IOICN,Ps.ej@>2$aBH1rd,JQRfQ7fXLbPftUCf2Euv"
			"9fs&kklltE.Im<VqHWnWBpcK7I_xmdw-oqWc1S9uPOU-)+L>A=l<-3OTlx=VPJrx82<&vX^vfbN^fWvgK@;{b("
			"3vF|8-{w6vJb7M;DbE@;V4^n8_QS=YV<9)Z6NDVfwqVRybr;@p_3w7855>C^95dh{+>=X&g03aq2ss>aNl->$q"
			".).s+gj+#Ox01X^5-ek-N$z>m&w>8nXbcLI_$g7SM~Ir;{gkU<*!|@yro#@9E@PfbpkHc&P+TzTF9uA_rl&svk"
			"8#>!nO7<D.Yv+zL0E59~VZEh.C*)wr4<D@g-wYK3(CX~-6kb2KzEWTqeSZ|G#>QbGEf8hJVNf+sfZ36dfQVO_z"
			"aS_bEg_3E,>V*U7YygaI}v3~qB%mc4o>agFxv0b1lw.VjO4Mmc,SQV&23tFM|^!WJxG9Y{U88ST3KL&=LPZ~uP"
			"^Yk.I{YC18bX}oBWQ>8hbcXe48)#RC7hv42xdjZ#A4JWGH!E&ILtp~f*yzaxZO9~TVtcYTc)Eb=Nds+M3|h#6_"
			"&4<Oanl++{S6GC8o*yaLqjKxdZ87ap+aPcf!5b>e&0q$,YPzqb+(qat3f7k*2I;XTH=C9!eg*ES*5NgV4NpVk-"
			"6^yJ.itbUzi1I5JJ|_qu}XiWXaQ8LH>S*o=;I}5A*ai^!#V47~KjQvLXjtnMi)p,Z6}rR)QFUfL7!e#P;_T0)="
			"TETI6o>fKvAztTRxNy2KQ{gu7L{.!i0.(m>l.K}TD,($LA1j$nVEp,nx1T0!&lH1c@q0N#|0b+z0Rx-vG=R&}+"
			"lBeGFJKtk(lSPE)KRJj|rNfVV>+RB|I4(>cRt2Ya7!2@%EtwIP|&LZr1H}o=O<6lmgK7NLtPf&yW{rx<iH.=@-"
			"N=88J>w+urHl<c}c@XFyMo1Rj2qbm3-I2IL<ZY*f>d<Zy;DO!65EGLXTF^TT;44W3ZEcHQE|&hDOq^@g5A*ai^"
			"!-JoA3sAwCmkTJj2coZ2I&Z@y6bBdq^$7hE_9G8gSWRQ*4&@Ddi7Pv+~<S+7&jEX#K0$z3QFp.LI,I8T7(U.q#"
			"yBgxAgL4O7%nh{S7@o8qyD+zo(Pb)d*bZAkvXgXVnpAk-KUYsBSzu3(X^|+;+0mwJB-}T#e2lfqfV^16JLF2Wg"
			"E;yAHtI;44s(+1CZH7fXLbCmM.23r.8vq)|SWhMrF9^+Ff91R7E)(xxy^ZP-).MueH(7PcLpExWk6feVqj#5EV"
			"ugKz~l>=Yp)8Z$FrpzJe%twMyEg*LD}I(;sd{-4Gb(=BEJ(=P&tjXGnnkdBsyOqT),6R>K.m=Pm+){y&C+kzO9"
			"4z&myT0~jsH&,^>5WFb7VRAP(hh2RbHvpLwEx_)@dHL(ZLI&H0a21m#qq,91hcqy^2=H%~fZr~c%fG${gQe2Y-"
			"&d)VPeXsP*zj-Z<l|K!Yg4YlGERgJ-gXKN!<rW4b{lJ06,)JCv(>LbyTC59a5p|.eAF|AyA0wV66-g(0>t=Rb_"
			"xx<LI&.%h8e&%>u$RP(i{%Dt@pIv(D,)yU~}{|@_5K($)~5kzoDm-BG;r5ZMR^VBOu(iO}^,G!+EEM3eaA*+ps"
			"#_<)mn.+ikl94Z5(nVVpq=tqtM|U9,fM@Iwstr^5{3E$Kq7#qH!,m(MJW4Ju|ucU86xO}7LZvS7Bjr_a4U+e%x"
			"*1!yO!sIA+HN+89x5^dUvWC^C0K._.;Xir>I..ZZfOA3jlg{iBNKB3*.<BDe<r*sAUe0*v!O5;vL<KtY#.Sm$p"
			"ZQ61sgDWg0dZH@ORs<Fn(5kXnSXzKtYJjGL>J2otX$y<A0+z6_(!nGmV%DM*YR{at1#JVj3vfX6kx-!Pu#gMY4"
			"6OxZfW084uki&>tdJM|VAnnt-D*eZP<6eEw*xCTKTI;c1^$rw=fc~tH6!#LZvA()LoLI(.}SXhxWBX.RQOwN2B"
			"f1w*6+hS+6Y>jUVt*MCgT4nqPuXy+psky8V=vshI>y2G!^rQ%Db>nU;2tILkn%e1JXr8gLn2JuQ7T8C#vRd2W_"
			"aoAWGk#3@y6r(qN%M*Kh1YntfNH5j9r4Ex_I8zx)v,tI)#RuE6w~lpS@wjfitspH-#z1+yx%>%*}^2HUo!{jkM"
			"Fc,%{3V1el<&~@AQ;e|Q3E6<-+VG~U}^Gy*|t3G{t,Juk-4Yv)o{-A}bE6IiS+jZC=DJamO>$mUhCKt1Owewfa"
			"Up0K$q1e9ckT%>f+i7b2VAi&$-Y8#fw_Sn)ku)N8*4w{-V*bHjwA-{Kk=I*HFW!kkOZ@@zTH2o5(51AxP*agGD"
			"c4fl(4FX-TK=$!U@xZCx%a8UO|jP9dAX3X^|+F-uP~~xL2GI&bMId2Lpt^AaWu66uVhtNP+Hn*D|6.yc{Ar*X{"
			"7~_3z,(LOC.%b!q%X;!@(<PC2@|>";
	}

	/**
	 *	@brief gets raw image data
	 *	@return Returns pointer to raw ARGB32 image data on success, 0 on failure.
	 */
	static inline uint32_t *p_Decompress()
	{
		return p_Decode_RLE_Huff_Base85(p_s_Base85_Data(), 150, 57, 9753, 3, 6, 6, 1, 4);
	}

protected:
	/**
	 *	@brief calculates reverse prediction on a single image plane
	 *
	 *	@param[in,out] p_buffer is pointer to image plane data (just the data, no padding or align)
	 *	@param[in] n_width is image width, in pixels
	 *	@param[in] n_height is image height, in pixels
	 *	@param[in] n_pred_type is predictor type (one of 0 = up, 1 = left, 2 = avg, 3 = paeth, 4 = med,
	 *		5 = gap, 6 = no prediction, 7 = up-left, 8 = avg2, 9 = diff, 10 = grad-h, 11 = grad-v)
	 */
	static void UnPredict_ImagePlane(uint8_t *p_buffer, int n_width, int n_height, int n_pred_type)
	{
		_ASSERTE(n_pred_type != 0 && n_pred_type != 1 && n_pred_type != 2 && n_pred_type != 4 &&
			n_pred_type != 5 && n_pred_type != 7 && n_pred_type != 8 && n_pred_type != 9 &&
			n_pred_type != 10 && n_pred_type != 11); // some code omitted
		int n_first_row = (n_pred_type == 1 || n_pred_type == 6)? 0 : ((n_pred_type == 5)? 2 : 1);
		int n_first_col = (n_pred_type == 0 || n_pred_type == 6)? 0 : ((n_pred_type == 5)? 2 : 1);
		for(int x = 0; x < n_first_col; ++ x) {
			for(int y = n_first_row + 1; y < n_height; ++ y)
				p_buffer[x + n_width * y] += p_buffer[x + n_width * (y - 1)];
		}
		for(int y = 0; y < n_first_row; ++ y) {
			for(int x = n_first_col + 1; x < n_width; ++ x)
				p_buffer[x + n_width * y] += p_buffer[(x - 1) + n_width * y];
		}
		p_buffer += n_first_col + n_first_row * n_width;
		for(int y = n_first_row; y < n_height; ++ y, p_buffer += n_first_col) {
			for(int x = n_first_col; x < n_width; ++ x, ++ p_buffer) {
				if(n_pred_type == 3) {
					int a = p_buffer[-1], b = p_buffer[-n_width], c = p_buffer[-1 - n_width];
					int p = a + b - c, pa = abs(p - a), pb = abs(p - b), pc = abs(p - c);
					*p_buffer += (pa <= pb && pa <= pc)? a : ((pb <= pc)? b : c); // paeth
				}
			}
		}
	}

	/**
	 *	@brief decompresses the image
	 *
	 *	@param[in] p_s_base85 is null-terminated string containing BASE85 compressed image data
	 *	@param[in] n_image_width is image width, in pixels
	 *	@param[in] n_image_height is image height, in pixels
	 *	@param[in] n_huff_stage_size size of the compressed data before Huffman encoding
	 *	@param[in] n_predictor_y is predictor type for the luminance plane
	 *	@param[in] n_predictor_uv is predictor type for the chrominance plane
	 *	@param[in] n_predictor_a is predictor type for the alpha plane
	 *	@param[in] n_subsample is number of chrominance samples per 
	 *	@param[in] n_color_type is color type bitmask (if the first bit is set the image is
	 *		grayscale, if the second bit is set the image has alpha channel, if the third
	 *		bit is set, lossless compression was employed)
	 */
	static uint32_t *p_Decode_RLE_Huff_Base85(const char *p_s_base85,
		int n_image_width, int n_image_height, size_t n_huff_stage_size,
		int n_predictor_y, int n_predictor_uv, int n_predictor_a,
		int n_subsample, int n_color_type)
	{
		bool b_gray = (n_color_type & 1) != 0, b_alpha = (n_color_type & 2) != 0,
			b_lossless_color = (n_color_type & 4) != 0;
		size_t n_base85_length = strlen(p_s_base85), n_base85_size = 0;
		int p_b85_ic_tab[128] = {0};
		{
			for(int i = 0, j = -10, k = 55, l = -62; i < 85; ++ i, ++ j, ++ k, ++ l)
				p_b85_ic_tab[(j < 0)? k - 7 : (l < 0)? k + j / 26 * 6 : "!#$%&()*+-;<=>.@^_,{|}~"[l]] = i;
			const char *p_s_src = p_s_base85, *p_s_end = p_s_base85 + n_base85_length;
			for(size_t n_diff, n_rem = n_base85_length; p_s_src < p_s_end;
			   p_s_src += n_diff * 4 + 1, n_rem -= n_diff * 4 + 1)
				n_base85_size += (n_diff = (p_b85_ic_tab[*p_s_src] == 84))? 4 : min(n_rem, size_t(5)) - 1;
		}
		size_t n_image_size = size_t(n_image_width) * n_image_height;
		int n_chroma_w = (n_image_width + n_subsample - 1) / n_subsample;
		int n_chroma_h = (n_image_height + n_subsample - 1) / n_subsample;
		size_t n_chroma_size = size_t(n_chroma_w) * n_chroma_h * 2;
		size_t n_image_data_size = n_image_size * ((b_alpha)? 2 : 1) +
			((b_gray)? 0 : n_chroma_size);

		size_t n_prehuff_size = max(n_base85_size, n_image_data_size);
		size_t n_temp_buffer_size = n_prehuff_size + n_huff_stage_size;
		uint8_t *p_temp_buffer;
		uint32_t *p_raster;
		if(!(p_temp_buffer = new(std::nothrow) uint8_t[n_temp_buffer_size]) ||
		   !(p_raster = new(std::nothrow) uint32_t[n_image_size])) {
			delete[] p_temp_buffer; // no effect on null
			return 0;
		}

		{
			uint8_t *p_dst = p_temp_buffer - 1; // points to one before the write sitze
			const char *p_s_src = p_s_base85, *p_s_end = p_s_base85 + n_base85_length;
			for(size_t n_rem = n_base85_length; p_s_src != p_s_end; -- n_rem, ++ p_s_src) {
				if(p_b85_ic_tab[*p_s_src] != 84) {
					uint32_t n_block = uint32_t(min(n_rem, size_t(5))), n_code = 0;
					_ASSERTE(n_block >= 2);
					for(unsigned int i = 0; i < 5; p_s_src += ((++ i < n_block)? 1 : 0))
						n_code = n_code * 85 + ((i < n_block)? p_b85_ic_tab[*p_s_src] : 84);
					for(unsigned int i = 1; i < n_block; ++ i, -- n_rem)
						*(++ p_dst) = n_code >> (8 * (4 - i));
				} else
					*(uint32_t*)((p_dst += 4) - 3) = 0;
			}
		}
		{
			const uint8_t *p_huff_src = p_temp_buffer, *p_huff_end = p_huff_src + n_base85_size;
			_ASSERTE(p_huff_src + 16 * sizeof(int32_t) <= p_huff_end);
			const int32_t *p_code_num = (const int32_t*)p_huff_src; p_huff_src += 16 * sizeof(int32_t);
			int p_min_code[16], p_max_code[16], p_table_off[16], n_code_num = 0;
			for(int i = 0, n_cw = 0; i < 16; ++ i, n_cw <<= 1) {
				p_min_code[i] = n_cw;
				p_max_code[i] = (n_cw += p_code_num[i]);
				p_table_off[i] = n_code_num - p_min_code[i];
				n_code_num += p_code_num[i];
			}
			_ASSERTE(p_huff_src + n_code_num <= p_huff_end);
			const uint8_t *p_symbol = p_huff_src; p_huff_src += n_code_num;
			uint8_t *p_huff_dest = p_temp_buffer + n_prehuff_size;
			for(int n_byte = 0, n_bit_num = 0, n_counter = n_huff_stage_size; n_counter --;) {
				for(int i = 0, n_code = 0;; ++ i) {
					_ASSERTE(i < 16);
					if(!(n_bit_num --)) {
						_ASSERTE(p_huff_src < p_huff_end);
						n_byte = *p_huff_src ++;
						n_bit_num = 7;
					}
					n_code = (n_code << 1) | ((n_byte >> 7) & 1);
					n_byte <<= 1;
					if(n_code >= p_min_code[i] && n_code < p_max_code[i]) {
						*p_huff_dest ++ = p_symbol[n_code + p_table_off[i]];
						break;
					}
				}
			}
		}
		{
			const uint8_t *p_rle_src = p_temp_buffer + n_prehuff_size,
				*p_src_end = p_rle_src + n_huff_stage_size;
			for(uint8_t *p_rle_dest = p_temp_buffer; p_rle_src != p_src_end;) {
				uint8_t n_code = *p_rle_src ++;
				bool b_compressed = n_code & 1;
				int n_run_length = (n_code >> 1) + 1;
				_ASSERTE(p_rle_src + ((b_compressed)? 1 : n_run_length) <= p_src_end);
				while(n_run_length --)
					*p_rle_dest ++ = (b_compressed)? *p_rle_src : *p_rle_src ++;
				if(b_compressed)
					++ p_rle_src;
			}
		}

		{
			_ASSERTE(!b_gray && !b_alpha && b_lossless_color);
			uint8_t *p_y = p_temp_buffer, *p_u = p_y + n_image_size,
				*p_v = p_u + n_chroma_size / 2, *p_a = p_u + n_chroma_size;
			UnPredict_ImagePlane(p_y, n_image_width, n_image_height, n_predictor_y);
			UnPredict_ImagePlane(p_u, n_chroma_w, n_chroma_h, n_predictor_uv);
			UnPredict_ImagePlane(p_v, n_chroma_w, n_chroma_h, n_predictor_uv);
			uint32_t *p_dest = p_raster;
			for(int y = 0, h = n_image_height; y < h; ++ y) {
				for(int x = 0, w = n_image_width; x < w; ++ x, ++ p_y, ++ p_dest) {
					size_t n_cr_idx = x / n_subsample + size_t(y / n_subsample) * n_chroma_w;
					int8_t u = p_u[n_cr_idx], v = p_v[n_cr_idx];
					uint8_t g = *p_y - (u >> 1);
					uint8_t s = g + u;
					uint8_t r = s - (v >> 1);
					uint8_t b = r + v; // lifting
					*p_dest = 0xff000000U | (b << 16) | (g << 8) | r;
				}
			}
		}

		delete[] p_temp_buffer;

		return p_raster;
	}
};

#endif // __OPENGL_LOGO_2_0_TGA_INCLUDED
