/**
 *	@file OpenGL20LogoLS.h
 *	@brief image in header, generated from 'opengl_logo_2_0.tga'
 *		- using prediction / RLE / Huff / BASE64 pipe (lossless)
 *		- predictors used: paeth for luminance, none for chrominance
 *	@date 2009-11-04 05:31:52
 *	@author ImageToHeader (built Nov 11 2013)
 */

#pragma once
#ifndef __OPENGL_LOGO_2_0_TGA_INCLUDED
#define __OPENGL_LOGO_2_0_TGA_INCLUDED

/**
 *	@brief image in header, generated from 'opengl_logo_2_0.tga'
 */
class COpenGLLogo_LS {
public:
	/**
	 *	@brief gets width of the image
	 *	@return Returns image width, in pixels.
	 */
	static inline int n_Width()
	{
		return 150;
	}

	/**
	 *	@brief gets height of the image
	 *	@return Returns image height, in pixels.
	 */
	static inline int n_Height()
	{
		return 57;
	}

	/**
	 *	@brief determines whether the image contains alpha channel
	 *	@return Returns true if the image contains alpha channel, otherwise false.
	 */
	static inline bool b_Alpha()
	{
		return false;
	}

	/**
	 *	@brief determines whether the image is grayscale
	 *	@return Returns true if the image is grayscale, otherwise false.
	 */
	static inline bool b_Grayscale()
	{
		return false;
	}

	/**
	 *	@brief determines whether the compression is lossless
	 *	@return Returns true if the compression is lossless, otherwise false.
	 */
	static inline bool b_Lossless()
	{
		return true;
	}

	/**
	 *	@brief gets BASE64 compressed image data
	 *	@return Returns BASE64 compressed image data in a null-terminated string.
	 */
	static inline const char *p_s_Base64_Data()
	{
		return "AAAAAAAAAAABAAAAAgAAAAUAAAALAAAAHgAAABUAAAAdAAAAGwAAABoAAAAeAAAAEQAAAAYAAAAAAAAAAAA"
			"AAAAHCAYFAgEEC0QDTAkKUDsQ/1X2D/r9EiJRDBMN+RYuL3sO9xX+GiZFFPh99HobNfJHFxwRGE/zQO3oIRk85"
			"GEe7vB82fHl9fsw6ikowx3rgSU03+Aq7yQn1Oy655c2/CDY2yvi4dXc4zLeuznQ1unm19rTzcw/PkvdLEM6vlN"
			"Zy8rRwjMt0jgfuFe1ra+doZ9Iv8fBmb2lxCNeYMYxRk5YWl2PkZujpqepQquys7e5wMXIzs9lrMmxlYucX4BbV"
			"k1KSapBaj1waWhnZmRUccY7gEcYjH5BemY8MocgEwBAQ8Jb5uTRgwyuDkmawzgSnhE+BZp0aT8XaE+bwbOPWzg"
			"SgLQwiYOYkXUhHKMB5+zTt7bXXE+Z7fg1s4lC0MMwYxaqTEgTCGkgBBB4ko039rane8OhM9vwcoShawzOZUtVB"
			"MmDCJWiLr8p8GhBe6nay9yd/tE/h9PwZ5QtZ+ZUtVJgmYRKphEQFFIvUcYCAOAB/lHuxfsbXN2nPzDf4fc5QlW"
			"s+MWqgmTMMp4YIqNWzZMNPB9I6EoC0OWMOfZx4+93h6vvXfn7Ln9w3+X5euJXa5dS1UEyZhEpIfi1NSq1SS8+g"
			"IAY0L3jmAcgtbFrY3ZWz6W77PZ+bac/CNyb1/YErtcvhFQTJmESgIp/bapTnqLziQ50h5NEYeZKmcGxa2Pdx/X"
			"9n7Ds7+sepw/Vzyu1y+EVBMGeUBFqXtKlOovJRzx23A0Ipt2VK5L2xse7+f3/4PE5/MObN9P4BsZ8dqoBMmYZQ"
			"f6Hb38tGilz1xpOOIi0cPJs6Xe9L+fzfSa/ILM32eOV2uXw1EirjwygPU7fc1JZuaAquNNaPa4d+V/l/J+3d/l"
			"Fmb9XlbGfHaqJGDHhlDS+ff2pZuUBOcwWcHepbuxoueEUZnvea1sVOEhOmYZT/Q+31bZufTD6EHraj/6RRm+96"
			"NrPw1KYs6XqXpwqJc/iGA0zXHBhmhKP+Af6/o2tipUpirgwd7wBKD2p+059Majg4PP2M4lPja2pxCrN6/TGt8u"
			"DvbFLRclh/HyAS6OUUZvaqArKOkH+X+5az1OGWNSZ7cwYQaPb+C83F94fbme/ytjPjtB6jyv2PF4nAMPsSu1wC"
			"98A2NDyPBE3tehzngzNpuaYRN2dnnEGVea5oh+b/jaz4+GmN+ZMwyoqNV+Vs+lZ4ev+3b+kH8P19n2t3vEOgdG"
			"L7ut8zgtd7g4djW5Xe5Y2Ok4kXZuz9oc3k1qcscz2Oa5TGpN4/Q5rWsKcsd/5kWwftdfDzLUseSZwDS9TSpC1s"
			"fW8syp/P/+nqj4pn19n5N3gGlRf527hx0fw0ua4OXw62HPe5cqzSmuJGlrfa5vJ8AGyOqGtnUceGlN2fQ5u7sg"
			"bOpT2ve5rmmH5ndwzOGpTHbmYRpX60SQOTSs/VR5f9PE58YvTfP6+xu8EX72B8St36/BhH+zoNNB+l/34J0TiR"
			"vzfk5vJ5h6tkYNYDsW3HhpTfe5u7s93yI90Cn+boNaYRK68zHpijMlC/1sCEiI3xn7CPu/Zo/GL3M9jP7WGKh2"
			"cDGY9If2Sh5fV+yQsygcu2ym4kTsPTubI5P6qXJ7CQzu1rrwVnrpGDrdVGp+fU1vh9DuOUw/N9PPzLVSmKMwDo"
			"dXAgh23IvJX9uZu7PbmgODlynKKKYPlynKKCEE0OCbyTX2gJuPlY8crxVrqADeGfZfsvTQKgfBNNNC7a7vcA7M"
			"9qd40jzdxoeSbztPk2e79PpAeWnrbKe25TCJvu8ypohla2imP/yj1frjP6ul/pytrb/c5UwWa32EATfT+DlTBZ"
			"2utOHB9A+Hz/gzhGX57o9Dl2sI61tBCi1t/HntTsCQwpkqkNJnV7opc9oJZL5AEvDyTbStYJQ4H8oGp9qUimEc"
			"zp1LVIIwjfoyx//OS9v0hysfK2Nj2+cwqnj+TzfwIm+z9Hq3CqeP5Pc//z4OUPwe5MaqeP1fd/9v7FSoItE0jS"
			"mgP7e2AlwCoH6Q0jzdIWdsDmSotYd37Dwo3Om1T2bL7wZT83a0wq1y9EIMPJlj/6cQ0gVMfe9XYw+KqMPo63v9"
			"Xxe19Hqp84x6Xt+r93/ta4Odn2+aY9LsTP1fl1rQFF9wCZ/hnIRSva/L9kApkqkNJOCcFOCb6POa2R2X3g/NA1"
			"g4kUUga2px3JYOZUtCpbATSAYkQVPHy9bg9TrZUclL1pn7HV7vLufF1Zczf/y8/7Xzczhzo+Lqy5mDnSuxyctI"
			"BEN+V7nAAScfO8HcAqB+kFOOEIsfHztrzDuwHLCqeyQCUhmyLlICpSCETBzKQHjSOtZAmP/b86m5gT9b2+n0+v"
			"U29LbOaJ3n7vCkaWp2dpyaPJ7PgmNVJh1CG/K9PwSnzQM+tcAKZKyjBN2dm615h3etbOWNTWASBcEvWAj84Ggd"
			"f5XJY/hma0wUmATtqm4ETrfe1t3Ytc78cRCpw96VyngL0TgcohFTx2ZiQJiREj1/ZA5OXMlEGVA/tjBN4/Q5u7"
			"sju9b93TpCrqc7mAKHJT2eYuWEInemikDQOP8qKYwTfBjmDSQKKXyHkVb9wWuHYuM4CqAIQaQqy8Q6DQDKTPGj"
			"x+7dQKP2NobH1FazwUUzbFWbx+hzd3ZGPQn03LYHaSH+YJe6KumDZbExFIGj0/teJxoVeZ6PDh35yAVoOEPJyx"
			"MetCl9hrltDltUqXAkBxIDEjto1KPOQP8fUwBN3Um+VqprPvBiDs0hVm8foc3k2e752bbNymGJq6yRO8YFSPkA"
			"JksPntM8cxFIGj7tvacIepM+vu45Xr0Q0FehouAePtY336Mqp3NR4MQ9wJAVLE9Hr/0hFr8Hzdtxyb5vRmWpkp"
			"4GQ5fny2h20zu16AGt4Piy0Y7QFGb2vQSNJ/7/wj4ak1y4BsjaOWDTOq9hGmP+swDh/8/+ufTcmd7u/B6fB6nV"
			"s5+WJn5ufEJnm5WHszr3no+p/yMCbwKMgLksb9na6H+b49v7+WzT5Wx8mtnaHZqAfJ2jetPWhsUvpehzeTkp/F"
			"L9hIrc0LT6HOG1LqaezqU1bI2ebuju/TTLFFyKv2JgRLH7Uy5Mmfh/NSetbHtY+DofHtoA1pnyfx/lR1/q8pH2"
			"7df0fB7Gx1tvH5u7Q/dGOUFEPi5eecEdL+rnbomc7lRVLWtnQjhAmipjwnj5yCD8yZUx3d14DaSK27+j+Gd09r"
			"W83HB0ODZGtpBrd2R1onNMUX+rV88BDQ8iAyj5+flA8IlRa/W36ZDxXNT0v+KJmFH721Z39D6PP9H5EDOeOaOA"
			"C48PFKQBT2v3/o8soZ+UJQ0vU/z4QHBrcAlaYY/wcp4DZeGl3JmEeYDuP7WwvZGyQZyfZfpCyi36/n4UTENDfQ"
			"A76XOGOdR1NrS39Nwh4qPr3t2UH69aciz5w3d2UBd7e05Z/fz7SiHirMqoDmih+t6XOx8MU7t9nSpfWs7U1nr6"
			"mekKNd7k9MeNlMdnpIOr8GwPOOj2fZ9H5QO6PJXiRbFGz2fF9XOaGhpEJvt/HalAPzrdFLjw8RdXs+1Kfe1Jxh"
			"Gi/tZ7Up96dbTg/+cy24kfbf87SeogOafNy7/ug2qU629L6otm51urapCLURucAtPWnnh0LMtW+nmCc+jffy7G"
			"tM86ll1D0REjb62z5QgIaE57P9T5ogxKUaYoy8G3zEuGQ33IqeEcwGlwU3w44kGjRwBxI0nGk+76NDaQx9APAE"
			"uM0cFzTBqcFnUpC8pxzTs3ApwI0Z2MTEPG5lFlruSse6DQQiqFae2Pv7nNcpBWdiUUgpxqmFOOUwpxx4WZuH+7"
			"6uhtaLhBTjhBTjm2A5lCnHGgxxw+eItPzh/ZugIQkCoQP6Ov8M5ymEd6VOmaAszfZ+75/z6Utz+QTnMHnWvW3R"
			"hsoICokH19ja6054Gz19Sqi+LPpex0bnz83fa/3jAjB1nvo8oBoQkT6lQnh7nX2vl0XAD63Veo/CJ2Hd9j3ucz"
			"5+bvn+kVUaIf1P8JQw2QhI36gtRTPc69LudKI9HAHPXFWbwef6O76cyr6/Z22vxCq5ovvVf3N0A5lFIu1C4XhR"
			"w7D2pS35zmYXcPB4OvsbHp50c3rbWBH4xruU+5qYPZ9jhlPgIQKgqEATXaP0X7NLbfpubQnzMfBybGfYw8rWzj"
			"f9fS39Nz9Y/5uNGjS2vrerwyg+aAgVKgKoKOezsbPoh+yKSHg+EjmCUOQbAziVaz4+dnEroVt/altfgHxOYKMv"
			"S3frerwypT4MICKlQWhjFEItbA2SHqPyn5T8p+ULWGZj4ZmcSh0L2l1bZuf2ieejL1NLY9n0sfCJQfBhCRpVBa"
			"AeBBIRMRMSO3zKlqoMYwygIuhXpZYqbn946zjRzse11+9zvS4JUoSg+AYEwDWQ0IpgEwYQJRCKKfpaVLUlm5+g"
			"dBxw7OCVydmV2NnHj4ZQEoB9IQeE8JASqYwRaj/bwUp1F43PqCehEWDbled7UrvYd2VjxjhlJDJQlUxdiGo/Zq"
			"tUpz1Gilz3BPQiKbpYZUy1a2N3PnlYxjeG/RAo6lmlSesvoY+456Y1HHDimzeZa87ktWpSQLSRgeD7wnIfNLnL"
			"GBxxBzZ03mAeN4WWAJCXHIwsKccjEYjEY/CAtIS4lTHHFxhoIWHFPMaSTFKXUClqJiUqQjRJKEJYxXtAKSxCUo"
			"Qku4aSQlji+MPqYxKUJKmaiLbQgkERGZExS/fFlbGJSgiaNRFLRTYFNMShREk1Ez84fUxiUFTME0iixiliOPRF"
			"GOMLUxiSQZoX+oPuMYkiaNRESEMUuPMKKlMIzR/eDYxJE0aiJKGMVHfD6mEaV/hBsYkiaMElCmK+kEKM1f1hDG"
			"IKmb5IQSo/vBEakJ/WDWxJE0YJKFKj3gpRfjCFMQVMzJCGR//YC/xBDiUFTNBIJUYaCHEoKWaiQQC4wkMSgqRh"
			"TxKQz/UBxLDSxji6YYpTEgLth6P7gKP9kMSgspqIkmomfxBCmIIjSQU8ImJI2BjESwqO41NEeiFR3HpoudIMYg"
			"rZoJDGJUbCMy+mEMSRvERhhCcwjNQYlLjQRHNm8SbCeIXKQZHN4isM4uKblDEEVI2IQxoGojMpBVYkzQhilMQS"
			"TDiREkzILSpdMMm8Vh7EmwI5YRHN4rBYk2Bc0QxhFSNhIZLBrIzV9IPoI0MjeBsQRKSEJMytiK5xWMWJYGJNgX"
			"JYq3OKxijjVHisWJuiFIK2akIpAKSYj1QbCMmJAjIEiJYCTNAXpiK5YxYo1gRpsCbLCOLisYiAmpsCOkGLIrZq"
			"QrTClhJ6YC7YC7YC6YMjNC5YQtSlpCEmZUgqOanEQNdixixUwcfFYxRkDuWLGK5SClFompEdsTkmTApjgYklIU"
			"0AxJYEMWAtjA4hJBiQbhGSPuBCTNFsJjFx4I4rGLFTB3LFjFNIC4mwLlIBmiaiRojfSZAMQgzQlBmlIiWRoSgz"
			"JI8hEwzSgzIBhmTPuBCTMuqDucVjFHTB3LFjFcIHcsWMU2kAnbMFoj9phkwMMyXHGEmagCNIjjUZqCzMkiONRm"
			"oKMyY8GmRJJYCTNH7IfuTbGLFHTB3LFjFcIC4mwqavTALbNRLtiJhksJNCnhRQZBhIeFlJmAZMeESDSEmZJeAJ"
			"J4CIzYAkzL7gox3JtjFijlg7lixiuEDuWLGKbSALbMFoiywyASZNCiozCDJoUTMAyU8DSaQpJhDwQkkEk7JKAS"
			"Zo6QijucVjFijEdMHcsWMVwgdzisYptIAsphVsWSMgEmx4PrYZgiOcRGZIAMmgaTQAkwh4ErAkzQoBJmWUUY5v"
			"FYxYo6QFxNgXCB3LFjFHSAZlMFSEThmQCTS0LyjMGbEMShiGMcBkp4PsNACEmGSxgIzQoBJmW2KMc3isYsUdsC"
			"4mwJpA7nFYxXKQCukYVpiJJkoBJoaGokzCDTGIwIyDDJTwfYaAFEdMROEZkoBKTCrYfjm8VjFHlCbAmpD65tix"
			"ijtgI6RywhhGhIQwzU8KJGwKNFIMMlPBjDQkAkmEPCctJGaFAJSYTSFmObN4rFwB6NgEZXFCamwI0hE2xixaIC"
			"ukaiU8DYRoUkISZkQiUZJAI0NB9YBkp4eow0ALUgjMmMUxBmRIUAkjqkhKEoQSBc4isDiKb2eLiAuTZtjiFzFY"
			"scUcdzisYo9sbZhiTiJCUEZoUQCSN9TjDJiRpJIyYtSTUAaFPBiSQQYxBJMEk8BMYhCgCMrZqHFbsXpoFyxYxT"
			"QMWKxY4uKxYxYsoUorZqQoifMiQxbwNJsUSTYTIyDFESTURpDEIU8GJQx4BSUJLAhDAxCFAK20AbeJgFwsSRLx"
			"CPpBRFbNio1ExSl0waTYASpYeUIyAXTClxtCzGpjEMYtIUpZALtqUAmMK040g7kcYWkCNOJMYX0gxZFbMJyhiT"
			"T94CP6QC6YQ4xUfcDFIK2YRthiTTQCmJ/SGMQVI2ETlsMSTNUKYf4gxiCpGwiZSDFIR8YQskR/kCGIItMzIkMX"
			"LClx/+Ahhoj/mCFIQVI0ESGfeBsM2R/0A1oQRaZpJiGL+MPuJIzV+AHGxCCtm+RISxz4RZcYgjJi/7Qa2IQVs0"
			"kaEsY55wqrDjGIIzIlesFKYlAK2aCJCEpSxTi6QU44TJyUEZkSFR/oClMShRFomkkoeTVYliWJYlKCJJmRIQr6"
			"gYtjCQoi2z0SaMElCmK94IjWwnkJLqmknkKYrrg41qYymgiYZG8UtCGKVH0wiMKUlnSQ+xilLjjDFqVbYpS4xG"
			"IxGIxGIxGKQQbREmqnK/VqyyJ6MJD5lVyz56a7WZNc5+WW0vWCHpeWemunM/DDr69++TaL9/X10wnmrz8pcob6"
			"ss+vXzZoYde/fddoSFA86mDBJQoOt39fNXqn7g7astevmzQ699t2hJJA6623tw6jcLbbsElBu/Xyn9QeRcufXz"
			"Zob7btCSCB1tuXCm8U8XUz03kw2W23ZHb9cuiNJeWvXzQ33XaEkkDrbUM69PiaaWtS1kEriUpa2mrs+8ltEDsM"
			"v9Qu1a9fNrtu0JJIHW2yhivXWlqCwp4U1tCqtamort5t2SEvvi6Vevm126FCSSB1ttMNG9EtQCq41FhS1qauz2"
			"5Mx/gGoufXza7dChJJBA2mF+9daWtXwgLSH1NXYJMv9Ioqr14b7tBMk6B1uGFuJYVqhK2Rbmb9Yfl182u3QKRT"
			"raYWRLX9MPkFxNtfkD+WvDfdoFI+63DDPXvA1ktUv8QOrmhbdekowNwtxLV/qGPBf8oOrmhv0GpLMDe40Ao4w4"
			"DLNC27TkwQSRX227+vDPLeE56rPr181evVNoRFlyz2g1LapAayewNb7gR0+x2On+yEZob7suRME511tt2B1uuv"
			"/oKuWvDfdoUHb+vr5XhOr5td2eqvXhVTCun32uoOnohXY773UHf6QRPhvuy5NKB1uG9PuxXbzcFC+994In5r8j"
			"zZuyOuzyE7nt0HZw59atVaFHsdTqb2hq6Cd4d+kJ3l6m9oaurob291MoRDrt0Jchuwwz2krohUTbsmvIN+fmdd"
			"hhn3Yp8LbskFVInVqEDbUutE0p4IX1N7QeyJ0B2JYR2OpvapZEauhod/RCJ+vfoS5KMDcM9SlkH1tNwQZaA8hQ"
			"tuw3lrAW1ehbbupB1qEDbRALeB9/e0MmRLQyJ1R0ZYq9He1cnGudx5NXQ8NsGuG+7QlyIdhhVTFFa4nYHdbVEV"
			"e/I3eUS9ZIDRQ1ZYFahBC0YC2hF0dXJk8EsBadUeGWIt7e1ci1AeFOqPLSCJd9uhLkRA7Dd0w+aoHXSphTx0gp"
			"47YUbzQf13XYWlUxVauxNEBWkgba0wrp+FOQLSDl6GhkyUw/5d7Qycakg/W0NXJ0aQRObdoS5EQOwrtjSrQNzx"
			"lr1Wq+vfvw5Xh4lV9e/fhnmAdeu9Vhv39eu0BVboNwyxqLJYCwK1CCFrTD6+nx8fvkQPe0MmR5oH39DVyeFIor"
			"6Ohq6vrL0wjnu0KEuRkDcOiN+tA20K8MLsG5W3IKGZI+eXryblbcgoa4Ba+vz5IK25BI2sT3ZG7xdIHWkgbath"
			"i1kQPv72rk46Y0ujoaGT31gL6OhoZPCvTCKztChLkRA62u2P2ufI3z1c+g620tbVaCTKGteSs0tcUEk4S3YG6z"
			"S1xOwThOoSNz3gJ71edmvywK1CCFraFHv9TQyZOmtoP9HQ1cnrLSH+joaur4T0wxuhQ05EQOty6Q/bXz5G2irQ"
			"QxBQCtyC+J7e4oBQrSOrXI3eUApe47WGahI3WIKXrpdqt33YJ4FaSBtrpCjrd/qaGTJxyw/0dDQyestIPo6Grk"
			"8NIBvRkY62u2J3PkbaKs62taR2SigoCF1tawFNSOqXI3dJInKrO1lTpIHdx4b9ZuFt2CBucBWoQQtZRF2O/vaG"
			"TJxr6dMH0dDVyesQf6O9q5PC9pgN6MjIHZ1sRX4G1KrOzyIdA+fJAtuhBI6227I3CFyNtPCdWg3CXBA7uKICcm"
			"KrWgdhnAVpIG2tsWfL1N7VyZONemH+joaur6y0g+joaGTjpBXPg0ZFQN0hFVddbWK0lZ4dBc6SBVB29uT625P3"
			"L16quRuc8H+fBuKXuJgE8gFJXVboQQzgK1CBtrRD/l6m9q5MiV6Yf6Ohq6vhWkH0d7VyetphC50EGjIqDLpiLN"
			"I3dUK1DceHQXmkdXuO1lqWpS1BS5G5xDAvnwbgauuwQO0xqVdd2BucBWoSOzrYs+Xqb2hk41FbAWnVHhSKJ9TQ"
			"1cngXphC9yCDRkU6VMYJ7bsKgOfQkyvCzruzxdd3Fywhcjc4hqL58G4Apt2ChCRDSl5r9B2GcBWoUJMwptYHh0"
			"+p1N7V98K6ZazAOmXfUPCnVHYSEdTQyZLYQqJ2DTkTAiRvKtIfantwQxJB1qEDa0iLLQbrBpuCF4UXjC5G5xDr"
			"L58G4BLihbgd168/LXhoQNtwzgKyZNR3XhzQ5oYW4R394tAbxdT5d7eA7/U6mhvK9bJq6G92Ox397VycaqQNan"
			"XYJcnQgdvOwUG4c0LcjsN1awK0CXa2WrXoN3gF1m4G58vLmoZQt2GcQ+JdZvcAWJ8LbsFBt2hA3evQwzgG3W3X"
			"YHpDgddVvPar2h8ur4QOjoauTwkMmTV1d7e0NXJkWvRCLrbsEuRkG5dJt91tuG808MFaC9dbdgdbvLSNJd1tt2"
			"CBt1YXDDOIIXWhvEFLuphS3ghhntT4YZwF3RhVuL28jFL6JZGBpUvIrwK2wam24INOTBdXFPn3p91pS3hgrQT1"
			"NRXbsSlEGLaiTdsxLIE00sgha2ltCeuKfehvT2lhUTSwtTVuJ9Q8HHxxS+PU8AC/f4+NRglcach8fGuWvbBk02"
			"27TkTQZWWEr0xFWgrAgsLaFVZLCwtQCy0wFNB9QaaWrRFtdkBS1hYaWCSES1rUQo1Z85agraB3YW4IHpIqFB12"
			"EgF6YZWgrJAXohS1/ZCp9ZIC/4wa58LbrUj9Cg63r1bYZWbn6oZXoL/SH1z4W3YGpH6Drd+u9phl2Hc+MIl39x"
			"f4g+qfC23A1JRoOt34Z5tBC1NL0AZV5Nxf4xRXdhhbdgako0Hb+vDPaeDGgr5g+Vd2Cev+gUWoYW24IHpIqFBu"
			"/rw15a9ARPVczcDt1RfrCVvz4YW3XXpMFCg67f14c0+q9CImqteFuBu81/uES2r0MLbrsD0mpQddb19eHNXn1W"
			"l9wXTKrPrw69CBtu6pf3wxUV5MKG3YIHpKNB12/fhhTm3K8+fVlkTTTzzTRFVqz59evmhvuwNtw3V/qCFqivJh"
			"fbbddggKSjQoOu37+umF7N8tfNXzV81fNmh177skDbcMN1pav0A1ran3ihfbbddggKRNCJ11tu/f17+uV+y27Q"
			"kkddbTC/eiUFL/OHyWtqe29CltLpQU5EwKddS29Cd6Jpa/rCJYC+m1dn3qcJNsdbdeblwsvXYkrCvMKqwQWtqK"
			"7PvXulDOvXrsTS1AK9oVVhQWtpqK7PntXkz511ppQWQC5oUsEslWVrC1qC4w8EraCVxjtA";
	}

	/**
	 *	@brief gets raw image data
	 *	@return Returns pointer to raw ARGB32 image data on success, 0 on failure.
	 */
	static inline uint32_t *p_Decompress()
	{
		return p_Decode_RLE_Huff_Base64(p_s_Base64_Data(), 150, 57, 9753, 3, 6, 0, 1, 4);
	}

protected:
	/**
	 *	@brief calculates reverse prediction on a single image plane
	 *
	 *	@param[in,out] p_buffer is pointer to image plane data (just the data, no padding or align)
	 *	@param[in] n_width is image width, in pixels
	 *	@param[in] n_height is image height, in pixels
	 *	@param[in] n_pred_type is predictor type (one of 0 = up, 1 = left, 2 = avg, 3 = paeth, 4 = med,
	 *		5 = gap, 6 = no prediction, 7 = up-left, 8 = avg2, 9 = diff, 10 = grad-h, 11 = grad-v)
	 */
	static void UnPredict_ImagePlane(uint8_t *p_buffer, int n_width, int n_height, int n_pred_type)
	{
		int n_first_row = (n_pred_type == 1 || n_pred_type == 6)? 0 : ((n_pred_type == 5)? 2 : 1);
		int n_first_col = (n_pred_type == 0 || n_pred_type == 6)? 0 : ((n_pred_type == 5)? 2 : 1);
		for(int x = 0; x < n_first_col; ++ x) {
			for(int y = n_first_row + 1; y < n_height; ++ y)
				p_buffer[x + n_width * y] += p_buffer[x + n_width * (y - 1)];
		}
		for(int y = 0; y < n_first_row; ++ y) {
			for(int x = n_first_col + 1; x < n_width; ++ x)
				p_buffer[x + n_width * y] += p_buffer[(x - 1) + n_width * y];
		}
		p_buffer += n_first_col + n_first_row * n_width;
		for(int y = n_first_row; y < n_height; ++ y, p_buffer += n_first_col) {
			for(int x = n_first_col; x < n_width; ++ x, ++ p_buffer) {
				if(n_pred_type == 0)
					*p_buffer += p_buffer[-n_width]; // up
				else if(n_pred_type == 1)
					*p_buffer += p_buffer[-1]; // left
				else if(n_pred_type == 2) {
					*p_buffer += (int(p_buffer[-1]) + int(p_buffer[-n_width]) +
						int(p_buffer[-1 - n_width])) / 3; // avg
				} else if(n_pred_type == 3) {
					int a = p_buffer[-1], b = p_buffer[-n_width], c = p_buffer[-1 - n_width];
					int p = a + b - c, pa = abs(p - a), pb = abs(p - b), pc = abs(p - c);
					*p_buffer += (pa <= pb && pa <= pc)? a : ((pb <= pc)? b : c); // paeth
				} else if(n_pred_type == 4 || (n_pred_type == 5 && x + 1 == n_width)) { // med
					int a = p_buffer[-1], b = p_buffer[-n_width], c = p_buffer[-1 - n_width];
					*p_buffer += (c >= max(a, b))? min(a, b) : (c <= min(a, b))? max(a, b) : a + b - c;
				} else if(n_pred_type == 5) { // gap
					_ASSERTE(x + 1 != n_width); // the last column predicted using med (gap looks right)
					int nne = p_buffer[1 - 2 * n_width], n = p_buffer[-n_width], w = p_buffer[-1],
						ww = p_buffer[-2], nn = p_buffer[-2 * n_width], ne = p_buffer[1 - n_width],
						nw = p_buffer[-1 - n_width], n_d = abs(w - nw) + abs(n - nn) +
						abs(ne - nne) - abs(w - ww) - abs(n - nw) - abs(ne - n), n_ad = abs(n_d);
					uint8_t f = (w + n) / 2 + (ne - nw) / 4, g = (n_d > 0)? w : n;
					*p_buffer += (n_ad > 80)? g : (n_ad > 32)? (f + g) / 2 : (n_ad > 8)? (3 * f + g) / 4 : f;
				} else if(n_pred_type == 7) // 6 = no prediction
					*p_buffer += p_buffer[-1 - n_width]; // up-left
				else if(n_pred_type == 8)
					*p_buffer += (int(p_buffer[-1]) + int(p_buffer[-n_width])) / 2; // avg2
				else if(n_pred_type == 9)
					*p_buffer += p_buffer[-1] + p_buffer[-n_width] - p_buffer[-1 - n_width]; // diff
				else if(n_pred_type == 10)
					*p_buffer += p_buffer[-1] + (p_buffer[-n_width] - p_buffer[-1 - n_width]) / 2; // grad-h
				else if(n_pred_type == 11)
					*p_buffer += p_buffer[-n_width] + (p_buffer[-1] - p_buffer[-1 - n_width]) / 2; // grad-v
			}
		}
	}

	/**
	 *	@brief decompresses the image
	 *
	 *	@param[in] p_s_base64 is null-terminated string containing BASE64 compressed image data
	 *	@param[in] n_image_width is image width, in pixels
	 *	@param[in] n_image_height is image height, in pixels
	 *	@param[in] n_huff_stage_size size of the compressed data before Huffman encoding
	 *	@param[in] n_predictor_y is predictor type for the luminance plane
	 *	@param[in] n_predictor_uv is predictor type for the chrominance plane
	 *	@param[in] n_predictor_a is predictor type for the alpha plane
	 *	@param[in] n_subsample is number of chrominance samples per 
	 *	@param[in] n_color_type is color type bitmask (if the first bit is set the image is
	 *		grayscale, if the second bit is set the image has alpha channel, if the third
	 *		bit is set, lossless compression was employed)
	 */
	static uint32_t *p_Decode_RLE_Huff_Base64(const char *p_s_base64,
		int n_image_width, int n_image_height, size_t n_huff_stage_size,
		int n_predictor_y, int n_predictor_uv, int n_predictor_a,
		int n_subsample, int n_color_type)
	{
		bool b_gray = (n_color_type & 1) != 0, b_alpha = (n_color_type & 2) != 0,
			b_lossless_color = (n_color_type & 4) != 0;
		size_t n_base64_length = strlen(p_s_base64);
		size_t n_base64_out_size = (n_base64_length / 4) * 3 +
			max(int(n_base64_length % 4) - 1, 0);
		size_t n_image_size = size_t(n_image_width) * n_image_height;
		int n_chroma_w = (n_image_width + n_subsample - 1) / n_subsample;
		int n_chroma_h = (n_image_height + n_subsample - 1) / n_subsample;
		size_t n_chroma_size = size_t(n_chroma_w) * n_chroma_h * 2;
		size_t n_image_data_size = n_image_size * ((b_alpha)? 2 : 1) +
			((b_gray)? 0 : n_chroma_size);

		size_t n_prehuff_size = max(n_base64_out_size, n_image_data_size);
		size_t n_temp_buffer_size = n_prehuff_size + n_huff_stage_size;
		uint8_t *p_temp_buffer;
		uint32_t *p_raster;
		if(!(p_temp_buffer = new(std::nothrow) uint8_t[n_temp_buffer_size]) ||
		   !(p_raster = new(std::nothrow) uint32_t[n_image_size])) {
			delete[] p_temp_buffer; // no effect on null
			return 0;
		}

		{
			int p_ic_tab[256];
			for(int i = 0; i < 256; ++ i) {
				p_ic_tab[i] = (isalpha(i))? (i | 32) - 'a' + ((i < 'a')? 0 : 26) :
					(isdigit(i))? i - '0' + 52 : (i == '+')? 62 : 63;
			}
			uint8_t *p_src = (uint8_t*)p_s_base64, *p_dst = p_temp_buffer;
			for(const uint8_t *p_end = p_src + n_base64_length - 3; p_src < p_end; p_src += 4, p_dst += 3) {
				uint8_t p_tmp[] = {p_ic_tab[p_src[1]], p_ic_tab[p_src[2]]};
				*p_dst = (p_ic_tab[p_src[0]] << 2) | (p_tmp[0] >> 4);
				p_dst[1] = (p_tmp[0] << 4) | (p_tmp[1] >> 2);
				p_dst[2] = (p_tmp[1] << 6) | p_ic_tab[p_src[3]];
			}
			if(n_base64_length % 4 == 3) {
				uint8_t n_tmp = p_ic_tab[p_src[1]];
				*p_dst = (p_ic_tab[p_src[0]] << 2) | (n_tmp >> 4);
				p_dst[1] = (n_tmp << 4) | ((p_ic_tab[p_src[2]] >> 2) & 0xf); // fixed byte order
			} else if(n_base64_length % 4 == 2)
				*p_dst = (p_ic_tab[p_src[0]] << 2) | (p_ic_tab[p_src[1]] >> 4);
		}
		{
			const uint8_t *p_huff_src = p_temp_buffer, *p_huff_end = p_huff_src + n_base64_out_size;
			_ASSERTE(p_huff_src + 16 * sizeof(int32_t) <= p_huff_end);
			const int32_t *p_code_num = (const int32_t*)p_huff_src; p_huff_src += 16 * sizeof(int32_t);
			int p_min_code[16], p_max_code[16], p_table_off[16], n_code_num = 0;
			for(int i = 0, n_cw = 0; i < 16; ++ i, n_cw <<= 1) {
				p_min_code[i] = n_cw;
				p_max_code[i] = (n_cw += p_code_num[i]);
				p_table_off[i] = n_code_num - p_min_code[i];
				n_code_num += p_code_num[i];
			}
			_ASSERTE(p_huff_src + n_code_num <= p_huff_end);
			const uint8_t *p_symbol = p_huff_src; p_huff_src += n_code_num;
			uint8_t *p_huff_dest = p_temp_buffer + n_prehuff_size;
			for(int n_byte = 0, n_bit_num = 0, n_counter = n_huff_stage_size; n_counter --;) {
				for(int i = 0, n_code = 0;; ++ i) {
					_ASSERTE(i < 16);
					if(!(n_bit_num --)) {
						_ASSERTE(p_huff_src < p_huff_end);
						n_byte = *p_huff_src ++;
						n_bit_num = 7;
					}
					n_code = (n_code << 1) | ((n_byte >> 7) & 1);
					n_byte <<= 1;
					if(n_code >= p_min_code[i] && n_code < p_max_code[i]) {
						*p_huff_dest ++ = p_symbol[n_code + p_table_off[i]];
						break;
					}
				}
			}
		}
		{
			const uint8_t *p_rle_src = p_temp_buffer + n_prehuff_size,
				*p_src_end = p_rle_src + n_huff_stage_size;
			for(uint8_t *p_rle_dest = p_temp_buffer; p_rle_src != p_src_end;) {
				uint8_t n_code = *p_rle_src ++;
				bool b_compressed = n_code & 1;
				int n_run_length = (n_code >> 1) + 1;
				_ASSERTE(p_rle_src + ((b_compressed)? 1 : n_run_length) <= p_src_end);
				while(n_run_length --)
					*p_rle_dest ++ = (b_compressed)? *p_rle_src : *p_rle_src ++;
				if(b_compressed)
					++ p_rle_src;
			}
		}

		if(!b_gray) {
			uint8_t *p_y = p_temp_buffer, *p_u = p_y + n_image_size,
				*p_v = p_u + n_chroma_size / 2, *p_a = p_u + n_chroma_size;
			UnPredict_ImagePlane(p_y, n_image_width, n_image_height, n_predictor_y);
			UnPredict_ImagePlane(p_u, n_chroma_w, n_chroma_h, n_predictor_uv);
			UnPredict_ImagePlane(p_v, n_chroma_w, n_chroma_h, n_predictor_uv);
			if(b_alpha)
				UnPredict_ImagePlane(p_a, n_image_width, n_image_height, n_predictor_a);
			uint32_t *p_dest = p_raster;
			for(int y = 0, h = n_image_height; y < h; ++ y) {
				for(int x = 0, w = n_image_width; x < w; ++ x, ++ p_y, ++ p_dest) {
					size_t n_cr_idx = x / n_subsample + size_t(y / n_subsample) * n_chroma_w;
					uint8_t r, g, b;
					if(!b_lossless_color) {
						int Y = *p_y, u = p_u[n_cr_idx] - 128, v = p_v[n_cr_idx] - 128;
						r = uint8_t(max(0, min(255, Y + 1.402f * v)));
						g = uint8_t(max(0, min(255, Y - 0.34414f * u - 0.71414f * v)));
						b = uint8_t(max(0, min(255, Y + 1.772f * u))); // JPEG-like YUV
					} else {
						int8_t u = p_u[n_cr_idx], v = p_v[n_cr_idx];
						g = *p_y - (u >> 1);
						uint8_t s = g + u;
						r = s - (v >> 1);
						b = r + v; // lifting
					}
					if(b_alpha) {
						*p_dest = (*p_a << 24) | (b << 16) | (g << 8) | r;
						++ p_a;
					} else
						*p_dest = 0xff000000U | (b << 16) | (g << 8) | r;
				}
			}
		} else {
			uint8_t *p_a = p_temp_buffer + n_image_size;
			uint32_t *p_dest = p_raster;
			UnPredict_ImagePlane(p_temp_buffer, n_image_width, n_image_height, n_predictor_y);
			if(b_alpha) {
				UnPredict_ImagePlane(p_a, n_image_width, n_image_height, n_predictor_a);
				for(const uint8_t *p_y = p_temp_buffer,
				   *p_end = p_y + n_image_size; p_y != p_end; ++ p_y, ++ p_a)
					*p_dest ++ = (*p_a << 24) | (*p_y << 16) | (*p_y << 8) | *p_y; // gray / alpha
			} else {
				for(const uint8_t *p_y = p_temp_buffer,
				   *p_end = p_y + n_image_size; p_y != p_end; ++ p_y)
					*p_dest ++ = 0xff000000U | (*p_y << 16) | (*p_y << 8) | *p_y; // gray
			}
		}

		delete[] p_temp_buffer;

		return p_raster;
	}
};

#endif // __OPENGL_LOGO_2_0_TGA_INCLUDED
