/**
 *	@file OpenGL20Logo_New85.h
 *	@brief image in header, generated from 'opengl_logo_2_0.tga'
 *		- using prediction / RLE / Huff / BASE85 pipe (lossy)
 *		- predictors used: paeth for luminance, paeth for chrominance
 *	@date 2009-11-04 05:31:52
 *	@author ImageToHeader (built May 19 2017)
 */

#pragma once
#ifndef __OPENGL_LOGO_2_0_TGA_INCLUDED
#define __OPENGL_LOGO_2_0_TGA_INCLUDED

/**
 *	@brief image in header, generated from 'opengl_logo_2_0.tga'
 */
class COpenGLLogo {
public:
	/**
	 *	@brief gets width of the image
	 *	@return Returns image width, in pixels.
	 */
	static inline int n_Width()
	{
		return 150;
	}

	/**
	 *	@brief gets height of the image
	 *	@return Returns image height, in pixels.
	 */
	static inline int n_Height()
	{
		return 57;
	}

	/**
	 *	@brief determines whether the image contains alpha channel
	 *	@return Returns true if the image contains alpha channel, otherwise false.
	 */
	static inline bool b_Alpha()
	{
		return false;
	}

	/**
	 *	@brief determines whether the image is grayscale
	 *	@return Returns true if the image is grayscale, otherwise false.
	 */
	static inline bool b_Grayscale()
	{
		return false;
	}

	/**
	 *	@brief determines whether the compression is lossless
	 *	@return Returns true if the compression is lossless, otherwise false.
	 */
	static inline bool b_Lossless()
	{
		return false;
	}

	/**
	 *	@brief determines whether the BASE85 data is allocated dynamically
	 *	@return Returns true if the caller needs to delete the string
	 *		returned by p_s_Base85_Data(), otherwise false.
	 */
	static inline bool b_Dynamic()
	{
		return false;
	}

	/**
	 *	@brief returns CRC32 of the stored image data
	 *	@return Returns CRC32 of the stored image data (if lossy compression
	 *		is employed, then this is different from the original image).
	 */
	static inline uint32_t n_CRC32()
	{
		return 0x078e93c7; // after lossy compression (original image 0xa35d092b)
	}

	/**
	 *	@brief gets BASE85 compressed image data
	 *	@return Returns BASE85 compressed image data in a null-terminated string.
	 */
	static inline const char *p_s_Base85_Data()
	{
		return "~0RR91~~2LJ#73jhEB761SM761SM82|tP9smFU82|tP8vp<RCIA2c~~~0Q>|62>1yD2KV#~2MP-f5c>P}6#"
			"eiI^Xv{15fcLP_3,-{92Fkq813&D;~gUFCMy>18{H,8CnOo^Am,%c+~^}UFd^RID%#lA|J&6iHvZ8m(AnS8)GW"
			"+CJ2*MJO&>9WQ&}!FGCaS.$v02aElBF%MYB3eOV,0K%gU-h$Hc.Jk-oS=P%~DqNk.X~tGTVCz{SP^&Cg6jLO.y"
			"4ZEIy=mtI|aSD$}.bIx&xaEgmWZfIj*Us_mIR8mn+prN9qrKg>nu9&s9x4M<QyV>maP4MjYPRad-y!F{gsu)5d"
			"CY7XHsubCOYOWi,0Ho4r!nK<>B%4IlsiDrjdjL,jL*(TOF(,XYp&WIr>0*<{YR}B(Ucgc*56)K~Wa<hcF{mC,)"
			"v4=|@M_%nP1*UJ%,%Zm,RHTpC!oSVq+)CBB2&xjtDmXhx$hdad2.W-Qo%zXWaSt~<sP&UsMnUbKpQ~a=(%nFzd"
			"za4cerJ%<!O|uV6HyGdN97yov3rxveG!n)NaxWMIrm!)!^FNIldf!XJOy,GT-cTN.I4#,w8g6KBFD399mJ+YgZ"
			"8PCPQ5lh5,KwS{irxH#2-c7ssma%6oM>eql>O{)obQFpq_<4S4C=T&;44Y8-k)D5Zx-LY9YKzts4B|HX6k&uXv"
			"i;H9B|L}57t;cJI.Qsuc.r@RLPi3zH0(xrob#)n_-d*9LMJN1r@PG5Afg1hVq=)(Bli(f7&VN<;W8=UmoOu^37"
			"vDW{Wi~Ul6VP>aqw@X6)ixh0%!uWS}_w&|Uzd5q$B+}8*%S-lu!}>P=.pdk!wCrH6,xH~Zh4U|)m!(;5|8Z&5."
			"Bv$Dr=gwS&O<+c#Y)38Vl7XF_WWN%gJo{@$liH(v&Z~IH9P)FSTtEFXK&Bnv@uTplA6^~&KXcs-{K.b,6*aqB{"
			"pqs.{x({-hXpd-npH|hf,YtN;892<VMX-pAmcN<krx+oz;l%*9m0XA*q6K=w8$#zxQciW{qP!{yGdKO3m+X{%O"
			"Cg^XK~db}(0bY,T8u(DWP(^C@U(9uIV},@JTQRKd)u(K{8LY<i})wOEAB)pn5,PpL}<eHl!%(S,d^%O(Cz$aHr"
			"<M$fE9&%epZ%e4,^6qf#b-<,wy8rnJ+_p~4^Wpa#FHM>Q4FIj~5bvmw;&r@@Xycdfw*Q@WnkY5(#^gmeRqN$gm"
			"sc.SBhvA{0@c$zI1I.fB@^!OSGRr4Bmks$o#!qR)8aJ@lmJBti)N+N_.N@,b5g%0gc,,Yqbv3xF.,BaRJ1}^<u"
			"C_-%h57VZDZxGyFURa#P+-)p_SM+)JqLXwUZ+!X#%i{{jX26$e&*H_^!l<$M^E6|wQb5W)YGpAV4BIxcsm~3nq"
			"#ThX7*_@r{&F#&)n6L*!3;R>)Ror^W*4Kc|^;M!PZyL>PhsCdOXY=m~DTvtC3EF8TzlCz0YDI%j8*dCRZrR&28"
			"+){>3~Ez8!tsO)lPIihUjkv3JYQb2;vmj;AgPA7rF6hQ_@&qBtElr_u4zn|rxX9ACcaUX)$..v.0|#ZYlltw|&"
			"bkZISx|F,UIybEc2dP>cx3>q#;Bs1ab{DHsElGPn^u_.z>XoEDI8AGQP.Af^8DD_Vj4AK+oWO,Hlvg_8t2WwNz"
			")8NJTbmuF2o!5e=FT1BXTc7XTG(Y-&_fy@#J*npHo;&a1IvX!ULnjZ.uKlcv61m^FW4oz*r!0b%3;>p#buhtrk"
			"|z=E*fH}dJt*}YOn%_@6D&24(CXYc4s;rJEN0.)ug},.e@oRne}kGe,TJg1@-J&l,yNT_KR-9G{pj_W!q&>vE}"
			"%z=L@IDFZNnP>9@#D+p#|bZG>5&cSsNQf+3alFF24ql^g~rx{{x<d;+1_4),lN%NPoYB-rw{&--DXps.)9G=Kt"
			"^De.y85zdfg0t<>~>jrYPC925Wl1Vq%iKi}*E=YHXhRP7gBRP9xRF}oW,>ILB{Ay8h&JxapoeeszAHvuX.5)lR"
			"Jz21f>uw4Jt|F65>zJC6_Y&m}CPt5s|qXU0,UbY&1%lnuwC.1H*OUlp%s=pR(&|uqz*E%9={W,pzf=&h23oQjG"
			"PHmpez-7Vbs1a}wquH_)H|T6i>S^%!{!MMhaO!Zbp|jJ.qN5)VS5.&wUx$+omQNG$8EJDlkG3TcU+)6ve{82yT"
			"U$;J!6!#ab&U6cLEa&}9qoZ.H$1miKhr%~%ZUt}a=3cc&SmV@AL9SbwT#i)e|e$1ZNsG$,X-%0g+$MLeSq4*L-"
			"7e<-V&Wn&MN!ai8.-|YlhA;fVx3szjm<m**cG07V+hM7o{oG=2xK9h>__cINhWav~(_)nEQsc<rigaM(iM)k4~"
			"xnp4-Ge&pgokeVffLu6,3{rsoxX.8g57tggrv)JH)M@t)YU=@Y$hTis9G^c^9yN0Ubmt+$1~IwOwpL~Jd2@zRW"
			".9Xfg{2PhJwf-Nbziaw,yn617VorxKFtrGN7+%{@%aaV&hn*Cf$bfQ%^O+};w6<,vY#B1lhJnvi<_s^xO=#OfD"
			"zsr69I#Lkn={OOge#~=Ue}6kfyxkQA+QzJ2ck2p&{=Xk_&Z*Y&PW=zGTFczFWH=Rb2M}KL_3>615>&y=QH,^_J"
			"c^F&hGQ!03st.ovaO$zaMAyt&E.AJ^}GJ}Qm=Pj&FBgJA1-2kzHC07t=^iyWBFDUG(Tx^2YRuV&r9O^.K6H|O4"
			"fAjcCSGp{&ojjL9x<~kz${($zB4<gT0t5pJiOirzAcJcQM)i@3d=Iyh({wh+S,^)}VT^{S;ll)cYQdIO$mAzgJ"
			"_@;dn1m&Hn$T7dP#1H~4aNd;HJavG3!(;_v=XWWM=!Bh7*fL)m}F&gCfL&25j~fvwsKgZJ>oe~IXb=b@GK_nHt"
			"W_AgJ-wXI_IZJy..=4^L@3)zm1w_72PUvH)lNO8P9H%<-WEF<>5ZiZQ6JGXduKb=%zZ_(*l%lp2MPq)oc1W(i|"
			"hk2)U_rhM6,+XkU<Qv20UWeA&2M^UBwkAy<ucTta!>}JDoPMY7W-~-5e}X%Om$G@.JSv^(46g^R*5.ppmlsP@E"
			"w@B>Ve_|i.~-(Vi%(hDH1zL>OJ9xB,q#PlVmrT$dQT40dOuUG&Vy>!P5q2_JT<xX6X#;VaEGGZ{KY8cI=JFo-k"
			"pP9DSD.,_()^ew)R3BJzsC_!4uLL)-$Q;KS(3Bk,+0pb.tQgl%sBYOCHjXj=S,uZM~Ib{uE.#k3Kz&YlIzdql+"
			"(yY;^5pZEbTR-O$&5;Wl@.{So%Q)|;}{yOk&{$oHovEo<nGo-P&X6FrNez1tK$A!)ilvGLmyr9EthwLDZQ%ZSS"
			"9rC~s|IF>QaP,9+Hj!})$ZT&v~<mo(^-WN<$lci6+Y+ctDcy1c^T<dmw#n%sMT7aGAt=napH~wn;q)$Xl#lG7g"
			"m+<>exLtv&df|1_N.miMF1gJt)Mx2^uS=z*=!>p&Mb|ro9kyL_q!Q;Zz)f#p|HmjP<pUxY,kde1xami>pQ%6RE"
			"Y$7(moMSRS>JfH>U$Kw2PuXZq6R2l<&J;9aiY,bV$yr&EcU$5aQr<SvVZud^*)4tk8C1S$~9QUwDPw(|5rPKe$"
			"Kk#,z5An,JNso,Mn&g{v&1WB0OG;<,_qmWnlfe{H@A+8D.I5gS,W0riW9>%haQ9&g$Zm{>IC+qi&bo<p,*eMkX"
			"&sq_5bIhbO0T-2)ReH@UVfbs%p;q0*-J{7>L.yZPz%|8Hsbf}R*LV7W9K<c_vXQcCWTt37.Hy4Wl~n)C**ovD,"
			"FzvzE$(k<+LFAq0q@v$g)V+F961#29hLORAsnnoy~q*XPH1u9r8@jySZ>SgIxll4zE)ZwkEr{U)9KKn.84>5z~"
			"a#8A54oHt,I#JS&lyr(u&tFD(2hEM$P7Rg2=QUTQTRx_TZ^Z,C_|hRtF|d3ZEKv0CPNRZ,KEnBh@U,)DY2vplz"
			"fksFBJDxPv15zHto!5RLLi(kJs~vVL4+TOn%4%VrOfq~@2GCM%d.V}4Tf%SSA%Krd>WzXu*HTTeo~#T88zwLw<"
			"}iftZKaU)c9#,{FJOer+&N!)9MoV{H7~M43)H_r)hG+r+qV3=ccKs%2-(bhMnve>yR|d2uq61%59cMlN+6;XLF"
			"Y|N|Zmbf%oYsDJZ8I8%uFUwL1At&Utk$RG<*j%0WV$.#cT_*E_~t^.hHw9<KPbq(VQmLX@ou647W7#D5tYR+Nd"
			"hSx7=5kbjuR2(*b1frt>8feK3Dg%wfjgfS)&3_}ozfej,=BwWRh^_HPpQXvdtJu=D&AY8>.NK)ZQA&._rTNw&b"
			",H7OXq!7x#j3D%c!nCM,Db5J7uz71*Qi28$t^}s2KbZmGXue9Kdy)y6DTuO&5GI~}cKMBPrHoqBVGCV|SfU=f0"
			"iRo-q8}eQBP#S7T}omtA_f91Q>SCNVudh4LZMnvAb~_YjGMu&*Gxs4sq)V$73EN*v>6fRu>#U8frKj{WWcmoN="
			"O9|F%^i>oHBV)6Khq*(QrX3i>pk4hMsB|m{9,es<qWj))FGDG~i4CwSsI)8j2IzTrDF&Ac7!X+4K;Sz{#dV7%r"
			"H~qE.Y0wSz7Tukyh*dd1YGpos*gYN,~Qq7+(77MfuMC{ax.LY1-z7cwo8==,jk9IXaK6GSEjrJ%Ts^9)*2fh<E"
			"HP(vXM6HU%SR}hrL0*zPs&~fTfLb(Z+$J<sIViJfZkloIKB~&Fe>cWALuB|$#ki^Iroe3BTA%#Y-xnUgNlwU%,"
			"6y~ep6AM};h)hRSj9A7X83I_u2uv_B5g4k7fs0HGN(%{S^eajtCWaHa<Epjika-nmN,%6j5,!8Hh!CKGMKll~5"
			"C}s<Qc@n,1Gtu39%WgQq2$v=RRTA}(.wqZAw|.9A&He.SR_q27(ve-h89)$3,|5TNRXL.2-_n}DJrwpE~2WJog"
			"zhvKrsl2w3Mt$NEnY.#>OoxNRc81p,euyBB~Mm!dNk>Q8H2>5QZrq$Z..nl!+1,K!kr$bqMT=F8aQ&-VaxvCV>"
			"hPkzdqDLJ$b7B,I(5k-mWfG7zAFDO$gndbor{Jdr85M#dn8Ubyvf2vHhEiB>|(XhI-F%JqfULIgD;wF@dyLKy|"
			"WNFRv{61A(qMxiL7UznNpApn)H>W.TD^n|eph>aCQmi7-V3_=nurF1O_wh7K8,C2Y$Lo|V1q{&Leq77,D<~P,c"
			"tq6c>5R@%MJZS~)_0&V2ngqkwXrx3;mV$^hZTAZ-Le{DnhJ>minJn#O<3vT6QO!67u|.VuATA@%NIroA+E+lf*"
			"ANh)30j3@I1^M>w;4i+VX%Rat%.Rp3W)v%B,9K6hz24QK$HU60>p#p1Y4A+V4+%!fk2ptl0#KOP$8w-6w_5GAy"
			"o*0D,<+M)}<n03K)P*!EMI4ELIeTf+Q}%Z9.cm1jKo3VWJCQphPS~.Sx|!Y>j!>2RRJ|#1KR#6e1%U3KS3vVi2"
			"VvNhMG+LKU(Es)RHd5Vq%sonb|(h!~W=3mFjdmc%IX(p5+z6)=EeQZWl+(-CPZ5Q.cln2W4pjb4<-JmNa@E(j*"
			"wLLfs=J#0z=5TyuOR0&!VwFyENmBc);P^l5Zlmg@)XE_OonT#~,Az~~_U4{h<OA,vDE~T*-QrL%-5~#GKCQwi|"
			"K(Nwk6{ewDXl-L<N+1w~q6Es&Q$bMzr4yoC.g>z(7gVf<CX5h(LKe|{@#^SIzX6G<fDnYCj7nR!M*9J2^@vpp7"
			"zj~i31UQvh_rzM1TAX*u_{txMUX%sOn,+CC23ds2b4C2A~c8uG-_^&{!-F~4WK}Vi%5}Q+!moiyCQ%";
	}

	/**
	 *	@brief gets raw image data
	 *	@return Returns pointer to raw ARGB32 image data on success, 0 on failure.
	 */
	static inline uint32_t *p_Decompress()
	{
		return p_Decode_RLE_Huff_Base85(p_s_Base85_Data(), 150, 57, 6030, 3, 3, 6, 2, 0);
	}

protected:
	/**
	 *	@brief calculates reverse prediction on a single image plane
	 *
	 *	@param[in,out] p_buffer is pointer to image plane data (just the data, no padding or align)
	 *	@param[in] n_width is image width, in pixels
	 *	@param[in] n_height is image height, in pixels
	 *	@param[in] n_pred_type is predictor type (one of 0 = up, 1 = left, 2 = avg, 3 = paeth, 4 = med,
	 *		5 = gap, 6 = no prediction, 7 = up-left, 8 = avg2, 9 = diff, 10 = grad-h, 11 = grad-v)
	 */
	static void UnPredict_ImagePlane(uint8_t *p_buffer, int n_width, int n_height, int n_pred_type)
	{
		_ASSERTE(n_pred_type != 0 && n_pred_type != 1 && n_pred_type != 2 && n_pred_type != 4 &&
			n_pred_type != 5 && n_pred_type != 7 && n_pred_type != 8 && n_pred_type != 9 &&
			n_pred_type != 10 && n_pred_type != 11); // some code omitted
		int n_first_row = (n_pred_type == 1 || n_pred_type == 6)? 0 : ((n_pred_type == 5)? 2 : 1);
		int n_first_col = (n_pred_type == 0 || n_pred_type == 6)? 0 : ((n_pred_type == 5)? 2 : 1);
		for(int x = 0; x < n_first_col; ++ x) {
			for(int y = n_first_row + 1; y < n_height; ++ y)
				p_buffer[x + n_width * y] += p_buffer[x + n_width * (y - 1)];
		}
		for(int y = 0; y < n_first_row; ++ y) {
			for(int x = n_first_col + 1; x < n_width; ++ x)
				p_buffer[x + n_width * y] += p_buffer[(x - 1) + n_width * y];
		}
		p_buffer += n_first_col + n_first_row * n_width;
		for(int y = n_first_row; y < n_height; ++ y, p_buffer += n_first_col) {
			for(int x = n_first_col; x < n_width; ++ x, ++ p_buffer) {
				if(n_pred_type == 3) {
					int a = p_buffer[-1], b = p_buffer[-n_width], c = p_buffer[-1 - n_width];
					int p = a + b - c, pa = abs(p - a), pb = abs(p - b), pc = abs(p - c);
					*p_buffer += (pa <= pb && pa <= pc)? a : ((pb <= pc)? b : c); // paeth
				}
			}
		}
	}

	/**
	 *	@brief decompresses the image
	 *
	 *	@param[in] p_s_base85 is null-terminated string containing BASE85 compressed image data
	 *	@param[in] n_image_width is image width, in pixels
	 *	@param[in] n_image_height is image height, in pixels
	 *	@param[in] n_huff_stage_size size of the compressed data before Huffman encoding
	 *	@param[in] n_predictor_y is predictor type for the luminance plane
	 *	@param[in] n_predictor_uv is predictor type for the chrominance plane
	 *	@param[in] n_predictor_a is predictor type for the alpha plane
	 *	@param[in] n_subsample is number of chrominance samples per 
	 *	@param[in] n_color_type is color type bitmask (if the first bit is set the image is
	 *		grayscale, if the second bit is set the image has alpha channel, if the third
	 *		bit is set, lossless compression was employed)
	 */
	static uint32_t *p_Decode_RLE_Huff_Base85(const char *p_s_base85,
		int n_image_width, int n_image_height, size_t n_huff_stage_size,
		int n_predictor_y, int n_predictor_uv, int n_predictor_a,
		int n_subsample, int n_color_type)
	{
		bool b_gray = (n_color_type & 1) != 0, b_alpha = (n_color_type & 2) != 0,
			b_lossless_color = (n_color_type & 4) != 0;
		size_t n_base85_length = strlen(p_s_base85), n_base85_size = 0;
		int p_b85_ic_tab[128] = {0};
		{
			for(int i = 0, j = -10, k = 55, l = -62; i < 85; ++ i, ++ j, ++ k, ++ l)
				p_b85_ic_tab[(j < 0)? k - 7 : (l < 0)? k + j / 26 * 6 : "!#$%&()*+-;<=>.@^_,{|}~"[l]] = i;
			const char *p_s_src = p_s_base85, *p_s_end = p_s_base85 + n_base85_length;
			for(size_t n_diff, n_rem = n_base85_length; p_s_src < p_s_end;
			   p_s_src += n_diff * 4 + 1, n_rem -= n_diff * 4 + 1)
				n_base85_size += (n_diff = (p_b85_ic_tab[*p_s_src] == 84))? 4 : min(n_rem, size_t(5)) - 1;
		}
		size_t n_image_size = size_t(n_image_width) * n_image_height;
		int n_chroma_w = (n_image_width + n_subsample - 1) / n_subsample;
		int n_chroma_h = (n_image_height + n_subsample - 1) / n_subsample;
		size_t n_chroma_size = size_t(n_chroma_w) * n_chroma_h * 2;
		size_t n_image_data_size = n_image_size * ((b_alpha)? 2 : 1) +
			((b_gray)? 0 : n_chroma_size);

		size_t n_prehuff_size = max(n_base85_size, n_image_data_size);
		size_t n_temp_buffer_size = n_prehuff_size + n_huff_stage_size;
		uint8_t *p_temp_buffer;
		uint32_t *p_raster;
		if(!(p_temp_buffer = new(std::nothrow) uint8_t[n_temp_buffer_size]) ||
		   !(p_raster = new(std::nothrow) uint32_t[n_image_size])) {
			delete[] p_temp_buffer; // no effect on null
			return 0;
		}

		{
			uint8_t *p_dst = p_temp_buffer - 1; // points to one before the write sitze
			const char *p_s_src = p_s_base85, *p_s_end = p_s_base85 + n_base85_length;
			for(size_t n_rem = n_base85_length; p_s_src != p_s_end; -- n_rem, ++ p_s_src) {
				if(p_b85_ic_tab[*p_s_src] != 84) {
					uint32_t n_block = uint32_t(min(n_rem, size_t(5))), n_code = 0;
					_ASSERTE(n_block >= 2);
					for(unsigned int i = 0; i < 5; p_s_src += ((++ i < n_block)? 1 : 0))
						n_code = n_code * 85 + ((i < n_block)? p_b85_ic_tab[*p_s_src] : 84);
					for(unsigned int i = 1; i < n_block; ++ i, -- n_rem)
						*(++ p_dst) = n_code >> (8 * (4 - i));
				} else
					*(uint32_t*)((p_dst += 4) - 3) = 0;
			}
		}
		{
			const uint8_t *p_huff_src = p_temp_buffer, *p_huff_end = p_huff_src + n_base85_size;
			_ASSERTE(p_huff_src + 16 * sizeof(int32_t) <= p_huff_end);
			const int32_t *p_code_num = (const int32_t*)p_huff_src; p_huff_src += 16 * sizeof(int32_t);
			int p_min_code[16], p_max_code[16], p_table_off[16], n_code_num = 0;
			for(int i = 0, n_cw = 0; i < 16; ++ i, n_cw <<= 1) {
				p_min_code[i] = n_cw;
				p_max_code[i] = (n_cw += p_code_num[i]);
				p_table_off[i] = n_code_num - p_min_code[i];
				n_code_num += p_code_num[i];
			}
			_ASSERTE(p_huff_src + n_code_num <= p_huff_end);
			const uint8_t *p_symbol = p_huff_src; p_huff_src += n_code_num;
			uint8_t *p_huff_dest = p_temp_buffer + n_prehuff_size;
			for(int n_byte = 0, n_bit_num = 0, n_counter = n_huff_stage_size; n_counter --;) {
				for(int i = 0, n_code = 0;; ++ i) {
					_ASSERTE(i < 16);
					if(!(n_bit_num --)) {
						_ASSERTE(p_huff_src < p_huff_end);
						n_byte = *p_huff_src ++;
						n_bit_num = 7;
					}
					n_code = (n_code << 1) | ((n_byte >> 7) & 1);
					n_byte <<= 1;
					if(n_code >= p_min_code[i] && n_code < p_max_code[i]) {
						*p_huff_dest ++ = p_symbol[n_code + p_table_off[i]];
						break;
					}
				}
			}
		}
		{
			const uint8_t *p_rle_src = p_temp_buffer + n_prehuff_size,
				*p_src_end = p_rle_src + n_huff_stage_size;
			for(uint8_t *p_rle_dest = p_temp_buffer; p_rle_src != p_src_end;) {
				uint8_t n_code = *p_rle_src ++;
				bool b_compressed = n_code & 1;
				int n_run_length = (n_code >> 1) + 1;
				_ASSERTE(p_rle_src + ((b_compressed)? 1 : n_run_length) <= p_src_end);
				while(n_run_length --)
					*p_rle_dest ++ = (b_compressed)? *p_rle_src : *p_rle_src ++;
				if(b_compressed)
					++ p_rle_src;
			}
		}

		{
			_ASSERTE(!b_gray && !b_alpha && !b_lossless_color);
			uint8_t *p_y = p_temp_buffer, *p_u = p_y + n_image_size,
				*p_v = p_u + n_chroma_size / 2, *p_a = p_u + n_chroma_size;
			UnPredict_ImagePlane(p_y, n_image_width, n_image_height, n_predictor_y);
			UnPredict_ImagePlane(p_u, n_chroma_w, n_chroma_h, n_predictor_uv);
			UnPredict_ImagePlane(p_v, n_chroma_w, n_chroma_h, n_predictor_uv);
			uint32_t *p_dest = p_raster;
			for(int y = 0, h = n_image_height; y < h; ++ y) {
				for(int x = 0, w = n_image_width; x < w; ++ x, ++ p_y, ++ p_dest) {
					size_t n_cr_idx = x / n_subsample + size_t(y / n_subsample) * n_chroma_w;
					int Y = *p_y, u = p_u[n_cr_idx] - 128, v = p_v[n_cr_idx] - 128;
					uint8_t r = uint8_t(max(0, min(255, Y + 1.402f * v)));
					uint8_t g = uint8_t(max(0, min(255, Y - 0.34414f * u - 0.71414f * v)));
					uint8_t b = uint8_t(max(0, min(255, Y + 1.772f * u))); // JPEG-like YUV
					*p_dest = 0xff000000U | (b << 16) | (g << 8) | r;
				}
			}
		}

		delete[] p_temp_buffer;

		return p_raster;
	}
};

#endif // __OPENGL_LOGO_2_0_TGA_INCLUDED
