/**
 *	@file OpenGL20Logo.h
 *	@brief image in header, generated from 'opengl_logo_2_0.tga'
 *		- using prediction / RLE / Huff / BASE64 pipe (lossy)
 *		- predictors used: paeth for luminance, paeth for chrominance
 *	@date 2009-11-04 05:31:52
 *	@author ImageToHeader (built Nov 11 2013)
 */

#pragma once
#ifndef __OPENGL_LOGO_2_0_TGA_INCLUDED
#define __OPENGL_LOGO_2_0_TGA_INCLUDED

/**
 *	@brief image in header, generated from 'opengl_logo_2_0.tga'
 */
class COpenGLLogo {
public:
	/**
	 *	@brief gets width of the image
	 *	@return Returns image width, in pixels.
	 */
	static inline int n_Width()
	{
		return 150;
	}

	/**
	 *	@brief gets height of the image
	 *	@return Returns image height, in pixels.
	 */
	static inline int n_Height()
	{
		return 57;
	}

	/**
	 *	@brief determines whether the image contains alpha channel
	 *	@return Returns true if the image contains alpha channel, otherwise false.
	 */
	static inline bool b_Alpha()
	{
		return false;
	}

	/**
	 *	@brief determines whether the image is grayscale
	 *	@return Returns true if the image is grayscale, otherwise false.
	 */
	static inline bool b_Grayscale()
	{
		return false;
	}

	/**
	 *	@brief determines whether the compression is lossless
	 *	@return Returns true if the compression is lossless, otherwise false.
	 */
	static inline bool b_Lossless()
	{
		return false;
	}

	/**
	 *	@brief gets BASE64 compressed image data
	 *	@return Returns BASE64 compressed image data in a null-terminated string.
	 */
	static inline const char *p_s_Base64_Data()
	{
		return "AAAAAAEAAAAAAAAAAAAAAAcAAAALAAAAFgAAABYAAAAZAAAAHgAAABkAAAAbAAAAJgAAAAAAAAAAAAAAAAA"
			"AAAD8BAUI+AkDBvf0DAcKCw0Q+vv2FP3wD/PsEg4REwLy9fH5GhwVHuQY7e8X4x0i6yYr7hYb3eYoJxkkIOni5"
			"+UjNTDo3CHe1uHY2ir/JdXbNv7fKdDR2Tss0j441MwfMTlNuy6CMjw0U1lIvy3TTzfq4MlFyC+z1zpKS8EzP5H"
			"LQcpHSVDHr1bDwqq4vmbEAT1AQ6NCTK2yucXGV83Pe8Bta2VhXl2rl5mfRGBOUVJUVVhalaWHX66Ki7pjvHNxf"
			"3CkoqGgbrW2nWibgJi3zqe72ez2TfDs9k7J/Ya89dlIqhhCIiaVpFuqFNl/Zq4bxgCk0mjCtatXJJtE1amh0L1"
			"7AFIKQ+TlCjEoe02hHHWtaWKTvmrPzOZewFIpD85XH2TqCiIxqB5Y1anrkfDq3PfN6fmczTKRSfnoY+wnoMI/p"
			"GJr7SJTy+srm6ngufIatXkzYKRSwUMfZOUYR+UeshCo15a4QBsg3di5Lf8XN9nVd7plq+dplKlgrj7CejC+0p2"
			"Yc9a00jjI1G9SCkUh+9u14NnZOj4cf19h3/0y3+p0SloX2PsJ6MI+ox2eDFpR02tXEPAmQ10ThgH9Cload/l3M"
			"3v+97mq78B7FTp+eUtC/ojCejCPhZ4deOnZXK1yh2ocWkMopYdHQpaHWr/V9/4fvXP6T16v7uCloX9EYTkD4We"
			"De1LluVqnvAcLiQmqbdKlg37Gh1vxfJ/P6Tv1jn1OT5ixgrvsCejC+N97Xy4pYVO9Ixuc9NpMwdDUsdf/l4/8M"
			"n9haqdvt0tC/osUbV/C+Hd19/PWW77htOkk0tHRy0v3f9H59v/0Wqn39OxgrvsUU7+F8y+Zl6VZbv7pZdTtZNa"
			"5p6Gd39RDP4vHSsM0YizPhfb730uHaW72yN55d7PH/WQ1PF5dLBoslLW35u/ZGKd/QU1qqOcMqCnv9JH0/LpWG"
			"MlNqzt7vVFPN5va1Xe2Z3Gh1dbAUozh1bkRtVOnxl758mtoXM7qxHfrhLJtkNTBOPQvahHf/HSwM0axnn79BhI"
			"lZvk3vuzfvHmz/b07GCu+Nl0/d+l6TgZ59LQ0DwfMWP2Ok0eqYOZVaJ2KzrY9U1tarEJm7DtIjqfVpYK+jKZZ6"
			"ML9mGWS/y7kOjufn2vaI2fm5eXk2Yjeikt/QvfccP6Gto6F/d0ICxlcoxVNbuFeC9ahPm1Ow6Uz1NzjrwXi1DX"
			"q/C9kF8e4/Q/WOKiqZedqXB+x4ffoZ/0/6r+A8yf83L181UyyydDkw35PyZPXcQaN7DXlgw1qdRyhdfuV4OpER"
			"9g+jkyOaR1Nbjr7uZRHjtQePsOtkc/hfn0WSnDPhMvuerbUGDUrfoV1PP9J31DXqdXcsZqtn6dOMpafu7OE/p7"
			"EkhHT+DZs23KMtTTrwdQmtHJeDqew5pjqdRm7mkxp+PNjtfi1ZLY9S3J69shofPc51N5RMuMwddX0PRk+oa9Hn"
			"4OXDZ/v9jIp0GM/ZfO3uerEWnyLLkTK5RlZrbuY39ingbfDrb2JpdvMUU+fwxYvEXnuZzXSkdTkwUPslIZw2Ne"
			"m9EcLpvQ5/fozbvaqA4v33SvSi7990r0R96oOKlWpJIFSDTr33/Y9XbeBbS9uyVm1AYNFySSGfD1viDf5slmjr"
			"HUlOKpskGaThyh04r2bNxOlHqnjoZpCfRyPSn/mXXrYIO5qefp8OL8enOVvR7rwVOT5tOcrc34bhof6j9Xq/Ng"
			"HtTzNs799/Cc7aeiIZOD6ld+zkUJXO/cMd3UvlOWQUqGAEtOKphgvEkTiPbsGPmUnpR6jjY/cHsJlhrH53VuDA"
			"dCDTsWM3G81+fueP+h6p2/y9Ea/P3PO/kXs6Z+Ty56z8/R63+6PWYws7S1C6gR4lEKnAwbcMa/rbZLiChBeJEN"
			"Ie9rFobG0Ta6m1bLr8GkPRDVVj/g56F4pV9DuaGH2NIf8WD5N/0uh+Xot+dp1+/0f+/wP6HHBt+a06/X6vqfTv"
			"vhDI4J/9mCImpcv9z1QXO/cMaqdkuuKncqwZjejaR1AvCVEKgvY56lYXO++MyAm4CVH3kIgvVe7zsUWC5/2n/i"
			"3vFfP19ethy/i6fn/KjRgb+vr1sNPmX9zBeUD0RlpedoAtVfjzbwMG3C650RNf6dXl6hJwrrBaaClCc212bgMu"
			"Dz1Ai4CFHs2gob9LYldTT4e/8WtuM4NTgXUNrp5tFRj4OxquqGr7/LhtMnifiMtLmcx9sSiC/3gXO/tlOpra2n"
			"B1CTn6S6xnvAoO8Q3g72wLUbnlOrH+KerOXEhk4pXD1m5zL2aw/x//Laxmjsv7rQ3rbh0op9E06gwqJnvY6gbO"
			"Ch+ISwbwFOpucdfdzEnP9GtcNrGUBdILRfu1h57J1Xrgt4876b0pTqcyvQakRI9JEcTtIKWjoXS8x9w1ryi7K2"
			"I3oQTcenVP9HbeIfZ5pofo7N5pdXPwG1U3OOvu5jf39WV2QK6iOgh3TPbFp0id64Le6v8HpOkNqjy9HDq23hb4"
			"6I4rxRGws+bHSjKUdOnoqBygSo4YtKbmKPq92mK2+Cp1JGXmtEvRS3DaqbnHXgzSa/YxLdKJVN01FlAMVYBKax"
			"GvmvTzvXBb30NLVdEevP+bkvv+SUhDp6TgRoX7Uc19/fztEvN0VBdrGrF5P1hT///3O051Tr+XO/Q+0WsvclqQ"
			"4VXMHGF70NfFWGBJUwcxRjbO8PIqO7IZjKusLVb2+uq2fhnDR/4/L5Urp9bxfJ1avd17V6An9TypifrZsPoWd7"
			"pq/c/lWFTQ/SXEHerGW10ve+20zfg1K1rTsdy9BIf22B19BsdKOkWKft8teAtGDvZgrn11cyqcsPgl3Mdr/965"
			"rV7xJiVWIXW+f16B6sfz0Xb/V/J6lOOlY5b9XY9PgeC9R0f8vpxdH7+639PJz/FzP37Hw473j8X4fZL75diPMg"
			"gsj2X+10OQo481tj96BrdkKg/fwxX+N6IjnoZX091oQKPVvT8+zrWL2ba7WruZsd4IL2Y59t1shj19vpg9IcTw"
			"9N04N0iwj9n5edlliO7d4Nz+pVGFv0+lay/sep0+30VEET9Qqh3mndffCXpf3vU7b5Buj5l532dkHD9UftiZNH"
			"7ekYsLDqB8UnF6P8GYzRCd/hjuFp7J5OnhVO9IZXg9rr9AgyS4ulqZbbojuw+Te075Jz/VsvWtg09O+HS1+J0v"
			"tXubdiO79Zek8O0no/R6/Qg2bOTf2Mdzw1ubUT5MWC4Q89u/mKUcp2McS5vQsGvFL2Dr3wkMexbeyENrsex+iC"
			"J6QxrGdX036QR2ckKnNO69rp+KlG3PZWPaUfFXfpRtt7Ssn6aMjlHmx7GNcIOt8/Fl8Y2OnZyNra5kW7na79wm"
			"zveboj7X2tN6WtdypQW5HvQkxa19EdPFwL0iZ7Fzt3tih6Qst0f3PctiVKetkNanioU5cRldNKwoFqcSxjnKFv"
			"aVMcoxuk2/o+L8PSeTG8LpinJ0qfeti7ri1wXDXuudbtd4uuHtKzATvNW7bLUm/8tfkInoiZi322Pwfa9d1wuw"
			"NU9cLrpJS650pdc5paqM/a+/6fS0nRF1zoi653ADtsuudIJc5fgJrewf5+QFPKBkQv9vo/q3HSj2y/Un+4Wqnb"
			"/a5PtY6zvsFl1PYpfl5DDC9EDFC9yxzfhuNFp8mLSe+Utdzz/dPtc/LJ/jKb1PnR+p2wiU8o1WMW087c5vz53A"
			"v2ddcP1yyzT8/w8bfM5+Vf9ZtPaRHi9R8wwjyjKwftz+duU9jLMvPkHekbVTQ6vl8nVo2/J2MUn/g2naUbdL8f"
			"IEVEijExei0lfsR8GT0LjucYmaG70bFjqwN53O6VN7/mfqOl389Pt/v7L7QU8MGLBcmg3y462TFJK7pGrPX2au"
			"tgsP5r0Bq+TUy23f5D/26Rb2PpeHo7L42JQ8MYLYS4K1jl8sjrGSJpGKKCkVTWMBSpYK/HAP7Ho5elWk/ZPMdT"
			"hramn4ejsvvtIhQ8xg+VyUepWDliPXjpR0o6UdIpPz19GeAfNje1OHaW76Bqr0q2fU0O344NkfGkQpRjYPg0WK"
			"Hp3p1HDQx9hfML4Wfe59PFbld+2ey6RdmDi2LHH49Z98fGhEE4XnpCacKDCD8RNZ4dTUuZ6y3fVN5zl2slLBsM"
			"3N2vBsvg+DVD0WGLDED8pTs8EmvTuW5Wrd9k1XnpqfBS3vipWH9O/XgNl9Ql8flMVk4JK2lHTsrlhU76JqvPTV"
			"NRlLCx/Q072C/XIGmWEJcVq5TbLI8mNztMzucuapUof2MD79JQUlFOMjaW4o1qdfKbnPLqWalAIaWkgoU53ZP0"
			"i653fLvret9gPW3xaUiEf7yFKVoSJaLQIYj+MjStKRNstJCEQyD/WY4RaRIhAxAhMQIUlcMKKqPbCGJMIhiGIR"
			"ECGkyASLmLH+AswrSkQhjEegWkEEC5ir6YpcKQQyBGwLYyFKPukyVrSCGVfrBB6YmFaVEKU5wRY2DylrSlBAwh"
			"XAlNUH8yA8DRfLVE9qQTMlMRaRAgTTz9DfMa4UsYtabCFrsQsUQ9ZAM+zzlEPf6CRlXnNLqUxFlEDARYp07HaM"
			"UKYIKFQrSgQQKIeVk3g1usmItVU+UecivKoUloMiPMYgWkWQMIVkDJgWiwlJAKIGIrEaM4ZPOiJtarjaLgglUX"
			"VpkBDTzEMTCiBc1Va6qZrCRFWGnAmAFrBNiUNRQnuLhaRoBBBEC9s+khJYGTTIYwXTGVRK0iQWsGXBdf44Js9Y"
			"upS0ESCUzVVCk3RCiyli00wghQoppghStkEC5kWyPR+Nk2OVoMiCaITAtLQXEZ5hi0pQJYhkCghkIYJpughK4h"
			"KYYFGq/0IOLUooVyky2PtqwwxCUQTSG9nQJKqEpp1YUDIV1adVEhiZAvOhIwEkMKjV92wjo/GL51iCnNV8ImFr"
			"RLEJiOwxixjEAyBLGIEJhgYiIxVREDFpgYlBYS0ehWlERNDCdrv1VrzyDyKsyVCYU2JQY0GRAhQQKKaCBAIBCG"
			"hqSkPaQHaSy2PMqzJUPJpoqqBG+Jpoq+AEKLqEZDEyrCsEiacDCDmj0MLKvwGJiIVpEhMwgRtkaYUlVntF1FVS"
			"86RIsSgGIREWUpWJSQMR7ZjYxaVpEiRAtDQSoeRVQj+YSwY1KiZKRAIQxSP5DiQgEpEiRAgQj+EuoR2RRd9b1v"
			"sB63NE0CFCUiv4SOhCARWEpS3+MjfQIEZCFBAlK1fzD1cQiIeSJTcI2MQQq9seriEKI0ixKshabQhECJle0Lro"
			"QIakVqFpSihDILfpg/EhYla1eAjUJRQr7pM+xCAStfzjygV9QSxCIiNFUSW9g8pDEISLaV0LQi2Cc4k+NouaEM"
			"0gV2kyUrEog1sm+Y32IStCIBqEJQtRDxJBe91lEOemgTD1mikREyWgog0bfaLTELWqhiGhKohmSzuZOJERahR0"
			"ThFsUXaESAuI81IPoEC2ldAttcQEKEJWoVkOFNUVrcRQohhsIGQrYoGSgqI/UUlKGJWiAYiFECUAtkCxIPoBFu"
			"Up2ChWoyBQJiHkkNVQlAhpdoU01UoIVUIgStoiqLWpSJhChiATcFtxrgsVhSGgiQuwW1C6EIExHlLYaILYKBEL"
			"EPthGMTbI151wdBDQXEEEQmFCIjGgoUEAtiEKUhSSVQMkIVsgSqhDQZELbnh6FhRZmIGJS/CxkQ8pbEKPKSVUg"
			"iFTCAYlIxC2LTEWUqEIqpQJiLrGKNXpTGPOI60y4IJt5CIENPNWxKARClCFpUCVoStQlCFpXEPLFQqRHClALkH"
			"mdBCYiZjDT1IWIsSl2GBQtLEwqkLqWxF1LYh5QSqLKkJlBQNkCw0moVpqFaaG1jaUogEISiBMrQU0FRAqUTolv"
			"tCVClF1SshiaMEIBCFtF80eroTL8BiamAEIShjEpbtkb7AWn2iFUKGAhRaQliRImIsoECBC1q/eEqUmJFoEAgT"
			"ICFDyVpV/mHlDaFIjSIBDRqbor+UsqFDaBAhotIkV/tFqFCuyKA";
	}

	/**
	 *	@brief gets raw image data
	 *	@return Returns pointer to raw ARGB32 image data on success, 0 on failure.
	 */
	static inline uint32_t *p_Decompress()
	{
		return p_Decode_RLE_Huff_Base64(p_s_Base64_Data(), 150, 57, 6030, 3, 3, 0, 2, 0);
	}

protected:
	/**
	 *	@brief calculates reverse prediction on a single image plane
	 *
	 *	@param[in,out] p_buffer is pointer to image plane data (just the data, no padding or align)
	 *	@param[in] n_width is image width, in pixels
	 *	@param[in] n_height is image height, in pixels
	 *	@param[in] n_pred_type is predictor type (one of 0 = up, 1 = left, 2 = avg, 3 = paeth, 4 = med,
	 *		5 = gap, 6 = no prediction, 7 = up-left, 8 = avg2, 9 = diff, 10 = grad-h, 11 = grad-v)
	 */
	static void UnPredict_ImagePlane(uint8_t *p_buffer, int n_width, int n_height, int n_pred_type)
	{
		int n_first_row = (n_pred_type == 1 || n_pred_type == 6)? 0 : ((n_pred_type == 5)? 2 : 1);
		int n_first_col = (n_pred_type == 0 || n_pred_type == 6)? 0 : ((n_pred_type == 5)? 2 : 1);
		for(int x = 0; x < n_first_col; ++ x) {
			for(int y = n_first_row + 1; y < n_height; ++ y)
				p_buffer[x + n_width * y] += p_buffer[x + n_width * (y - 1)];
		}
		for(int y = 0; y < n_first_row; ++ y) {
			for(int x = n_first_col + 1; x < n_width; ++ x)
				p_buffer[x + n_width * y] += p_buffer[(x - 1) + n_width * y];
		}
		p_buffer += n_first_col + n_first_row * n_width;
		for(int y = n_first_row; y < n_height; ++ y, p_buffer += n_first_col) {
			for(int x = n_first_col; x < n_width; ++ x, ++ p_buffer) {
				if(n_pred_type == 0)
					*p_buffer += p_buffer[-n_width]; // up
				else if(n_pred_type == 1)
					*p_buffer += p_buffer[-1]; // left
				else if(n_pred_type == 2) {
					*p_buffer += (int(p_buffer[-1]) + int(p_buffer[-n_width]) +
						int(p_buffer[-1 - n_width])) / 3; // avg
				} else if(n_pred_type == 3) {
					int a = p_buffer[-1], b = p_buffer[-n_width], c = p_buffer[-1 - n_width];
					int p = a + b - c, pa = abs(p - a), pb = abs(p - b), pc = abs(p - c);
					*p_buffer += (pa <= pb && pa <= pc)? a : ((pb <= pc)? b : c); // paeth
				} else if(n_pred_type == 4 || (n_pred_type == 5 && x + 1 == n_width)) { // med
					int a = p_buffer[-1], b = p_buffer[-n_width], c = p_buffer[-1 - n_width];
					*p_buffer += (c >= max(a, b))? min(a, b) : (c <= min(a, b))? max(a, b) : a + b - c;
				} else if(n_pred_type == 5) { // gap
					_ASSERTE(x + 1 != n_width); // the last column predicted using med (gap looks right)
					int nne = p_buffer[1 - 2 * n_width], n = p_buffer[-n_width], w = p_buffer[-1],
						ww = p_buffer[-2], nn = p_buffer[-2 * n_width], ne = p_buffer[1 - n_width],
						nw = p_buffer[-1 - n_width], n_d = abs(w - nw) + abs(n - nn) +
						abs(ne - nne) - abs(w - ww) - abs(n - nw) - abs(ne - n), n_ad = abs(n_d);
					uint8_t f = (w + n) / 2 + (ne - nw) / 4, g = (n_d > 0)? w : n;
					*p_buffer += (n_ad > 80)? g : (n_ad > 32)? (f + g) / 2 : (n_ad > 8)? (3 * f + g) / 4 : f;
				} else if(n_pred_type == 7) // 6 = no prediction
					*p_buffer += p_buffer[-1 - n_width]; // up-left
				else if(n_pred_type == 8)
					*p_buffer += (int(p_buffer[-1]) + int(p_buffer[-n_width])) / 2; // avg2
				else if(n_pred_type == 9)
					*p_buffer += p_buffer[-1] + p_buffer[-n_width] - p_buffer[-1 - n_width]; // diff
				else if(n_pred_type == 10)
					*p_buffer += p_buffer[-1] + (p_buffer[-n_width] - p_buffer[-1 - n_width]) / 2; // grad-h
				else if(n_pred_type == 11)
					*p_buffer += p_buffer[-n_width] + (p_buffer[-1] - p_buffer[-1 - n_width]) / 2; // grad-v
			}
		}
	}

	/**
	 *	@brief decompresses the image
	 *
	 *	@param[in] p_s_base64 is null-terminated string containing BASE64 compressed image data
	 *	@param[in] n_image_width is image width, in pixels
	 *	@param[in] n_image_height is image height, in pixels
	 *	@param[in] n_huff_stage_size size of the compressed data before Huffman encoding
	 *	@param[in] n_predictor_y is predictor type for the luminance plane
	 *	@param[in] n_predictor_uv is predictor type for the chrominance plane
	 *	@param[in] n_predictor_a is predictor type for the alpha plane
	 *	@param[in] n_subsample is number of chrominance samples per 
	 *	@param[in] n_color_type is color type bitmask (if the first bit is set the image is
	 *		grayscale, if the second bit is set the image has alpha channel, if the third
	 *		bit is set, lossless compression was employed)
	 */
	static uint32_t *p_Decode_RLE_Huff_Base64(const char *p_s_base64,
		int n_image_width, int n_image_height, size_t n_huff_stage_size,
		int n_predictor_y, int n_predictor_uv, int n_predictor_a,
		int n_subsample, int n_color_type)
	{
		bool b_gray = (n_color_type & 1) != 0, b_alpha = (n_color_type & 2) != 0,
			b_lossless_color = (n_color_type & 4) != 0;
		size_t n_base64_length = strlen(p_s_base64);
		size_t n_base64_out_size = (n_base64_length / 4) * 3 +
			max(int(n_base64_length % 4) - 1, 0);
		size_t n_image_size = size_t(n_image_width) * n_image_height;
		int n_chroma_w = (n_image_width + n_subsample - 1) / n_subsample;
		int n_chroma_h = (n_image_height + n_subsample - 1) / n_subsample;
		size_t n_chroma_size = size_t(n_chroma_w) * n_chroma_h * 2;
		size_t n_image_data_size = n_image_size * ((b_alpha)? 2 : 1) +
			((b_gray)? 0 : n_chroma_size);

		size_t n_prehuff_size = max(n_base64_out_size, n_image_data_size);
		size_t n_temp_buffer_size = n_prehuff_size + n_huff_stage_size;
		uint8_t *p_temp_buffer;
		uint32_t *p_raster;
		if(!(p_temp_buffer = new(std::nothrow) uint8_t[n_temp_buffer_size]) ||
		   !(p_raster = new(std::nothrow) uint32_t[n_image_size])) {
			delete[] p_temp_buffer; // no effect on null
			return 0;
		}

		{
			int p_ic_tab[256];
			for(int i = 0; i < 256; ++ i) {
				p_ic_tab[i] = (isalpha(i))? (i | 32) - 'a' + ((i < 'a')? 0 : 26) :
					(isdigit(i))? i - '0' + 52 : (i == '+')? 62 : 63;
			}
			uint8_t *p_src = (uint8_t*)p_s_base64, *p_dst = p_temp_buffer;
			for(const uint8_t *p_end = p_src + n_base64_length - 3; p_src < p_end; p_src += 4, p_dst += 3) {
				uint8_t p_tmp[] = {p_ic_tab[p_src[1]], p_ic_tab[p_src[2]]};
				*p_dst = (p_ic_tab[p_src[0]] << 2) | (p_tmp[0] >> 4);
				p_dst[1] = (p_tmp[0] << 4) | (p_tmp[1] >> 2);
				p_dst[2] = (p_tmp[1] << 6) | p_ic_tab[p_src[3]];
			}
			if(n_base64_length % 4 == 3) {
				uint8_t n_tmp = p_ic_tab[p_src[1]];
				*p_dst = (p_ic_tab[p_src[0]] << 2) | (n_tmp >> 4);
				p_dst[1] = (n_tmp << 4) | ((p_ic_tab[p_src[2]] >> 2) & 0xf); // fixed byte order
			} else if(n_base64_length % 4 == 2)
				*p_dst = (p_ic_tab[p_src[0]] << 2) | (p_ic_tab[p_src[1]] >> 4);
		}
		{
			const uint8_t *p_huff_src = p_temp_buffer, *p_huff_end = p_huff_src + n_base64_out_size;
			_ASSERTE(p_huff_src + 16 * sizeof(int32_t) <= p_huff_end);
			const int32_t *p_code_num = (const int32_t*)p_huff_src; p_huff_src += 16 * sizeof(int32_t);
			int p_min_code[16], p_max_code[16], p_table_off[16], n_code_num = 0;
			for(int i = 0, n_cw = 0; i < 16; ++ i, n_cw <<= 1) {
				p_min_code[i] = n_cw;
				p_max_code[i] = (n_cw += p_code_num[i]);
				p_table_off[i] = n_code_num - p_min_code[i];
				n_code_num += p_code_num[i];
			}
			_ASSERTE(p_huff_src + n_code_num <= p_huff_end);
			const uint8_t *p_symbol = p_huff_src; p_huff_src += n_code_num;
			uint8_t *p_huff_dest = p_temp_buffer + n_prehuff_size;
			for(int n_byte = 0, n_bit_num = 0, n_counter = n_huff_stage_size; n_counter --;) {
				for(int i = 0, n_code = 0;; ++ i) {
					_ASSERTE(i < 16);
					if(!(n_bit_num --)) {
						_ASSERTE(p_huff_src < p_huff_end);
						n_byte = *p_huff_src ++;
						n_bit_num = 7;
					}
					n_code = (n_code << 1) | ((n_byte >> 7) & 1);
					n_byte <<= 1;
					if(n_code >= p_min_code[i] && n_code < p_max_code[i]) {
						*p_huff_dest ++ = p_symbol[n_code + p_table_off[i]];
						break;
					}
				}
			}
		}
		{
			const uint8_t *p_rle_src = p_temp_buffer + n_prehuff_size,
				*p_src_end = p_rle_src + n_huff_stage_size;
			for(uint8_t *p_rle_dest = p_temp_buffer; p_rle_src != p_src_end;) {
				uint8_t n_code = *p_rle_src ++;
				bool b_compressed = n_code & 1;
				int n_run_length = (n_code >> 1) + 1;
				_ASSERTE(p_rle_src + ((b_compressed)? 1 : n_run_length) <= p_src_end);
				while(n_run_length --)
					*p_rle_dest ++ = (b_compressed)? *p_rle_src : *p_rle_src ++;
				if(b_compressed)
					++ p_rle_src;
			}
		}

		if(!b_gray) {
			uint8_t *p_y = p_temp_buffer, *p_u = p_y + n_image_size,
				*p_v = p_u + n_chroma_size / 2, *p_a = p_u + n_chroma_size;
			UnPredict_ImagePlane(p_y, n_image_width, n_image_height, n_predictor_y);
			UnPredict_ImagePlane(p_u, n_chroma_w, n_chroma_h, n_predictor_uv);
			UnPredict_ImagePlane(p_v, n_chroma_w, n_chroma_h, n_predictor_uv);
			if(b_alpha)
				UnPredict_ImagePlane(p_a, n_image_width, n_image_height, n_predictor_a);
			uint32_t *p_dest = p_raster;
			for(int y = 0, h = n_image_height; y < h; ++ y) {
				for(int x = 0, w = n_image_width; x < w; ++ x, ++ p_y, ++ p_dest) {
					size_t n_cr_idx = x / n_subsample + size_t(y / n_subsample) * n_chroma_w;
					uint8_t r, g, b;
					if(!b_lossless_color) {
						int Y = *p_y, u = p_u[n_cr_idx] - 128, v = p_v[n_cr_idx] - 128;
						r = uint8_t(max(0, min(255, Y + 1.402f * v)));
						g = uint8_t(max(0, min(255, Y - 0.34414f * u - 0.71414f * v)));
						b = uint8_t(max(0, min(255, Y + 1.772f * u))); // JPEG-like YUV
					} else {
						int8_t u = p_u[n_cr_idx], v = p_v[n_cr_idx];
						g = *p_y - (u >> 1);
						uint8_t s = g + u;
						r = s - (v >> 1);
						b = r + v; // lifting
					}
					if(b_alpha) {
						*p_dest = (*p_a << 24) | (b << 16) | (g << 8) | r;
						++ p_a;
					} else
						*p_dest = 0xff000000U | (b << 16) | (g << 8) | r;
				}
			}
		} else {
			uint8_t *p_a = p_temp_buffer + n_image_size;
			uint32_t *p_dest = p_raster;
			UnPredict_ImagePlane(p_temp_buffer, n_image_width, n_image_height, n_predictor_y);
			if(b_alpha) {
				UnPredict_ImagePlane(p_a, n_image_width, n_image_height, n_predictor_a);
				for(const uint8_t *p_y = p_temp_buffer,
				   *p_end = p_y + n_image_size; p_y != p_end; ++ p_y, ++ p_a)
					*p_dest ++ = (*p_a << 24) | (*p_y << 16) | (*p_y << 8) | *p_y; // gray / alpha
			} else {
				for(const uint8_t *p_y = p_temp_buffer,
				   *p_end = p_y + n_image_size; p_y != p_end; ++ p_y)
					*p_dest ++ = 0xff000000U | (*p_y << 16) | (*p_y << 8) | *p_y; // gray
			}
		}

		delete[] p_temp_buffer;

		return p_raster;
	}
};

#endif // __OPENGL_LOGO_2_0_TGA_INCLUDED
