/*
								+----------------------------------+
								|                                  |
								|  ***   Image to header v3   ***  |
								|                                  |
								|   Copyright  -tHE SWINe- 2013   |
								|                                  |
								|             Main.cpp             |
								|                                  |
								+----------------------------------+
*/

#include "../UberLame_src/NewFix.h"
#include "../UberLame_src/CallStack.h"
#include <string.h>
#include <stdio.h>
#include <ctype.h>
#include <vector>
#include <set>
#include <algorithm>
#include "../UberLame_src/Integer.h"
#include "../UberLame_src/Tga.h"
#include "../UberLame_src/Jpeg.h"
#include "../UberLame_src/MinMax.h"
#include "../UberLame_src/StlUtils.h"
#include "../UberLame_src/Buffer.h"
#include "../UberLame_src/Compress.h"
#include "../UberLame_src/Base64.h"
#include "../UberLame_src/Base85.h"
#include "../UberLame_src/Parallel.h"
#include "../UberLame_src/Dir.h"
#include "../UberLame_src/Crc.h"
#include "../UberLame_src/iface/PNGLoad.h"
namespace base64_dec {
#include "Decompress64.h"
} // ~base64_dec
#include "Decompress64Src.h"
namespace base85_dec {
#include "Decompress85.h"
} // ~base64_dec
#include "Decompress85Src.h"

//#include "opengl_logo_2_0.h" // test
//#include "LosslessTest.h" // debug - testing the decompressor code

#if defined(_MSC_VER) && !defined(__MWERKS__) && !defined(for) && _MSC_VER <= 1200
#define for if(0) {} else for
#endif // _MSC_VER && !__MWERKS__ && !for && _MSC_VER <= 1200
// msvc 'for' scoping hack

#define WEIGHTED_UV // high quality images and good compression

#define LOSSLESS_MEDIAN_UV // others probably are not lossless

//#define GAP_USES_MED_FOR_LAST_COL // requires corresponding changes in Decompress.h; seems to give very slightly better compression without MED (undefined)

enum {
	pred_Up,
	pred_Left,
	pred_Avg,
	pred_Paeth,
	pred_Med,
	pred_Gap, // surprisingly lousy (10x more data) .., could be buggy // fixed

	pred_None,
	pred_UpLeft,
	pred_Avg2,
	pred_Diff,
	pred_GradH,
	pred_GradV,

	pred_Num
};

static const char *p_pred_name_list[] = {"up", "left", "avg", "paeth",
	"med", "gap", "none", "up-left", "avg2", "diff", "grad-h", "grad-v"};

bool ReadFile(std::string &r_s_output, const char *p_s_filename)
{
	FILE *p_fr;
	if(!(p_fr = fopen(p_s_filename, "rb")))
		return false;
	long n_length;
	if(fseek(p_fr, 0, SEEK_END) ||
	   (n_length = ftell(p_fr)) < 0 ||
	   fseek(p_fr, 0, SEEK_SET)) {
		fclose(p_fr);
		return false;
	}
	r_s_output.erase();
	if(!stl_ut::Reserve_N(r_s_output, n_length)) {
		fclose(p_fr);
		return false;
	}
	r_s_output.resize(n_length);
	if(fread(&r_s_output[0], n_length, sizeof(char), p_fr) != 1) {
		fclose(p_fr);
		return false;
	}
	fclose(p_fr);
	return true;
}

inline int n_RGB_Dot(uint32_t n_value, float f_r_weight,
	float f_g_weight, float f_b_weight, int n_off = 0)
{
	return max(0, min(int(f_r_weight * (n_value & 0xff) +
		f_g_weight * ((n_value >> 8) & 0xff) +
		f_b_weight * ((n_value >> 16) & 0xff)) + n_off, 255));
}

void ImagePlane_CropBits(uint8_t *p_buffer, int n_width, int n_height, int n_bpp)
{
	_ASSERTE(n_bpp <= 8);
	if(n_bpp == 8)
		return;
	int n_shift = 8 - n_bpp;
	int n_low_bits = ((1 << n_shift) - 1);
	uint8_t n_mask = ~uint8_t(n_low_bits);
	for(uint8_t *p_end = p_buffer + n_width * n_height; p_buffer != p_end; ++ p_buffer) {
		uint8_t n_result = *p_buffer & n_mask;
		// apply masking ... but now the range reduced

		if(n_bpp < 4) {
			n_result |= *p_buffer >> n_bpp;
			n_result |= *p_buffer >> (n_bpp * 2);
			n_result |= *p_buffer >> (n_bpp * 4); // replicate multiple times to fill the whole byte
		} else
			n_result |= *p_buffer >> n_bpp;
		// put something to the low bits so black is black and white is white,
		// but this "postfix" must not add on entropy (this doesn't)

		*p_buffer = n_result;
		// store
	}
}

bool Predict_ImagePlane(uint8_t *p_buffer, int n_width, int n_height, int n_pred_type)
{
	int n_first_row = (n_pred_type == pred_Left ||
		n_pred_type == pred_None)? 0 : ((n_pred_type == pred_Gap)? 2 : 1);
	int n_first_col = (n_pred_type == pred_Up ||
		n_pred_type == pred_None)? 0 : ((n_pred_type == pred_Gap)? 2 : 1);
	// some predictors can't predict first line / first column, or even more

	TBuffer t_tmp;
	if(!t_tmp.Resize((n_first_row + 1) * n_width * sizeof(uint8_t)))
		return false;
	// alloc temp buffer to hold a single scanline (two scanlines if
	// predictor references previous scanline)

	for(int y = n_first_row; y < n_height; ++ y) {
		uint8_t *p_tmp = t_tmp.p_Data() + ((n_first_row)? (y % (n_first_row + 1)) * n_width : 0);
		// get scanline pointer

		if(n_first_col) {
			for(int x = 0; x < n_first_col; ++ x)
				p_tmp[x] = p_buffer[x + y * n_width];
		}
		// remember the first pixel(s) in case we don't predict it, so p_tmp contains the whole scanline
		// note that there is no need to remember the first scanline, it is simply not modified

		for(int x = n_first_col; x < n_width; ++ x) {
			switch(n_pred_type) {
			case pred_Up:
				p_tmp[x] = p_buffer[x + y * n_width] - p_buffer[x + (y - 1) * n_width];
				break;
			case pred_Left:
				p_tmp[x] = p_buffer[x + y * n_width] - p_buffer[(x - 1) + y * n_width];
				break;
			case pred_Avg:
				p_tmp[x] = p_buffer[x + y * n_width] - (int(p_buffer[x + (y - 1) * n_width]) +
					int(p_buffer[(x - 1) + y * n_width]) +
					int(p_buffer[(x - 1) + (y - 1) * n_width])) / 3;
				break;
			case pred_Paeth:
				{
					uint8_t b = p_buffer[x + (y - 1) * n_width], // above
						a = p_buffer[(x - 1) + y * n_width], // left
						c = p_buffer[(x - 1) + (y - 1) * n_width]; // upper left
					// get upper-left neighbourhood

					int p = int(a) + int(b) - int(c);
					int pa = abs(p - a);
					int pb = abs(p - b);
					int pc = abs(p - c);
					// estimate distances

					if(pa <= pb && pa <= pc)
						p_tmp[x] = p_buffer[x + y * n_width] - uint8_t(a);
					else if(pb <= pc)
						p_tmp[x] = p_buffer[x + y * n_width] - uint8_t(b);
					else
						p_tmp[x] = p_buffer[x + y * n_width] - uint8_t(c);
					// return nearest
				}
				break;
			case pred_Med:
				{
					uint8_t b = p_buffer[x + (y - 1) * n_width], // above
						a = p_buffer[(x - 1) + y * n_width], // left
						c = p_buffer[(x - 1) + (y - 1) * n_width]; // upper left
					// get upper-left neighbourhood

					uint8_t p = (c >= max(a, b))? min(a, b) : (c <= min(a, b))? max(a, b) : a + b - c;
					p_tmp[x] = p_buffer[x + y * n_width] - p;
					// predict using MED
				}
				break;
			case pred_Gap:
				{
#ifdef GAP_USES_MED_FOR_LAST_COL
					if(x + 1 == n_width) {
						uint8_t b = p_buffer[x + (y - 1) * n_width], // above
							a = p_buffer[(x - 1) + y * n_width], // left
							c = p_buffer[(x - 1) + (y - 1) * n_width]; // upper left
						// get upper-left neighbourhood

						uint8_t p = (c >= max(a, b))? min(a, b) : (c <= min(a, b))? max(a, b) : a + b - c;
						p_tmp[x] = p_buffer[x + y * n_width] - p;
						// predict using MED, that does not need to look to the right

						break;
					}
					// no prediction for the last scanline pixel, needs right neighbourhood
#endif // GAP_USES_MED_FOR_LAST_COL

					uint8_t n = p_buffer[x + (y - 1) * n_width], // above
						w = p_buffer[(x - 1) + y * n_width], // left
						nw = p_buffer[(x - 1) + (y - 1) * n_width], // upper left
						ww = p_buffer[(x - 2) + y * n_width], // left left
						nn = p_buffer[x + (y - 2) * n_width], // above above
#ifdef GAP_USES_MED_FOR_LAST_COL
						nne = p_buffer[(x + 1) + (y - 2) * n_width], // above above right
						ne = p_buffer[(x + 1) + (y - 1) * n_width]; // above right
#else // GAP_USES_MED_FOR_LAST_COL
						nne = p_buffer[min(x + 1, n_width - 1) + (y - 2) * n_width], // above above right
						ne = p_buffer[min(x + 1, n_width - 1) + (y - 1) * n_width]; // above right
#endif // GAP_USES_MED_FOR_LAST_COL
					// get 7 pixels from the neighbourhood

					int dv = abs(int(w) - int(nw)) + abs(int(n) - int(nn)) + abs(int(ne) - int(nne));
					int dh = abs(int(w) - int(ww)) + abs(int(n) - int(nw)) + abs(int(n) - int(ne)); // some google book has w-nw for the first term, seems worse though
					// calculate derivation

					uint8_t p;
					if(dv - dh > 80)
						p = w;
					else if(dv - dh < -80)
						p = n;
					else {
						p = (int(w) + n) / 2 + (int(ne) - nw) / 4;
						if(dv - dh > 32)
							p = (p + w) / 2;
						else if(dv - dh > 8)
							p = (3 * p + w) / 4;
						else if(dv - dh < -32)
							p = (p + n) / 2;
						else if(dv - dh < -8)
							p = (3 * p + n) / 4;
					}
					p_tmp[x] = p_buffer[x + y * n_width] - p;
					// predict using GAP
				}
				break;
			case pred_None:
				p_tmp[x] = p_buffer[x + y * n_width]; // no prediction
				break;
			case pred_UpLeft:
				p_tmp[x] = p_buffer[x + y * n_width] - p_buffer[(x - 1) + (y - 1) * n_width];
				break;
			case pred_Avg2:
				p_tmp[x] = p_buffer[x + y * n_width] - (int(p_buffer[x + (y - 1) * n_width]) +
					int(p_buffer[(x - 1) + y * n_width])) / 2; // only straight top and straight left
				break;
			case pred_Diff:
				p_tmp[x] = p_buffer[x + y * n_width] - (int(p_buffer[x + (y - 1) * n_width]) -
					int(p_buffer[(x - 1) + (y - 1) * n_width]) +
					int(p_buffer[(x - 1) + y * n_width])); // left + top - top-left
				break;
			case pred_GradH:
				p_tmp[x] = p_buffer[x + y * n_width] - (int(p_buffer[(x - 1) + y * n_width]) +
					(int(p_buffer[x + (y - 1) * n_width]) -
					int(p_buffer[(x - 1) + (y - 1) * n_width])) / 2); // left + (top - top-left) / 2
				break;
			case pred_GradV:
				p_tmp[x] = p_buffer[x + y * n_width] - (int(p_buffer[x + (y - 1) * n_width]) +
					(int(p_buffer[(x - 1) + y * n_width]) -
					int(p_buffer[(x - 1) + (y - 1) * n_width])) / 2); // top + (left - top-left) / 2
				break;
			}
		}
		// predict one scanline
		// note that jpeg-ls actually (reportedly) choses (a different) predictor per each pixel

		if(!n_first_row)
			memcpy(p_buffer + y * n_width, p_tmp, n_width * sizeof(uint8_t));
		else if(y > 2 * n_first_row - 1) {
			memcpy(p_buffer + (y - n_first_row) * n_width,
				t_tmp.p_Data() + ((y + 1) % (n_first_row + 1)) * n_width,
				n_width * sizeof(uint8_t));
			// the current writes at scanline y % (n_first_row + 1)
			// the previous one should be (y - 1 + (n_first_row + 1)) % (n_first_row + 1)
			// but we need the one before n_first_row, that is (y + 1) % (n_first_row + 1)
			// note we copy only one at a time!
		}
		// copy scanline back (delayed in case predictor references previous scanline)
	}
	// predict the image

	if(n_first_row) {
		for(int y = n_height, n = n_first_row; n; -- n, ++ y) {
			memcpy(p_buffer + (y - n_first_row) * n_width,
				t_tmp.p_Data() + ((y + 1) % (n_first_row + 1)) * n_width,
				n_width * sizeof(uint8_t));
		}
	}
	// copy the last scanline(s) back

	for(int y = 0; y < n_first_row; ++ y) {
		for(int x = n_width - 1; x > n_first_col; -- x)
			p_buffer[x + n_width * y] -= p_buffer[(x - 1) + n_width * y];
	}
	for(int x = 0; x < n_first_col; ++ x) {
		for(int y = n_height - 1; y > n_first_row; -- y)
			p_buffer[x + n_width * y] -= p_buffer[x + n_width * (y - 1)];
	}
	// predict n_first_row and n_first_col using left and up, respectively,
	// in order to completely avoid having intensities in the image (except for the first pixel)

	return true;
}

static bool b_verbose = false;
static bool b_gray = false;
static int n_subsample = 2;
static int n_chroma_bits = 6;
static bool b_lossless_color = false;
static bool b_advanced_predictors = false;
static int n_alpha_bits = 8;
// too lazy to pass these to CImageCompressPredictorPass as parameters

/**
 *	@brief parallel predictor test loop
 *
 *	In this implementation, the predictor is chosen per entire image plane,
 *	based on the final compressed size. This is not complicated, and always
 *	gains the best compression, but is time constming, this wraps the old
 *	loop in a function object in order to make it run parallel.
 */
class CImageCompressPredictorPass {
protected:
	CAtomicCounter<> m_counter;
	CMutex m_mutex;
	size_t m_n_afterhuff_size;
	uint32_t m_n_decomp_image_crc32;
	TBuffer m_t_packed;
	int m_n_predictor_y, m_n_predictor_uv, m_n_predictor_a;
	const TBmp *m_p_image;
	int m_n_predictor_num;

public:
	inline CImageCompressPredictorPass(const TBmp *p_image, int m_n_predictor_num)
		:m_counter(0), m_p_image(p_image), m_n_predictor_num(m_n_predictor_num)
	{}

	inline void operator()(size_t n_thread, size_t n_thread_num) // throw(std::bad_alloc)
	{
		const TBmp *p_im_orig = m_p_image;
		TBmp *p_thread_copy = 0;
		if(n_thread_num == 1 || !(p_thread_copy = p_im_orig->p_Clone())) { // no need to copy for single thread
			if(Run(p_thread_copy))
				throw std::bad_alloc(); // use exception
		} else {
			bool b_result = !Run(p_thread_copy);
			p_thread_copy->Delete();
			if(!b_result)
				throw std::bad_alloc(); // use exception
		}
		// alloc different copy of the image in each thread (as long as there is enough memory)
	}

	inline TBuffer &r_t_Buffer()
	{
		return m_t_packed;
	}

	inline const TBuffer &r_t_Buffer() const
	{
		return m_t_packed;
	}

	inline size_t n_RLE_Size() const
	{
		return m_n_afterhuff_size;
	}

	inline uint32_t n_CRC32_Decompressed() const
	{
		return m_n_decomp_image_crc32;
	}

	inline int n_Predictor_Y() const
	{
		return m_n_predictor_y;
	}

	inline int n_Predictor_UV() const
	{
		return m_n_predictor_uv;
	}

	inline int n_Predictor_A() const
	{
		return m_n_predictor_a;
	}

protected:
	inline int Run(const TBmp *p_thread_copy) // too lazy, copied code from main(), returns zero on success, -1 otherwise
	{
		const TBmp *p_image = p_thread_copy;
		const int n_use_pred = m_n_predictor_num;

#ifdef LOSSLESS_MEDIAN_UV
		std::vector<uint8_t> u_list, v_list; // signed!!
		if(!b_gray && b_lossless_color &&
		   (!stl_ut::Resize_To_N(u_list, n_subsample * n_subsample) ||
		   !stl_ut::Resize_To_N(v_list, n_subsample * n_subsample))) {
			fprintf(stderr, "error: not enough memory\n");
			return -1;
		}
#endif / LOSSLESS_MEDIAN_UV

		int n_predictor_combination_num = n_use_pred, n_predictor;
		if(p_image->b_alpha)
			n_predictor_combination_num *= n_use_pred;
		if(!b_gray)
			n_predictor_combination_num *= n_use_pred;
		while((n_predictor = m_counter.n_Atomic_Increment() - 1) < n_predictor_combination_num) {
			int n_pred_y = (n_predictor / n_use_pred) % n_use_pred;
			int n_pred_uv = n_predictor % n_use_pred;
			int n_pred_a = n_predictor / (n_use_pred * n_use_pred);
			// try all the predictors

			uint32_t n_decomp_image_crc32 = 0xbaadf00d;

			TBuffer t_decor_data;
			if(!b_gray) {
				size_t n_image_size = p_image->n_width * p_image->n_height;
				// get image size in pixels

				int n_chroma_w = (p_image->n_width + n_subsample - 1) / n_subsample;
				int n_chroma_h = (p_image->n_height + n_subsample - 1)/ n_subsample;
				size_t n_chroma_plane_size = n_chroma_w * n_chroma_h;
				size_t n_chroma_size = n_chroma_plane_size * 2; // U, V
				// get chroma size (subsampling)

				if(!t_decor_data.Resize((n_image_size + n_chroma_size +
				   ((p_image->b_alpha)? n_image_size : 0)) * sizeof(uint8_t))) {
					fprintf(stderr, "error: not enough memory\n");
					return -1;
				}
				// alloc buffer

				if(p_image->b_alpha) {
					uint8_t *p_A = t_decor_data.p_Data() + n_image_size + 2 * n_chroma_plane_size;
					// get destination pointer

					for(const uint32_t *p_src = p_image->p_buffer,
					   *p_end = p_image->p_buffer + n_image_size; p_src != p_end; ++ p_src, ++ p_A)
						*p_A = *p_src >> 24;
				}
				// get the alpha plane, if present

				if(b_lossless_color) { // Reversible Color Transform (RCT)
					uint8_t *p_Y = t_decor_data.p_Data();
					uint8_t *p_U = p_Y + n_image_size; // U = Cb
					uint8_t *p_V = p_U + n_chroma_plane_size; // V = Cr
					// get destination pointers

					for(const uint32_t *p_src = p_image->p_buffer,
					   *p_end = p_image->p_buffer + n_image_size; p_src != p_end; ++ p_src, ++ p_Y) {
						uint32_t n_pixel = *p_src;
						uint8_t r = n_pixel;
						uint8_t g = n_pixel >> 8;
						uint8_t b = n_pixel >> 16;
						int8_t v = int8_t(b - r);
						uint8_t t = r + (v >> 1);
						int8_t u = int8_t(t - g);
						*p_Y = uint8_t(g + (u >> 1));
					}
					_ASSERTE(p_Y == p_U);
					// get luma

					const uint32_t *p_src = p_image->p_buffer;
					for(int y = 0, h = p_image->n_height; y < h; y += n_subsample) {
						for(int x = 0, w = p_image->n_width; x < w; x += n_subsample, ++ p_U, ++ p_V) {
							// do not really need weighting and stuff, does not work for subsampled
							// images (but keeping it just in case it can be fixed)
#ifdef LOSSLESS_WEIGHTED_UV
							int u = 0, v = 0, w_sum = 0;
							for(int dy = 0; dy < n_subsample; ++ dy) {
								for(int dx = 0; dx < n_subsample; ++ dx) {
									int n_index = min(x + dx, w - 1) + min(y + dy, h - 1) * w;
									int w = 129 - abs(127 - t_decor_data.p_Data()[n_index]);
									w *= w; // weight based on lightness
									uint32_t n_pixel = p_src[n_index];
									uint8_t r = n_pixel;
									uint8_t g = n_pixel >> 8;
									uint8_t b = n_pixel >> 16;
									v += int8_t(b - r);
									uint8_t t = r + (v >> 1);
									u += int8_t(t - g);
									w_sum += w;
								}
							}
							// calculate chrominance

							*p_U = uint8_t(u / w_sum);
							*p_V = uint8_t(v / w_sum);
							// average
#endif // LOSSLESS_WEIGHTED_UV
#ifdef LOSSLESS_AVERAGE_UV
							int u = 0, v = 0;
							for(int dy = 0; dy < n_subsample; ++ dy) {
								for(int dx = 0; dx < n_subsample; ++ dx) {
									int n_index = min(x + dx, w - 1) + min(y + dy, h - 1) * w;
									uint32_t n_pixel = p_src[n_index];
									uint8_t r = n_pixel;
									uint8_t g = n_pixel >> 8;
									uint8_t b = n_pixel >> 16;
									v += int8_t(b - r);
									uint8_t t = r + (v >> 1);
									u += int8_t(t - g);
								}
							}
							// calculate chrominance

							*p_U = uint8_t(u / (n_subsample * n_subsample));
							*p_V = uint8_t(v / (n_subsample * n_subsample));
							// average
#endif // LOSSLESS_AVERAGE_UV
#ifdef LOSSLESS_MEDIAN_UV
							_ASSERTE(u_list.size() == v_list.size() &&
								u_list.size() == n_subsample * n_subsample); // allocated beforehand
							for(int dy = 0, i = 0; dy < n_subsample; ++ dy) {
								for(int dx = 0; dx < n_subsample; ++ dx, ++ i) {
									int n_index = min(x + dx, w - 1) + min(y + dy, h - 1) * w;
									uint32_t n_pixel = p_src[n_index];
									uint8_t r = n_pixel;
									uint8_t g = n_pixel >> 8;
									uint8_t b = n_pixel >> 16;
									int8_t v = b - r;
									uint8_t t = r + (v >> 1);
									int8_t u = t - g;
									u_list[i] = u;
									v_list[i] = v;
								}
							}
							// calculate chrominance

							std::sort(u_list.begin(), u_list.end());
							std::sort(v_list.begin(), v_list.end());
							*p_U = u_list[n_subsample * n_subsample / 2];
							*p_V = v_list[n_subsample * n_subsample / 2];
							// median
#endif // LOSSLESS_MEDIAN_UV
						}
					}
					//_ASSERTE(p_U < p_V && p_V == t_decor_data.p_Data() + t_decor_data.n_Size()); // not with alpha
					_ASSERTE(p_Y == t_decor_data.p_Data() + n_image_size);
					_ASSERTE(p_U == p_Y + n_chroma_plane_size);
					_ASSERTE(p_V == p_U + n_chroma_plane_size);
					// get chromas
				} else { // YUV colors (lossy)
					uint8_t *p_Y = t_decor_data.p_Data();
					uint8_t *p_U = p_Y + n_image_size;
					uint8_t *p_V = p_U + n_chroma_plane_size;
					// get destination pointers

					for(const uint32_t *p_src = p_image->p_buffer,
					   *p_end = p_image->p_buffer + n_image_size; p_src != p_end;)
						*p_Y ++ = n_RGB_Dot(*p_src ++, 0.299f, 0.587f, 0.114f); // calculate luminance
					_ASSERTE(p_Y == p_U);
					// get luma

					const uint32_t *p_src = p_image->p_buffer;
					for(int y = 0, h = p_image->n_height; y < h; y += n_subsample) {
						for(int x = 0, w = p_image->n_width; x < w; x += n_subsample) {
#ifdef WEIGHTED_UV
							int u = 0, v = 0, w_sum = 0;
							for(int dy = 0; dy < n_subsample; ++ dy) {
								for(int dx = 0; dx < n_subsample; ++ dx) {
									int n_index = min(x + dx, w - 1) + min(y + dy, h - 1) * w;
									int w = 129 - abs(127 - t_decor_data.p_Data()[n_index]);
									w *= w; // weight based on lightness
									u += w * n_RGB_Dot(p_src[n_index], -0.168736f, -0.331264f, 0.5f, 128);
									v += w * n_RGB_Dot(p_src[n_index], 0.5f, -0.418688f, -0.081312f, 128);
									w_sum += w;
								}
							}
							// calculate chrominance

							*p_U ++ = uint8_t(u / w_sum);
							*p_V ++ = uint8_t(v / w_sum);
							// average
#endif // WEIGHTED_UV
#ifdef AVERAGE_UV
							int u = 0, v = 0;
							for(int dy = 0; dy < n_subsample; ++ dy) {
								for(int dx = 0; dx < n_subsample; ++ dx) {
									int n_index = min(x + dx, w - 1) + min(y + dy, h - 1) * w;
									u += n_RGB_Dot(p_src[n_index], -0.168736f, -0.331264f, 0.5f, 128);
									v += n_RGB_Dot(p_src[n_index], 0.5f, -0.418688f, -0.081312f, 128);
								}
							}
							// calculate chrominance

							*p_U ++ = uint8_t(u / (n_subsample * n_subsample));
							*p_V ++ = uint8_t(v / (n_subsample * n_subsample));
							// average
#endif // AVERAGE_UV
#ifdef MEDIAN_UV
							std::vector<uint8_t> u_list, v_list;
							if(!stl_ut::Reserve_N(u_list, n_subsample * n_subsample) ||
							   !stl_ut::Reserve_N(v_list, n_subsample * n_subsample)) {
								fprintf(stderr, "error: not enough memory\n");
								return -1;
							}
							for(int dy = 0; dy < n_subsample; ++ dy) {
								for(int dx = 0; dx < n_subsample; ++ dx) {
									int n_index = min(x + dx, w - 1) + min(y + dy, h - 1) * w;
									u_list.push_back(n_RGB_Dot(p_src[n_index], -0.168736f, -0.331264f, 0.5f, 128));
									v_list.push_back(n_RGB_Dot(p_src[n_index], 0.5f, -0.418688f, -0.081312f, 128));
								}
							}
							// calculate chrominance

							std::sort(u_list.begin(), u_list.end());
							std::sort(v_list.begin(), v_list.end());
							*p_U ++ = u_list[u_list.size() / 2];
							*p_V ++ = v_list[v_list.size() / 2];
							// median
#endif // MEDIAN_UV
						}
					}
					//_ASSERTE(p_U < p_V && p_V == t_decor_data.p_Data() + t_decor_data.n_Size()); // not with alpha
					_ASSERTE(p_Y == t_decor_data.p_Data() + n_image_size);
					_ASSERTE(p_U == p_Y + n_chroma_plane_size);
					_ASSERTE(p_V == p_U + n_chroma_plane_size);
					// get chromas
				}

				{
					uint8_t *p_Y = t_decor_data.p_Data();
					uint8_t *p_U = p_Y + n_image_size;
					uint8_t *p_V = p_U + n_chroma_plane_size;
					uint8_t *p_A = p_V + n_chroma_plane_size;
					// get destination pointers

					ImagePlane_CropBits(p_U, n_chroma_w, n_chroma_h, n_chroma_bits);
					ImagePlane_CropBits(p_V, n_chroma_w, n_chroma_h, n_chroma_bits);
					if(p_image->b_alpha)
						ImagePlane_CropBits(p_A, p_image->n_width, p_image->n_height, n_alpha_bits);
					// drop some bits from chroma plane

					n_decomp_image_crc32 = CCrc_32::n_Start();
					uint8_t *p_y = p_Y, *p_a = p_A;
					for(int y = 0, h = p_image->n_height; y < h; ++ y) {
						for(int x = 0, w = p_image->n_width; x < w; ++ x, ++ p_y, ++ p_a) {
							size_t n_cr_idx = x / n_subsample + size_t(y / n_subsample) * n_chroma_w;
							uint8_t r, g, b;
							if(b_lossless_color) {
								int8_t u = p_U[n_cr_idx], v = p_V[n_cr_idx];
								g = *p_y - (u >> 1);
								uint8_t s = g + u;
								r = s - (v >> 1);
								b = r + v; // lifting
							} else {
								int Y = *p_y, u = p_U[n_cr_idx] - 128, v = p_V[n_cr_idx] - 128;
								r = uint8_t(max(0, min(255, Y + 1.402f * v)));
								g = uint8_t(max(0, min(255, Y - 0.34414f * u - 0.71414f * v)));
								b = uint8_t(max(0, min(255, Y + 1.772f * u))); // JPEG-like YUV
							}
							uint32_t n_pixel = ((p_image->b_alpha)? *p_a << 24 : 0xff000000U) |
								(b << 16) | (g << 8) | r;
							n_decomp_image_crc32 = CCrc_32::n_Crc(sizeof(uint32_t), &n_pixel, n_decomp_image_crc32);
						}
					}
					n_decomp_image_crc32 = CCrc_32::n_Finalize(n_decomp_image_crc32);
					// calculate CRC of the expected decompressed RGB(A) image

					Predict_ImagePlane(p_Y, p_image->n_width, p_image->n_height, n_pred_y);
					Predict_ImagePlane(p_U, n_chroma_w, n_chroma_h, n_pred_uv);
					Predict_ImagePlane(p_V, n_chroma_w, n_chroma_h, n_pred_uv);
					if(p_image->b_alpha)
						Predict_ImagePlane(p_A, p_image->n_width, p_image->n_height, n_pred_a);
					// apply predictor
				}
			} else {
				size_t n_image_size = p_image->n_width * p_image->n_height;
				// get image size in pixels

				if(!t_decor_data.Resize((p_image->b_alpha)? 2 * n_image_size : n_image_size)) {
					fprintf(stderr, "error: not enough memory\n");
					return -1;
				}
				// alloc buffer for gray / gray alpha

				if(p_image->b_alpha) {
					uint8_t *p_A = t_decor_data.p_Data() + n_image_size;
					// get destination pointer

					for(const uint32_t *p_src = p_image->p_buffer,
					   *p_end = p_image->p_buffer + n_image_size; p_src != p_end; ++ p_src, ++ p_A)
						*p_A = *p_src >> 24;
				}
				// get the alpha plane, if present

				const uint32_t *p_pixel = p_image->p_buffer;
				for(uint8_t *p_dest = t_decor_data.p_Data(), *p_end = t_decor_data.p_Data() +
				   n_image_size; p_dest != p_end; ++ p_dest, ++ p_pixel)
					*p_dest = uint8_t(*p_pixel);
				// just copy data

				{
					uint8_t *p_Y = t_decor_data.p_Data();
					uint8_t *p_A = t_decor_data.p_Data() + n_image_size;

					if(p_image->b_alpha)
						ImagePlane_CropBits(p_A, p_image->n_width, p_image->n_height, n_alpha_bits);
					// before CRC!

					n_decomp_image_crc32 = CCrc_32::n_Start();
					uint8_t *p_y = p_Y, *p_a = p_A;
					for(int y = 0, h = p_image->n_height; y < h; ++ y) {
						for(int x = 0, w = p_image->n_width; x < w; ++ x, ++ p_y, ++ p_a) {
							uint8_t n_y = *p_y;
							uint32_t n_pixel = ((p_image->b_alpha)? *p_a << 24 : 0xff000000U) |
								(n_y << 16) | (n_y << 8) | n_y;
							n_decomp_image_crc32 = CCrc_32::n_Crc(sizeof(uint32_t), &n_pixel, n_decomp_image_crc32);
						}
					}
					n_decomp_image_crc32 = CCrc_32::n_Finalize(n_decomp_image_crc32);
					// calculate CRC of the expected decompressed image

					Predict_ImagePlane(p_Y, p_image->n_width, p_image->n_height, n_pred_y);
					if(p_image->b_alpha)
						Predict_ImagePlane(p_A, p_image->n_width, p_image->n_height, n_pred_a);
					// apply predictor
				}
			}
			// decorrelate image components (if rgb(a) or grey+a, for grey it's just copy image components)

			TBuffer t_packed_data;
			if(!CRunLengthCodec::Encode(t_decor_data, t_packed_data)) {
				fprintf(stderr, "error: not enough memory\n");
				return -1;
			}
			// pack using simple RLE (easy to unpack)

			size_t n_afterhuff = t_packed_data.n_Size();

			{
				TBuffer t_tmp;
				if(!CHuffmanCodec::Encode(t_packed_data, t_tmp)) {
					fprintf(stderr, "error: not enough memory\n");
					return -1;
				}
				// encode

				/*TBuffer t_tmp2;
				if(!CHuffmanCodec::Decode(t_tmp, t_tmp2)) {
					fprintf(stderr, "error: not enough memory for decoding\n");
					return -1;
				}
				_ASSERTE(t_tmp2.n_Size() == t_packed_data.n_Size());
				_ASSERTE(!memcmp(t_tmp2.p_Data(), t_packed_data.p_Data(), t_packed_data.n_Size()));*/
				// decode, make sure there is no bug in huffman

				t_packed_data.Swap(t_tmp);
			}
			// huffman step

			if(!m_mutex.Lock()) {
				fprintf(stderr, "fatal error: failed to lock mutex\n");
				return -1;
			}
			// must be protected

			/*printf("predictor %d %d %d gives " PRIsize " bytes\n",
				n_pred_y, n_pred_uv, n_pred_a, t_packed_data.n_Size());*/ // debug

			if(!m_t_packed.n_Size() || m_t_packed.n_Size() > t_packed_data.n_Size()) {
				m_t_packed.Swap(t_packed_data); // save compressed data
				m_n_predictor_y = n_pred_y;
				m_n_predictor_uv = n_pred_uv;
				m_n_predictor_a = n_pred_a; // remember predictors
				m_n_afterhuff_size = n_afterhuff; // remember size needed to extract huffman
				m_n_decomp_image_crc32 = n_decomp_image_crc32; // remember the expected decompressed CRC32
			}
			// choose best of predictors

			m_mutex.Unlock();
		}

		return 0;
		// success
	}
};

int main(int n_arg_num, const char **p_arg_list)
{
#if 0
	for(int r = 0; r < 256; ++ r) {
		for(int g = 0; g < 256; ++ g) {
			for(int b = 0; b < 256; ++ b) {
				/*uint8_t y = (r + 2 * g + b) / 4;
				int u = (b - g);
				int v = (r - g); // evidently needs 9 bits, that's a bummer
				int G = y - ((u + v > 0)? (u + v) / 4 : (u + v - 3) / 4);
				int R = v + G;
				int B = u + G;*/
				// this one is from jpeg and does not work, need 26 bits

				int8_t v = b - r;
				uint8_t t = r + (v >> 1);
				int8_t u = t - g;
				uint8_t y = g + (u >> 1);
				uint8_t G = y - (u >> 1);
				uint8_t s = G + u;
				uint8_t R = s - (v >> 1);
				uint8_t B = R + v;
				// "lifting" - seems to work well

				// try lifting with different weights (3/8)

				// try lyuv?

				_ASSERTE(G == g);
				_ASSERTE(R == r);
				_ASSERTE(B == b);
			}
		}
	}

	return 0;
#endif // 0
	// test of the lossless decorelation techniques

#if 0
	TBuffer t_image;
	t_image.Resize(256 * 256);
	uint8_t *p_data = t_image.p_Data();
	for(int i = 0; i < 256 * 256; ++ i)
		p_data[i] = rand();
	// generate some noise

	TBuffer t_pred;
	t_pred.Resize(256 * 256);
	uint8_t *p_pred = t_pred.p_Data();
	// copy to a predictor

	for(int i = 0; i < pred_Num; ++ i) {
		memcpy(p_pred, p_data, 256 * 256 * sizeof(uint8_t));
		Predict_ImagePlane(p_pred, 256, 256, i);
		UnPredict_ImagePlane(p_pred, 256, 256, i);
		if(memcmp(p_pred, p_data, 256 * 256 * sizeof(uint8_t))) {
			fprintf(stderr, "error: predictor %d failed\n", i);
			for(int y = 0; y < 256; ++ y) {
				if(memcmp(p_pred + y * 256, p_data + y * 256, 256 * sizeof(uint8_t))) {
					int x = 0;
					for(; x < 256; ++ x) {
						if(p_pred[x + y * 256] != p_data[x + y * 256])
							break;
					}
					fprintf(stderr, "error: the first difference appears on line %d, col %d\n", y, x);
					break;
				}
			}
		}
	}
	return 0;
#endif // 0
	// test predictors on some noise (might not be a good test for the nonlinear predictors)

#if 0
	uint32_t *p_buff = CTestImage::p_Decompress();
	delete[] p_buff;
#endif // 0
	// test to compile & run the resulting file

	if(n_arg_num < 3) {
		fprintf(stderr, "error: missing program arguments.\n"
			"usage:\n"
			"ImageToHeader <image-file> <header-file> [options]\n"
			"where image-file is source file, containing image in jpeg or tga format,\n"
			"and header-file is output file to contain image.\n"
			"--verbose parameter turns on verbose output\n"
			"--subsample n parameter sets croma subsampling to n pixels (default 2)\n"
			"--chroma-bpp m parameter sets chroma bpp to 2 * m bits (per Cb and Cr)\n"
			"--alpha-bpp m parameter sets alpha channe bpp to m bits\n"
			"--gray forces grayscale colors (single channel)\n"
			"--lossless turns on lossless color transform\n"
			"--exhaustive tests some extra predictors (takes longer, might compress better)\n"
			"--class-name n sets class name to n (does not perform any syntax checking)\n"
			"--max-cstr-len sets maximum \"C\"-string length (default 32767)\n"
			"--max-line-len sets maximum line length in the generated header\n"
			"               (only applies to the lines with data; default 100)\n"
			"--alpha|--no-alpha enables or disables alpha channel (otherwise follows image)\n"
			"--shared-decompress sets shared decompression routines (otherwise the\n"
			"               decompressor is private)\n"
			"--no-code-opts disables decompress code optimizations (only if\n"
			"               --shared-decompress not specified)\n"
			"--base-64 uses BASE-64 decoding instead of the default BASE-85\n");
		return 0;
	}

	/*bool b_verbose = false;
	bool b_gray = false;
	int n_subsample = 2;
	int n_chroma_bits = 6;
	bool b_lossless_color = false;
	bool b_advanced_predictors = false;
	int n_alpha_bits = 8;*/ // made it global
	// config

	unsigned int n_max_line_length = 100;
	unsigned int n_max_string_length = 32767; // to avoid c++ compilers complaining
	const char *p_s_infile = p_arg_list[1];
	const char *p_s_outfile = p_arg_list[2];
	const char *p_s_classname = 0;
	bool b_shared_decompress = false;
	bool b_allow_code_opts = true;
	bool b_use_base85 = true;
	int n_alpha_opt = -1; // do nothing

	bool b_reparsed = false;
	for(int i = 3; i < n_arg_num; ++ i) {
		if(!strcmp(p_arg_list[i], "--verbose"))
			b_verbose = true;
		else if(!strcmp(p_arg_list[i], "--base-64"))
			b_use_base85 = false;
		else if(!strcmp(p_arg_list[i], "--no-code-opts"))
			b_allow_code_opts = false;
		else if(!strcmp(p_arg_list[i], "--gray"))
			b_gray = true;
		else if(!strcmp(p_arg_list[i], "--alpha"))
			n_alpha_opt = 1;
		else if(!strcmp(p_arg_list[i], "--no-alpha"))
			n_alpha_opt = 0;
		else if(!strcmp(p_arg_list[i], "--exhaustive"))
			b_advanced_predictors = true;
		else if(!strcmp(p_arg_list[i], "--shared-decompress"))
			b_shared_decompress = true;
		else if(!strcmp(p_arg_list[i], "--lossless")) {
			b_lossless_color = true;
			if(!b_reparsed) {
				n_subsample = 1; // no subsampling
				n_chroma_bits = 8; // full precision
				b_reparsed = true;
				i = 2; // account for ++ i in the loop
				continue;
				// set defaults for lossless and parse again to make it possible to change them
			}
		} else if(i + 1 == n_arg_num) {
			fprintf(stderr, "warning: parameter: \'%s\': "
				"unknown parameter or needs a value (skipping)\n", p_arg_list[i]);
		} else if(!strcmp(p_arg_list[i], "--max-line-len"))
			n_max_line_length = atol(p_arg_list[++ i]);
		else if(!strcmp(p_arg_list[i], "--max-cstr-len"))
			n_max_string_length = atol(p_arg_list[++ i]);
		else if(!strcmp(p_arg_list[i], "--chroma-bpp"))
			n_chroma_bits = atol(p_arg_list[++ i]);
		else if(!strcmp(p_arg_list[i], "--alpha-bpp"))
			n_alpha_bits = atol(p_arg_list[++ i]);
		else if(!strcmp(p_arg_list[i], "--subsample"))
			n_subsample = atol(p_arg_list[++ i]);
		else if(!strcmp(p_arg_list[i], "--class-name"))
			p_s_classname = p_arg_list[++ i];
		else
			fprintf(stderr, "warning: unknown parameter: \'%s\' (skipping)\n", p_arg_list[i]);
	}
	// parse command-line

	if(b_verbose)
		printf("ImageToHeader v3.20 (built %s)\n\n", __DATE__);
	// print version

	if(b_lossless_color && n_subsample > 1) {
		fprintf(stderr, "warning: lossless color transformation"
			" selected, and subsampling is %d\n", n_subsample);
	}
	// subsampling does not work with lossless, except for some rare cases

	if(b_lossless_color && n_chroma_bits < 8) {
		fprintf(stderr, "warning: lossless color transformation"
			" selected and chroma bits is only %d\n", n_chroma_bits);
	}
	// less chroma bits works with lossless, but becomes lossy
	// (except for images with low bpp perhaps)

	n_max_string_length = max(n_max_string_length, n_max_line_length);
	// must be at least the same

	n_max_line_length -= 2; // the quotes
	n_max_line_length -= 3 * 4; // the tabs

	TBmp *p_image = 0;
	if(strrchr(p_s_infile, '.') && !_stricmp(strrchr(p_s_infile, '.'), ".tga")) {
		if(b_verbose)
			printf("loading image in TGA format ...\n");
		p_image = CTgaCodec::p_Load_TGA(p_s_infile);
	} else if(strrchr(p_s_infile, '.') && !_stricmp(strrchr(p_s_infile, '.'), ".png")) {
		if(b_verbose)
			printf("loading image in PNG format ...\n");
		p_image = CPngCodec::p_Load_PNG(p_s_infile);
	} else if(strrchr(p_s_infile, '.') && (!_stricmp(strrchr(p_s_infile, '.'), ".jpg") ||
	   !_stricmp(strrchr(p_s_infile, '.'), ".jpeg"))) {
		if(b_verbose)
			printf("loading image in JPEG format ...\n");
		FILE *p_fr;
		if(p_fr = fopen(p_s_infile, "rb")) {
			p_image = CTinyJpegDecoder().p_Decode_JPEG(p_fr);
			fclose(p_fr);
		}
	} else {
		fprintf(stderr, "error: unknown input file format\n");
		return -1;
	}
	if(!p_image) {
		fprintf(stderr, "error: error loading image file \'%s\'\n", p_s_infile);
		return -1;
	}
	// load image

	const uint32_t n_orig_image_crc32 = CCrc_32::n_Finalize(CCrc_32::n_Crc(p_image->n_width *
		p_image->n_height * sizeof(uint32_t), p_image->p_buffer, CCrc_32::n_Start()));

	if(b_gray && !p_image->b_grayscale) {
		if(p_image->b_alpha) {
			for(uint32_t *p_pixel = p_image->p_buffer,
			   *p_end = p_image->p_buffer + (p_image->n_width * p_image->n_height);
			   p_pixel != p_end; ++ p_pixel) {
				int n_value = n_RGB_Dot(*p_pixel, 0.299f, 0.587f, 0.114f);
				*p_pixel = (*p_pixel & 0xff000000U) | (n_value << 16) | (n_value << 8) | n_value; // preserve alpha
			}
		} else {
			for(uint32_t *p_pixel = p_image->p_buffer,
			   *p_end = p_image->p_buffer + (p_image->n_width * p_image->n_height);
			   p_pixel != p_end; ++ p_pixel) {
				int n_value = n_RGB_Dot(*p_pixel, 0.299f, 0.587f, 0.114f);
				*p_pixel = 0xff000000U | (n_value << 16) | (n_value << 8) | n_value; // full alpha
			}
		}
		p_image->b_grayscale = true;
	}
	b_gray = p_image->b_grayscale; // in case it is already grayscale
	// convert to grayscale

	if(n_alpha_opt != -1) {
		if(n_alpha_opt && !p_image->b_alpha) {
			p_image->b_alpha = true;
			printf("forcing alpha channel as per --alpha\n");
		} else if(!n_alpha_opt && p_image->b_alpha) {
			p_image->b_alpha = false;
			printf("stripping alpha channel as per --no-alpha\n");

			for(uint32_t *p_pix = p_image->p_Begin(), *p_end = p_image->p_End(); p_pix != p_end; ++ p_pix)
				*p_pix |= 0xff000000U;
			// fill, otherwise verify fails
		}
	}
	// force / clear alpha channel

	const uint32_t n_trans_image_crc32 = CCrc_32::n_Finalize(CCrc_32::n_Crc(p_image->n_width *
		p_image->n_height * sizeof(uint32_t), p_image->p_buffer, CCrc_32::n_Start()));
	// after alpha/grascale transformations

	if(b_verbose)
		printf("compressing image data ...\n");

	const int n_use_pred = (b_advanced_predictors)? pred_Num : pred_None;
	// decide how many predictors to use

	const int n_base = (b_use_base85)? 85 : 64;
	// which base are we encoding in?

	TBuffer t_packed;
	size_t n_afterhuff_size;
	uint32_t n_deco_image_crc32;
	int n_predictor_y, n_predictor_uv, n_predictor_a; // predictors chosen based on compression
	{
		CImageCompressPredictorPass try_predictors(p_image, n_use_pred);
#if defined(_MSC_VER) && !defined(__MWERKS__) && _MSC_VER <= 1200
		CParallelLoop_NoCopy<CImageCompressPredictorPass> loop(max(CThread::n_CPU_Num() - 1, size_t(1)));
		// MSVC 6.0 generates somehow very dense code, give up
		// some time to move the mouse pointer and to other programs
#else // _MSC_VER) && !__MWERKS__ && _MSC_VER <= 1200
		CParallelLoop_NoCopy<CImageCompressPredictorPass> loop;
#endif // _MSC_VER) && !__MWERKS__ && _MSC_VER <= 1200
		try {
			if(!loop.Run(try_predictors) || !loop.Quit())
				throw std::bad_alloc(); // handle all errors at one place
		} catch(std::bad_alloc&) {
			fprintf(stderr, "error: not enough memory\n");
			return -1;
		}
		t_packed.Swap(try_predictors.r_t_Buffer());
		if(t_packed.b_Empty()) {
			fprintf(stderr, "error: packed buffer came out empty, something went wrong\n");
			return -1;
		}
		n_afterhuff_size = try_predictors.n_RLE_Size();
		n_deco_image_crc32 = try_predictors.n_CRC32_Decompressed();
		n_predictor_y = try_predictors.n_Predictor_Y();
		n_predictor_uv = try_predictors.n_Predictor_UV();
		n_predictor_a = try_predictors.n_Predictor_A();

		if(b_gray)
			n_predictor_uv = pred_None;
		if(!p_image->b_alpha)
			n_predictor_a = pred_None;
		// use no prediction instead of a random value in case it is not going to be used
	}
	// do the hardest task in parallel

	std::string s_base64;
	if(b_use_base85) {
		const char *p_s_base85_alphabet = "0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ"
			"abcdefghijklmnopqrstuvwxyz!#$%&()*+-;<=>.@^_,{|}~"; // as RFC 1924, but '?' is '.' and '`' is ','
		// modified alphabet for Base-85 that will not cause trigraphs

		if(!CModifiedBase85::Encode(s_base64, t_packed.n_Size() - sizeof(uint32_t),
		   t_packed.p_Data() + sizeof(uint32_t), true, p_s_base85_alphabet)) {
			fprintf(stderr, "error: not enough memory\n");
			return -1;
		}
		// encode as base85, skip huffman unpack length, we save it otherwise
	} else {
		if(!CModifiedBase64::Encode(s_base64, t_packed.n_Size() - sizeof(uint32_t),
		   t_packed.p_Data() + sizeof(uint32_t))) {
			fprintf(stderr, "error: not enough memory\n");
			return -1;
		}
		// encode as base64, skip huffman unpack length, we save it otherwise
	}

	if(b_verbose) {
		printf("\tencoding " PRIsize " bytes as BASE%d\n", t_packed.n_Size(), n_base);
		if(t_packed.n_Size() >= 5) {
			printf("\tthe last 5 bytes of data to BASE%d are: 0x%02x 0x%02x 0x%02x 0x%02x 0x%02x\n",
				n_base, t_packed.p_Data()[t_packed.n_Size() - 5],
				t_packed.p_Data()[t_packed.n_Size() - 4], t_packed.p_Data()[t_packed.n_Size() - 3],
				t_packed.p_Data()[t_packed.n_Size() - 2], t_packed.p_Data()[t_packed.n_Size() - 1]);
		}
		// debugging a glitch with BASE64 decode

		if(!b_gray && p_image->b_alpha) {
			printf("\t(%d bytes, using %s for predicting Y, %s for UV and %s for A)\n",
				s_base64.length(), p_pred_name_list[n_predictor_y],
				p_pred_name_list[n_predictor_uv], p_pred_name_list[n_predictor_a]);
		} else if(!b_gray && !p_image->b_alpha) {
			printf("\t(%d bytes, using %s for predicting Y, %s for UV and there is no A)\n",
				s_base64.length(), p_pred_name_list[n_predictor_y],
				p_pred_name_list[n_predictor_uv]/*, p_pred_name_list[n_predictor_a]*/);
		} else if(b_gray && p_image->b_alpha) {
			printf("\t(%d bytes, using %s for predicting Y, there is no UV and %s for A)\n",
				s_base64.length(), p_pred_name_list[n_predictor_y],
				/*p_pred_name_list[n_predictor_uv],*/ p_pred_name_list[n_predictor_a]);
		} else if(b_gray && !p_image->b_alpha) {
			printf("\t(%d bytes, using %s for predicting Y, there is no UV and there is no A)\n",
				s_base64.length(), p_pred_name_list[n_predictor_y]/*,
				p_pred_name_list[n_predictor_uv], p_pred_name_list[n_predictor_a]*/);
		}
		printf("\tcompression ratio: %f:1\n", float(p_image->n_width *
			p_image->n_height * (((b_gray)? 1 : 3) +
			((p_image->b_alpha)? 1 : 0))) / s_base64.length());

		printf("writing image data ...\n");
	}

	{
		std::string s_ident, s_header;
		if(!stl_ut::AssignCStr(s_ident, p_s_infile) ||
		   !stl_ut::AssignCStr(s_header, p_s_infile)) {
			fprintf(stderr, "error: not enough memory\n");
			return -1;
		}
		for(size_t i = 0, n = s_ident.length(); i < n; ++ i) {
			if(isalpha(uint8_t(s_ident[i])))
				s_ident[i] = toupper(uint8_t(s_ident[i]));
			else if(!isdigit(uint8_t(s_ident[i]))) {
				s_ident[i] = '_';
				s_header[i] = '_';
			}
		}
		// create class name

		FILE *p_fw;
#if defined(_MSC_VER) && !defined(__MWERKS__) && _MSC_VER >= 1400
		if(fopen_s(&p_fw, p_s_outfile, "w")) {
#else // _MSC_VER && !__MWERKS__ && _MSC_VER >= 1400
		if(!(p_fw = fopen(p_s_outfile, "w"))) {
#endif // _MSC_VER && !__MWERKS__ && _MSC_VER >= 1400
			fprintf(stderr, "error: failed to open \'%s\' for writing\n", p_s_outfile);
			return -1;
		}

		fprintf(p_fw, "/**\n");
		fprintf(p_fw, " *\t@file %s\n", p_s_outfile);
		fprintf(p_fw, " *\t@brief image in header, generated from \'%s\'\n", p_s_infile);
		fprintf(p_fw, " *\t\t- using prediction / RLE / Huff / BASE%d pipe (loss%s)\n",
			n_base, (b_lossless_color)? "less" : "y");
		fprintf(p_fw, " *\t\t- predictors used: %s for luminance", p_pred_name_list[n_predictor_y]);
		if(!b_gray)
			fprintf(p_fw, ", %s for chrominance", p_pred_name_list[n_predictor_uv]);
		if(p_image->b_alpha)
			fprintf(p_fw, ", %s for alpha", p_pred_name_list[n_predictor_a]);
		fprintf(p_fw, "\n");
		TFileInfo::TTime t_time = TFileInfo(p_s_infile).p_time[TFileInfo::time_LastWrite];
		fprintf(p_fw, " *\t@date %4d-%02d-%02d %02d:%02d:%02d\n", t_time.n_year,
			t_time.n_month, t_time.n_day, t_time.n_hour, t_time.n_minute, t_time.n_second);
		fprintf(p_fw, " *\t@author ImageToHeader (built %s)\n", __DATE__);
		fprintf(p_fw, " */\n\n");
		fprintf(p_fw, "#pragma once\n");
		fprintf(p_fw, "#ifndef __%s_INCLUDED\n", s_ident.c_str());
		fprintf(p_fw, "#define __%s_INCLUDED\n\n", s_ident.c_str());

		fprintf(p_fw, "/**\n");
		fprintf(p_fw, " *\t@brief image in header, generated from \'%s\'\n", p_s_infile);
		fprintf(p_fw, " */\n");
		if(!p_s_classname)
			fprintf(p_fw, "class C%s {\n", s_header.c_str());
		else
			fprintf(p_fw, "class %s {\n", p_s_classname); // class name override
		fprintf(p_fw, "public:\n");
		fprintf(p_fw, "\t/**\n"
					  "\t *\t@brief gets width of the image\n"
					  "\t *\t@return Returns image width, in pixels.\n"
					  "\t */\n");
		fprintf(p_fw, "\tstatic inline int n_Width()\n\t{\n\t\treturn %d;\n\t}\n\n", p_image->n_width);
		fprintf(p_fw, "\t/**\n"
					  "\t *\t@brief gets height of the image\n"
					  "\t *\t@return Returns image height, in pixels.\n"
					  "\t */\n");
		fprintf(p_fw, "\tstatic inline int n_Height()\n\t{\n\t\treturn %d;\n\t}\n\n", p_image->n_height);
		fprintf(p_fw, "\t/**\n"
					  "\t *\t@brief determines whether the image contains alpha channel\n"
					  "\t *\t@return Returns true if the image contains alpha channel, otherwise false.\n"
					  "\t */\n");
		fprintf(p_fw, "\tstatic inline bool b_Alpha()\n\t{\n\t\treturn %s;\n\t}\n\n", (p_image->b_alpha)? "true" : "false");
		fprintf(p_fw, "\t/**\n"
					  "\t *\t@brief determines whether the image is grayscale\n"
					  "\t *\t@return Returns true if the image is grayscale, otherwise false.\n"
					  "\t */\n");
		fprintf(p_fw, "\tstatic inline bool b_Grayscale()\n\t{\n\t\treturn %s;\n\t}\n\n", (b_gray)? "true" : "false");
		fprintf(p_fw, "\t/**\n"
					  "\t *\t@brief determines whether the compression is lossless\n"
					  "\t *\t@return Returns true if the compression is lossless, otherwise false.\n"
					  "\t */\n");
		fprintf(p_fw, "\tstatic inline bool b_Lossless()\n\t{\n\t\treturn %s;\n\t}\n\n", (b_lossless_color)? "true" : "false");

		fprintf(p_fw, "\t/**\n"
					  "\t *\t@brief determines whether the BASE%d data is allocated dynamically\n"
					  "\t *\t@return Returns true if the caller needs to delete the string\n"
					  "\t *\t\treturned by p_s_Base%d_Data(), otherwise false.\n"
					  "\t */\n", n_base, n_base);
		fprintf(p_fw, "\tstatic inline bool b_Dynamic()\n\t{\n\t\treturn %s;\n\t}\n\n",
			(s_base64.length() > n_max_string_length)? "true" : "false");

		fprintf(p_fw, "\t/**\n"
					  "\t *\t@brief returns CRC32 of the stored image data\n"
					  "\t *\t@return Returns CRC32 of the stored image data (if lossy compression\n"
					  "\t *\t\tis employed, then this is different from the original image).\n"
					  "\t */\n");
		if(n_deco_image_crc32 == n_orig_image_crc32 && n_orig_image_crc32 == n_trans_image_crc32) {
			fprintf(p_fw, "\tstatic inline uint32_t n_CRC32()\n\t{\n\t\treturn 0x%08x;\n\t}\n\n",
				n_deco_image_crc32);
		} else if(n_deco_image_crc32 == n_trans_image_crc32) {
			fprintf(p_fw, "\tstatic inline uint32_t n_CRC32()\n\t{\n\t\treturn 0x%08x;"
				" // after transformations (original image 0x%08x)\n\t}\n\n",
				n_deco_image_crc32, n_orig_image_crc32);
		} else if(n_orig_image_crc32 == n_trans_image_crc32) {
			fprintf(p_fw, "\tstatic inline uint32_t n_CRC32()\n\t{\n\t\treturn 0x%08x;"
				" // after lossy compression (original image 0x%08x)\n\t}\n\n",
				n_deco_image_crc32, n_orig_image_crc32);
		} else {
			fprintf(p_fw, "\tstatic inline uint32_t n_CRC32()\n\t{\n\t\treturn 0x%08x;"
				" // after transformations and lossy compression\n\t\t// (transformed image"
				" 0x%08x, original 0x%08x)\n\t}\n\n",
				n_deco_image_crc32, n_trans_image_crc32, n_orig_image_crc32);
		}
		if(s_base64.length() <= n_max_string_length) {
			fprintf(p_fw, "\t/**\n"
						  "\t *\t@brief gets BASE%d compressed image data\n"
						  "\t *\t@return Returns BASE%d compressed image data in a null-terminated string.\n"
						  "\t */\n", n_base, n_base);
			fprintf(p_fw, "\tstatic inline const char *p_s_Base%d_Data()\n\t{\n\t\treturn ", n_base);
			int n_first_line_length = n_max_line_length - strlen("return ") + 4; // there is return, but it isn't indented
			const char *p_s_base64 = s_base64.c_str();
			for(bool b_first_line = true; *p_s_base64;) {
				fprintf(p_fw, "\t\t\t\"" + ((b_first_line)? 3 : 0));
				int n_line_len = (b_first_line)? n_first_line_length : n_max_line_length;
				if(strlen(p_s_base64) > unsigned(n_line_len)) {
					b_first_line = false;
					for(int i = 0; i < n_line_len; ++ i)
						fputc(*p_s_base64 ++, p_fw);
					fprintf(p_fw, "\"\n");
				} else {
					while(*p_s_base64)
						fputc(*p_s_base64 ++, p_fw);
					fprintf(p_fw, "\"");
				}
			}
			fprintf(p_fw, ";\n\t}\n\n");
			// a single chunk

			fprintf(p_fw, "\t/**\n"
					  "\t *\t@brief gets raw image data\n"
					  "\t *\t@return Returns pointer to raw ARGB32 image data on success, 0 on failure.\n"
					  "\t */\n");
			fprintf(p_fw, "\tstatic inline uint32_t *p_Decompress()\n\t{\n\t\treturn "
				"%s(p_s_Base%d_Data(), %d, %d, %d, %d, %d, %d, %d, %d);\n\t}\n\n",
				(b_shared_decompress)? "p_Call_Decompress" : ((b_use_base85)? "p_Decode_RLE_Huff_Base85" :
				"p_Decode_RLE_Huff_Base64"), n_base, p_image->n_width, p_image->n_height,
				n_afterhuff_size, n_predictor_y, n_predictor_uv, n_predictor_a, n_subsample,
				((b_gray)? 1 : 0) | ((p_image->b_alpha)? 2 : 0) | ((b_lossless_color)? 4 : 0));
		} else {
			fprintf(p_fw, "\t/**\n"
					  "\t *\t@brief gets BASE%d compressed image data\n"
					  "\t *\t@return Returns BASE%d compressed image data in a null-terminated string\n"
					  "\t *\t\ton success, or 0 on failure (not enough memory).\n"
					  "\t *\t@note The caller is responsible for deleting the data once no longer needed.\n"
					  "\t */\n", n_base, n_base);
			fprintf(p_fw, "\tstatic inline char *p_s_Base%d_Data()\n\t{\n\t\tstatic "
				"const char *p_data[] = {\n", n_base);
			size_t n_chunk_num = (s_base64.length() + n_max_string_length - 1) / n_max_string_length;
			std::string s_chunk;
			for(size_t i = 0; i < n_chunk_num; ++ i) {
				size_t n_off = i * n_max_string_length;
				size_t n_size = (i + 1 == n_chunk_num)?
					s_base64.length() - n_off : n_max_string_length;
				s_chunk.erase();
				s_chunk.insert(s_chunk.begin(), s_base64.begin() + n_off,
					s_base64.begin() + (n_off + n_size));
				const char *p_s_base64 = s_chunk.c_str();
				// cut the long string to smaller pieces

				while(*p_s_base64) {
					fprintf(p_fw, "\t\t\t\"");
					if(strlen(p_s_base64) > n_max_line_length) {
						for(size_t i = 0; i < n_max_line_length; ++ i, ++ p_s_base64)
							fputc(*p_s_base64, p_fw);
						fprintf(p_fw, "\"\n");
					} else {
						fprintf(p_fw, "%s\"", p_s_base64);
						break;
					}
				}
				// print the string

				if(i + 1 < n_chunk_num)
					fprintf(p_fw, ",\n");
				// there will be more strings
			}
			fprintf(p_fw, "\n\t\t};\n\n"
				"\t\tchar *p_s_data;\n"
				"\t\tif(!(p_s_data = new(std::nothrow) char[" PRIsize "]))\n"
				"\t\t\treturn 0;\n"
				"\t\tchar *p_s_dest = p_s_data;\n"
				"\t\tfor(size_t i = 0, n = sizeof(p_data) / sizeof(p_data[0]); i < n; ++ i) {\n"
				"\t\t\tsize_t n_chunk = (i + 1 < n)? " PRIsize " : " PRIsize ";\n"
				"\t\t\tmemcpy(p_s_dest, p_data[i], n_chunk * sizeof(char));\n"
				"\t\t\tp_s_dest += n_chunk;\n"
				"\t\t}\n"
				"\t\t*p_s_dest = 0;\n"
				"\t\treturn p_s_data;\n\t}\n\n", s_base64.length() + 1, n_max_string_length,
				s_base64.length() - n_max_string_length * (n_chunk_num - 1));
			// store the data as multiple strings, concatenate at runitme (requires a dynamic buffer, lazy me)

			fprintf(p_fw, "\t/**\n"
					  "\t *\t@brief gets raw image data\n"
					  "\t *\t@return Returns pointer to raw ARGB32 image data on success, 0 on failure.\n"
					  "\t */\n");
			fprintf(p_fw, "\tstatic inline uint32_t *p_Decompress()\n"
				"\t{\n"
				"\t\tchar *p_s_base%d;\n"
				"\t\tif(!(p_s_base%d = p_s_Base%d_Data()))\n"
				"\t\t\treturn 0; // not enough memory\n"
				"\t\tuint32_t *p_result = %s(p_s_base%d, %d, %d, %d, %d, %d, %d, %d, %d);\n"
				"\t\tdelete[] p_s_base%d;\n"
				"\t\treturn p_result;\n"
				"\t}\n\n", n_base, n_base, n_base, (b_shared_decompress)? "p_Call_Decompress" :
				((b_use_base85)? "p_Decode_RLE_Huff_Base85" : "p_Decode_RLE_Huff_Base64"),
				n_base, p_image->n_width, p_image->n_height, n_afterhuff_size,
				n_predictor_y, n_predictor_uv, n_predictor_a, n_subsample,
				((b_gray)? 1 : 0) | ((p_image->b_alpha)? 2 : 0) | ((b_lossless_color)? 4 : 0), n_base);
			// decompress, must delete BASE64 data
		}

		std::string s_decompress_src;
		uint32_t n_decompressor_crc;
		if(b_use_base85) {
			_ASSERTE(!CDecompress85_h::b_Dynamic()); // should be stored as a simple string
			if(!stl_ut::AssignCStr(s_decompress_src, CDecompress85_h::p_Data())) {
				fprintf(stderr, "error: not enough memory\n");
				fclose(p_fw);
				return -1;
			} else {
				size_t n_pos = 0;
				while((n_pos = s_decompress_src.find("\r\n", n_pos)) != std::string::npos)
					s_decompress_src.erase(n_pos, 1);
				// condense newlines

				n_decompressor_crc = CCrc_32::n_Crc(s_decompress_src.length() *
					sizeof(char), s_decompress_src.data());
				// calculate CRC of it
			}
		} else {
#if 1
			_ASSERTE(!CDecompress64_h::b_Dynamic()); // should be stored as a simple string
			if(!stl_ut::AssignCStr(s_decompress_src, CDecompress64_h::p_Data())) {
				fprintf(stderr, "error: not enough memory\n");
#else
			if(!ReadFile(s_decompress_src, "Decompress64.h")) {
				fprintf(stderr, "error: failed to read \'Decompress64.h\',"
					" unable to include decompress routines\n");
#endif
				fclose(p_fw);
				return -1;
			} else {
				size_t n_pos = 0;
				while((n_pos = s_decompress_src.find("\r\n", n_pos)) != std::string::npos)
					s_decompress_src.erase(n_pos, 1);
				// condense newlines

				n_decompressor_crc = CCrc_32::n_Crc(s_decompress_src.length() *
					sizeof(char), s_decompress_src.data());
				// calculate CRC of it
			}
		}

		if(b_shared_decompress) {
			fprintf(p_fw, "protected:\n");
			fprintf(p_fw, "\t/**\n"
						  "\t *\t@copydoc CITHDecompressCode_%08x::p_Decode_RLE_Huff_Base%d\n"
						  "\t */\n"
						  "\tstatic inline uint32_t *p_Call_Decompress(const char *p_s_base%d,\n"
						  "\t\tint n_image_width, int n_image_height, size_t n_huff_stage_size,\n"
						  "\t\tint n_predictor_y, int n_predictor_uv, int n_predictor_a,\n"
						  "\t\tint n_subsample, int n_color_type);\n", n_decompressor_crc, n_base, n_base);
			fprintf(p_fw, "};\n");

			fprintf(p_fw, "\n#ifndef __IMAGE_TO_HEADER_DECOMPRESS_%08X_INCLUDED\n", n_decompressor_crc);
			fprintf(p_fw, "#define __IMAGE_TO_HEADER_DECOMPRESS_%08X_INCLUDED\n\n", n_decompressor_crc);

			fprintf(p_fw, "/**\n"
						  " *\t@brief decompression routine implementation\n"
						  " *\t@note While this allows all the compressed files to share decompressor implementation,\n"
						  " *\t\tit restricts all the files to be included in a single .cpp file, otherwise linking\n"
						  " *\t\tfails because of duplicate symbols (remove body of decompress function in such case).\n"
						  " */\n"
						  "class CITHDecompressCode_%08x {\npublic:\n", n_decompressor_crc);
			fprintf(p_fw, "%s", s_decompress_src.c_str());
			// include decompress routines

			fprintf(p_fw, "};\n\n#endif // __FILE_TO_HEADER_DECOMPRESS_%08X_INCLUDED\n\n", n_decompressor_crc);

			fprintf(p_fw, "inline uint32_t *%s%s::p_Call_Decompress(const char *p_s_base%d,\n"
						  "\tint n_image_width, int n_image_height, size_t n_huff_stage_size,\n"
						  "\tint n_predictor_y, int n_predictor_uv, int n_predictor_a,\n"
						  "\tint n_subsample, int n_color_type)\n"
						  "{\n"
						  "\treturn CITHDecompressCode_%08x::p_Decode_RLE_Huff_Base%d(p_s_base%d,\n"
						  "\t\tn_image_width, n_image_height, n_huff_stage_size, n_predictor_y,\n"
						  "\t\tn_predictor_uv, n_predictor_a, n_subsample, n_color_type);\n"
						  "}\n"
						  "// a dummy function that calls the decompressor, which is now declared\n"
						  "// (allows us to keep it at the end of the file)\n",
						  (p_s_classname)? "" : "C", (p_s_classname)? p_s_classname : s_header.c_str(), // fix: use p_s_classname here as well
						  n_base, n_decompressor_crc, n_base, n_base);
			// implement the body of the dummy routine that calls the decompress after we declared it
		} else {
			std::set<int> predictors;
			predictors.insert(n_predictor_y);
			if(!b_gray)
				predictors.insert(n_predictor_uv);
			if(p_image->b_alpha)
				predictors.insert(n_predictor_a);
			// get all the predictors

			if(b_allow_code_opts) {
				fprintf(stderr, "warning: experimental code optimization enabled; check your decompress now\n");
				if(b_verbose)
					printf("\n");

				{
					/*
					int n_first_row = (n_pred_type == 1 || n_pred_type == 6)? 0 : ((n_pred_type == 5)? 2 : 1);
					int n_first_col = (n_pred_type == 0 || n_pred_type == 6)? 0 : ((n_pred_type == 5)? 2 : 1);
					*/

					bool b_need_first_row_replicate = false;
					bool b_need_first_col_replicate = false;
					for(std::set<int>::const_iterator p_pred_it = predictors.begin(),
					   p_end_it = predictors.end(); p_pred_it != p_end_it; ++ p_pred_it) {
						int n_pred_type = *p_pred_it;
						int n_first_row = (n_pred_type == 1 || n_pred_type == 6)? 0 : ((n_pred_type == 5)? 2 : 1);
						int n_first_col = (n_pred_type == 0 || n_pred_type == 6)? 0 : ((n_pred_type == 5)? 2 : 1);
						if(n_first_row)
							b_need_first_row_replicate = true;
						if(n_first_col)
							b_need_first_col_replicate = true;
					}
					// see if any of the predictors need it

					if(!b_need_first_row_replicate) {
						if(b_verbose)
							printf("\tcode opts: can ommit first row replication for the predictors\n");
						size_t n_pos = s_decompress_src.find("for(int y = 0; y < n_first_row; ++ y) {");
						_ASSERTE(n_pos != std::string::npos);
						size_t n_end = s_decompress_src.find("}", n_pos) + 1;
						s_decompress_src.erase(n_pos, n_end - n_pos);
						s_decompress_src.insert(n_pos, "_ASSERTE(!n_first_row); // code not needed, omitted");
					}
					if(!b_need_first_col_replicate) {
						if(b_verbose)
							printf("\tcode opts: can ommit first col replication for the predictors\n");
						size_t n_pos = s_decompress_src.find("for(int x = 0; x < n_first_col; ++ x) {");
						_ASSERTE(n_pos != std::string::npos);
						size_t n_end = s_decompress_src.find("}", n_pos) + 1;
						s_decompress_src.erase(n_pos, n_end - n_pos);
						s_decompress_src.insert(n_pos, "_ASSERTE(!n_first_col); // code not needed, omitted");
					}
					// edit the code
				}
				// optimization #1 - omission of the first row / col replication code

				{
					std::string s_assert = "\n\t\t_ASSERTE(";
					int n_removed_pred_num = 0;

					bool b_erasing_first_label = true;
					for(int n_pred = 0; n_pred < pred_Num; ++ n_pred) {
						if(n_pred == pred_None)
							continue; // no code associated with that one
						if(predictors.count(n_pred)) { // is this one used?
							b_erasing_first_label = false; // there is now the first label
							continue;
						}

						std::string s_pattern;
						stl_ut::Format(s_pattern, (n_removed_pred_num)? (!(n_removed_pred_num % 4))?
							" &&\n\t\t\tn_pred_type != %d" : " && n_pred_type != %d" :
							"n_pred_type != %d", n_pred);
						s_assert += s_pattern;
						++ n_removed_pred_num;

#ifdef GAP_USES_MED_FOR_LAST_COL
						if(n_pred == 4) { // 4 is unused
							if(predictors.count(5)) { // but 5 is used
								const char *p_s_pat = "if(n_pred_type == 4 || (n_pred_type == 5 && x + 1 == n_width))";
								const char *p_s_rep = "if(n_pred_type == 5 && x + 1 == n_width)";
								size_t n_pos;
								if((n_pos = s_decompress_src.find(p_s_pat)) != std::string::npos) {
									s_decompress_src.erase(n_pos, strlen(p_s_pat));
									s_decompress_src.insert(n_pos, p_s_rep);
								} else
									fprintf(stderr, "warning: couldnt find template for code opt\n");
								// t_odo - replace "if(n_pred_type == 4 || (n_pred_type == 5 && x + 1 == n_width))" by "if(n_pred_type == 5 && x + 1 == n_width)"
								continue; // if 5 is needed then the code for 4 is needed as well
							} else
								s_pattern = "if(n_pred_type == 4 || (n_pred_type == 5 && x + 1 == n_width))";
						} else if(n_pred == 5) { // 5 is unused
							if(predictors.count(4)) { // but 4 is used
								const char *p_s_pat = "if(n_pred_type == 4 || (n_pred_type == 5 && x + 1 == n_width))";
								const char *p_s_rep = "if(n_pred_type == 4)";
								size_t n_pos;
								if((n_pos = s_decompress_src.find(p_s_pat)) != std::string::npos) {
									s_decompress_src.erase(n_pos, strlen(p_s_pat));
									s_decompress_src.insert(n_pos, p_s_rep);
								} else
									fprintf(stderr, "warning: couldnt find template for code opt\n");
								// t_odo - replace "if(n_pred_type == 4 || (n_pred_type == 5 && x + 1 == n_width))" by "if(n_pred_type == 4)"
							}
							if(!stl_ut::Format(s_pattern, "if(n_pred_type == %d)", n_pred)) {
								fprintf(stderr, "error: not enough memory\n");
								return -1;
							}
						} else
#endif // GAP_USES_MED_FOR_LAST_COL
						{
							if(!stl_ut::Format(s_pattern, "if(n_pred_type == %d)", n_pred)) {
								fprintf(stderr, "error: not enough memory\n");
								return -1;
							}
						}
						if(b_verbose) {
							printf("\tcode opts: can ommit code for the %s predictor (%d)\n",
								p_pred_name_list[n_pred], n_pred);
						}
						size_t n_pos = s_decompress_src.find(s_pattern);
						if(n_pos == std::string::npos) {
							fprintf(stderr, "fatal error: can't find pattern for this predictor\n");
							return -1;
						}
						// find the starting position

						bool b_starts_with_brace = false;
						{
							size_t b = n_pos + s_pattern.length(), e = s_decompress_src.length();
							while(b != e && isspace(uint8_t(s_decompress_src[b])))
								++ b;
							if(b != e && s_decompress_src[b] == '{')
								b_starts_with_brace = true;
						}
						// see if it starts with brace

						bool b_erasing_last_label = (n_pred + 1 == pred_Num);
						// see if it is the last one

						{
							if(!b_erasing_first_label && n_pos > 4)
								n_pos = s_decompress_src.find("else", n_pos - 6);
							// start erasing with "else", will end before the next "else"

							bool b_prev_ends_with_brace = !b_erasing_first_label &&
								n_pos > 2 && s_decompress_src[n_pos - 2] == '}';
							// see if the prev one is a one-liner or if it ends with a brace

							size_t n_end;
							if(b_starts_with_brace)
								n_end = s_decompress_src.find("}", n_pos); // end brace // todo - find with counting the matching braces (not needed for the current predictors but to make it universal)
							else
								n_end = s_decompress_src.find("\n", s_decompress_src.find("\n", n_pos) + 1); // next line
							if(n_end == std::string::npos) {
								fprintf(stderr, "fatal error: can't find end-pattern for this predictor\n");
								return -1;
							}
							++ n_end; // skip the brace / newline
							// find the end of the branch

							bool b_culled_space_at_end = false;
							if(b_starts_with_brace) {
								size_t e = s_decompress_src.length();
								while(n_end != e && isspace(uint8_t(s_decompress_src[n_end]))) {
									++ n_end;
									if(s_decompress_src[n_end] != '\n') {
										if(b_erasing_last_label && b_prev_ends_with_brace)
											-- n_end; // if it is the last one and the prev one has brace, keep the newline
										break; // erase the newline but nothing more
									}
								}
								// erase whitespace after the brace, before "else"
							} else if(!b_erasing_first_label && b_prev_ends_with_brace) { // the previous one ends with brace? the next if will be on the same line
								if(!b_erasing_last_label) {
									size_t e = s_decompress_src.length();
									while(n_end != e && isspace(uint8_t(s_decompress_src[n_end])))
										++ n_end;
									b_culled_space_at_end = true;
								} else
									-- n_end; // keep the final newline
							}
							if(!b_culled_space_at_end && !b_erasing_first_label &&
							   (!b_starts_with_brace || b_erasing_last_label)) { // except for the first label; maintain the indent there
								while(n_pos && s_decompress_src[n_pos - 1] != '\n' &&
								   isspace(uint8_t(s_decompress_src[n_pos - 1])))
									-- n_pos;
								// erase whitespace on the *current* line to maintain indentation of the next line
							}
							// * in case this was a block "if() { ... }" then
							//       erase space after "}" (before else; not any newlines)
							// * in case this was a one-line "if() ..." following a braced block and
							//     not the last predictor then
							//       erase all the whitespace after it, so that the next "else" would be next to the brace
							// * in case this was a one-line "if() ..." and the above does not apply then
							//       also erase whitespace before if, to not mess with indentation of the next line

							if(b_erasing_first_label) {
								n_end = s_decompress_src.find("else", n_end);
								if(n_end == std::string::npos) {
									fprintf(stderr, "fatal error: can't find end-pattern for this predictor\n");
									return -1;
								}
								n_end += 5; // strlen("else ")
							}
							// in case it is the first label, it eats the next "else" as well
							// so that the block would start with an "if"

							s_decompress_src.erase(n_pos, n_end - n_pos);
							// erase the corresponding code

							/*FILE *p_fw;
							if((p_fw = fopen("debug.h", "w"))) {
								fprintf(p_fw, "%s", s_decompress_src.c_str());
								fclose(p_fw);
							}*/
							// debug - save intermediates
						}
					}

					if(n_removed_pred_num) {
						s_assert += "); // some code omitted"; // no newline!
						size_t n_pos = s_decompress_src.find("void UnPredict_ImagePlane");
						if(n_pos == std::string::npos) {
							fprintf(stderr, "fatal error: can't find pattern for UnPredict_ImagePlane()\n");
							return -1;
						}
						n_pos = s_decompress_src.find("{", n_pos);
						s_decompress_src.insert(n_pos + 1, s_assert);
					}
					// assert that it is none of them
				}
				// optimization #2 - omission of the unused predictors

				{
					size_t n_pos = s_decompress_src.find("\n\t\tif(!b_gray) {"); // find the global grayscale branch
					size_t n_else = s_decompress_src.find("\n\t\t} else {", n_pos); // find the matching else
					size_t n_end = s_decompress_src.find("\n\t\t}\n", n_else); // find the matching else
					if(n_pos == std::string::npos || n_else == std::string::npos || n_end == std::string::npos) {
						fprintf(stderr, "fatal error: can't find pattern for the outer color type branch\n"); // did you change indent?
						return -1;
					}
					n_pos += 3;
					n_else += 3;
					n_end += 3;
					if(b_gray) {
						if(b_verbose)
							printf("\tcode opts: can ommit code for the RGB(A) branch\n");

						s_decompress_src.insert(n_else + strlen("} else {"), (p_image->b_alpha)?
							"{\n\t\t\t_ASSERTE(b_gray && b_alpha);" : "{\n\t\t\t_ASSERTE(b_gray && !b_alpha);");
						s_decompress_src.erase(n_pos, n_else + strlen("} else {") - n_pos);
						// snip the RGB(A) branch

						n_pos = s_decompress_src.find("\n\t\t\tif(b_alpha) {", n_pos); // find the global grayscale branch
						if(n_pos > n_else) {
							fprintf(stderr, "fatal error: can't find pattern for the inner gray type branch\n"); // did you change indent?
							return -1;
						}
						n_else = s_decompress_src.find("\n\t\t\t} else {", n_pos); // find the matching else
						n_end = s_decompress_src.find("\n\t\t\t}\n", n_else); // find the matching else
						if(n_pos == std::string::npos || n_else == std::string::npos || n_end == std::string::npos) {
							fprintf(stderr, "fatal error: can't find pattern for the inner gray type branch\n"); // did you change indent?
							return -1;
						}
						n_pos += 4;
						n_else += 4;
						n_end += 4;
						if(p_image->b_alpha) {
							if(b_verbose)
								printf("\tcode opts: can ommit code for the gray-only branch\n");
							s_decompress_src.erase(n_else, n_end - n_else); // first, to not disrupt the indices
							s_decompress_src.insert(n_pos + strlen("if(b_alpha) {"), "{"/*"\n\t\t\t\t_ASSERTE(b_alpha);"*/);
							s_decompress_src.erase(n_pos, strlen("if(b_alpha) {")); // last
						} else {
							if(b_verbose)
								printf("\tcode opts: can ommit code for the gray-alpha branch\n");
							s_decompress_src.insert(n_else + strlen("} else {"), "{"/*"\n\t\t\t\t_ASSERTE(!b_alpha);"*/);
							s_decompress_src.erase(n_pos, n_else + strlen("} else {") - n_pos);
						}
						// snip the alpha branch in the grayscale code
					} else {
						if(b_verbose)
							printf("\tcode opts: can ommit code for the grayscale branch\n");

						s_decompress_src.erase(n_else, n_end - n_else); // first, to not disrupt the indices
						s_decompress_src.insert(n_pos + strlen("if(!b_gray) {"),
							(b_lossless_color)? ((p_image->b_alpha)?
							"{\n\t\t\t_ASSERTE(!b_gray && b_alpha && b_lossless_color);" :
							"{\n\t\t\t_ASSERTE(!b_gray && !b_alpha && b_lossless_color);") :
							((p_image->b_alpha)? "{\n\t\t\t_ASSERTE(!b_gray && b_alpha && !b_lossless_color);" :
							"{\n\t\t\t_ASSERTE(!b_gray && !b_alpha && !b_lossless_color);"));
						s_decompress_src.erase(n_pos, strlen("if(!b_gray) {")); // last
						// snip the grayscale branch

						if(!p_image->b_alpha) {
							if(b_verbose)
								printf("\tcode opts: can ommit code for the alpha unpredict branch\n");

							n_pos = s_decompress_src.find("\n\t\t\tif(b_alpha)\n", n_pos); // find the first alpha branch
							if(n_pos == std::string::npos) {
								fprintf(stderr, "fatal error: can't find pattern for the inner alpha unpredict branch\n"); // did you change indent?
								return -1;
							}
							n_end = s_decompress_src.find("\n", s_decompress_src.find("\n", n_pos + 1) + 1);
							s_decompress_src.erase(n_pos, n_end - n_pos);
						} else {
							if(b_verbose)
								printf("\tcode opts: can optimize code for the alpha unpredict branch\n");
							n_pos = s_decompress_src.find("\n\t\t\tif(b_alpha)\n", n_pos); // find the first alpha branch
							if(n_pos == std::string::npos) {
								fprintf(stderr, "fatal error: can't find pattern for the inner alpha unpredict branch\n"); // did you change indent?
								return -1;
							}
							s_decompress_src.erase(n_pos + 1, strlen("\n\t\t\tif(b_alpha)\n")); // hack - erase one char from the next row (decrease indent)
						}
						// snip the (whole) alpha unpredict branch (or at least its if statement) in the RGB(A) code

						n_pos = s_decompress_src.find("\n\t\t\t\t\tif(!b_lossless_color) {"); // find the global lossless branch
						n_else = s_decompress_src.find("\n\t\t\t\t\t} else {", n_pos); // find the matching else
						n_end = s_decompress_src.find("\n\t\t\t\t\t}\n", n_else); // find the matching else
						if(n_pos == std::string::npos || n_else == std::string::npos || n_end == std::string::npos) {
							fprintf(stderr, "fatal error: can't find pattern for the inner compression type branch\n"); // did you change indent?
							return -1;
						}
						n_pos += 1;
						n_else += 1;
						n_end += 8;
						if(b_lossless_color) {
							if(b_verbose)
								printf("\tcode opts: can ommit code for the lossy color branch\n");

							s_decompress_src.erase(n_end - 8, 7); // first
							s_decompress_src.erase(n_pos, n_else + strlen("\t\t\t\t\t} else {\n") - n_pos); // last
						} else {
							if(b_verbose)
								printf("\tcode opts: can ommit code for the lossless color branch\n");

							s_decompress_src.erase(n_else, n_end - n_else); // first
							s_decompress_src.erase(n_pos, strlen("\n\t\t\t\t\tif(!b_lossless_color) {")); // last
						}
						// delete the lossy/lossless branch in the RGB(A) code

						size_t n_color_rows_start = n_pos;
						// remember

						n_pos = s_decompress_src.find("\n\t\t\t\t\tif(b_alpha) {"); // find the global lossless branch
						n_else = s_decompress_src.find("\n\t\t\t\t\t} else\n", n_pos); // find the matching else
						n_end = s_decompress_src.find("\n", s_decompress_src.find("\n", n_else + 1) + 1); // find the matching else
						if(n_pos == std::string::npos || n_else == std::string::npos || n_end == std::string::npos) {
							fprintf(stderr, "fatal error: can't find pattern for the inner compression type branch\n"); // did you change indent?
							return -1;
						}
						n_pos += 1;
						n_else += 1;
						n_end += 1;
						if(!p_image->b_alpha) {
							if(b_verbose)
								printf("\tcode opts: can ommit code for the RGBA branch\n");

							//s_decompress_src.erase(n_end, 7); // first
							s_decompress_src.erase(n_pos, n_else + strlen("\t\t\t\t\t} else\n") - n_pos); // last
						} else {
							if(b_verbose)
								printf("\tcode opts: can ommit code for the RGB branch\n");

							s_decompress_src.erase(n_else, n_end - n_else); // first 
							s_decompress_src.erase(n_pos, strlen("\n\t\t\t\t\tif(b_alpha) {")); // last
						}
						// snip the alpha/no alpha branch in the RGB code

						n_pos = n_color_rows_start;
						size_t n_color_rows_end = s_decompress_src.find("\n\t\t\t\t}\n", n_pos);
						while((n_pos = s_decompress_src.find("\t\t\t\t\t\t", n_pos)) !=
						   std::string::npos && n_pos < n_color_rows_end) {
							s_decompress_src.erase(n_pos, 1);
							-- n_color_rows_end; // !!
							n_pos += 5;
						}
						// reduce indent in the loop

						n_pos = s_decompress_src.find("\n\t\t\t\t\tuint8_t r, g, b;\n", n_color_rows_start - 30);
						size_t n_red = s_decompress_src.find("\tr = ", n_pos);
						size_t n_grn = s_decompress_src.find("\tg = ", n_pos);
						size_t n_blu = s_decompress_src.find("\tb = ", n_pos);
						if(n_pos != std::string::npos && n_red != std::string::npos &&
						   n_grn != std::string::npos && n_blu != std::string::npos) {
							if(b_verbose)
								printf("\tcode opts: can ommit forward declaration for RGB\n");

							size_t p_order[] = {n_red, n_grn, n_blu};
							std::sort(p_order, p_order + 3);
							s_decompress_src.insert(p_order[2] + 1, "uint8_t ");
							s_decompress_src.insert(p_order[1] + 1, "uint8_t ");
							s_decompress_src.insert(p_order[0] + 1, "uint8_t ");
							// insert in reverse order to not disrupt indexing

							s_decompress_src.erase(n_pos + 1, strlen("\n\t\t\t\t\tuint8_t r, g, b;"/*"\n"*/));
							// erase last
						}
					}
				}
				// optimization #3 - omission of the unused color code path

				if(b_verbose)
					printf("\n");
			}

			fprintf(p_fw, "protected:\n");
			fprintf(p_fw, "%s", s_decompress_src.c_str());
			fprintf(p_fw, "};\n");
		}
		// include decompress routines


		fprintf(p_fw, "\n#endif // __%s_INCLUDED\n", s_ident.c_str());

		if(ferror(p_fw)) {
			fprintf(stderr, "error: failed to write code to \'%s\'\n", p_s_outfile);
			return -1;
		}

		fclose(p_fw);
	}
	// write C++ header file

	int n_result = 0;
	{
		uint32_t *p_raster;
		if(b_use_base85) {
			p_raster = base85_dec::p_Decode_RLE_Huff_Base85(s_base64.c_str(),
				p_image->n_width, p_image->n_height, n_afterhuff_size,
				n_predictor_y, n_predictor_uv, n_predictor_a, n_subsample,
				((b_gray)? 1 : 0) | ((p_image->b_alpha)? 2 : 0) | ((b_lossless_color)? 4 : 0));
		} else {
			p_raster = base64_dec::p_Decode_RLE_Huff_Base64(s_base64.c_str(),
				p_image->n_width, p_image->n_height, n_afterhuff_size,
				n_predictor_y, n_predictor_uv, n_predictor_a, n_subsample,
				((b_gray)? 1 : 0) | ((p_image->b_alpha)? 2 : 0) | ((b_lossless_color)? 4 : 0));
		}
		// call decoder

		const uint32_t n_real_deco_image_crc32 = CCrc_32::n_Finalize(CCrc_32::n_Crc(p_image->n_width *
			p_image->n_height * sizeof(uint32_t), p_raster, CCrc_32::n_Start()));
		if(n_deco_image_crc32 != n_real_deco_image_crc32) {
			fprintf(stderr,
				"********************************************************************************\n"
				"* fatal error: decompress output differs (expected 0x%08x, got 0x%08x) *\n"
				"********************************************************************************\n",
				n_deco_image_crc32, n_real_deco_image_crc32);
			n_result = -1;
		} else if(b_verbose)
			printf("\tdecompress CRC test passed\n");
		// see if we really get what we should

		if(!memcmp(p_image->p_buffer, p_raster,
		   p_image->n_width * p_image->n_height * sizeof(uint32_t))) {
			if(b_verbose)
				printf("\tlossless compression achieved\n");
		} else {
			size_t n_diff_num = 0, n = size_t(p_image->n_width) * p_image->n_height;
			for(size_t i = 0; i < n; ++ i) {
				if(p_image->p_buffer[i] != p_raster[i])
					++ n_diff_num;
			}
			if(b_lossless_color && n_subsample == 1 && n_chroma_bits == 8 &&
			   (!p_image->b_alpha || n_alpha_bits == 8)) {
				fprintf(stderr,
					"********************************************************************************\n"
					"*%78s*\r* fatal error: lossy compression (" PRIsize " out of " PRIsize " pixels differ)\n"
					"********************************************************************************\n",
					"", n_diff_num, n);
				n_result = -1;
			} else if(b_verbose) {
				printf("\twarning: lossy compression (" PRIsize " out of " PRIsize " pixels differ)\n",
					n_diff_num, n);
			}
		}

		uint32_t *p_buffer_orig = p_image->p_buffer;
		{
			p_image->p_buffer = p_raster;

			if(!CTgaCodec::Save_TGA("test_decompress.tga", *p_image, true)) {
				fprintf(stderr, "error: failed to save tga\n");
				return -1;
			}
			// save test image (can't easily verify lossy compression)

			delete[] p_raster;
		}
		p_image->p_buffer = p_buffer_orig;
	}
	// test inverse coding procedure

	if(b_verbose)
		printf("\ndone\n");

	delete[] p_image->p_buffer;
	delete p_image;

	return n_result;
}
